@@ -45,7 +45,7 @@ Magick::ImageRef::ImageRef ( void )
     _mutexLock()
 {
   // Allocate default image
-  _image = AllocateImage( _options->imageInfo() );
+  _image = AcquireImage( _options->imageInfo() );
 
   // Test for error and throw exception (like throwImageException())
   throwException(_image->exception);
@@ -57,7 +57,9 @@ Magick::ImageRef::~ImageRef( void )
   // Unregister image (if still registered)
   if( _id > -1 )
     {
-      DeleteMagickRegistry( _id );
+      char id[MaxTextExtent];
+      sprintf(id,"%ld",_id);
+      DeleteImageRegistry( id );
       _id=-1;
     }
 
@@ -92,6 +94,10 @@ void  Magick::ImageRef::options ( Magick::Options * options_ )
 void Magick::ImageRef::id ( const long id_ )
 {
   if( _id > -1 )
-    DeleteMagickRegistry( _id );
+    {
+      char id[MaxTextExtent];
+      sprintf(id,"%ld",_id);
+      DeleteImageRegistry( id );
+    }
   _id = id_;
 }
