@@ -466,6 +466,7 @@ namespace Magick
   using MagickLib::AcquireCacheViewPixels;
   using MagickLib::AcquireImagePixels;
   using MagickLib::AcquireMagickMemory;
+  using MagickLib::AcquireQuantumInfo;
   using MagickLib::AcquireString;
 	using MagickLib::AcquireStringInfo;
   using MagickLib::AdaptiveBlurImage;
@@ -473,7 +474,7 @@ namespace Magick
   using MagickLib::AddNoiseImage;
   using MagickLib::AffineMatrix;
   using MagickLib::AffineTransformImage;
-  using MagickLib::AllocateImage;
+  using MagickLib::AcquireImage;
   using MagickLib::AnnotateImage;
   using MagickLib::AspectValue;
   using MagickLib::Base64Decode;
@@ -495,7 +496,7 @@ namespace Magick
   using MagickLib::CloneImage;
   using MagickLib::CloneImageInfo;
   using MagickLib::CloneQuantizeInfo;
-  using MagickLib::CloseCacheView;
+  using MagickLib::DestroyCacheView;
   using MagickLib::CoderError;
   using MagickLib::CoderFatalError;
   using MagickLib::CoderWarning;
@@ -528,6 +529,7 @@ namespace Magick
   using MagickLib::DestroyMagickWand;
   using MagickLib::DestroyPixelWand;
   using MagickLib::DestroyQuantizeInfo;
+  using MagickLib::DestroyQuantumInfo;
   using MagickLib::DestroyStringInfo;
   using MagickLib::DisplayImages;
   using MagickLib::DrawAffine;
@@ -666,7 +668,6 @@ namespace Magick
   using MagickLib::GetPageGeometry;
   using MagickLib::GetPixels;
   using MagickLib::GetQuantizeInfo;
-  using MagickLib::GetQuantumInfo;
   using MagickLib::GetStringInfoDatum;
   using MagickLib::GetStringInfoLength;
   using MagickLib::GetTypeMetrics;
@@ -719,7 +720,7 @@ namespace Magick
   using MagickLib::NoiseType;
   using MagickLib::NormalizeImage;
   using MagickLib::OilPaintImage;
-  using MagickLib::OpenCacheView;
+  using MagickLib::AcquireCacheView;
   using MagickLib::OptionError;
   using MagickLib::OptionFatalError;
   using MagickLib::OptionWarning;
