@@ -85,7 +85,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -99,7 +99,10 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     y;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
+
+  QuantumType
+    quantum_type;
 
   MagickBooleanType
     status;
@@ -126,7 +129,7 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -138,15 +141,15 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ReadBlobLSBShort(image);
   image->columns=(unsigned long) ReadBlobLSBShort(image);
   (void) ReadBlobLSBShort(image);
-  image->columns=(unsigned long) ReadBlobLSBShort(image);
+  image->rows=(unsigned long) ReadBlobLSBShort(image);
   /*
     Initialize image colormap.
   */
-  if (AllocateImageColormap(image,2) == MagickFalse)
+  if (AcquireImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   if (SetImageExtent(image,0,0) == MagickFalse)
@@ -154,14 +157,13 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       InheritException(exception,&image->exception);
       return(DestroyImageList(image));
     }
-  length=(image->columns+7)/8;
-  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   /*
     Convert bi-level image to pixel packets.
   */
-  GetQuantumInfo(image_info,&quantum_info);
+  quantum_type=IndexQuantum;
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  pixels=GetQuantumPixels(quantum_info);
+  length=GetQuantumExtent(image,quantum_info,quantum_type);
   for (y=0; y < (long) image->rows; y++)
   {
     q=SetImagePixels(image,0,y,image->columns,1);
@@ -170,7 +172,7 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count=ReadBlob(image,length,pixels);
     if (count != (ssize_t) length)
       ThrowReaderException(CorruptImageError,"UnableToReadImageData");
-    status=ExportQuantumPixels(image,&quantum_info,IndexQuantum,pixels);
+    (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
     count=ReadBlob(image,(size_t) (-(ssize_t) length) & 0x01,pixels);
     if (SyncImagePixels(image) == MagickFalse)
       break;
@@ -183,11 +185,12 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
       }
   }
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+  SetQuantumImageType(image,quantum_type);
+  quantum_info=DestroyQuantumInfo(quantum_info);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -273,7 +276,7 @@ ModuleExport void UnregisterARTImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -321,7 +324,7 @@ static MagickBooleanType WriteARTImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobLSBShort(image,(unsigned short) image->columns);
   (void) WriteBlobLSBShort(image,0);
   (void) WriteBlobLSBShort(image,(unsigned short) image->rows);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   length=(image->columns+7)/8;
   pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
@@ -332,13 +335,12 @@ static MagickBooleanType WriteARTImage(const ImageInfo *image_info,Image *image)
   */
   (void) SetImageType(image,BilevelType);
   GetQuantumInfo(image_info,&quantum_info);
-  quantum_info.min_is_white=MagickFalse;
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,pixels);
+    (void) ExportQuantumPixels(image,&quantum_info,GrayQuantum,pixels);
     count=WriteBlob(image,length,pixels);
     if (count != (ssize_t) length)
       ThrowWriterException(CorruptImageError,"UnableToWriteImageData");
@@ -353,6 +355,6 @@ static MagickBooleanType WriteARTImage(const ImageInfo *image_info,Image *image)
       }
   }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
