@@ -48,6 +48,7 @@
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
+#include "magick/delegate.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/geometry.h"
@@ -61,6 +62,7 @@
 #include "magick/profile.h"
 #include "magick/property.h"
 #include "magick/quantum-private.h"
+#include "magick/resource_.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
@@ -292,7 +294,7 @@ static inline size_t MagickMin(const size_t x,const size_t y)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -771,10 +773,8 @@ static void JPEGSourceManagerBLOB(j_decompress_ptr cinfo,Image *image, unsigned
   source->source_data=0;
   source->source_length=source_length;
 }
-
-
 #endif
-
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -796,7 +796,7 @@ static void JPEGSourceManagerBLOB(j_decompress_ptr cinfo,Image *image, unsigned
 %
 %  A description of each parameter follows:
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
 %    o compression:  A value of 1 means the compressed pixels are runlength
 %      encoded for a 256-color bitmap.  A value of 2 means a 16-color bitmap.
@@ -924,11 +924,15 @@ static MagickBooleanType DecodeImage(Image *image,
             if (compression == BI_RLE8)
               {
                 if ((count & 0x01) != 0)
-                  (void) ReadBlobByte(image);
+                  if (ReadBlobByte(image) == EOF)
+                    ThrowBinaryException(CorruptImageError,
+                      "UnexpectedEndOfFile",image->filename);
               }
             else
               if (((count & 0x03) == 1) || ((count & 0x03) == 2))
-                (void) ReadBlobByte(image);
+                if (ReadBlobByte(image) == EOF)
+                  ThrowBinaryException(CorruptImageError,
+                    "UnexpectedEndOfFile",image->filename);
             break;
           }
         }
@@ -942,8 +946,12 @@ static MagickBooleanType DecodeImage(Image *image,
           break;
       }
   }
-  (void) ReadBlobByte(image);  /* end of line */
-  (void) ReadBlobByte(image);
+  if (ReadBlobByte(image) == EOF)
+    ThrowBinaryException(CorruptImageError,"UnexpectedEndOfFile",
+      image->filename);
+  if (ReadBlobByte(image) == EOF)
+    ThrowBinaryException(CorruptImageError,"UnexpectedEndOfFile",
+      image->filename);
   return(MagickTrue);
 }
 
@@ -1007,11 +1015,87 @@ static MagickBooleanType IsAVI(const unsigned char *magick,const size_t length)
 %      reading. A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
 */
+
+static Image *DecodeAVIImage(const ImageInfo *image_info,
+  ExceptionInfo *exception)
+{
+  Image
+    *image,
+    *images;
+
+  ImageInfo
+    *read_info;
+
+  MagickBooleanType
+    status;
+
+  register long
+    i;
+
+  /*
+    Open image file.
+  */
+  assert(image_info != (const ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  if (image_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  image=AcquireImage(image_info);
+  status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
+  if (status == MagickFalse)
+    {
+      image=DestroyImageList(image);
+      return((Image *) NULL);
+    }
+  (void) CloseBlob(image);
+  (void) DestroyImageList(image);
+  /*
+    Convert AVI to PPM with delegate.
+  */
+  image=AcquireImage(image_info);
+  read_info=CloneImageInfo(image_info);
+  (void) InvokeDelegate(read_info,image,"avi:decode",(char *) NULL,exception);
+  image=DestroyImage(image);
+  /*
+    Read PNG files.
+  */
+  images=NewImageList();
+  for (i=1; ; i++)
+  {
+    (void) FormatMagickString(read_info->filename,MaxTextExtent,"%08ld.png",i);
+    if (IsAccessible(read_info->filename) == MagickFalse)
+      break;
+    image=ReadImage(read_info,exception);
+    if (image == (Image *) NULL)
+      break;
+    (void) CopyMagickString(image->magick,image_info->magick,MaxTextExtent);
+    image->scene=(unsigned long) i;
+    AppendImageToList(&images,image);
+    if (read_info->number_scenes != 0)
+      if (i >= (long) (read_info->scene+read_info->number_scenes-1))
+        break;
+  }
+  /*
+    Relinquish resources.
+  */
+  for (i=1; ; i++)
+  {
+    (void) FormatMagickString(read_info->filename,MaxTextExtent,"%08ld.png",i);
+    if (IsAccessible(read_info->filename) == MagickFalse)
+      break;
+    (void) RelinquishUniqueFileResource(read_info->filename);
+  }
+  read_info=DestroyImageInfo(read_info);
+  return(images);
+}
+
 static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   AVIInfo
@@ -1024,8 +1108,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     bmp_info;
 
   char
-    id[MaxTextExtent],
-    message[MaxTextExtent];
+    id[MaxTextExtent];
 
   Image
     *image;
@@ -1037,6 +1120,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     y;
 
   MagickBooleanType
+    riff_chunk,
     status;
 
   MagickOffsetType
@@ -1109,7 +1193,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -1145,18 +1229,20 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   jpeg_info.client_data=(void *) &error_manager;
   jpeg_create_decompress(&jpeg_info);
-
   JPEGSourceManagerMemory(&jpeg_info, (unsigned char *) &MJPGDHTSeg, 0x1A8);
   jpeg_read_header(&jpeg_info, FALSE);
 #endif
-
-  for ( ; ; )
+  for (riff_chunk=MagickTrue; ; riff_chunk=MagickFalse)
   {
     count=ReadBlob(image,4,(unsigned char *) id);
     if (count != 4)
       break;
     id[4]='\0';
+    if ((riff_chunk == MagickTrue) && (memcmp(id,"RIFF",4) != 0))
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     chunk_size=ReadBlobLSBLong(image);
+    if (EOFBlob(image) != MagickFalse)
+      ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
     if (chunk_size == 0)
       break;
     if ((chunk_size & 0x01) != 0)
@@ -1273,7 +1359,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               jpeg_info.quantize_colors=MagickTrue;
               jpeg_info.desired_number_of_colors=(int) image_info->colors;
-              if (AllocateImageColormap(image,image_info->colors) == MagickFalse)
+              if (AcquireImageColormap(image,image_info->colors) == MagickFalse)
                 ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
             }
             (void) jpeg_start_decompress(&jpeg_info);
@@ -1283,7 +1369,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if ((jpeg_info.output_components == 1) &&
               (jpeg_info.quantize_colors == MagickFalse))
             {
-              if (AllocateImageColormap(image,1UL << image->depth) == MagickFalse)
+              if (AcquireImageColormap(image,1UL << image->depth) == MagickFalse)
                 ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
             }
             if (image->debug != MagickFalse)
@@ -1493,7 +1579,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (image_info->ping != MagickFalse)
               {
                 jpeg_destroy_decompress(&jpeg_info);
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(GetFirstImageInList(image));
               }
             if (SetImageExtent(image,0,0) == MagickFalse)
@@ -1613,25 +1699,22 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Consume Buffer.
             */
-            chunk_size = (unsigned long) ((SourceManager *) jpeg_info.src)->source_length;
+            chunk_size=(unsigned long) ((SourceManager *)
+              jpeg_info.src)->source_length;
             for ( ; chunk_size != 0; chunk_size--)
-              (void) ReadBlobByte(image);
+              if (ReadBlobByte(image) == EOF)
+                ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
             /*
               Free jpeg resources.
             */
             (void) jpeg_finish_decompress(&jpeg_info);
             jpeg_pixels=(unsigned char *) RelinquishMagickMemory(jpeg_pixels);
 #else
-            (void) FormatMagickString(message,MaxTextExtent,
-              "AVI compression %s not yet supported",bmp_info.compression);
-            (void) ThrowMagickException(exception,GetMagickModule(),
-              CorruptImageWarning,message,"`%s'",image->filename);
-            for ( ; chunk_size != 0; chunk_size--)
-              (void) ReadBlobByte(image);
-            continue;
+            (void) CloseBlob(image);
+            DestroyImageList(image);
+            return(DecodeAVIImage(image_info,exception));
 #endif
           }
-
         /*
           Read BMP image
         */
@@ -1651,8 +1734,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image->units=PixelsPerCentimeterResolution;
           image->x_resolution=(double) bmp_info.x_pixels/100.0;
           image->y_resolution=(double) bmp_info.y_pixels/100.0;
-          status=AllocateImageColormap(image,number_colors != 0 ?
-            number_colors : 256);
+          status=AcquireImageColormap(image,number_colors != 0 ? number_colors :
+            256);
           if (status == MagickFalse)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           if (number_colors != 0)
@@ -1837,8 +1920,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 {
                   word=(unsigned long) (*p++);
                   word|=(*p++ << 8);
-                  q->red=ScaleCharToQuantum(ScaleColor5to8((word >> 11) & 0x1f));
-                  q->green=ScaleCharToQuantum(ScaleColor6to8((word >> 5) & 0x3f));
+                  q->red=ScaleCharToQuantum(ScaleColor5to8((word >> 11) &
+                    0x1f));
+                  q->green=ScaleCharToQuantum(ScaleColor6to8((word >> 5) &
+                    0x3f));
                   q->blue=ScaleCharToQuantum(ScaleColor5to8(word & 0x1f));
                   q++;
                 }
@@ -1909,7 +1994,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Allocate next image structure.
             */
-            AllocateNextImage(image_info,image);
+            AcquireNextImage(image_info,image);
             if (GetNextImageInList(image) == (Image *) NULL)
               {
                 image=DestroyImageList(image);
@@ -1952,13 +2037,15 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (LocaleCompare(id,"idx1") == 0)
       {
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (LocaleCompare(id,"JUNK") == 0)
       {
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (LocaleCompare(id,"LIST") == 0)
@@ -2021,19 +2108,23 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     ReadBlobByte(image));
                   colormap[i].red=ScaleCharToQuantum((unsigned char)
                     ReadBlobByte(image));
-                  (void) ReadBlobByte(image);
+                  if (ReadBlobByte(image) == EOF)
+                    ThrowReaderException(CorruptImageError,
+                      "UnexpectedEndOfFile");
                   chunk_size-=4;
                 }
               }
             for ( ; chunk_size != 0; chunk_size--)
-              (void) ReadBlobByte(image);
+              if (ReadBlobByte(image) == EOF)
+                ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
             if (image_info->verbose != MagickFalse)
               (void) fprintf(stdout,"Video compression: %s\n",
                 bmp_info.compression);
             continue;
           }
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (LocaleCompare(id,"strh") == 0)
@@ -2057,7 +2148,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if ((chunk_size & 0x01) != 0)
           chunk_size++;
         for (chunk_size-=48; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         if (image_info->verbose != MagickFalse)
           (void) fprintf(stdout,"AVI Test handler: %s\n",
             stream_info.data_handler);
@@ -2066,13 +2158,15 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (LocaleCompare(id,"strn") == 0)
       {
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (LocaleCompare(id,"vedt") == 0)
       {
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (strlen(id) == 4 && LocaleCompare(id + 2,"wb") == 0)
@@ -2081,7 +2175,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Skip audio chunks (##wb).
         */
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (LocaleCompare(id,"ISFT") == 0)
@@ -2090,7 +2185,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Skip Info Chunks.
         */
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
     if (LocaleCompare(id,"IDIT") == 0)
@@ -2099,18 +2195,15 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Skip Timecode Information (TODO: seeking).
         */
         for ( ; chunk_size != 0; chunk_size--)
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
         continue;
       }
-    (void) FormatMagickString(message,MaxTextExtent,
-      "AVI chunk %s not yet supported",id);
-    (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageWarning,
-      message,"`%s'",image->filename);
-    for ( ; chunk_size != 0; chunk_size--)
-      (void) ReadBlobByte(image);
-    continue;
+    (void) CloseBlob(image);
+    DestroyImageList(image);
+    return(DecodeAVIImage(image_info,exception));
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   if ((image->columns == 0) || (image->rows == 0))
     {
       image=DestroyImageList(image);
