@@ -17,7 +17,7 @@
 %                               February 2002                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,9 +53,10 @@
 #include "magick/memory_.h"
 #include "magick/option.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -79,7 +80,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -89,7 +90,8 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
 {
   char
     *caption,
-    geometry[MaxTextExtent];
+    geometry[MaxTextExtent],
+    *property;
 
   const char
     *gravity;
@@ -123,14 +125,16 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if (image->columns == 0)
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
+  (void) ResetImagePage(image,"0x0+0+0");
   /*
     Format caption.
   */
-  (void) SetImageProperty(image,"caption",InterpretImageProperties(image_info,
-    image,image_info->filename));
+  property=InterpretImageProperties(image_info,image,image_info->filename);
+  (void) SetImageProperty(image,"caption",property);
+  property=DestroyString(property);
   caption=ConstantString(GetImageProperty(image,"caption"));
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
   draw_info->text=ConstantString(caption);
@@ -138,7 +142,8 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   if (gravity != (char *) NULL)
     draw_info->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
       MagickFalse,gravity);
-  if ((image->rows != 0) && (image_info->pointsize == 0.0))
+  if ((*caption != '\0') && (image->rows != 0) &&
+      (image_info->pointsize == 0.0))
     {
       char
         *text;
@@ -155,7 +160,7 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
         (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
           -metrics.bounds.x1,metrics.ascent);
         if (draw_info->gravity == UndefinedGravity)
-          (void) CloneString(&draw_info->geometry,AcquireString(geometry));
+          (void) CloneString(&draw_info->geometry,geometry);
         status=GetMultilineTypeMetrics(image,draw_info,&metrics);
         width=(unsigned long) (metrics.width+draw_info->stroke_width+0.5);
         height=(unsigned long) (metrics.height+draw_info->stroke_width+0.5);
@@ -173,7 +178,7 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
         (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
           -metrics.bounds.x1,metrics.ascent);
         if (draw_info->gravity == UndefinedGravity)
-          (void) CloneString(&draw_info->geometry,AcquireString(geometry));
+          (void) CloneString(&draw_info->geometry,geometry);
         status=GetMultilineTypeMetrics(image,draw_info,&metrics);
         width=(unsigned long) (metrics.width+draw_info->stroke_width+0.5);
         height=(unsigned long) (metrics.height+draw_info->stroke_width+0.5);
@@ -194,13 +199,13 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   /*
     Draw caption.
   */
-  (void) CloneString(&draw_info->text,AcquireString(caption));
+  (void) CloneString(&draw_info->text,caption);
   status=GetMultilineTypeMetrics(image,draw_info,&metrics);
   (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
     -metrics.bounds.x1+draw_info->stroke_width/2.0,metrics.ascent+
     draw_info->stroke_width/2.0);
   if (draw_info->gravity == UndefinedGravity)
-    (void) CloneString(&draw_info->geometry,AcquireString(geometry));
+    (void) CloneString(&draw_info->geometry,geometry);
   (void) AnnotateImage(image,draw_info);
   draw_info=DestroyDrawInfo(draw_info);
   caption=DestroyString(caption);
@@ -227,20 +232,21 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterCAPTIONImage method is:
 %
-%      RegisterCAPTIONImage(void)
+%      unsigned long RegisterCAPTIONImage(void)
 %
 */
-ModuleExport void RegisterCAPTIONImage(void)
+ModuleExport unsigned long RegisterCAPTIONImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CAPTION");
-  entry->decoder=(DecoderHandler *) ReadCAPTIONImage;
+  entry->decoder=(DecodeImageHandler *) ReadCAPTIONImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Image caption");
   entry->module=ConstantString("CAPTION");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
