@@ -283,7 +283,7 @@ static MagickBooleanType IsCIN(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -397,7 +397,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     offset;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -430,7 +430,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -691,15 +691,15 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   image->rows=cin.image.channel[0].lines_per_image;
   if (image_info->ping)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(image);
     }
   /*
     Convert CIN raster image to pixel packets.
   */
-  GetQuantumInfo(image_info,&quantum_info);
-  quantum_info.quantum=32;
-  quantum_info.pack=MagickFalse;
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  quantum_info->quantum=32;
+  quantum_info->pack=MagickFalse;
   quantum_type=RGBQuantum;
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
   if (cin.image.number_channels == 1)
@@ -712,9 +712,8 @@ static Image *ReadCINImage(const ImageInfo *image_info,
       InheritException(exception,&image->exception);
       return(DestroyImageList(image));
     }
-  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+  pixels=GetQuantumPixels(quantum_info);
+  length=GetQuantumExtent(image,quantum_info,quantum_type);
   for (y=0; y < (long) image->rows; y++)
   {
     q=SetImagePixels(image,0,y,image->columns,1);
@@ -723,9 +722,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     count=ReadBlob(image,length,pixels);
     if ((size_t) count != length)
       break;
-    status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
-    if (status == MagickFalse)
-      break;
+    (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
     if (SyncImagePixels(image) == MagickFalse)
       break;
     if (image->previous == (Image *) NULL)
@@ -738,12 +735,13 @@ static Image *ReadCINImage(const ImageInfo *image_info,
             break;
         }
   }
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+  SetQuantumImageType(image,quantum_type);
+  quantum_info=DestroyQuantumInfo(quantum_info);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   image->colorspace=LogColorspace;
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -827,7 +825,7 @@ ModuleExport void UnregisterCINImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -866,7 +864,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     offset;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -901,7 +899,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace != LogColorspace)
+  if (image->colorspace != LogColorspace)
     (void) SetImageColorspace(image,LogColorspace);
   /*
     Write image information.
@@ -976,7 +974,8 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     offset+=WriteBlobFloat(image,cin.image.channel[0].min_data);
     cin.image.channel[i].min_quantity=0.0;
     offset+=WriteBlobFloat(image,cin.image.channel[0].min_quantity);
-    cin.image.channel[i].max_data=(float) ((1UL << image->depth)-1UL);
+    cin.image.channel[i].max_data=(float) ((MagickOffsetType)
+      GetQuantumRange(image->depth));
     offset+=WriteBlobFloat(image,cin.image.channel[0].max_data);
     cin.image.channel[i].max_quantity=2.048f;
     offset+=WriteBlobFloat(image,cin.image.channel[0].max_quantity);
@@ -1141,32 +1140,28 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   /*
     Convert pixel packets to CIN raster image.
   */
-  GetQuantumInfo(image_info,&quantum_info);
-  quantum_info.quantum=32;
-  quantum_info.pack=MagickFalse;
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  quantum_info->quantum=32;
+  quantum_info->pack=MagickFalse;
   quantum_type=RGBQuantum;
+  pixels=GetQuantumPixels(quantum_info);
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
   if (0)
     {
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    status=ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
-    if (status == MagickFalse)
-      break;
+    (void) ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
     count=WriteBlob(image,length,pixels);
     if (count != (ssize_t) length)
       break;
   }
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  CloseBlob(image);
+  quantum_info=DestroyQuantumInfo(quantum_info);
+  (void) CloseBlob(image);
   return(status);
 }
