@@ -16,7 +16,7 @@
 %                                April 2004                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,9 +54,10 @@
 #include "magick/monitor.h"
 #include "magick/property.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -85,20 +86,21 @@ static MagickBooleanType
 %
 %  The format of the RegisterCIPImage method is:
 %
-%      RegisterCIPImage(void)
+%      unsigned long RegisterCIPImage(void)
 %
 */
-ModuleExport void RegisterCIPImage(void)
+ModuleExport unsigned long RegisterCIPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CIP");
-  entry->encoder=(EncoderHandler *) WriteCIPImage;
+  entry->encoder=(EncodeImageHandler *) WriteCIPImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Cisco IP phone image format");
   entry->module=ConstantString("CIP");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -145,7 +147,7 @@ ModuleExport void UnregisterCIPImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -195,7 +197,7 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   if (status == MagickFalse)
     return(status);
   (void) WriteBlobString(image,"<CiscoIPPhoneImage>\n");
-  value=GetImageProperty(image,"Label");
+  value=GetImageProperty(image,"label");
   if (value != (const char *) NULL)
     (void) FormatMagickString(buffer,MaxTextExtent,"<Title>%s</Title>\n",value);
   else
@@ -223,7 +225,7 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   (void) FormatMagickString(buffer,MaxTextExtent,"<Depth>2</Depth>\n");
   (void) WriteBlobString(image,buffer);
   (void) WriteBlobString(image,"<Data>");
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -263,6 +265,6 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   }
   (void) WriteBlobString(image,"</Data>\n");
   (void) WriteBlobString(image,"</CiscoIPPhoneImage>\n");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
