@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -48,9 +48,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -78,19 +79,20 @@ static MagickBooleanType
 %
 %  The format of the RegisterCLIPImage method is:
 %
-%      RegisterCLIPImage(void)
+%      unsigned long RegisterCLIPImage(void)
 %
 */
-ModuleExport void RegisterCLIPImage(void)
+ModuleExport unsigned long RegisterCLIPImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CLIP");
-  entry->encoder=(EncoderHandler *) WriteCLIPImage;
+  entry->encoder=(EncodeImageHandler *) WriteCLIPImage;
   entry->description=ConstantString("Image Clip Mask");
   entry->module=ConstantString("CLIP");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -138,7 +140,7 @@ ModuleExport void UnregisterCLIPImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
