@@ -12,7 +12,7 @@
 %                                 May 2002                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -35,7 +35,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#if defined(HasWINGDI32)
+#if defined(MAGICKCORE_WINGDI32_DELEGATE)
 #  if defined(__CYGWIN__)
 #    include <windows.h>
 #  else
@@ -53,14 +53,15 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/nt-feature.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
 */
-#if defined(HasWINGDI32)
+#if defined(MAGICKCORE_WINGDI32_DELEGATE)
 static MagickBooleanType
   WriteCLIPBOARDImage(const ImageInfo *,Image *);
 #endif
@@ -87,12 +88,12 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
 */
-#if defined(HasWINGDI32)
+#if defined(MAGICKCORE_WINGDI32_DELEGATE)
 static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
@@ -115,7 +116,7 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   {
     HBITMAP
       bitmapH;
@@ -124,8 +125,8 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
       hPal;
 
     OpenClipboard(NULL);
-    bitmapH=GetClipboardData(CF_BITMAP);
-    hPal = GetClipboardData(CF_PALETTE);
+    bitmapH=(HBITMAP) GetClipboardData(CF_BITMAP);
+    hPal=(HPALETTE) GetClipboardData(CF_PALETTE);
     CloseClipboard();
     if ( bitmapH == NULL )
       ThrowReaderException(CoderError,"NoBitmapOnClipboard");
@@ -150,7 +151,7 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
 
       /* create an offscreen DC for the source */
       hMemDC=CreateCompatibleDC(NULL);
-      hOldBitmap=SelectObject(hMemDC,bitmapH);
+      hOldBitmap=(HBITMAP) SelectObject(hMemDC,bitmapH);
       GetObject(bitmapH,sizeof(BITMAP),(LPSTR) &bitmap);
       if ((image->columns == 0) || (image->rows == 0))
         {
@@ -220,10 +221,10 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
       DeleteObject(hBitmap);
     }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
-#endif /* HasWINGDI32 */
+#endif /* MAGICKCORE_WINGDI32_DELEGATE */
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -245,23 +246,24 @@ static Image *ReadCLIPBOARDImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterCLIPBOARDImage method is:
 %
-%      RegisterCLIPBOARDImage(void)
+%      unsigned long RegisterCLIPBOARDImage(void)
 %
 */
-ModuleExport void RegisterCLIPBOARDImage(void)
+ModuleExport unsigned long RegisterCLIPBOARDImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CLIPBOARD");
-#if defined(HasWINGDI32)
-  entry->decoder=(DecoderHandler *) ReadCLIPBOARDImage;
-  entry->encoder=(EncoderHandler *) WriteCLIPBOARDImage;
+#if defined(MAGICKCORE_WINGDI32_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadCLIPBOARDImage;
+  entry->encoder=(EncodeImageHandler *) WriteCLIPBOARDImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("The system clipboard");
   entry->module=ConstantString("CLIPBOARD");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -308,12 +310,12 @@ ModuleExport void UnregisterCLIPBOARDImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
 */
-#if defined(HasWINGDI32)
+#if defined(MAGICKCORE_WINGDI32_DELEGATE)
 static MagickBooleanType WriteCLIPBOARDImage(const ImageInfo *image_info,
   Image *image)
 {
@@ -332,11 +334,11 @@ static MagickBooleanType WriteCLIPBOARDImage(const ImageInfo *image_info,
 
     OpenClipboard( NULL );
     EmptyClipboard();
-    bitmapH=ImageToHBITMAP(image);
+    bitmapH=(HBITMAP) ImageToHBITMAP(image);
     SetClipboardData(CF_BITMAP,bitmapH);
     CloseClipboard();
   }
   return(MagickTrue);
 }
-#endif /* HasWINGDI32 */
+#endif /* MAGICKCORE_WINGDI32_DELEGATE */
 
