@@ -59,9 +59,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 typedef struct
@@ -295,7 +296,7 @@ static int GetCutColors(Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -332,7 +333,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -382,7 +383,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->columns=Header.Width;
   image->rows=Header.Height;
   image->depth=8;
-  image->colors=1UL << (unsigned long) i;
+  image->colors=(unsigned long) (GetQuantumRange(1UL*i)+1);
 
   if (image_info->ping) goto Finish;
   if (SetImageExtent(image,0,0) == MagickFalse)
@@ -429,7 +430,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
     }
 
-  if( (palette=AllocateImage(clone_info))==NULL ) goto NoPalette;
+  if( (palette=AcquireImage(clone_info))==NULL ) goto NoPalette;
   status=OpenBlob(clone_info,palette,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -458,7 +459,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
       if(PalHeader.MaxIndex<1) goto ErasePalette;
       image->colors=PalHeader.MaxIndex+1;
-      if (AllocateImageColormap(image,image->colors) == MagickFalse) goto NoMemory;
+      if (AcquireImageColormap(image,image->colors) == MagickFalse) goto NoMemory;
 
       if(PalHeader.MaxRed==0) PalHeader.MaxRed=(unsigned int) QuantumRange;  /*avoid division by 0*/
       if(PalHeader.MaxGreen==0) PalHeader.MaxGreen=(unsigned int) QuantumRange;
@@ -504,7 +505,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     {
 
       image->colors=256;
-      if (AllocateImageColormap(image,image->colors) == MagickFalse)
+      if (AcquireImageColormap(image,image->colors) == MagickFalse)
         {
         NoMemory:
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -588,7 +589,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   if(image->colormap[i].blue!=sample) goto Finish;
                 }
 
-              image->colormap[1].red=image->colormap[1].green=image->colormap[1].blue=QuantumRange;
+              image->colormap[1].red=image->colormap[1].green=image->colormap[1].blue=(Quantum) QuantumRange;
               for (i=0; i < (long)image->rows; i++)
                 {
                   q=SetImagePixels(image,0,i,image->columns,1);
@@ -596,7 +597,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     {
                       if(q->red==ScaleCharToQuantum(1))
                         {
-                          q->red=q->green=q->blue=QuantumRange;
+                          q->red=q->green=q->blue=(Quantum) QuantumRange;
                         }
                       q++;
                     }
@@ -616,7 +617,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -640,20 +641,21 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterCUTImage method is:
 %
-%      RegisterCUTImage(void)
+%      unsigned long RegisterCUTImage(void)
 %
 */
-ModuleExport void RegisterCUTImage(void)
+ModuleExport unsigned long RegisterCUTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("CUT");
-  entry->decoder=(DecoderHandler *) ReadCUTImage;
+  entry->decoder=(DecodeImageHandler *) ReadCUTImage;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("DR Halo");
   entry->module=ConstantString("CUT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
