@@ -117,7 +117,7 @@ static MagickBooleanType IsDJVU(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -230,7 +230,7 @@ process_message(ddjvu_message_t *message)
    case DDJVU_DOCINFO:
    {
       ddjvu_document_t* document= message->m_any.document;
-      // ddjvu_document_decoding_status  is set by libdjvu!
+      /* ddjvu_document_decoding_status  is set by libdjvu! */
       /* we have some info on the document  */
       LoadContext *lc = ddjvu_document_get_user_data(document);
       lc->pages = ddjvu_document_get_pagenum(document);
@@ -419,7 +419,7 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
 #endif 
                                r = SetImagePixels(lc->image,0,i,lc->image->columns,1);
 
-                                ExportQuantumPixels(lc->image,
+                                ImportQuantumPixels(lc->image,
                                                     quantum_info,
                                                     RGBQuantum, /*GrayQuantum*/
                                                     q+i*stride);
@@ -512,7 +512,7 @@ get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
                                     pagerect.w * 3, /* ?? */
                                     (char*)q);
 
-        ExportQuantumPixels(lc->image,
+        ImportQuantumPixels(lc->image,
                             quantum_info,
 #if RGB
                             RGBQuantum
@@ -550,7 +550,7 @@ p%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %    o mng_info: Specifies a pointer to a MngInfo structure.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -565,7 +565,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
         int logging;
         /* register PixelPacket *q; */
         
-        QuantumInfo quantum_info;
+        QuantumInfo *quantum_info;
 
         ddjvu_message_t *message;
         logging=LogMagickEvent(CoderEvent,GetMagickModule(), "  enter ReadOneDJVUImage()");
@@ -616,7 +616,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                 image->storage_class = PseudoClass;
                 image->depth =  8UL;    /* i only support that? */
                 image->colors= 2;
-                if (AllocateImageColormap(image,image->colors) == MagickFalse)
+                if (AcquireImageColormap(image,image->colors) == MagickFalse)
                   ThrowReaderException(ResourceLimitError,
                    "MemoryAllocationFailed");
         } else {
@@ -634,10 +634,10 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
 
 #if 1                           /* per_line */
-        GetQuantumInfo(image_info,&quantum_info);
+        quantum_info=AcquireQuantumInfo(image_info,image);
         
         /* q = SetImagePixels(image,0,0,image->columns,image->rows); */
-        get_page_image(lc, lc->page, 0, 0, info.width, info.height, &quantum_info);
+        get_page_image(lc, lc->page, 0, 0, info.width, info.height, quantum_info);
 #else                                        
         int i;
         for (i = 0;i< image->rows; i++)
@@ -649,7 +649,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                         SyncImagePixels(image);
 #else
                         q = SetImagePixels(image,0,i,image->columns,1);
-                        get_page_line_new(lc, i, &quantum_info);
+                        get_page_line_new(lc, i, quantum_info);
                         SyncImagePixels(image);
 #endif
                 }
@@ -662,6 +662,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 #endif 
 
         SyncImage(image);
+        quantum_info=DestroyQuantumInfo(quantum_info);
         /* indexes=GetIndexes(image); */
         /* mmc: ??? Convert PNM pixels to runlength-encoded MIFF packets. */
         /* image->colors =  */
@@ -682,7 +683,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
 #if 0
 /* palette */
-  if (AllocateImageColormap(image,2) == MagickFalse)
+  if (AcquireImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   /*
     Monochrome colormap.   mmc: this is the default!
@@ -734,7 +735,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
 
   logging = LogMagickEvent(CoderEvent,GetMagickModule(),"enter ReadDJVUImage()");
 
-  image = AllocateImage(image_info); /* mmc: ?? */
+  image = AcquireImage(image_info); /* mmc: ?? */
   
 
   lc = (LoadContext *) NULL;
@@ -821,7 +822,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
   
 
   djvu_close_lc(lc);
-  CloseBlob(image);
+  (void) CloseBlob(image);
 
 #if 0  
   if ((image->page.width == 0) && (image->page.height == 0))
