@@ -17,7 +17,7 @@
 %                                March 2001                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -55,10 +55,11 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
-#include "magick/version.h"
+#include "magick/module.h"
+#include "magick/module.h"
 
 /*
   Typedef declaration.
@@ -362,7 +363,7 @@ static MagickBooleanType IsDPX(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -556,7 +557,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     offset;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -590,7 +591,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -1003,7 +1004,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   /*
@@ -1014,9 +1015,9 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       InheritException(exception,&image->exception);
       return(DestroyImageList(image));
     }
-  GetQuantumInfo(image_info,&quantum_info);
-  quantum_info.quantum=32;
-  quantum_info.pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  quantum_info->quantum=32;
+  quantum_info->pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
     MagickFalse;
   samples_per_pixel=1;
   quantum_type=GrayQuantum;
@@ -1053,6 +1054,11 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image->colorspace=Rec709YCbCrColorspace;
       break;
     }
+    case LumaComponentType:
+    {
+      image->colorspace=RGBColorspace;
+      break;
+    }
     default:
     {
       image->colorspace=RGBColorspace;
@@ -1061,14 +1067,17 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
     }
   }
+  if (image->colorspace != UndefinedColorspace)
+    image->colorspace=image->colorspace;
   length=GetBytesPerRow(image->columns,samples_per_pixel,image->depth,
     dpx.image.image_element[0].packing == 0 ? MagickFalse : MagickTrue);
-  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  if ((quantum_type == GrayQuantum) && (quantum_info.pack == MagickFalse) &&
+  pixels=GetQuantumPixels(quantum_info);
+  if ((quantum_type == GrayQuantum) && (quantum_info->pack == MagickFalse) &&
       (image->depth == 10) && (image->endian == MSBEndian))
     {
+      QuantumAny
+        scale;
+
       register long
         x;
 
@@ -1077,6 +1086,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
       pixel=0UL;
       i=0;
+      scale=GetQuantumScale(image->depth);
       for (y=0; y < (long) image->rows; y++)
       {
         q=SetImagePixels(image,0,y,image->columns,1);
@@ -1089,17 +1099,19 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             case 0:
             {
               pixel=ReadBlobMSBLong(image);
-              q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,image->depth);
+              q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,image->depth,scale);
               break;
             }
             case 1:
             {
-              q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,image->depth);
+              q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,image->depth,
+                scale);
               break;
             }
             case 2:
             {
-              q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,image->depth);
+              q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,image->depth,
+                scale);
               break;
             }
           }
@@ -1132,9 +1144,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       count=ReadBlob(image,length,pixels);
       if ((size_t) count != length)
         break;
-      status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
-      if (status == MagickFalse)
-        break;
+      (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
       if (SyncImagePixels(image) == MagickFalse)
         break;
       if (image->previous == (Image *) NULL)
@@ -1147,11 +1157,12 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
     }
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+  SetQuantumImageType(image,quantum_type);
+  quantum_info=DestroyQuantumInfo(quantum_info);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -1175,10 +1186,10 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterDPXImage method is:
 %
-%      RegisterDPXImage(void)
+%      unsigned long RegisterDPXImage(void)
 %
 */
-ModuleExport void RegisterDPXImage(void)
+ModuleExport unsigned long RegisterDPXImage(void)
 {
   MagickInfo
     *entry;
@@ -1191,13 +1202,14 @@ ModuleExport void RegisterDPXImage(void)
     };
 
   entry=SetMagickInfo("DPX");
-  entry->decoder=(DecoderHandler *) ReadDPXImage;
-  entry->encoder=(EncoderHandler *) WriteDPXImage;
-  entry->magick=(MagickHandler *) IsDPX;
+  entry->decoder=(DecodeImageHandler *) ReadDPXImage;
+  entry->encoder=(EncodeImageHandler *) WriteDPXImage;
+  entry->magick=(IsImageFormatHandler *) IsDPX;
   entry->description=ConstantString("SMPTE 268M-2003 (DPX 2.0)");
   entry->note=ConstantString(DPXNote);
   entry->module=ConstantString("DPX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1243,7 +1255,7 @@ ModuleExport void UnregisterDPXImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -1317,7 +1329,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     geometry_info;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -1585,7 +1597,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   *dpx.film.prefix='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.prefix");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.offset,value,sizeof(dpx.film.prefix));
+    (void) CopyMagickString(dpx.film.prefix,value,sizeof(dpx.film.prefix));
   offset+=WriteBlob(image,sizeof(dpx.film.prefix),(unsigned char *)
     dpx.film.prefix);
   *dpx.film.count='\0';
@@ -1735,9 +1747,9 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   /*
     Convert pixel packets to DPX raster image.
   */
-  GetQuantumInfo(image_info,&quantum_info);
-  quantum_info.quantum=32;
-  quantum_info.pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  quantum_info->quantum=32;
+  quantum_info->pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
     MagickFalse;
   quantum_type=RGBQuantum;
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
@@ -1746,22 +1758,18 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+  pixels=GetQuantumPixels(quantum_info);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    status=ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
-    if (status == MagickFalse)
-      break;
+    (void) ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
     count=WriteBlob(image,length,pixels);
     if (count != (ssize_t) length)
       break;
   }
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  CloseBlob(image);
+  quantum_info=DestroyQuantumInfo(quantum_info);
+  (void) CloseBlob(image);
   return(status);
 }
