@@ -137,6 +137,11 @@ static MagickBooleanType IsFITS(const unsigned char *magick,const size_t length)
 %
 */
 
+static inline double GetFITSQuantumRange(const unsigned long depth)
+{
+  return((double) ((MagickOffsetType) GetQuantumRange(depth)));
+}
+
 static inline size_t MagickMin(const size_t x,const size_t y)
 {
   if (x < y)
@@ -237,7 +242,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -363,6 +368,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     }
   for (scene=0; scene < (long) fits_info.number_planes; scene++)
   {
+    unsigned long
+      colors;
+
     /*
       Create linear colormap.
     */
@@ -372,7 +380,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       MagickMin(MAGICKCORE_QUANTUM_DEPTH,16));
     image->storage_class=PseudoClass;
     image->scene=(unsigned long) scene;
-    if (AllocateImageColormap(image,1UL << image->depth) == MagickFalse)
+    colors=(unsigned long) (GetQuantumRange(image->depth)+1);
+    if (AcquireImageColormap(image,colors) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"UnableToAllocateColormap");
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -402,7 +411,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if ((fits_info.min_data != 0.0) || (fits_info.max_data != 0.0))
       {
         if ((fits_info.bits_per_pixel != 0) && (fits_info.max_data == 0.0))
-          fits_info.max_data=(double) (1UL << fits_info.bits_per_pixel)-1;
+          fits_info.max_data=GetFITSQuantumRange(1UL*
+            fits_info.bits_per_pixel);
       }
     else
       {
@@ -517,8 +527,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     */
     scale=1.0;
     if ((fits_info.bits_per_pixel < 0) || ((fits_info.max_data-
-        fits_info.min_data) > (double) ((1UL << image->depth)-1)))
-      scale=(double) ((1UL << image->depth)-1)/(fits_info.max_data-
+        fits_info.min_data) > GetFITSQuantumRange(image->depth)))
+      scale=GetFITSQuantumRange(image->depth)/(fits_info.max_data-
         fits_info.min_data);
     p=fits_pixels;
     for (y=(long) image->rows-1; y >= 0; y--)
@@ -577,9 +587,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           }
         scale_pixel=scale*(pixel*fits_info.scale-fits_info.min_data+
           fits_info.zero);
-        index=(IndexPacket) ((scale_pixel < 0.0) ? 0 : ((unsigned long)
-          scale_pixel > ((1UL << image->depth)-1)) ? ((1UL << image->depth)-1) :
-          (unsigned long) (scale_pixel+0.5));
+        index=(IndexPacket) ((scale_pixel < 0.0) ? 0 : (scale_pixel >
+          GetFITSQuantumRange(image->depth)) ? (unsigned long)
+          GetQuantumRange(image->depth) : (unsigned long) (scale_pixel+0.5));
         index=ConstrainColormapIndex(image,1UL*index);
         indexes[x]=index;
         *q++=image->colormap[(long) index];
@@ -613,7 +623,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -629,7 +639,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           }
       }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -726,7 +736,7 @@ ModuleExport void UnregisterFITSImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -784,7 +794,7 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   /*
     Allocate image memory.
@@ -843,11 +853,11 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   (void) strncpy(fits_info+offset,header,strlen(header));
   offset+=80;
   (void) FormatMagickString(header,MaxTextExtent,"BZERO   =         %E",
-    image->depth > 8 ? 1.0*(1UL << (image->depth-1UL)) : 0.0);
+    image->depth > 8 ? GetFITSQuantumRange(image->depth) : 0.0);
   (void) strncpy(fits_info+offset,header,strlen(header));
   offset+=80;
   (void) FormatMagickString(header,MaxTextExtent,"DATAMAX =         %E",
-    image->depth == 32 ? 4294967295.0 : 1.0*(1UL << image->depth)-1.0);
+    1.0*((MagickOffsetType) GetQuantumRange(image->depth)));
   (void) strncpy(fits_info+offset,header,strlen(header));
   offset+=80;
   (void) FormatMagickString(header,MaxTextExtent,"DATAMIN =         %E",0.0);
@@ -894,17 +904,17 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
           case 4: pixel=(MagickRealType) p->opacity; break;
         }
         if (image->depth > 8)
-          pixel+=1.0*(1UL << (image->depth-1UL));
+          pixel+=1.0*((MagickOffsetType) GetQuantumRange(image->depth));
         if (image->depth > 16)
           {
             (void) WriteBlobByte(image,((unsigned char)
-              ((unsigned long) (pixel+0.5) >> 24) & 0xff));
+              (((unsigned long) (pixel+0.5) >> 24) & 0xff)));
             (void) WriteBlobByte(image,((unsigned char)
-              ((unsigned long) (pixel+0.5) >> 16) & 0xff));
+              (((unsigned long) (pixel+0.5) >> 16) & 0xff)));
           }
         if (image->depth > 8)
           (void) WriteBlobByte(image,((unsigned char)
-            ((unsigned long) (pixel+0.5) >> 8) & 0xff));
+            (((unsigned long) (pixel+0.5) >> 8) & 0xff)));
         (void) WriteBlobByte(image,(unsigned char)
           ((unsigned long) (pixel+0.5) & 0xff));
         p++;
@@ -925,6 +935,6 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
     fits_info);
   fits_info=DestroyString(fits_info);
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
