@@ -150,7 +150,7 @@ static ssize_t
 %
 %  A description of each parameter follows:
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
 %    o opacity:  The colormap index associated with the transparent color.
 %
@@ -248,25 +248,25 @@ static inline int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
   register long
     i;
 
-  if (((lzw_info->code_info.bit+bits) > (8*lzw_info->code_info.count)) &&
-      (lzw_info->code_info.eof == MagickFalse))
-    {
-      ssize_t
-        count;
+  while (((lzw_info->code_info.bit+bits) > (8*lzw_info->code_info.count)) &&
+         (lzw_info->code_info.eof == MagickFalse))
+  {
+    ssize_t
+      count;
 
-      lzw_info->code_info.buffer[0]=lzw_info->code_info.buffer[
-        lzw_info->code_info.count-2];
-      lzw_info->code_info.buffer[1]=lzw_info->code_info.buffer[
-        lzw_info->code_info.count-1];
-      lzw_info->code_info.bit-=8*(lzw_info->code_info.count-2);
-      lzw_info->code_info.count=2;
-      count=ReadBlobBlock(lzw_info->image,&lzw_info->code_info.buffer[
-        lzw_info->code_info.count]);
-      if (count >= 0)
-        lzw_info->code_info.count+=count;
-      else
-        lzw_info->code_info.eof=MagickTrue;
-    }
+    lzw_info->code_info.buffer[0]=lzw_info->code_info.buffer[
+      lzw_info->code_info.count-2];
+    lzw_info->code_info.buffer[1]=lzw_info->code_info.buffer[
+      lzw_info->code_info.count-1];
+    lzw_info->code_info.bit-=8*(lzw_info->code_info.count-2);
+    lzw_info->code_info.count=2;
+    count=ReadBlobBlock(lzw_info->image,&lzw_info->code_info.buffer[
+      lzw_info->code_info.count]);
+    if (count >= 0)
+      lzw_info->code_info.count+=count;
+    else
+      lzw_info->code_info.eof=MagickTrue;
+  }
   if ((lzw_info->code_info.bit+bits) > (8*lzw_info->code_info.count))
     return(-1);
   code=0;
@@ -517,9 +517,9 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
 %    o data_size:  The number of bits in the compressed packet.
 %
@@ -870,7 +870,7 @@ static MagickBooleanType IsGIF(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o data:  Specifies an area to place the information requested from
 %      the file.
@@ -914,7 +914,7 @@ static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -1015,7 +1015,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -1074,7 +1074,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Read graphics control extension.
             */
-            while (ReadBlobBlock(image,header) != 0);
+            while (ReadBlobBlock(image,header) != 0) ;
             dispose=(unsigned long) (header[0] >> 2);
             delay=(unsigned long) ((header[2] << 8) | header[1]);
             if ((long) (header[0] & 0x01) == 0x01)
@@ -1124,26 +1124,28 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
             else
               {
-                /* store GIF application extension as a generic profile */
                 char
                   name[MaxTextExtent];
 
+                int
+                  block_length,
+                  info_length,
+                  reserved_length;
+
+                MagickBooleanType
+                  i8bim,
+                  icc,
+                  iptc;
+
                 StringInfo
                   *profile;
 
                 unsigned char
                   *info;
 
-                MagickBooleanType
-                  i8bim,
-                  icc,
-                  iptc;
-
-                int
-                   block_length,
-                   info_length,
-                   reserved_length;
-
+                /*
+                  Store GIF application extension as a generic profile.
+                */
                 i8bim=LocaleNCompare((char *) header,"MGK8BIM0000",11) == 0 ?
                   MagickTrue : MagickFalse;
                 icc=LocaleNCompare((char *) header,"ICCRGBG1012",11) == 0 ?
@@ -1155,9 +1157,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   "    Reading GIF application extension");
                 info=(unsigned char *) AcquireQuantumMemory(255UL,
                   sizeof(*info));
-                info_length=0;
                 reserved_length=255;
-                for ( ; ; )
+                for (info_length=0; ; )
                 {
                   block_length=(int) ReadBlobBlock(image,&info[info_length]);
                   if (block_length == 0)
@@ -1193,7 +1194,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           default:
           {
-            while (ReadBlobBlock(image,header) != 0);
+            while (ReadBlobBlock(image,header) != 0) ;
             break;
           }
         }
@@ -1205,7 +1206,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -1261,7 +1262,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Inititialize colormap.
     */
-    if (AllocateImageColormap(image,image->colors) == MagickFalse)
+    if (AcquireImageColormap(image,image->colors) == MagickFalse)
       {
         global_colormap=(unsigned char *) RelinquishMagickMemory(
           global_colormap);
@@ -1354,7 +1355,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   global_colormap=(unsigned char *) RelinquishMagickMemory(global_colormap);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(CorruptImageError,"NegativeOrZeroImageSize");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -1450,7 +1451,7 @@ ModuleExport void UnregisterGIFImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -1567,7 +1568,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
   scene=0;
   do
   {
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     opacity=(-1);
     if (image->matte == MagickFalse)
@@ -1885,6 +1886,6 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
   global_colormap=(unsigned char *) RelinquishMagickMemory(global_colormap);
   colormap=(unsigned char *) RelinquishMagickMemory(colormap);
   write_info=DestroyImageInfo(write_info);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
