@@ -52,7 +52,8 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum-private.h"
+#include "magick/pixel.h"
+#include "magick/pixel-private.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -87,7 +88,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -96,23 +97,27 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
   Image
+    *canvas_image,
     *image;
 
   long
-    j,
     y;
 
   MagickBooleanType
     status;
 
-  MagickOffsetType
-    offset;
-
   QuantumInfo
-    quantum_info;
+    *quantum_info;
+
+  QuantumType
+    quantum_type;
+
+  register const PixelPacket
+    *p;
 
   register long
-    i;
+    i,
+    x;
 
   register PixelPacket
     *q;
@@ -121,14 +126,11 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
     count;
 
   size_t
-    packet_size;
+    length;
 
   unsigned char
     *pixels;
 
-  unsigned long
-    width;
-
   /*
     Open image file.
   */
@@ -139,7 +141,7 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
@@ -156,13 +158,14 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
         break;
       }
   /*
-    Allocate memory for a pixels.
+    Create virtual canvas to support cropping (i.e. image.gray[100x100+10+20]).
   */
-  packet_size=(size_t) (image->depth+7)/8;
-  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
-    packet_size*sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+  canvas_image=CloneImage(image,image->extract_info.width,1,MagickTrue,
+    exception);
+  (void) SetImageVirtualPixelMethod(canvas_image,BlackVirtualPixelMethod);
+  quantum_type=GrayQuantum;
+  quantum_info=AcquireQuantumInfo(image_info,canvas_image);
+  pixels=GetQuantumPixels(quantum_info);
   if (image_info->number_scenes != 0)
     while (image->scene < image_info->scene)
     {
@@ -170,48 +173,57 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
         Skip to next image.
       */
       image->scene++;
+      length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
       for (y=0; y < (long) image->rows; y++)
       {
-        count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-        if (count != (ssize_t) (packet_size*image->extract_info.width))
+        count=ReadBlob(image,length,pixels);
+        if (count != (ssize_t) length)
           break;
       }
     }
-  offset=(MagickOffsetType) (packet_size*image->extract_info.x);
   do
   {
     /*
-      Convert raster image to pixel packets.
+      Read pixels to virtual canvas image then push to image.
     */
-    GetQuantumInfo(image_info,&quantum_info);
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    if (SetImageExtent(image,0,0) == MagickFalse)
-      {
-        InheritException(exception,&image->exception);
-        return(DestroyImageList(image));
-      }
-    for (y=0; y < image->extract_info.y; y++)
+    if ((SetImageExtent(image,0,0) == MagickFalse) ||
+        (SetImageExtent(canvas_image,0,0) == MagickFalse))
+      break;
+    length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
+    count=ReadBlob(image,length,pixels);
+    if (count != (ssize_t) length)
+      break;
+    for (y=0; y < (long) image->extract_info.height; y++)
     {
-      count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-      if (count != (ssize_t) (packet_size*image->extract_info.width))
-        break;
-    }
-    for (y=0; y < (long) image->rows; y++)
-    {
-      if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
-        {
-          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-          if (count != (ssize_t) (packet_size*image->extract_info.width))
-            break;
-        }
-      q=SetImagePixels(image,0,y,image->columns,1);
+      q=GetImagePixels(canvas_image,0,0,canvas_image->columns,1);
       if (q == (PixelPacket *) NULL)
         break;
-      (void) ExportQuantumPixels(image,&quantum_info,GrayQuantum,pixels+offset);
-      if (SyncImagePixels(image) == MagickFalse)
+      length=ImportQuantumPixels(canvas_image,quantum_info,quantum_type,pixels);
+      if (SyncImagePixels(canvas_image) == MagickFalse)
         break;
+      count=ReadBlob(image,length,pixels);
+      if (((y-image->extract_info.y) >= 0) && 
+          ((y-image->extract_info.y) < (long) image->rows))
+        {
+          p=AcquireImagePixels(canvas_image,canvas_image->extract_info.x,0,
+            image->columns,1,exception);
+          q=SetImagePixels(image,0,y-image->extract_info.y,image->columns,1);
+          if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+            break;
+          for (x=0; x < (long) image->columns; x++)
+          {
+            q->red=p->red;
+            q->green=p->green;
+            q->blue=p->blue;
+            p++;
+            q++;
+          }
+          if (SyncImagePixels(image) == MagickFalse)
+            break;
+        }
       if (image->previous == (Image *) NULL)
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
             (QuantumTick(y,image->rows) != MagickFalse))
@@ -222,32 +234,19 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
               break;
           }
     }
-    width=image->extract_info.height-image->rows-image->extract_info.y;
-    for (j=0; j < (long) width; j++)
-    {
-      count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-      if (count != (ssize_t) (packet_size*image->extract_info.width))
-        break;
-    }
-    if (y < (long) image->rows)
-      {
-        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
-          image->filename);
-        break;
-      }
+    SetQuantumImageType(image,quantum_type);
     /*
       Proceed to next image.
     */
     if (image_info->number_scenes != 0)
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-    if (count == (ssize_t) (packet_size*image->extract_info.width))
+    if (count == (ssize_t) length)
       {
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -262,9 +261,11 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
               break;
           }
       }
-  } while (count == (ssize_t) (packet_size*image->extract_info.width));
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  CloseBlob(image);
+  } while (count == (ssize_t) length);
+  quantum_info=DestroyQuantumInfo(quantum_info);
+  InheritException(exception,&canvas_image->exception);
+  canvas_image=DestroyImage(canvas_image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -352,7 +353,7 @@ ModuleExport void UnregisterGRAYImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -370,13 +371,19 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
     scene;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
+
+  QuantumType
+    quantum_type;
 
   register const PixelPacket
     *p;
 
+  ssize_t
+    count;
+
   size_t
-    packet_size;
+    length;
 
   unsigned char
     *pixels;
@@ -393,33 +400,26 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  /*
-    Convert image to gray scale PseudoColor class.
-  */
   scene=0;
   do
   {
     /*
-      Allocate memory for pixels.
+      Write grayscale pixels.
     */
-    GetQuantumInfo(image_info,&quantum_info);
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
-    packet_size=(size_t) (image->depth+7)/8;
-    pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
-      sizeof(*pixels));
-    if (pixels == (unsigned char *) NULL)
-      ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    /*
-      Convert MIFF to GRAY raster pixels.
-    */
+    quantum_type=GrayQuantum;
+    quantum_info=AcquireQuantumInfo(image_info,image);
+    pixels=GetQuantumPixels(quantum_info);
     for (y=0; y < (long) image->rows; y++)
     {
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,pixels);
-      (void) WriteBlob(image,packet_size*image->columns,pixels);
+      length=ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
+      count=WriteBlob(image,length,pixels);
+      if (count != (ssize_t) length)
+        break;
       if (image->previous == (Image *) NULL)
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
             (QuantumTick(y,image->rows) != MagickFalse))
@@ -430,7 +430,7 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
               break;
           }
     }
-    pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+    quantum_info=DestroyQuantumInfo(quantum_info);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
@@ -443,6 +443,6 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
