@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,10 +54,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -85,20 +86,21 @@ static MagickBooleanType
 %
 %  The format of the RegisterHISTOGRAMImage method is:
 %
-%      RegisterHISTOGRAMImage(void)
+%      unsigned long RegisterHISTOGRAMImage(void)
 %
 */
-ModuleExport void RegisterHISTOGRAMImage(void)
+ModuleExport unsigned long RegisterHISTOGRAMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("HISTOGRAM");
-  entry->encoder=(EncoderHandler *) WriteHISTOGRAMImage;
+  entry->encoder=(EncodeImageHandler *) WriteHISTOGRAMImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Histogram of the image");
   entry->module=ConstantString("HISTOGRAM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -153,7 +155,7 @@ ModuleExport void UnregisterHISTOGRAMImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -242,7 +244,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   /*
     Allocate histogram count arrays.
   */
-  length=MagickMax((size_t) ScaleQuantumToChar(QuantumRange)+1UL,
+  length=MagickMax((size_t) ScaleQuantumToChar((Quantum) QuantumRange)+1UL,
     histogram_image->columns);
   histogram=(MagickPixelPacket *) AcquireQuantumMemory(length,
     sizeof(*histogram));
@@ -275,15 +277,12 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   maximum=histogram[0].red;
   for (x=0; x < (long) histogram_image->columns; x++)
   {
-    if ((channel & RedChannel) != 0)
-      if (maximum < histogram[x].red)
-        maximum=histogram[x].red;
-    if ((channel & GreenChannel) != 0)
-      if (maximum < histogram[x].green)
-        maximum=histogram[x].green;
-    if ((channel & BlueChannel) != 0)
-      if (maximum < histogram[x].blue)
-        maximum=histogram[x].blue;
+    if (((channel & RedChannel) != 0) && (maximum < histogram[x].red))
+      maximum=histogram[x].red;
+    if (((channel & GreenChannel) != 0) && (maximum < histogram[x].green))
+      maximum=histogram[x].green;
+    if (((channel & BlueChannel) != 0) && (maximum < histogram[x].blue))
+      maximum=histogram[x].blue;
   }
   scale=(MagickRealType) histogram_image->rows/maximum;
   /*
@@ -303,7 +302,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
         r=q+y;
         for ( ; y < (long) histogram_image->rows; y++)
         {
-          r->red=QuantumRange;
+          r->red=(Quantum) QuantumRange;
           r++;
         }
       }
@@ -313,7 +312,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
         r=q+y;
         for ( ; y < (long) histogram_image->rows; y++)
         {
-          r->green=QuantumRange;
+          r->green=(Quantum) QuantumRange;
           r++;
         }
       }
@@ -323,7 +322,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
         r=q+y;
         for ( ; y < (long) histogram_image->rows; y++)
         {
-          r->blue=QuantumRange;
+          r->blue=(Quantum) QuantumRange;
           r++;
         }
       }
@@ -339,7 +338,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
       }
   }
   /*
-    Free resources.
+    Relinquish resources.
   */
   histogram=(MagickPixelPacket *) RelinquishMagickMemory(histogram);
   file=(FILE *) NULL;
@@ -356,10 +355,10 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
       */
       (void) GetNumberColors(image,file,&image->exception);
       (void) fclose(file);
-      property=FileToString(filename,~0,&image->exception);
+      property=FileToString(filename,~0UL,&image->exception);
       if (property != (char *) NULL)
         {
-          (void) SetImageProperty(histogram_image,"Comment",property);
+          (void) SetImageProperty(histogram_image,"comment",property);
           property=DestroyString(property);
         }
     }
