@@ -16,10 +16,10 @@
  %                                                                             %
  %                   Read/Write Scanalytics IPLab Image Format                 %
  %                                  Sean Burke                                 %
- %                                  2007.11.05                                 %
- %                                     v 0.3                                   %
+ %                                  2008.05.07                                 %
+ %                                     v 0.9                                   %
  %                                                                             %
- %  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+ %  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
  %  dedicated to making software imaging solutions freely available.           %
  %                                                                             %
  %  You may not use this file except in compliance with the License.  You may  %
@@ -113,7 +113,6 @@ void increase (void *pixel, int byteType){
  %
  %    o length: Specifies the length of the magick string.
  %
- %
  */
 static MagickBooleanType IsIPL(const unsigned char *magick,const size_t length)
 {
@@ -157,6 +156,15 @@ static MagickBooleanType IsIPL(const unsigned char *magick,const size_t length)
  %
  */
 
+void SetHeaderFromIPL(Image *image, IPLInfo *ipl){
+	image->columns = ipl->width;
+	image->rows = ipl->height;
+	image->depth = ipl->depth;
+	image->x_resolution = 1;
+	image->y_resolution = 1;
+}
+
+
 static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   
@@ -165,21 +173,25 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
    */
   Image *image;
   MagickBooleanType status;
-  long y,c;
   register PixelPacket *q;
   unsigned char magick[12], *pixels;
-  char buff[80];
   ssize_t count;
+  long y;
   unsigned long t_count=0;
   size_t length;
   IPLInfo
     ipl_info;
+  QuantumFormatType
+    quantum_format;
   QuantumInfo
     *quantum_info;
+  QuantumType
+    quantum_type;
+
   /*
    Open Image
    */
-  
+
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if ( image_info->debug != MagickFalse)
@@ -187,7 +199,7 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
   {
@@ -198,9 +210,7 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
    Read IPL image
    */
-  /*  Set default resolution */
-  image->x_resolution=1;
-  image->y_resolution=1;
+
   /* 
     Determine endianness 
    If we get back "iiii", we have LSB,"mmmm", MSB
@@ -215,7 +225,6 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
       ThrowReaderException(CorruptImageError, "ImproperImageHeader");
     }
   }
-  
   /* Skip o'er the next 8 bytes (garbage) */
   count=ReadBlob(image, 8, magick); 
   /*
@@ -234,169 +243,156 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   else { image->colorspace = GRAYColorspace; }
   ipl_info.z=ReadBlobLong(image); 
   ipl_info.time=ReadBlobLong(image); 
-  
+
   ipl_info.byteType=ReadBlobLong(image); 
 
-  quantum_info = AcquireQuantumInfo(image_info);
-  GetQuantumInfo(image_info, quantum_info);
-  
+
+  /* Initialize Quantum Info */
+
   switch (ipl_info.byteType) {
     case 0: 
       ipl_info.depth=8;
-      quantum_info->format=UnsignedQuantumFormat;
-      quantum_info->minimum = 0;
-      quantum_info->maximum = 255;
-      quantum_info->scale=1.0;
-      (void) SetImageProperty(image, "quantum:format", "UnsignedQuantumFormat");
-      (void) SetImageProperty(image, "quantum:minimum", "0");
-      (void) SetImageProperty(image, "quantum:maximum", "255");
+      quantum_format = UnsignedQuantumFormat;
       break;
     case 1: 
       ipl_info.depth=16;
-      quantum_info->format=SignedQuantumFormat;
-      quantum_info->minimum = -32767;
-      quantum_info->maximum = 32767;
-      (void) SetImageProperty(image, "quantum:format", "SignedQuantumFormat");
-      (void) SetImageProperty(image, "quantum:minimum", "-32767");
-      (void) SetImageProperty(image, "quantum:maximum", "32767");
+      quantum_format = SignedQuantumFormat;
       break;
     case 2: 
       ipl_info.depth=16;
-      quantum_info->format=UnsignedQuantumFormat;
-      quantum_info->minimum = 0;
-      quantum_info->maximum = 65535;
-      (void) SetImageProperty(image, "quantum:format", "UnsignedQuantumFormat");
-      (void) SetImageProperty(image, "quantum:minimum", "0");
-      (void) SetImageProperty(image, "quantum:maximum", "65535");
+      quantum_format = UnsignedQuantumFormat;
       break;
     case 3: 
       ipl_info.depth=32;
-      quantum_info->format=SignedQuantumFormat;
-      quantum_info->minimum = -2147483647;
-      quantum_info->maximum = 2147483647;
-      (void) SetImageProperty(image, "quantum:format", "SignedQuantumFormat");
-      (void) SetImageProperty(image, "quantum:minimum", "-2147483647");
-      (void) SetImageProperty(image, "quantum:maximum", "2147483647");
+      quantum_format = SignedQuantumFormat;
       break;
     case 4: ipl_info.depth=32;
-      quantum_info->format=FloatingPointQuantumFormat;
-      quantum_info->minimum = 0.0000000;
-      quantum_info->maximum = 1.0000000;
-      quantum_info->scale = QuantumRange;
-      (void) SetImageProperty(image, "quantum:format", "FloatingPointQuantumFormat");
-      (void) SetImageProperty(image, "quantum:minimum", "0.0000000");
-      (void) SetImageProperty(image, "quantum:maximum", "1.0000000");
+      quantum_format = FloatingPointQuantumFormat;
       break;
     case 5: 
       ipl_info.depth=8;
-      (void) SetImageProperty(image, "quantum:format", "UnsignedQuantumFormat");
+      quantum_format = UnsignedQuantumFormat;
       break;
     case 6: 
       ipl_info.depth=16;
-      (void) SetImageProperty(image, "quantum:format", "UnsignedQuantumFormat");
+      quantum_format = UnsignedQuantumFormat;
       break;
     case 10:  
       ipl_info.depth=64;
-      quantum_info->format=FloatingPointQuantumFormat;
-      quantum_info->minimum = 0.0000000;
-      quantum_info->maximum = 1.0000000;
-      quantum_info->scale = 1.000000/QuantumRange;
-      (void) SetImageProperty(image, "quantum:format", "FloatingPointQuantumFormat");
-      (void) SetImageProperty(image, "quantum:minimum", "0.0000000");
-      (void) SetImageProperty(image, "quantum:maximum", "1.0000000");
+      quantum_format = FloatingPointQuantumFormat;
       break; 
     default: 
       ipl_info.depth=16;
-      quantum_info->format=UnsignedQuantumFormat;
-      quantum_info->minimum = 0;
-      quantum_info->maximum = 65535;
-/*      (void) SetImageProperty(image, "quantum:format", "UnsignedQuantumFormat");*/
+      quantum_format = UnsignedQuantumFormat;
       break;
   }
 
   /*
     Set number of scenes of image
   */
-  (void) FormatMagickString(buff, MaxTextExtent, "%lu", ipl_info.z * ipl_info.time );
-  (void) SetImageProperty(image, "number_scenes", buff);
-  
+
+  SetHeaderFromIPL(image, &ipl_info);
+
   /* Thats all we need if we are pinging. */
   if (image_info->ping != MagickFalse)
   {
-    CloseBlob(image);
+    (void) CloseBlob(image);
     return(GetFirstImageInList(image));
   }
+  length=image->columns;
+  quantum_type=GetQuantumType(image,exception);
+ do
+  {
+    SetHeaderFromIPL(image, &ipl_info);
 
-  image->columns=ipl_info.width;
-  image->rows=ipl_info.height;
-  image->depth=ipl_info.depth; 
-
+  if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
+      if (image->scene >= (image_info->scene+image_info->number_scenes-1))
+        break;
   if (SetImageExtent(image,0,0) == MagickFalse)
     {
       InheritException(exception,&image->exception);
       return(DestroyImageList(image));
     }
-  length=image->columns * (image->depth)/8;
-  pixels=(unsigned char *) AcquireQuantumMemory(length,(image->depth/8)*
-    sizeof(*pixels));
-  if(pixels == (unsigned char *)NULL)
-    ThrowReaderException(ResourceLimitError, "MemoryAllocationFailed");
-  do
-  {
+/*
+   printf("Length: %lu, Memory size: %lu\n", length,(unsigned long)(image->depth));
+*/
+     quantum_info=AcquireQuantumInfo(image_info,image);
+     (void) SetQuantumFormat(image,quantum_format,quantum_info);
+     pixels=GetQuantumPixels(quantum_info); 
+     if(image->columns != ipl_info.width){
+/*
+ 		printf("Columns not set correctly!  Wanted: %lu, got: %lu\n",
+ 			ipl_info.width, image->columns);
+*/
+     }
+
     /* 
     Covert IPL binary to pixel packets
      */
-    for (c=0; c < (long) ipl_info.colors; c++){
+    
+  if(ipl_info.colors == 1){
       for(y = 0; y < (long) image->rows; y++){
-        (void) ReadBlob(image, length, pixels);
+        (void) ReadBlob(image, length*image->depth/8, pixels);
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
                 break;
-        if(ipl_info.colors == 1){
-          (void) ExportQuantumPixels(image, quantum_info, GrayQuantum, pixels);
+	(void) ImportQuantumPixels(image,quantum_info,GrayQuantum,pixels);
           if (SyncImagePixels(image) == MagickFalse)
                   break;
-/*          for(x = 0; x < image->columns; x++){
-            for( j= 0; j < 4; j++){          
-              printf("%2x", (unsigned int)pixels[4*x + j]);
-            }
-            printf("\t");
-          }
-          printf("\n"); */
-        }
-        else{
-          switch(c){
-          case 0:  
-            (void) ExportQuantumPixels(image, quantum_info, RedQuantum, pixels);
-          case 1:  
-            (void) ExportQuantumPixels(image, quantum_info, GreenQuantum, pixels);
-          default:  
-            (void) ExportQuantumPixels(image, quantum_info, BlueQuantum, pixels);
-          }
-          if (SyncImagePixels(image) == MagickFalse)
-                  break;
-        }
-      }  
-    }      
+  	}
+  }
+  else{
+      for(y = 0; y < (long) image->rows; y++){
+        (void) ReadBlob(image, length*image->depth/8, pixels);
+        q=SetImagePixels(image,0,y,image->columns,1);
+        if (q == (PixelPacket *) NULL)
+                break;
+	(void) ImportQuantumPixels(image,quantum_info,RedQuantum,pixels);	
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
+      }
+      for(y = 0; y < (long) image->rows; y++){
+        (void) ReadBlob(image, length*image->depth/8, pixels);
+        q=SetImagePixels(image,0,y,image->columns,1);
+        if (q == (PixelPacket *) NULL)
+                break;
+	(void) ImportQuantumPixels(image,quantum_info,GreenQuantum,pixels);
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
+      }
+      for(y = 0; y < (long) image->rows; y++){
+        (void) ReadBlob(image, length*image->depth/8, pixels);
+        q=SetImagePixels(image,0,y,image->columns,1);
+        if (q == (PixelPacket *) NULL)
+                break;
+	(void) ImportQuantumPixels(image,quantum_info,BlueQuantum,pixels);
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
+      }
+   }
+   SetQuantumImageType(image,quantum_type);
+ 
     t_count++;
+  quantum_info = DestroyQuantumInfo(quantum_info);
+
     if (EOFBlob(image) != MagickFalse)
     {
       ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
                  image->filename);
       break;
     }
-    if(t_count < ipl_info.z * ipl_info.time){
+   if(t_count < ipl_info.z * ipl_info.time){
       /*
        Proceed to next image.
        */
-
-      AllocateNextImage(image_info, image);
+      AcquireNextImage(image_info, image);
       if (GetNextImageInList(image) == (Image *) NULL)
       {
         image=DestroyImageList(image);
         return((Image *) NULL);
       }
       image=SyncNextImageInList(image); 
+
       if (image->progress_monitor != (MagickProgressMonitor) NULL)
       {
         status=image->progress_monitor(LoadImagesTag,TellBlob(image),
@@ -407,7 +403,6 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   } while (t_count < ipl_info.z*ipl_info.time);
   CloseBlob(image);
-  pixels = (unsigned char *) RelinquishMagickMemory(pixels);
   return(GetFirstImageInList(image));
 }
 
@@ -434,7 +429,6 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
  %
  %    o image:  The image.
  %
- %
  */
 
 static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
@@ -456,12 +450,10 @@ static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
   
   IPLInfo
     ipl_info;
-   QuantumInfo
-    *quantum_info;  
-   const char
-  *qType;
 
-   quantum_info = AcquireQuantumInfo(image_info);
+  QuantumInfo
+    *quantum_info;
+
    /*
     Open output image file.
   */
@@ -476,38 +468,46 @@ static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
     return(status);
   scene=0;
   
-  GetQuantumInfo(image_info, quantum_info);
-  qType = GetImageProperty(image, "quantum:format"); 
-  switch(image->depth){
+
+  quantum_info=AcquireQuantumInfo(image_info, image);
+  if ((quantum_info->format == UndefinedQuantumFormat) &&
+      (IsHighDynamicRangeImage(image,&image->exception) != MagickFalse))
+    (void) SetQuantumFormat(image,FloatingPointQuantumFormat,quantum_info);
+  switch(quantum_info->depth){
   case 8: 
     ipl_info.byteType = 0;
     break;
   case 16:
-    if(LocaleCompare(qType, "SignedQuantumFormat"))
+    if(quantum_info->format == SignedQuantumFormat){
       ipl_info.byteType = 2;
-    else
+    }
+    else{
       ipl_info.byteType = 1;
+    }
     break;
   case 32:
-    if(LocaleCompare(qType, "FloatingPointQuantumFormat"))
+    if(quantum_info->format == FloatingPointQuantumFormat){
       ipl_info.byteType = 3;
-    else
+    }
+    else{
       ipl_info.byteType = 4;
+    }
     break;
   case 64:
-      ipl_info.byteType = 10;
+    ipl_info.byteType = 10;
+    break;
+  default: 
+    ipl_info.byteType = 2; 
     break;
-  default: ipl_info.byteType = 2; break;
     
   }
-  
   ipl_info.z = GetImageListLength(image);
   /* There is no current method for detecting whether we have T or Z stacks */
   ipl_info.time = 1;
   ipl_info.width = image->columns;
   ipl_info.height = image->rows;
   
-  if (image->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   
   if(image->colorspace == RGBColorspace) { ipl_info.colors = 3; }
@@ -521,10 +521,16 @@ static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
   /*
     Write IPL header.
   */
-  if(image_info->endian == LSBEndian)
-    (void) WriteBlob(image, 4, (unsigned char *) "iiii");
-  else
+  /* Shockingly (maybe not if you have used IPLab),  IPLab itself CANNOT read MSBEndian
+  files!   The reader above can, but they cannot.  For compatability reasons, I will leave
+  the code in here, but it is all but useless if you want to use IPLab. */
+
+  if(image_info->endian == MSBEndian)
     (void) WriteBlob(image, 4, (unsigned char *) "mmmm");
+  else{
+    image->endian = LSBEndian;
+    (void) WriteBlob(image, 4, (unsigned char *) "iiii");
+  }
   (void) WriteBlobLong(image, 4);
   (void) WriteBlob(image, 4, (unsigned char *) "100f");
   (void) WriteBlob(image, 4, (unsigned char *) "data");
@@ -532,36 +538,48 @@ static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobLong(image, ipl_info.width); 
   (void) WriteBlobLong(image, ipl_info.height);
   (void) WriteBlobLong(image, ipl_info.colors);
+  if(image_info->adjoin == MagickFalse)
+  (void) WriteBlobLong(image, 1);
+  else
   (void) WriteBlobLong(image, ipl_info.z);
   (void) WriteBlobLong(image, ipl_info.time);
   (void) WriteBlobLong(image, ipl_info.byteType);
   
 
-
+  
  do
     {
       /*
   Convert MIFF to IPL raster pixels.
       */
-      pixels=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
-        (image->depth/8)*sizeof(*pixels));
-      if(pixels == (unsigned char *) NULL)
-    ThrowWriterException(ResourceLimitError, "MemoryAllocationFailed");
+      pixels=GetQuantumPixels(quantum_info);
+  if(ipl_info.colors == 1){
   /* Red frame */
   for(y = 0; y < (long) ipl_info.height; y++){
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=GetImagePixels(image,0,y,image->columns,1);
     if (p == (PixelPacket *) NULL)
       break;
-      (void) ImportQuantumPixels(image, quantum_info, GrayQuantum, pixels);
+      (void) ExportQuantumPixels(image, quantum_info, GrayQuantum, pixels);
       (void) WriteBlob(image, image->columns*image->depth/8, pixels);
   }
+
+}
   if(ipl_info.colors == 3){
+  /* Red frame */
+  for(y = 0; y < (long) ipl_info.height; y++){
+    p=GetImagePixels(image,0,y,image->columns,1);
+    if (p == (PixelPacket *) NULL)
+      break;
+      (void) ExportQuantumPixels(image, quantum_info, RedQuantum, pixels);
+      (void) WriteBlob(image, image->columns*image->depth/8, pixels);
+  }
+
     /* Green frame */
     for(y = 0; y < (long) ipl_info.height; y++){
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
       if (p == (PixelPacket *) NULL)
         break;
-        (void) ImportQuantumPixels(image, quantum_info, GrayQuantum, pixels);
+        (void) ExportQuantumPixels(image, quantum_info, GreenQuantum, pixels);
         (void) WriteBlob(image, image->columns*image->depth/8, pixels);
     }
     /* Blue frame */
@@ -569,7 +587,7 @@ static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
       if (p == (PixelPacket *) NULL)
         break;
-      (void) ImportQuantumPixels(image, quantum_info, GrayQuantum, pixels);
+      (void) ExportQuantumPixels(image, quantum_info, BlueQuantum, pixels);
       (void) WriteBlob(image, image->columns*image->depth/8, pixels);
       if (image->previous == (Image *) NULL){
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -581,7 +599,7 @@ static MagickBooleanType WriteIPLImage(const ImageInfo *image_info,Image *image)
       }
     }
   }
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+  quantum_info=DestroyQuantumInfo(quantum_info);
       if (GetNextImageInList(image) == (Image *) NULL)
   break;
       image=SyncNextImageInList(image);
@@ -658,4 +676,3 @@ ModuleExport void UnregisterIPLImage(void)
 {
   (void) UnregisterMagickInfo("IPL");
 }
-
