@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -79,7 +80,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -89,7 +90,8 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
   char
-    geometry[MaxTextExtent];
+    geometry[MaxTextExtent],
+    *property;
 
   const char
     *label;
@@ -120,10 +122,11 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   (void) ResetImagePage(image,"0x0+0+0");
-  (void) SetImageProperty(image,"label",InterpretImageProperties(image_info,
-    image,image_info->filename));
+  property=InterpretImageProperties(image_info,image,image_info->filename);
+  (void) SetImageProperty(image,"label",property);
+  property=DestroyString(property);
   label=GetImageProperty(image,"label");
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
   draw_info->text=ConstantString(label);
@@ -212,20 +215,21 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterLABELImage method is:
 %
-%      RegisterLABELImage(void)
+%      unsigned long RegisterLABELImage(void)
 %
 */
-ModuleExport void RegisterLABELImage(void)
+ModuleExport unsigned long RegisterLABELImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("LABEL");
-  entry->decoder=(DecoderHandler *) ReadLABELImage;
+  entry->decoder=(DecodeImageHandler *) ReadLABELImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Image label");
   entry->module=ConstantString("LABEL");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
