@@ -58,10 +58,12 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/option.h"
 #include "magick/shear.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 
 /*
@@ -181,27 +183,27 @@ static void InsertComplexDoubleRow(double *p, int y, Image * image, double MinVa
   {
     if (*p > 0)
     {
-      f = (*p / MaxVal) * (MaxRGB - q->red);
-      if (f + q->red > MaxRGB)
-        q->red = MaxRGB;
+      f = (double) (*p / MaxVal) * (QuantumRange - q->red);
+      if (f + q->red > QuantumRange)
+        q->red = (Quantum) QuantumRange;
       else
         q->red += (int) f;
-      if ((int) f / 2.0 > q->green)
-        q->green = q->blue = 0;
+      if ((f / 2.0) > (double) q->green)
+        q->green = q->blue = (Quantum) 0;
       else
-        q->green = q->blue -= (int) (f / 2.0);
+        q->green = q->blue -= (Quantum) (f / 2.0);
     }
     if (*p < 0)
     {
-      f = (*p / MaxVal) * (MaxRGB - q->blue);
-      if (f + q->blue > MaxRGB)
-        q->blue = MaxRGB;
+      f = (double) (*p / MaxVal) * (QuantumRange - q->blue);
+      if (f + q->blue > QuantumRange)
+        q->blue = (Quantum) QuantumRange;
       else
         q->blue += (int) f;
-      if ((int) f / 2.0 > q->green)
-        q->green = q->red = 0;
+      if ((f / 2.0) > (double) q->green)
+        q->green = q->red = (Quantum) 0;
       else
-        q->green = q->red -= (int) (f / 2.0);
+        q->green = q->red -= (Quantum) (f / 2.0);
     }
     p++;
     q++;
@@ -234,27 +236,27 @@ static void InsertComplexFloatRow(float *p, int y, Image * image, double MinVal,
   {
     if (*p > 0)
     {
-      f = (*p / MaxVal) * (MaxRGB - q->red);
-      if (f + q->red > MaxRGB)
-        q->red = MaxRGB;
+      f = (double) (*p / MaxVal) * (QuantumRange - q->red);
+      if (f + q->red > QuantumRange)
+        q->red = (Quantum) QuantumRange;
       else
         q->red += (int) f;
-      if ((int) f / 2.0 > q->green)
-        q->green = q->blue = 0;
+      if ((f / 2.0) > (double) q->green)
+        q->green = q->blue = (Quantum) 0;
       else
-        q->green = q->blue -= (int) (f / 2.0);
+        q->green = q->blue -= (Quantum) (f / 2.0);
     }
     if (*p < 0)
     {
-      f = (*p / MaxVal) * (MaxRGB - q->blue);
-      if (f + q->blue > MaxRGB)
-        q->blue = MaxRGB;
+      f = (double) (*p / MaxVal) * (QuantumRange - q->blue);
+      if (f + q->blue > QuantumRange)
+        q->blue = (Quantum) QuantumRange;
       else
         q->blue += (int) f;
-      if ((int) f / 2.0 > q->green)
-        q->green = q->red = 0;
+      if ((f / 2.0) > 1.0*q->green)
+        q->green = q->red = (Quantum) 0;
       else
-        q->green = q->red -= (int) (f / 2.0);
+        q->green = q->red -= (Quantum) (f / 2.0);
     }
     p++;
     q++;
@@ -279,7 +281,7 @@ static void ReadBlobFloatsLSB(Image * image, size_t len, float *data)
     len -= sizeof(float);
   }
   if (len > 0)
-    (void) SeekBlob(image, len, SEEK_CUR);
+    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
 }
 
 static void ReadBlobFloatsMSB(Image * image, size_t len, float *data)
@@ -290,7 +292,7 @@ static void ReadBlobFloatsMSB(Image * image, size_t len, float *data)
     len -= sizeof(float);
   }
   if (len > 0)
-    (void) SeekBlob(image, len, SEEK_CUR);
+    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
 }
 
 /* This function reads one block of doubles*/
@@ -302,7 +304,7 @@ static void ReadBlobDoublesLSB(Image * image, size_t len, double *data)
     len -= sizeof(double);
   }
   if (len > 0)
-    (void) SeekBlob(image, len, SEEK_CUR);
+    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
 }
 
 static void ReadBlobDoublesMSB(Image * image, size_t len, double *data)
@@ -313,7 +315,7 @@ static void ReadBlobDoublesMSB(Image * image, size_t len, double *data)
     len -= sizeof(double);
   }
   if (len > 0)
-    (void) SeekBlob(image, len, SEEK_CUR);
+    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
 }
 
 
@@ -380,16 +382,16 @@ float *fltrow;
 }
 
 
-static void FixSignedValues(PixelPacket *q, int y)
+static void FixSignedValues(PixelPacket *q, long y)
 {
   while(y-->0)
   {
      /* Please note that negative values will overflow
-        Q=8; MaxRGB=255: <0;127> + 127+1 = <128; 255> 
+        Q=8; QuantumRange=255: <0;127> + 127+1 = <128; 255> 
 		       <-1;-128> + 127+1 = <0; 127> */
-    q->red += MaxRGB/2 + 1;
-    q->green += MaxRGB/ + 1;
-    q->blue += MaxRGB/ + 1;
+    q->red += QuantumRange/2 + 1;
+    q->green += QuantumRange/ + 1;
+    q->blue += QuantumRange/ + 1;
     q++;
   }
 }
@@ -438,14 +440,16 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MATHeader MATLAB_HDR;
   unsigned long size;  
   unsigned long CellType;
-  QuantumInfo quantum_info;
-  int i;
+  QuantumInfo *quantum_info;
+  long i;
   long ldblk;
   unsigned char *BImgBuff = NULL;
   double MinVal, MaxVal;
   unsigned long Unknown6;
+  ImageInfo *clone_info;
   unsigned z;
   int logging;
+  ssize_t count;
   MagickOffsetType filepos=0x80;
   BlobInfo *blob;
 
@@ -464,7 +468,7 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
      Open image file.
    */
-  image = AllocateImage(image_info);
+  image = AcquireImage(image_info);
   status = OpenBlob(image_info, image, ReadBinaryBlobMode, exception);
   if (status == MagickFalse)
     {
@@ -474,11 +478,13 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
      Read MATLAB image.
    */
-  (void) ReadBlob(image, 124, (unsigned char *) &MATLAB_HDR.identific);
+  count=ReadBlob(image, 124, (unsigned char *) &MATLAB_HDR.identific);
+  if (count == 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   MATLAB_HDR.Version = ReadBlobLSBShort(image);
-  (void) ReadBlob(image, 2, (unsigned char *) &MATLAB_HDR.EndianIndicator);
-
-  GetQuantumInfo(image_info,&quantum_info);
+  count=ReadBlob(image, 2, (unsigned char *) &MATLAB_HDR.EndianIndicator);
+  if (count == 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
   if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),"  Endian %c%c",
         MATLAB_HDR.EndianIndicator[0],MATLAB_HDR.EndianIndicator[1]);
@@ -504,38 +510,35 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (strncmp(MATLAB_HDR.identific, "MATLAB", 6))
 MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
-  filepos = TellBlob(image);
-  while(!EOFBlob(image)) /* object parser loop */
+  filepos=TellBlob(image);
+  while (EOFBlob(image) == MagickFalse) /* object parser loop */
   {
-    SeekBlob(image,filepos,SEEK_SET);
-    //printf("pos=%X\n",TellBlob(image));
-
-    MATLAB_HDR.DataType = ReadBlobXXXLong(image);
-    if(EOFBlob(image)) break;
+    (void) SeekBlob(image,filepos,SEEK_SET);
+    MATLAB_HDR.DataType=ReadBlobXXXLong(image);
+    if (EOFBlob(image) != MagickFalse)
+      break;
     MATLAB_HDR.ObjectSize = ReadBlobXXXLong(image);
-    if(EOFBlob(image)) break;
-    filepos += MATLAB_HDR.ObjectSize + 4 + 4;
-
-    if (MATLAB_HDR.DataType != miMATRIX) continue;  /* skip another objects. */    
- 
-    MATLAB_HDR.unknown1 = ReadBlobXXXLong(image);
-    MATLAB_HDR.unknown2 = ReadBlobXXXLong(image);  
-
-    MATLAB_HDR.unknown5 = ReadBlobXXXLong(image);
-    MATLAB_HDR.StructureClass = MATLAB_HDR.unknown5 & 0xFF;
-    MATLAB_HDR.StructureFlag = (MATLAB_HDR.unknown5>>8) & 0xFF;  
-
-    MATLAB_HDR.unknown3 = ReadBlobXXXLong(image);
-    MATLAB_HDR.unknown4 = ReadBlobXXXLong(image);
-    MATLAB_HDR.DimFlag = ReadBlobXXXLong(image);
-    MATLAB_HDR.SizeX = ReadBlobXXXLong(image);
+    if (EOFBlob(image) != MagickFalse)
+      break;
+    filepos+=MATLAB_HDR.ObjectSize+4+4;
+    if (MATLAB_HDR.DataType == miCOMPRESSED)
+      continue;
+    if (MATLAB_HDR.DataType != miMATRIX)
+      continue;  /* skip another objects. */    
+    MATLAB_HDR.unknown1=ReadBlobXXXLong(image);
+    MATLAB_HDR.unknown2=ReadBlobXXXLong(image);  
+    MATLAB_HDR.unknown5=(unsigned short) ReadBlobXXXLong(image);
+    MATLAB_HDR.StructureClass=(unsigned char) (MATLAB_HDR.unknown5 & 0xFF);
+    MATLAB_HDR.StructureFlag=(unsigned char) ((MATLAB_HDR.unknown5 >> 8) & 0xFF);  
+    MATLAB_HDR.unknown3=ReadBlobXXXLong(image);
+    MATLAB_HDR.unknown4=ReadBlobXXXLong(image);
+    MATLAB_HDR.DimFlag=ReadBlobXXXLong(image);
+    MATLAB_HDR.SizeX=ReadBlobXXXLong(image);
     MATLAB_HDR.SizeY = ReadBlobXXXLong(image);  
-   
-
-    switch(MATLAB_HDR.DimFlag)
+    switch (MATLAB_HDR.DimFlag)
     {
       case  8: z=1; break;	       /* 2D matrix*/
-      case 12: z=ReadBlobXXXLong(image); /* 3D matrix RGB*/
+      case 12: z=(unsigned int) ReadBlobXXXLong(image); /* 3D matrix RGB*/
   	       Unknown6 = ReadBlobXXXLong(image);
 	       if(z!=3) ThrowReaderException(CoderError, "MultidimensionalMatricesAreNotSupported");
 	       break;
@@ -564,8 +567,8 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     {
       case 0:
         size = ReadBlobXXXLong(image);	/* Object name string size */
-        size = 4 * (long) ((size + 3 + 1) / 4);
-        (void) SeekBlob(image, size, SEEK_CUR);
+        size = 4UL * (long) ((size + 3 + 1) / 4);
+        (void) SeekBlob(image, (MagickOffsetType) size, SEEK_CUR);
         break;
       case 1:
       case 2:
@@ -583,6 +586,9 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   
     (void) ReadBlob(image, 4, (unsigned char *) &size);     /* data size */
 
+    image->columns = MATLAB_HDR.SizeX;
+    image->rows = MATLAB_HDR.SizeY;
+    clone_info=CloneImageInfo(image_info);
     switch (CellType)
     {
       case miINT8:
@@ -607,7 +613,7 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
         break;   
       case miSINGLE:
         image->depth= 32;
-        quantum_info.format=FloatingPointQuantumFormat;
+        (void) SetImageOption(clone_info,"quantum:format","floating-point");
         if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
 	{                         /* complex float type cell */
 	}
@@ -615,7 +621,7 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
         break;
       case miDOUBLE:
         image->depth= 64; 
-        quantum_info.format=FloatingPointQuantumFormat;
+        (void) SetImageOption(clone_info,"quantum:format","floating-point");
         if (sizeof(double) != 8)
           ThrowReaderException(CoderError, "IncompatibleSizeOfDouble");
         if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
@@ -626,10 +632,10 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
       default:
         ThrowReaderException(CoderError, "UnsupportedCellTypeInTheMatrix");
     }
+    quantum_info=AcquireQuantumInfo(clone_info,image);
+    clone_info=DestroyImageInfo(clone_info);
 
-    image->columns = MATLAB_HDR.SizeX;
-    image->rows = MATLAB_HDR.SizeY;
-    image->colors = 1l >> 8;
+    image->colors = 1UL >> 8;
     if (image->columns == 0 || image->rows == 0)
       goto MATLAB_KO;
 
@@ -642,11 +648,11 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
       unsigned long temp = image->columns;
       image->columns = image->rows;
       image->rows = temp;
-      goto done_reading; //!!!!!! BAD  !!!!
+      goto done_reading; 
     }  
 
   /* ----- Load raster data ----- */
-    BImgBuff = (unsigned char *) AcquireQuantumMemory(ldblk,sizeof(*BImgBuff));
+    BImgBuff = (unsigned char *) AcquireQuantumMemory((size_t) ldblk,sizeof(*BImgBuff));
     if (BImgBuff == NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
 
@@ -654,7 +660,7 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     MaxVal = 0;
     if (CellType==miDOUBLE || CellType==miSINGLE)        /* Find Min and Max Values for floats */
     {
-      CalcMinMax(image, &MATLAB_HDR, CellType, ldblk, BImgBuff, &quantum_info.minimum, &quantum_info.maximum);
+      CalcMinMax(image, &MATLAB_HDR, CellType, (unsigned int) ldblk, BImgBuff, &quantum_info->minimum, &quantum_info->maximum);
     }
 
     /* Main loop for reading all scanlines */
@@ -664,13 +670,13 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     {
       for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
       {
-        q=SetImagePixels(image,0,MATLAB_HDR.SizeY-i-1,image->columns,1);
-        if (q == (PixelPacket *)NULL) goto ExitLoop;
-        (void) ReadBlob(image, ldblk, (unsigned char *)BImgBuff);	  
-        (void) ExportQuantumPixels(image,&quantum_info,z2qtype[z],BImgBuff);
-        if (z<=1 &&			 // fix only during a last pass z==0 || z==1
+        q=SetImagePixels(image,0,(long) MATLAB_HDR.SizeY-i-1,image->columns,1);
+        if (q == (PixelPacket *)NULL) goto done_reading;
+        (void) ReadBlob(image, (size_t) ldblk, (unsigned char *)BImgBuff);	  
+        (void) ImportQuantumPixels(image,quantum_info,z2qtype[z],BImgBuff);
+        if (z<=1 &&
 	        (CellType==miINT8 || CellType==miINT16 || CellType==miINT32 || CellType==miINT64))
-	  FixSignedValues(q,MATLAB_HDR.SizeX);
+	  FixSignedValues(q,(long) MATLAB_HDR.SizeX);
         if (!SyncImagePixels(image)) goto ExitLoop;
       }
     } while(z-- >= 2);
@@ -681,27 +687,32 @@ ExitLoop:
     if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
     {        /* Find Min and Max Values for complex parts of floats */
       CellType = ReadBlobXXXLong(image);    /* Additional object type */
-      i = ReadBlobXXXLong(image);           /* size of a complex part - toss away*/
+      i = (long) ReadBlobXXXLong(image);           /* size of a complex part - toss away*/
 
       if (CellType==miDOUBLE || CellType==miSINGLE)
       {
-        CalcMinMax(image, &MATLAB_HDR, CellType, ldblk, BImgBuff, &MinVal, &MaxVal);      
+        CalcMinMax(image, &MATLAB_HDR, CellType, (unsigned int) ldblk, BImgBuff, &MinVal, &MaxVal);      
       }
 
       if (CellType==miDOUBLE)
         for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
 	{
-          ReadBlobDoublesXXX(image, ldblk, (double *)BImgBuff);
+          ReadBlobDoublesXXX(image, (size_t) ldblk, (double *)BImgBuff);
           InsertComplexDoubleRow((double *)BImgBuff, i, image, MinVal, MaxVal);
 	}
 
       if (CellType==miSINGLE)
         for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
 	{
-          ReadBlobFloatsXXX(image, ldblk, (float *)BImgBuff);
+          ReadBlobFloatsXXX(image, (size_t) ldblk, (float *)BImgBuff);
           InsertComplexFloatRow((float *)BImgBuff, i, image, MinVal, MaxVal);
 	}    
     }
+    if ((MATLAB_HDR.DimFlag == 8) &&
+        ((MATLAB_HDR.StructureFlag & FLAG_COMPLEX) == 0))
+      image->type=GrayscaleType;
+    if (image->depth == 1)
+      image->type=BilevelType;
 
       /* Image is gray when no complex flag is set and 2D Matrix AGAIN!!! */
       /*  Rotate image. */
@@ -722,7 +733,7 @@ ExitLoop:
 done_reading:
 
       /* Allocate next image structure. */    
-    AllocateNextImage(image_info,image);   
+    AcquireNextImage(image_info,image);   
     if (image->next == (Image *) NULL) break;                
     image=SyncNextImageInList(image);
     image->columns=image->rows=0;
@@ -730,11 +741,12 @@ done_reading:
 
       /* row scan buffer is no longer needed */
     BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
+    quantum_info=DestroyQuantumInfo(quantum_info);
   }
 
 
   BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
-  CloseBlob(image);
+  (void) CloseBlob(image);
 
 
   {
@@ -762,7 +774,7 @@ done_reading:
       Fix scene numbers
     */
     for (p=image; p != (Image *) NULL; p=p->next)
-      p->scene=scene++;
+      p->scene=(unsigned long) scene++;
   }
 
   if (logging) (void) LogMagickEvent(CoderEvent,GetMagickModule(),"return");
@@ -789,20 +801,23 @@ done_reading:
 %
 %  The format of the RegisterMATImage method is:
 %
-%      RegisterMATImage(void)
+%      unsigned long RegisterMATImage(void)
 %
 */
-ModuleExport void RegisterMATImage(void)
+ModuleExport unsigned long RegisterMATImage(void)
 {
-  MagickInfo * entry;
+  MagickInfo
+    *entry;
 
-  entry = SetMagickInfo("MAT");
-  entry->decoder=(DecoderHandler *) ReadMATImage;
-  entry->encoder=(EncoderHandler *) WriteMATImage;
+  entry=SetMagickInfo("MAT");
+  entry->decoder=(DecodeImageHandler *) ReadMATImage;
+  entry->encoder=(EncodeImageHandler *) WriteMATImage;
+  entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=AcquireString("MATLAB image format");
   entry->module=AcquireString("MAT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -861,20 +876,22 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
 {
   long y;
   unsigned z;
-  const PixelPacket *q;
+  const PixelPacket *p;
   unsigned int status;
   int logging;
   unsigned long DataSize;
   char padding;
-  char MATLAB_HDR[0x84];
+  char MATLAB_HDR[0x80];
   time_t current_time;
   const struct tm *t;
   unsigned char *pixels;
   int is_gray;
-  QuantumInfo quantum_info;
 
-  current_time=time((time_t *) NULL);
-  t=localtime(&current_time);
+  MagickOffsetType
+    scene;
+
+  QuantumInfo
+    *quantum_info;
 
   /*
     Open output image file.
@@ -889,22 +906,10 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
     return(MagickFalse);
   image->depth=8;
 
-  pixels=(unsigned char *) AcquireQuantumMemory(image->rows,sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-
-  is_gray = IsGrayImage(image,&image->exception);
-  z = is_gray ? 0 : 3;
-
-  /*
-    Store MAT header.
-  */
-  DataSize = image->rows /*Y*/ * image->columns /*X*/;
-  if(!is_gray) DataSize *= 3 /*Z*/;
-  padding=((unsigned char)(DataSize-1) & 0x7) ^ 0x7;
-
+  current_time=time((time_t *) NULL);
+  t=localtime(&current_time);
   (void) memset(MATLAB_HDR,' ',MagickMin(sizeof(MATLAB_HDR),124));
-  FormatMagickString(MATLAB_HDR,MaxTextExtent,"MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
+  (void) FormatMagickString(MATLAB_HDR,MaxTextExtent,"MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
     OsDesc,
     DayOfWTab[t->tm_wday],
     MonthsTab[t->tm_mon],
@@ -915,56 +920,76 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   MATLAB_HDR[0x7D]=1;
   MATLAB_HDR[0x7E]='I';
   MATLAB_HDR[0x7F]='M';
-  MATLAB_HDR[0x80]=0xE;
-  MATLAB_HDR[0x81]=0;  MATLAB_HDR[0x82]=0;   MATLAB_HDR[0x83]=0;
   (void) WriteBlob(image,sizeof(MATLAB_HDR),(unsigned char *) MATLAB_HDR);
-
-  (void) WriteBlobLSBLong(image, DataSize + 56l + padding); /* 0x84 */
-  (void) WriteBlobLSBLong(image, 0x6); /* 0x88 */
-  (void) WriteBlobLSBLong(image, 0x8); /* 0x8C */
-  (void) WriteBlobLSBLong(image, 0x6); /* 0x90 */  
-  (void) WriteBlobLSBLong(image, 0);   
-  (void) WriteBlobLSBLong(image, 0x5); /* 0x98 */
-  (void) WriteBlobLSBLong(image, is_gray?0x8:0xC); /* 0x9C - DimFlag */
-  (void) WriteBlobLSBLong(image, image->rows);    /* x: 0xA0 */  
-  (void) WriteBlobLSBLong(image, image->columns); /* y: 0xA4 */  
-  if(!is_gray)
+  scene=0;
+  do
   {
-    (void) WriteBlobLSBLong(image, 3); /* z: 0xA8 */  
-    (void) WriteBlobLSBLong(image, 0);
-  }
-  (void) WriteBlobLSBShort(image, 1);  /* 0xB0 */  
-  (void) WriteBlobLSBShort(image, 1);  /* 0xB2 */
-  (void) WriteBlobLSBLong(image, 'M'); /* 0xB4 */
-  (void) WriteBlobLSBLong(image, 0x2); /* 0xB8 */  
-  (void) WriteBlobLSBLong(image, DataSize); /* 0xBC */
+    if (image->colorspace != RGBColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
 
-  /*
-    Store image data.
-  */
-  {
-    GetQuantumInfo(image_info,&quantum_info);
+    is_gray = IsGrayImage(image,&image->exception);
+    z = is_gray ? 0U : 3U;
 
+    /*
+      Store MAT header.
+    */
+    DataSize = image->rows /*Y*/ * image->columns /*X*/;
+    if(!is_gray) DataSize *= 3 /*Z*/;
+    padding=(char) (((unsigned char)(DataSize-1) & 0x7) ^ 0x7);
+
+    (void) WriteBlobLSBLong(image, miMATRIX);
+    (void) WriteBlobLSBLong(image, DataSize+padding+(is_gray ? 48l : 56l));
+    (void) WriteBlobLSBLong(image, 0x6); /* 0x88 */
+    (void) WriteBlobLSBLong(image, 0x8); /* 0x8C */
+    (void) WriteBlobLSBLong(image, 0x6); /* 0x90 */  
+    (void) WriteBlobLSBLong(image, 0);   
+    (void) WriteBlobLSBLong(image, 0x5); /* 0x98 */
+    (void) WriteBlobLSBLong(image, (unsigned long) (is_gray ? 0x8 : 0xC)); /* 0x9C - DimFlag */
+    (void) WriteBlobLSBLong(image, image->rows);    /* x: 0xA0 */  
+    (void) WriteBlobLSBLong(image, image->columns); /* y: 0xA4 */  
+    if(!is_gray)
+    {
+      (void) WriteBlobLSBLong(image, 3); /* z: 0xA8 */  
+      (void) WriteBlobLSBLong(image, 0);
+    }
+    (void) WriteBlobLSBShort(image, 1);  /* 0xB0 */  
+    (void) WriteBlobLSBShort(image, 1);  /* 0xB2 */
+    (void) WriteBlobLSBLong(image, 'M'); /* 0xB4 */
+    (void) WriteBlobLSBLong(image, 0x2); /* 0xB8 */  
+    (void) WriteBlobLSBLong(image, DataSize); /* 0xBC */
+
+    /*
+      Store image data.
+    */
+    quantum_info=AcquireQuantumInfo(image_info,image);
+    pixels=GetQuantumPixels(quantum_info);
     do
     {
-      for (y=0; y<(long)image->columns; y++)
+      for (y=0; y < (long)image->columns; y++)
       {
-        q = AcquireImagePixels(image,y,0,1,image->rows,&image->exception);
-        (void) ImportQuantumPixels(image,&quantum_info,z2qtype[z],pixels);
+        p=AcquireImagePixels(image,y,0,1,image->rows,&image->exception);
+        if (p == (const PixelPacket *) NULL)
+          break;
+        (void) ExportQuantumPixels(image,quantum_info,z2qtype[z],pixels);
         (void) WriteBlob(image,image->rows,pixels);
       }    
+      if (!SyncImagePixels(image))
+        break;
     } while(z-- >= 2);
-  }
-
-  while(padding-->0) (void) WriteBlobByte(image,0);
-
-  status=MagickTrue;
-
-  CloseBlob(image);
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-
-  if (logging)
-    (void)LogMagickEvent(CoderEvent,GetMagickModule(),"return MAT");
-  
-  return(status != 0 ? MagickTrue : MagickFalse);
+    while(padding-->0) (void) WriteBlobByte(image,0);
+    quantum_info=DestroyQuantumInfo(quantum_info);
+    if (GetNextImageInList(image) == (Image *) NULL)
+      break;
+    image=SyncNextImageInList(image);
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        status=image->progress_monitor(SaveImagesTag,scene,
+          GetImageListLength(image),image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
+    scene++;
+  } while (image_info->adjoin != MagickFalse);
+  (void) CloseBlob(image);
+  return(MagickTrue);
 }
