@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -50,9 +50,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -80,19 +81,20 @@ static MagickBooleanType
 %
 %  The format of the RegisterMATTEImage method is:
 %
-%      RegisterMATTEImage(void)
+%      unsigned long RegisterMATTEImage(void)
 %
 */
-ModuleExport void RegisterMATTEImage(void)
+ModuleExport unsigned long RegisterMATTEImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MATTE");
-  entry->encoder=(EncoderHandler *) WriteMATTEImage;
+  entry->encoder=(EncodeImageHandler *) WriteMATTEImage;
   entry->description=ConstantString("MATTE format");
   entry->module=ConstantString("MATTE");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -140,11 +142,10 @@ ModuleExport void UnregisterMATTEImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteMATTEImage(const ImageInfo *image_info,
   Image *image)
@@ -168,9 +169,9 @@ static MagickBooleanType WriteMATTEImage(const ImageInfo *image_info,
     *q;
 
   if (image->matte == MagickFalse)
-    ThrowWriterException(CoderError,"ImageDoesNotHaveAMatteChannel");
-  matte_image=
-    CloneImage(image,image->columns,image->rows,MagickTrue,&image->exception);
+    ThrowWriterException(CoderError,"ImageDoesNotHaveAAlphaChannel");
+  matte_image=CloneImage(image,image->columns,image->rows,MagickTrue,
+    &image->exception);
   if (matte_image == (Image *) NULL)
     return(MagickFalse);
   (void) SetImageType(matte_image,TrueColorMatteType);
