@@ -1100,7 +1100,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -1116,7 +1116,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       /*
         Read 8BIM binary metadata.
       */
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       blob=(unsigned char *) AcquireQuantumMemory(length,sizeof(unsigned char));
@@ -1164,7 +1164,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
         name[MaxTextExtent];
 
       (void) FormatMagickString(name,MaxTextExtent,"APP%d",1);
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       blob=(unsigned char *) AcquireQuantumMemory(length,sizeof(unsigned char));
@@ -1190,7 +1190,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
               ThrowReaderException(CoderError,"NoIPTCProfileAvailable");
             }
           profile=CloneStringInfo((StringInfo *) image_info->profile);
-          iptc=AllocateImage((ImageInfo *) NULL);
+          iptc=AcquireImage((ImageInfo *) NULL);
           if (iptc == (Image *) NULL)
             {
               blob=DetachBlob(buff->blob);
@@ -1268,7 +1268,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
   if ((LocaleCompare(image_info->magick,"ICC") == 0) ||
       (LocaleCompare(image_info->magick,"ICM") == 0))
     {
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       blob=(unsigned char *) AcquireQuantumMemory(length,sizeof(unsigned char));
@@ -1298,7 +1298,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       register unsigned char
         *p;
 
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       blob=(unsigned char *) AcquireQuantumMemory(length,sizeof(unsigned char));
@@ -1339,7 +1339,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       p[10]=(unsigned char) (length >> 8);
       p[11]=(unsigned char) (length & 0xff);
       SetStringInfoDatum(profile,GetBlobStreamData(buff));
-      (void) SetImageProfile(image,"iptc",profile);
+      (void) SetImageProfile(image,"8bim",profile);
       profile=DestroyStringInfo(profile);
       blob=DetachBlob(buff->blob);
       blob=(unsigned char *) RelinquishMagickMemory(blob);
@@ -1347,7 +1347,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
     }
   if (LocaleCompare(image_info->magick,"XMP") == 0)
     {
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       blob=(unsigned char *) AcquireQuantumMemory(length,sizeof(unsigned char));
@@ -1372,7 +1372,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       blob=(unsigned char *) RelinquishMagickMemory(blob);
       buff=DestroyImage(buff);
     }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -2230,7 +2230,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         return(status);
       (void) WriteBlob(image,GetStringInfoLength(profile),
         GetStringInfoDatum(profile));
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickTrue);
     }
   if (LocaleCompare(image_info->magick,"iptc") == 0)
@@ -2241,7 +2241,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       unsigned char
         *info;
 
-      profile=GetImageProfile(image,"iptc");
+      profile=GetImageProfile(image,"8bim");
       if (profile == (StringInfo *) NULL)
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -2251,7 +2251,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       if (length == 0)
         ThrowWriterException(CoderError,"NoIPTCProfileAvailable");
       (void) WriteBlob(image,length,info);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickTrue);
     }
   if (LocaleCompare(image_info->magick,"8BIMTEXT") == 0)
@@ -2265,7 +2265,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
       if (status == MagickFalse)
         return(status);
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       AttachBlob(buff->blob,GetStringInfoDatum(profile),
@@ -2273,7 +2273,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       format8BIM(buff,image);
       (void) DetachBlob(buff->blob);
       buff=DestroyImage(buff);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickTrue);
     }
   if (LocaleCompare(image_info->magick,"8BIMWTEXT") == 0)
@@ -2286,7 +2286,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       unsigned char
         *info;
 
-      profile=GetImageProfile(image,"iptc");
+      profile=GetImageProfile(image,"8bim");
       if (profile == (StringInfo *) NULL)
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       info=GetStringInfoDatum(profile);
@@ -2297,14 +2297,14 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
       if (status == MagickFalse)
         return(status);
-      buff=AllocateImage((ImageInfo *) NULL);
+      buff=AcquireImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       AttachBlob(buff->blob,info,length);
       formatIPTC(buff,image);
       (void) DetachBlob(buff->blob);
       buff=DestroyImage(buff);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickTrue);
     }
   if (LocaleCompare(image_info->magick,"IPTCWTEXT") == 0)
@@ -2324,7 +2324,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         return(status);
       (void) WriteBlob(image,GetStringInfoLength(profile),
         GetStringInfoDatum(profile));
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickTrue);
     }
   if ((LocaleCompare(image_info->magick,"ICC") == 0) ||
@@ -2341,7 +2341,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         return(status);
       (void) WriteBlob(image,GetStringInfoLength(profile),
         GetStringInfoDatum(profile));
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickTrue);
     }
   return(MagickFalse);
