@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,9 +52,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -84,7 +85,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -127,7 +128,7 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
@@ -147,11 +148,11 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
     Initialize image colormap.
   */
   image->depth=1;
-  if (AllocateImageColormap(image,2) == MagickFalse)
+  if (AcquireImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   /*
@@ -198,7 +199,7 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -222,23 +223,24 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterMONOImage method is:
 %
-%      RegisterMONOImage(void)
+%      unsigned long RegisterMONOImage(void)
 %
 */
-ModuleExport void RegisterMONOImage(void)
+ModuleExport unsigned long RegisterMONOImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MONO");
-  entry->decoder=(DecoderHandler *) ReadMONOImage;
-  entry->encoder=(EncoderHandler *) WriteMONOImage;
+  entry->decoder=(DecodeImageHandler *) ReadMONOImage;
+  entry->encoder=(EncodeImageHandler *) WriteMONOImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Raw bi-level bitmap");
   entry->module=ConstantString("MONO");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -285,7 +287,7 @@ ModuleExport void UnregisterMONOImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -324,7 +326,7 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   /*
     Convert image to a bi-level image.
@@ -343,11 +345,11 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
       byte>>=1;
       if (image->endian == LSBEndian)
         {
-          if (PixelIntensity(p) < (QuantumRange/2.0))
+          if (PixelIntensity(p) < ((Quantum) QuantumRange/2.0))
             byte|=0x80;
         }
       else
-        if (PixelIntensity(p) >= (QuantumRange/2.0))
+        if (PixelIntensity(p) >= ((Quantum) QuantumRange/2.0))
           byte|=0x80;
       bit++;
       if (bit == 8)
@@ -369,6 +371,6 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
           break;
       }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
