@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/cache.h"
@@ -60,10 +61,11 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -97,7 +99,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsMPC(const unsigned char *magick,const size_t length)
 {
@@ -131,42 +132,11 @@ static MagickBooleanType IsMPC(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
 */
-static inline unsigned long PushLongPixel(const unsigned char **pixels)
-{
-  unsigned long
-    pixel;
-
-  pixel=(unsigned long) (*(*pixels)++ << 24);
-  pixel|=(unsigned long) (*(*pixels)++ << 16);
-  pixel|=(unsigned long) (*(*pixels)++ << 8);
-  pixel|=(unsigned long) (*(*pixels)++);
-  return(pixel);
-}
-
-static inline unsigned short PushShortPixel(const unsigned char **pixels)
-{
-  unsigned short
-    pixel;
-
-  pixel=(unsigned short) (*(*pixels)++ << 8);
-  pixel|=(unsigned short) (*(*pixels)++);
-  return(pixel);
-}
-
-static inline unsigned char PushCharPixel(const unsigned char **pixels)
-{
-  unsigned char
-    pixel;
-
-  pixel=(unsigned char) *(*pixels)++;
-  return(pixel);
-}
-
 static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   char
@@ -225,7 +195,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -251,7 +221,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     profiles=(LinkedListInfo *) NULL;
     length=MaxTextExtent;
     options=AcquireString((char *) NULL);
-    quantum_depth=QuantumDepth;
+    quantum_depth=MAGICKCORE_QUANTUM_DEPTH;
     image->depth=8;
     image->compression=NoCompression;
     while ((isgraph(c) != MagickFalse) && (c != (int) ':'))
@@ -289,7 +259,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (comment == (char *) NULL)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           *p='\0';
-          (void) SetImageProperty(image,"Comment",comment);
+          (void) SetImageProperty(image,"comment",comment);
           comment=DestroyString(comment);
           c=ReadBlobByte(image);
         }
@@ -306,7 +276,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (c == (int) '=')
                 break;
-              if ((size_t) (p-keyword) < (MaxTextExtent/2))
+              if ((size_t) (p-keyword) < MaxTextExtent)
                 *p++=(char) c;
               c=ReadBlobByte(image);
             } while (c != EOF);
@@ -697,7 +667,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (image->compression == UndefinedCompression) || (image->columns == 0) ||
         (image->rows == 0))
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-    if (quantum_depth != QuantumDepth)
+    if (quantum_depth != MAGICKCORE_QUANTUM_DEPTH)
       ThrowReaderException(CacheError,"InconsistentPersistentCacheDepth");
     if (image->montage != (char *) NULL)
       {
@@ -764,7 +734,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Create image colormap.
         */
-        if (AllocateImageColormap(image,image->colors) == MagickFalse)
+        if (AcquireImageColormap(image,image->colors) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         if (image->colors != 0)
           {
@@ -799,11 +769,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushCharPixel(&p);
+                  p=PushCharPixel(p,&pixel);
                   image->colormap[i].red=ScaleCharToQuantum(pixel);
-                  pixel=PushCharPixel(&p);
+                  p=PushCharPixel(p,&pixel);
                   image->colormap[i].green=ScaleCharToQuantum(pixel);
-                  pixel=PushCharPixel(&p);
+                  p=PushCharPixel(p,&pixel);
                   image->colormap[i].blue=ScaleCharToQuantum(pixel);
                 }
                 break;
@@ -815,11 +785,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushShortPixel(&p);
+                  p=PushShortPixel(MSBEndian,p,&pixel);
                   image->colormap[i].red=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(&p);
+                  p=PushShortPixel(MSBEndian,p,&pixel);
                   image->colormap[i].green=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(&p);
+                  p=PushShortPixel(MSBEndian,p,&pixel);
                   image->colormap[i].blue=ScaleShortToQuantum(pixel);
                 }
                 break;
@@ -831,11 +801,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushLongPixel(&p);
+                  p=PushLongPixel(MSBEndian,p,&pixel);
                   image->colormap[i].red=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(&p);
+                  p=PushLongPixel(MSBEndian,p,&pixel);
                   image->colormap[i].green=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(&p);
+                  p=PushLongPixel(MSBEndian,p,&pixel);
                   image->colormap[i].blue=ScaleLongToQuantum(pixel);
                 }
                 break;
@@ -876,7 +846,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -892,7 +862,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
       }
   } while (c != EOF);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -916,10 +886,10 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterMPCImage method is:
 %
-%      RegisterMPCImage(void)
+%      unsigned long RegisterMPCImage(void)
 %
 */
-ModuleExport void RegisterMPCImage(void)
+ModuleExport unsigned long RegisterMPCImage(void)
 {
   MagickInfo
     *entry;
@@ -930,12 +900,13 @@ ModuleExport void RegisterMPCImage(void)
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPC");
-  entry->decoder=(DecoderHandler *) ReadMPCImage;
-  entry->encoder=(EncoderHandler *) WriteMPCImage;
-  entry->magick=(MagickHandler *) IsMPC;
+  entry->decoder=(DecodeImageHandler *) ReadMPCImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPCImage;
+  entry->magick=(IsImageFormatHandler *) IsMPC;
   entry->description=ConstantString("Magick Persistent Cache image format");
   entry->module=ConstantString("MPC");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -982,34 +953,11 @@ ModuleExport void UnregisterMPCImage(void)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
-
-static inline void PopCharPixel(const unsigned char pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static inline void PopShortPixel(const unsigned short pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) ((pixel) >> 8);
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
-static inline void PopLongPixel(const unsigned long pixel,
-  unsigned char **pixels)
-{
-  *(*pixels)++=(unsigned char) ((pixel) >> 24);
-  *(*pixels)++=(unsigned char) ((pixel) >> 16);
-  *(*pixels)++=(unsigned char) ((pixel) >> 8);
-  *(*pixels)++=(unsigned char) (pixel);
-}
-
 static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
 {
   char
@@ -1060,7 +1008,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
       image->storage_class=DirectClass;
     (void) WriteBlobString(image,"id=MagickCache\n");
     (void) FormatMagickString(buffer,MaxTextExtent,"quantum-depth=%d\n",
-      QuantumDepth);
+      MAGICKCORE_QUANTUM_DEPTH);
     (void) WriteBlobString(image,buffer);
     (void) FormatMagickString(buffer,MaxTextExtent,
       "class=%s  colors=%lu  matte=%s\n",MagickOptionToMnemonic(
@@ -1241,26 +1189,24 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
     property=GetNextImageProperty(image);
     while (property != (const char *) NULL)
     {
-      if (*property != '[')
+      (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
+      (void) WriteBlobString(image,buffer);
+      value=GetImageProperty(image,property);
+      if (value != (const char *) NULL)
         {
-          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
-          (void) WriteBlobString(image,buffer);
-          value=GetImageProperty(image,property);
-          if (value != (const char *) NULL)
-            {
-              for (i=0; i < (long) strlen(value); i++)
-                if (isspace((int) ((unsigned char) value[i])) != 0)
-                  break;
-              if (i <= (long) strlen(value))
-                (void) WriteBlobByte(image,'{');
-              (void) WriteBlob(image,strlen(value),(unsigned char *) value);
-              if (i <= (long) strlen(value))
-                (void) WriteBlobByte(image,'}');
-            }
-          (void) WriteBlobByte(image,'\n');
+          for (i=0; i < (long) strlen(value); i++)
+            if (isspace((int) ((unsigned char) value[i])) != 0)
+              break;
+          if (i <= (long) strlen(value))
+            (void) WriteBlobByte(image,'{');
+          (void) WriteBlob(image,strlen(value),(unsigned char *) value);
+          if (i <= (long) strlen(value))
+            (void) WriteBlobByte(image,'}');
         }
+      (void) WriteBlobByte(image,'\n');
       property=GetNextImageProperty(image);
     }
+    ResetImageArtifactIterator(image);
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
       {
@@ -1325,11 +1271,11 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
                 pixel;
 
               pixel=ScaleQuantumToLong(image->colormap[i].red);
-              PopLongPixel(pixel,&q);
+              q=PopLongPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToLong(image->colormap[i].green);
-              PopLongPixel(pixel,&q);
+              q=PopLongPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
-              PopLongPixel(pixel,&q);
+              q=PopLongPixel(MSBEndian,pixel,q);
             }
             case 16:
             {
@@ -1337,11 +1283,11 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
                 pixel;
 
               pixel=ScaleQuantumToShort(image->colormap[i].red);
-              PopShortPixel(pixel,&q);
+              q=PopShortPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToShort(image->colormap[i].green);
-              PopShortPixel(pixel,&q);
+              q=PopShortPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToShort(image->colormap[i].blue);
-              PopShortPixel(pixel,&q);
+              q=PopShortPixel(MSBEndian,pixel,q);
               break;
             }
             case 8:
@@ -1350,12 +1296,12 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
                 pixel;
 
               pixel=(unsigned char) ScaleQuantumToChar(image->colormap[i].red);
-              PopCharPixel(pixel,&q);
+              q=PopCharPixel(pixel,q);
               pixel=(unsigned char) ScaleQuantumToChar(
                 image->colormap[i].green);
-              PopCharPixel(pixel,&q);
+              q=PopCharPixel(pixel,q);
               pixel=(unsigned char) ScaleQuantumToChar(image->colormap[i].blue);
-              PopCharPixel(pixel,&q);
+              q=PopCharPixel(pixel,q);
               break;
             }
           }
@@ -1382,6 +1328,6 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(status);
 }
