@@ -17,7 +17,7 @@
 %                                 July 1999                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,9 +54,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -123,7 +124,7 @@ static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -154,21 +155,21 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   (void) DestroyImageList(image);
   /*
     Convert MPEG to PPM with delegate.
   */
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   read_info=CloneImageInfo(image_info);
-  (void) InvokeDelegate(read_info,image,"mpeg-decode",(char *) NULL,exception);
+  (void) InvokeDelegate(read_info,image,"mpeg:decode",(char *) NULL,exception);
   image=DestroyImage(image);
   /*
     Read PPM files.
@@ -191,7 +192,7 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
         break;
   }
   /*
-    Free resources.
+    Relinquish resources.
   */
   for (i=0; ; i++)
   {
@@ -225,38 +226,39 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterMPEGImage method is:
 %
-%      RegisterMPEGImage(void)
+%      unsigned long RegisterMPEGImage(void)
 %
 */
-ModuleExport void RegisterMPEGImage(void)
+ModuleExport unsigned long RegisterMPEGImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("MPEG");
-  entry->decoder=(DecoderHandler *) ReadMPEGImage;
-  entry->encoder=(EncoderHandler *) WriteMPEGImage;
-  entry->magick=(MagickHandler *) IsMPEG;
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPG");
-  entry->decoder=(DecoderHandler *) ReadMPEGImage;
-  entry->encoder=(EncoderHandler *) WriteMPEGImage;
-  entry->magick=(MagickHandler *) IsMPEG;
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("M2V");
-  entry->decoder=(DecoderHandler *) ReadMPEGImage;
-  entry->encoder=(EncoderHandler *) WriteMPEGImage;
-  entry->magick=(MagickHandler *) IsMPEG;
+  entry->decoder=(DecodeImageHandler *) ReadMPEGImage;
+  entry->encoder=(EncodeImageHandler *) WriteMPEGImage;
+  entry->magick=(IsImageFormatHandler *) IsMPEG;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("MPEG Video Stream");
   entry->module=ConstantString("MPEG");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -306,7 +308,7 @@ ModuleExport void UnregisterMPEGImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -590,7 +592,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   /*
     Determine if the sequence of images have identical page info.
   */
@@ -676,7 +678,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
         case 1:
         {
           blob=(unsigned char *)
-            FileToBlob(previous_image,~0,&length,&image->exception);
+            FileToBlob(previous_image,~0UL,&length,&image->exception);
         }
         default:
         {
@@ -709,11 +711,11 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     Convert YUV to MPEG.
   */
   (void) CopyMagickString(coalesce_image->filename,basename,MaxTextExtent);
-  status=InvokeDelegate(write_info,coalesce_image,(char *) NULL,"mpeg-encode",
+  status=InvokeDelegate(write_info,coalesce_image,(char *) NULL,"mpeg:encode",
     &image->exception);
   write_info=DestroyImageInfo(write_info);
   /*
-    Free resources.
+    Relinquish resources.
   */
   count=0;
   for (p=coalesce_image; p != (Image *) NULL; p=GetNextImageInList(p))
