@@ -68,11 +68,11 @@
 */
 #define PALM_IS_COMPRESSED_FLAG  0x8000
 #define PALM_HAS_COLORMAP_FLAG  0x4000
+#define PALM_HAS_FOUR_BYTE_FIELD  0x0200
 #define PALM_HAS_TRANSPARENCY_FLAG  0x2000
 #define PALM_IS_INDIRECT  0x1000
 #define PALM_IS_FOR_SCREEN  0x0800
 #define PALM_IS_DIRECT_COLOR  0x0400
-
 #define PALM_COMPRESSION_SCANLINE  0x00
 #define PALM_COMPRESSION_RLE  0x01
 #define PALM_COMPRESSION_NONE  0xFF
@@ -179,7 +179,6 @@ static MagickBooleanType
 %
 %    o pixel: a pointer to the PixelPacket to be matched.
 %
-%
 */
 static int FindColor(PixelPacket *pixel)
 {
@@ -306,7 +305,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -318,6 +317,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
   {
     image->columns=ReadBlobMSBShort(image);
     image->rows=ReadBlobMSBShort(image);
+    if (EOFBlob(image) != MagickFalse)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     /*
       Copied from coders/pnm.c. TODO other checks ...
     */
@@ -337,7 +338,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
       Initialize image colormap.
     */
     if ((bits_per_pixel < 16) &&
-        !AllocateImageColormap(image,1L << bits_per_pixel))
+        (AcquireImageColormap(image,1L << bits_per_pixel) == MagickFalse))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     GetMagickPixelPacket(image,&transpix);
     if (bits_per_pixel == 16)  /* Direct Color */
@@ -353,17 +354,21 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
       }
     if (bits_per_pixel == 8)
       {
+        IndexPacket
+          index;
+
         if (flags & PALM_HAS_COLORMAP_FLAG)
           {
             count=(ssize_t) ReadBlobMSBShort(image);
             for (i=0; i < (long) count; i++)
             {
               ReadBlobByte(image);
-              image->colormap[255-i].red=
+              index=ConstrainColormapIndex(image,255-i);
+              image->colormap[(int) index].red=
                 ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
-              image->colormap[255-i].green=
+              image->colormap[(int) index].green=
                 ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
-              image->colormap[255-i].blue=
+              image->colormap[(int) index].blue=
                 ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
           }
         }
@@ -371,9 +376,13 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         {
           for (i=0; i < (long) (1L << bits_per_pixel); i++)
           {
-            image->colormap[255-i].red=ScaleCharToQuantum(PalmPalette[i][0]);
-            image->colormap[255-i].green=ScaleCharToQuantum(PalmPalette[i][1]);
-            image->colormap[255-i].blue=ScaleCharToQuantum(PalmPalette[i][2]);
+            index=ConstrainColormapIndex(image,255-i);
+            image->colormap[(int) index].red=
+              ScaleCharToQuantum(PalmPalette[i][0]);
+            image->colormap[(int) index].green=
+              ScaleCharToQuantum(PalmPalette[i][1]);
+            image->colormap[(int) index].blue=
+              ScaleCharToQuantum(PalmPalette[i][2]);
           }
         }
       }
@@ -523,7 +532,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         /*
           Allocate next image structure. Copied from coders/pnm.c
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             (void) DestroyImageList(image);
@@ -540,7 +549,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
           }*/
       }
   } while (nextDepthOffset != 0);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -620,7 +629,8 @@ ModuleExport void UnregisterPALMImage(void)
 %
 %  The format of the WritePALMImage method is:
 %
-%      MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image)
+%      MagickBooleanType WritePALMImage(const ImageInfo *image_info,
+%        Image *image)
 %
 %  A description of each parameter follows.
 %
@@ -635,9 +645,6 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
   int
     y;
 
-  const char
-    *value;
-
   Image
     *map;
 
@@ -676,10 +683,10 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
     *lastrow,
     *one_row,
     *ptr,
-    version = 0;
+    version;
 
   unsigned int
-    transparentIndex = 0;
+    transparentIndex;
 
   unsigned long
     count,
@@ -689,7 +696,7 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
 
   unsigned short
     color16,
-    flags = 0;
+    flags;
 
 
   /*
@@ -705,19 +712,20 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return(status);
   GetExceptionInfo(&exception);
+  flags=0;
   currentOffset=0;
+  transparentIndex=0;
   transpix.red=0;
   transpix.green=0;
   transpix.blue=0;
   transpix.opacity=0;
+  version=0;
   do
   {
-    value=GetImageProperty(image, "comment");
-    if (value != (const char *) NULL)
-      if (LocaleCompare("COLORMAP",value) == 0)
-        flags|=PALM_HAS_COLORMAP_FLAG;
-    count = GetNumberColors(image, NULL, &exception);
-    for (bits_per_pixel=1;  (1UL << bits_per_pixel) < count;  bits_per_pixel*=2);
+    if (image->colorspace != RGBColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
+    count=GetNumberColors(image,NULL,&exception);
+    for (bits_per_pixel=1;  (1UL << bits_per_pixel) < count;  bits_per_pixel*=2) ;
     if (image_info->depth > 100)
       bits_per_pixel=image_info->depth-100;
     if (bits_per_pixel < 16)
@@ -728,10 +736,14 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
         (void) SetImageType(image,PaletteType);
         (void) SortColormapByIntensity(image);
       }
-    if (bits_per_pixel > 8)
+    if ((image->storage_class == PseudoClass) && (image->colors > 256))
+      (void) SetImageStorageClass(image,DirectClass);
+    if (image->storage_class == PseudoClass)
+      flags|=PALM_HAS_COLORMAP_FLAG;
+    else
       flags|=PALM_IS_DIRECT_COLOR;
     (void) WriteBlobMSBShort(image,(unsigned short) image->columns); /* width */
-    (void) WriteBlobMSBShort(image,(unsigned short) image->rows );  /* height */
+    (void) WriteBlobMSBShort(image,(unsigned short) image->rows);  /* height */
     bytes_per_row=((image->columns+(16/bits_per_pixel-1))/(16/
       bits_per_pixel))*2;
     (void) WriteBlobMSBShort(image,(unsigned short) bytes_per_row);
@@ -946,7 +958,7 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
     offset=SeekBlob(image,currentOffset,SEEK_SET);
     image=SyncNextImageInList(image);
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   (void) DestroyExceptionInfo(&exception);
   return(MagickTrue);
 }
