@@ -94,15 +94,15 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
-%    o luma: The address of a character buffer that contains the
+%    o luma: the address of a character buffer that contains the
 %      luminance information.
 %
-%    o chroma1: The address of a character buffer that contains the
+%    o chroma1: the address of a character buffer that contains the
 %      chrominance information.
 %
-%    o chroma2: The address of a character buffer that contains the
+%    o chroma2: the address of a character buffer that contains the
 %      chrominance information.
 %
 */
@@ -326,7 +326,7 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
     count--;
   }
   /*
-    Free resources.
+    Relinquish resources.
   */
   for (i=0; i < (image->columns > 1536 ? 3 : 1); i++)
     pcd_table[i]=(PCDTable *) RelinquishMagickMemory(pcd_table[i]);
@@ -392,7 +392,7 @@ static MagickBooleanType IsPCD(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -549,7 +549,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -714,7 +714,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Allocate next image structure.
             */
-            AllocateNextImage(image_info,image);
+            AcquireNextImage(image_info,image);
             if (GetNextImageInList(image) == (Image *) NULL)
               {
                 image=DestroyImageList(image);
@@ -830,7 +830,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   if (image_info->ping == MagickFalse)
     if ((rotate == 1) || (rotate == 3))
       {
@@ -960,7 +960,7 @@ ModuleExport void UnregisterPCDImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -1037,7 +1037,7 @@ static MagickBooleanType WritePCDTile(const ImageInfo *image_info,Image *image,
       tile_image=bordered_image;
     }
   (void) TransformImage(&tile_image,(char *) NULL,tile_geometry);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(tile_image,YCCColorspace);
   downsample_image=ResizeImage(tile_image,tile_image->columns/2,
     tile_image->rows/2,TriangleFilter,1.0,&image->exception);
@@ -1128,7 +1128,7 @@ static MagickBooleanType WritePCDImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,pcd_image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(pcd_image,RGBColorspace);
   /*
     Write PCD image header.
@@ -1169,7 +1169,7 @@ static MagickBooleanType WritePCDImage(const ImageInfo *image_info,Image *image)
   status=WritePCDTile(image_info,pcd_image,"768x512>","192x128");
   status=WritePCDTile(image_info,pcd_image,"768x512>","384x256");
   status=WritePCDTile(image_info,pcd_image,"768x512>","768x512");
-  CloseBlob(pcd_image);
+  (void) CloseBlob(pcd_image);
   if (pcd_image != image)
     pcd_image=DestroyImage(pcd_image);
   return(status);
