@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,9 +53,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declarations.
@@ -189,7 +190,7 @@ static MagickBooleanType IsPCX(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -277,7 +278,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -344,7 +345,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image->columns == 0) || (image->rows == 0) ||
         (pcx_info.bits_per_pixel == 0))
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-    image->depth=pcx_info.bits_per_pixel <= 8 ? 8U : QuantumDepth;
+    image->depth=pcx_info.bits_per_pixel <= 8 ? 8U : MAGICKCORE_QUANTUM_DEPTH;
     image->units=PixelsPerInchResolution;
     image->x_resolution=(double) pcx_info.horizontal_resolution;
     image->y_resolution=(double) pcx_info.vertical_resolution;
@@ -361,7 +362,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
         image->colors=(unsigned long) MagickMin(1UL << (1UL*
           pcx_info.bits_per_pixel*pcx_info.planes),256UL);
-    if (AllocateImageColormap(image,image->colors) == MagickFalse)
+    if (AcquireImageColormap(image,image->colors) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((pcx_info.bits_per_pixel >= 8) && (pcx_info.planes != 1))
       image->storage_class=DirectClass;
@@ -452,9 +453,9 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
               image->colormap[0].red=(Quantum) 0;
               image->colormap[0].green=(Quantum) 0;
               image->colormap[0].blue=(Quantum) 0;
-              image->colormap[1].red=QuantumRange;
-              image->colormap[1].green=QuantumRange;
-              image->colormap[1].blue=QuantumRange;
+              image->colormap[1].red=(Quantum) QuantumRange;
+              image->colormap[1].green=(Quantum) QuantumRange;
+              image->colormap[1].blue=(Quantum) QuantumRange;
             }
           else
             if (image->colors > 16)
@@ -659,7 +660,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -677,7 +678,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   }
   if (page_table != (MagickOffsetType *) NULL)
     page_table=(MagickOffsetType *) RelinquishMagickMemory(page_table);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -701,31 +702,32 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPCXImage method is:
 %
-%      RegisterPCXImage(void)
+%      unsigned long RegisterPCXImage(void)
 %
 */
-ModuleExport void RegisterPCXImage(void)
+ModuleExport unsigned long RegisterPCXImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("DCX");
-  entry->decoder=(DecoderHandler *) ReadPCXImage;
-  entry->encoder=(EncoderHandler *) WritePCXImage;
+  entry->decoder=(DecodeImageHandler *) ReadPCXImage;
+  entry->encoder=(EncodeImageHandler *) WritePCXImage;
   entry->seekable_stream=MagickTrue;
-  entry->magick=(MagickHandler *) IsDCX;
+  entry->magick=(IsImageFormatHandler *) IsDCX;
   entry->description=ConstantString("ZSoft IBM PC multi-page Paintbrush");
   entry->module=ConstantString("PCX");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PCX");
-  entry->decoder=(DecoderHandler *) ReadPCXImage;
-  entry->encoder=(EncoderHandler *) WritePCXImage;
-  entry->magick=(MagickHandler *) IsPCX;
+  entry->decoder=(DecodeImageHandler *) ReadPCXImage;
+  entry->encoder=(EncodeImageHandler *) WritePCXImage;
+  entry->magick=(IsImageFormatHandler *) IsPCX;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("ZSoft IBM PC Paintbrush");
   entry->module=ConstantString("PCX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -773,7 +775,7 @@ ModuleExport void UnregisterPCXImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -876,7 +878,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   page_table=(MagickOffsetType *) NULL;
   if ((LocaleCompare(image_info->magick,"DCX") == 0) ||
@@ -940,8 +942,8 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         if (image->matte != MagickFalse)
           pcx_info.planes++;
       }
-    pcx_info.bytes_per_line=(unsigned short)
-      (((unsigned long) image->columns*pcx_info.bits_per_pixel+7)/8);
+    pcx_info.bytes_per_line=(unsigned short) (((unsigned long) image->columns*
+      pcx_info.bits_per_pixel+7)/8);
     pcx_info.palette_info=1;
     pcx_info.colormap_signature=0x0c;
     /*
@@ -1058,71 +1060,17 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         }
       }
     else
-      if (pcx_info.bits_per_pixel > 1)
-        for (y=0; y < (long) image->rows; y++)
-        {
-          p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
-          if (p == (const PixelPacket *) NULL)
-            break;
-          indexes=GetIndexes(image);
-          q=pcx_pixels;
-          for (x=0; x < (long) image->columns; x++)
-            *q++=(unsigned char) indexes[x];
-          if (PCXWritePixels(&pcx_info,pcx_pixels,image) == MagickFalse)
-            break;
-          if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
-        }
-      else
-        {
-          IndexPacket
-            polarity;
-
-          register unsigned char
-            bit,
-            byte;
-
-          /*
-            Convert PseudoClass image to a PCX monochrome image.
-          */
-          polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-            (QuantumRange/2) ? 1 : 0);
-          if (image->colors == 2)
-            polarity=(IndexPacket) (
-              PixelIntensityToQuantum(&image->colormap[0]) <
-              PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
+      {
+        if (pcx_info.bits_per_pixel > 1)
           for (y=0; y < (long) image->rows; y++)
           {
             p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
             if (p == (const PixelPacket *) NULL)
               break;
             indexes=GetIndexes(image);
-            bit=0;
-            byte=0;
             q=pcx_pixels;
             for (x=0; x < (long) image->columns; x++)
-            {
-              byte<<=1;
-              if (indexes[x] == polarity)
-                byte|=0x01;
-              bit++;
-              if (bit == 8)
-                {
-                  *q++=byte;
-                  bit=0;
-                  byte=0;
-                }
-              p++;
-            }
-            if (bit != 0)
-              *q++=byte << (8-bit);
+              *q++=(unsigned char) indexes[x];
             if (PCXWritePixels(&pcx_info,pcx_pixels,image) == MagickFalse)
               break;
             if (image->previous == (Image *) NULL)
@@ -1135,9 +1083,66 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
                     break;
                 }
           }
-        }
-    (void) WriteBlobByte(image,pcx_info.colormap_signature);
-    (void) WriteBlob(image,3*256,pcx_colormap);
+        else
+          {
+            IndexPacket
+              polarity;
+
+            register unsigned char
+              bit,
+              byte;
+
+            /*
+              Convert PseudoClass image to a PCX monochrome image.
+            */
+            polarity=(IndexPacket) (PixelIntensityToQuantum(
+              &image->colormap[0]) < ((Quantum) QuantumRange/2) ? 1 : 0);
+            if (image->colors == 2)
+              polarity=(IndexPacket) (
+                PixelIntensityToQuantum(&image->colormap[0]) <
+                PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
+            for (y=0; y < (long) image->rows; y++)
+            {
+              p=AcquireImagePixels(image,0,y,image->columns,1,
+                &image->exception);
+              if (p == (const PixelPacket *) NULL)
+                break;
+              indexes=GetIndexes(image);
+              bit=0;
+              byte=0;
+              q=pcx_pixels;
+              for (x=0; x < (long) image->columns; x++)
+              {
+                byte<<=1;
+                if (indexes[x] == polarity)
+                  byte|=0x01;
+                bit++;
+                if (bit == 8)
+                  {
+                    *q++=byte;
+                    bit=0;
+                    byte=0;
+                  }
+                p++;
+              }
+              if (bit != 0)
+                *q++=byte << (8-bit);
+              if (PCXWritePixels(&pcx_info,pcx_pixels,image) == MagickFalse)
+                break;
+              if (image->previous == (Image *) NULL)
+                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                    (QuantumTick(y,image->rows) != MagickFalse))
+                  {
+                    status=image->progress_monitor(SaveImageTag,y,image->rows,
+                      image->client_data);
+                    if (status == MagickFalse)
+                      break;
+                  }
+            }
+          }
+        (void) WriteBlobByte(image,pcx_info.colormap_signature);
+        (void) WriteBlob(image,3*256,pcx_colormap);
+      }
     pcx_pixels=(unsigned char *) RelinquishMagickMemory(pcx_pixels);
     pcx_colormap=(unsigned char *) RelinquishMagickMemory(pcx_colormap);
     if (GetNextImageInList(image) == (Image *) NULL)
@@ -1166,8 +1171,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
       (void) WriteBlobLSBLong(image,0x3ADE68B1L);
       for (i=0; i <= (long) scene; i++)
         (void) WriteBlobLSBLong(image,(unsigned long) page_table[i]);
-      page_table=(MagickOffsetType *)
-        RelinquishMagickMemory(page_table);
+      page_table=(MagickOffsetType *) RelinquishMagickMemory(page_table);
     }
   if (status == MagickFalse)
     {
@@ -1179,6 +1183,6 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         FileOpenError,"UnableToWriteFile","`%s': %s",image->filename,message);
       message=DestroyString(message);
     }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
