@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -34,6 +34,13 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %
+    20071202 TS * rewrote RLE decoder - old version could cause buffer overflows
+                * failure of RLE decoding now thows error RLEDecoderError
+                * fixed bug in RLE decoding - now all rows are decoded, not just
+		  the first one
+		* fixed bug in reader - record offsets now handled correctly
+		* fixed bug in reader - only bits 0..2 indicate compression type
+                * in writer: now using image color count instead of depth
 */
 
 /*
@@ -54,10 +61,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declarations.
@@ -142,45 +150,48 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
 %    o pixels:  The address of a byte (8 bits) array of pixel data created by
 %      the decoding process.
 %
+%    o length:  Number of bytes to read into buffer 'pixels'.
 %
 */
-static MagickBooleanType DecodeImage(Image *image,unsigned char *pixels,
+static MagickBooleanType DecodeImage(Image *image, unsigned char *pixels,
   const size_t length)
 {
-  long
-    pixel;
+#define RLE_MODE_NONE -1
+#define RLE_MODE_COPY  0
+#define RLE_MODE_RUN   1
 
-  register long
-    i;
+	int           data = 0, count = 0;
+	unsigned char *p;
+	int           mode = RLE_MODE_NONE;
 
-  register unsigned char
-    *p;
+	for (p = pixels; p < pixels + length; p++) {
+		if (0 == count) {
+			data = ReadBlobByte( image );
+			if (-1 == data) return MagickFalse;
+			if (data > 128) {
+				mode  = RLE_MODE_RUN;
+				count = data - 128 + 1;
+				data  = ReadBlobByte( image );
+				if (-1 == data) return MagickFalse;
+			} else {
+				mode  = RLE_MODE_COPY;
+				count = data + 1;
+			}
+		}
 
-  ssize_t
-    count;
-
-  p=pixels;
-  while (p < (pixels+length))
-  {
-    pixel=ReadBlobByte(image);
-    if (pixel <= 0x80)
-      {
-        count=(ssize_t) (pixel+1);
-        for (i=0; i < (long) count; i++)
-          *p++=(unsigned char) ReadBlobByte(image);
-        continue;
-      }
-    count=(ssize_t) (pixel+1-0x80);
-    pixel=ReadBlobByte(image);
-    for (i=0; i < (long) count; i++)
-      *p++=(unsigned char) pixel;
-  }
-  return(MagickTrue);
+		if (RLE_MODE_COPY == mode) {
+			data = ReadBlobByte( image );
+			if (-1 == data) return MagickFalse;
+		}
+		*p = (unsigned char)data;
+		--count;
+	}
+	return MagickTrue;
 }
 
 /*
@@ -208,7 +219,6 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *pixels,
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsPDB(const unsigned char *magick,const size_t length)
 {
@@ -240,16 +250,15 @@ static MagickBooleanType IsPDB(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  char
-    record_type,
+  unsigned char
+    attributes, /* TS */
     tag[3];
 
   Image
@@ -259,7 +268,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     index;
 
   long
-    offset,
+    img_offset, /* TS */
+    comment_offset = 0,
     y;
 
   MagickBooleanType
@@ -290,6 +300,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *pixels;
 
   unsigned long
+    num_pad_bytes, /* TS */
     bits_per_pixel,
     packets;
 
@@ -303,7 +314,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -335,31 +346,23 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read record header.
   */
-  offset=(long) ReadBlobMSBLong(image);
+  img_offset=(long) ReadBlobMSBLong(image); /* TS */
+  attributes=(unsigned char) ReadBlobByte(image);
   count=ReadBlob(image,3,(unsigned char *) tag);
-  record_type=ReadBlobByte(image);
-  if (((record_type != 0x00) && (record_type != 0x01)) ||
-      (memcmp(tag,"\x40\x6f\x80",3) != 0))
+  if (count != 3  ||  memcmp(tag,"\x6f\x80\x00",3) != 0)
     ThrowReaderException(CorruptImageError,"CorruptImage");
-  if ((offset-TellBlob(image)) == 6)
-    {
-      (void) ReadBlobByte(image);
-      (void) ReadBlobByte(image);
-    }
+
   if (pdb_info.number_records > 1)
     {
-      offset=(long) ReadBlobMSBLong(image);
+      comment_offset=(long) ReadBlobMSBLong(image);
+      attributes=(unsigned char) ReadBlobByte(image);
       count=ReadBlob(image,3,(unsigned char *) tag);
-      record_type=ReadBlobByte(image);
-      if (((record_type != 0x00) && (record_type != 0x01)) ||
-          (memcmp(tag,"\x40\x6f\x80",3) != 0))
+      if (count != 3  ||  memcmp(tag,"\x6f\x80\x01",3) != 0)
         ThrowReaderException(CorruptImageError,"CorruptImage");
-      if ((offset-TellBlob(image)) == 6)
-        {
-          (void) ReadBlobByte(image);
-          (void) ReadBlobByte(image);
-        }
     }
+
+  num_pad_bytes = (unsigned long) (img_offset - TellBlob( image ));
+  while (num_pad_bytes--) ReadBlobByte( image );
   /*
     Read image header.
   */
@@ -383,11 +386,11 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->depth=8;
   image->storage_class=PseudoClass;
   bits_per_pixel=pdb_image.type == 0 ? 2UL : pdb_image.type == 2 ? 4UL : 1UL;
-  if (AllocateImageColormap(image,1 << bits_per_pixel) == MagickFalse)
+  if (AcquireImageColormap(image,1 << bits_per_pixel) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   if (SetImageExtent(image,0,0) == MagickFalse)
@@ -400,23 +403,25 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  switch (pdb_image.version)
+
+  switch (pdb_image.version & 7) /* TS */
   {
     case 0:
     {
       image->compression=NoCompression;
-      count=(ssize_t) ReadBlob(image,packets,pixels);
+      count=(ssize_t) ReadBlob(image, packets * image -> rows, pixels);
       break;
     }
     case 1:
     {
       image->compression=RLECompression;
-      (void) DecodeImage(image,pixels,packets);
+      if (!DecodeImage(image, pixels, packets * image -> rows))
+      	ThrowReaderException( CorruptImageError, "RLEDecoderError" ); /* TS */
       break;
     }
     default:
       ThrowReaderException(CorruptImageError,
-        "UnrecognizedImageCompressionType");
+			   "UnrecognizedImageCompressionType" );
   }
   p=pixels;
   switch (bits_per_pixel)
@@ -535,11 +540,12 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     default:
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   }
+
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  if ((offset-TellBlob(image)) == 0)
+  if (pdb_info.number_records > 1) /* TS */
     {
       char
         *comment;
@@ -553,6 +559,9 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       unsigned long
         length;
 
+      num_pad_bytes = (unsigned long) (comment_offset - TellBlob( image ));
+      while (num_pad_bytes--) ReadBlobByte( image );
+
       /*
         Read comment.
       */
@@ -578,10 +587,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       *p='\0';
       if (comment == (char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      (void) SetImageProperty(image,"Comment",comment);
+      (void) SetImageProperty(image,"comment",comment);
       comment=DestroyString(comment);
     }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -605,21 +614,22 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterPDBImage method is:
 %
-%      RegisterPDBImage(void)
+%      unsigned long RegisterPDBImage(void)
 %
 */
-ModuleExport void RegisterPDBImage(void)
+ModuleExport unsigned long RegisterPDBImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PDB");
-  entry->decoder=(DecoderHandler *) ReadPDBImage;
-  entry->encoder=(EncoderHandler *) WritePDBImage;
-  entry->magick=(MagickHandler *) IsPDB;
+  entry->decoder=(DecodeImageHandler *) ReadPDBImage;
+  entry->encoder=(EncodeImageHandler *) WritePDBImage;
+  entry->magick=(IsImageFormatHandler *) IsPDB;
   entry->description=ConstantString("Palm Database ImageViewer Format");
   entry->module=ConstantString("PDB");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -665,7 +675,7 @@ ModuleExport void UnregisterPDBImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -745,13 +755,19 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
-  bits_per_pixel=image->depth;
-  if (GetImageType(image,&image->exception) == BilevelType)
-    bits_per_pixel=1;
-  if ((bits_per_pixel != 1) && (bits_per_pixel != 2))
-    bits_per_pixel=4;
+
+  if (image -> colors <= 2  ||  GetImageType( image, &image -> exception ) == BilevelType) { /* TS */
+    bits_per_pixel = 1;
+  } else if (image -> colors <= 4) {
+    bits_per_pixel = 2;
+  } else if (image -> colors <= 8) {
+    bits_per_pixel = 3;
+  } else {
+    bits_per_pixel = 4;
+  }
+
   (void) ResetMagickMemory(pdb_info.name,0,32);
   (void) CopyMagickString(pdb_info.name,image_info->filename,32);
   pdb_info.attributes=0;
@@ -766,7 +782,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   (void) CopyMagickMemory(pdb_info.id,"View",4);
   pdb_info.seed=0;
   pdb_info.next_record=0;
-  comment=GetImageProperty(image,"Comment");
+  comment=GetImageProperty(image,"comment");
   pdb_info.number_records=(comment == (const char *) NULL ? 1 : 2);
   (void) WriteBlob(image,32,(unsigned char *) pdb_info.name);
   (void) WriteBlobMSBShort(image,(unsigned short) pdb_info.attributes);
@@ -814,7 +830,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   /*
     Convert to GRAY raster scanline.
@@ -830,7 +846,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,scanline);
+    (void) ExportQuantumPixels(image,&quantum_info,GrayQuantum,scanline);
     for (x=0; x < pdb_image.width; x++)
     {
       if (x < (long) image->columns)
@@ -930,6 +946,6 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   runlength=(unsigned char *) RelinquishMagickMemory(runlength);
   if (pdb_info.number_records > 1)
     (void) WriteBlobString(image,comment);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
