@@ -48,6 +48,7 @@
 #include "magick/compress.h"
 #include "magick/constitute.h"
 #include "magick/delegate.h"
+#include "magick/delegate-private.h"
 #include "magick/draw.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -106,7 +107,7 @@ static MagickBooleanType
 %    o verbose: A value other than zero displays the command prior to
 %      executing it.
 %
-%    o command: The address of a character string containing the command to
+%    o command: the address of a character string containing the command to
 %      execute.
 %
 */
@@ -138,11 +139,16 @@ static MagickBooleanType InvokePostscriptDelegate(
     gs_func_struct;
 
   gs_func=(&gs_func_struct);
+  (void) ResetMagickMemory(&gs_func,0,sizeof(gs_func));
+  gs_func_struct.new_instance=(int (*)(gs_main_instance **,void *))
+    gsapi_new_instance;
+  gs_func_struct.init_with_args=(int (*)(gs_main_instance *,int,char **))
+    gsapi_init_with_args;
+  gs_func_struct.run_string=(int (*)(gs_main_instance *,const char *,int,int *))
+    gsapi_run_string;
+  gs_func_struct.delete_instance=(void (*)(gs_main_instance *))
+    gsapi_delete_instance;
   gs_func_struct.exit=(int (*)(gs_main_instance *)) gsapi_exit;
-  gs_func_struct.init_with_args=(int (*)(gs_main_instance *,int,char **)) gsapi_init_with_args;
-  gs_func_struct.new_instance=(int (*)(gs_main_instance **,void *)) gsapi_new_instance;
-  gs_func_struct.run_string=(int (*)(gs_main_instance *,const char *,int,int *)) gsapi_run_string;
-  gs_func_struct.delete_instance=(void (*)(gs_main_instance *)) gsapi_delete_instance;
 #endif
   if (gs_func == (GhostscriptVectors *) NULL)
     return(SystemCommand(verbose,command) == 0 ? MagickFalse : MagickTrue);
@@ -167,12 +173,10 @@ static MagickBooleanType InvokePostscriptDelegate(
   for (i=0; i < (long) argc; i++)
     argv[i]=DestroyString(argv[i]);
   argv=(char **) RelinquishMagickMemory(argv);
-  if ((status == 0) || (status <= -100))
-    {
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-        "Ghostscript returns status %d, exit code %d",status,code);
-      return(SystemCommand(verbose,command) != 0 ? MagickTrue : MagickFalse);
-    }
+  if ((status == 0) || (status == -101))
+    return(MagickFalse);
+  (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+    "Ghostscript returns status %d, exit code %d",status,code);
   return(MagickTrue);
 #else
   return(SystemCommand(verbose,command) != 0 ? MagickTrue : MagickFalse);
@@ -235,7 +239,7 @@ static MagickBooleanType IsPDF(const unsigned char *magick,const size_t offset)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -245,7 +249,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define CropBox  "CropBox"
 #define DeviceCMYK  "DeviceCMYK"
 #define MediaBox  "MediaBox"
-#define RenderPostscriptText  "  Rendering Postscript...  "
+#define RenderPostscriptText  "Rendering Postscript...  "
+#define PDFRotate  "Rotate"
 #define SpotColor  "Separation"
 #define TrimBox  "TrimBox"
 #define PDFVersion  "PDF-"
@@ -265,6 +270,9 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   const DelegateInfo
     *delegate_info;
 
+  double
+    angle;
+
   Image
     *image,
     *next_image,
@@ -316,7 +324,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Open image file.
   */
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -355,7 +363,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine page geometry from the PDF media box.
   */
-  cmyk=image_info->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
+  cmyk=image->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
   cropbox=MagickFalse;
   option=GetImageOption(image_info,"pdf:use-cropbox");
   if (option != (const char *) NULL)
@@ -373,6 +381,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ResetMagickMemory(command,0,sizeof(command));
   hires_bounds.x2=0.0;
   hires_bounds.y2=0.0;
+  angle=0.0;
   p=command;
   for (c=ReadBlobByte(image); c != EOF; c=ReadBlobByte(image))
   {
@@ -387,6 +396,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       continue;
     *(--p)='\0';
     p=command;
+    if (LocaleNCompare(PDFRotate,command,strlen(PDFRotate)) == 0)
+      count=(ssize_t) sscanf(command,"Rotate %lf",&angle);
     /*
       Is this a CMYK document?
     */
@@ -481,8 +492,17 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         hires_bounds=bounds;
       }
   }
-  CloseBlob(image);
-  if (image_info->colorspace == RGBColorspace)
+  (void) CloseBlob(image);
+  if ((fabs(angle) == 90.0) || (fabs(angle) == 270.0))
+    {
+      unsigned long
+        swap;
+
+      swap=page.width;
+      page.width=page.height;
+      page.height=swap;
+    }
+  if (image->colorspace == RGBColorspace)
     cmyk=MagickFalse;
   /*
     Create Ghostscript control file.
@@ -539,13 +559,9 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       char
         pages[MaxTextExtent];
 
-      if (read_info->number_scenes != 1)
-        (void) FormatMagickString(pages,MaxTextExtent,"-dLastPage=%lu",
-          read_info->scene+read_info->number_scenes);
-      else
-        (void) FormatMagickString(pages,MaxTextExtent,"-dFirstPage=%lu "
-          "-dLastPage=%lu",read_info->scene+1,read_info->scene+
-          read_info->number_scenes);
+      (void) FormatMagickString(pages,MaxTextExtent,"-dFirstPage=%lu "
+        "-dLastPage=%lu",read_info->scene+1,read_info->scene+
+        read_info->number_scenes);
       (void) ConcatenateMagickString(options,pages,MaxTextExtent);
       read_info->number_scenes=0;
       if (read_info->scenes != (char *) NULL)
@@ -587,6 +603,24 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           pdf_image=cmyk_image;
         }
     }
+  if (image_info->number_scenes != 0)
+    {
+      Image
+        *clone_image;
+
+      register long
+        i;
+
+      /*
+        Add place holder images to meet the subimage specification requirement.
+      */
+      for (i=0; i < (long) image_info->scene; i++)
+      {
+        clone_image=CloneImage(pdf_image,1,1,MagickTrue,exception);
+        if (clone_image != (Image *) NULL)
+          PrependImageToList(&pdf_image,clone_image);
+      }
+    }
   scene=0;
   do
   {
@@ -661,6 +695,16 @@ ModuleExport unsigned long RegisterPDFImage(void)
   entry->description=ConstantString("Portable Document Format");
   entry->module=ConstantString("PDF");
   (void) RegisterMagickInfo(entry);
+  entry=SetMagickInfo("PDFA");
+  entry->decoder=(DecodeImageHandler *) ReadPDFImage;
+  entry->encoder=(EncodeImageHandler *) WritePDFImage;
+  entry->magick=(IsImageFormatHandler *) IsPDF;
+  entry->blob_support=MagickFalse;
+  entry->seekable_stream=MagickTrue;
+  entry->thread_support=EncoderThreadSupport;
+  entry->description=ConstantString("Portable Document Archive Format");
+  entry->module=ConstantString("PDF");
+  (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
 
@@ -688,6 +732,7 @@ ModuleExport void UnregisterPDFImage(void)
   (void) UnregisterMagickInfo("AI");
   (void) UnregisterMagickInfo("EPDF");
   (void) UnregisterMagickInfo("PDF");
+  (void) UnregisterMagickInfo("PDFA");
 }
 
 /*
@@ -710,7 +755,7 @@ ModuleExport void UnregisterPDFImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -764,6 +809,43 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
 #define CFormat  "/Filter [ /%s ]\n"
 #define ObjectsPerImage  14
 
+  static const char
+    XMPProfile[]=
+    {
+      "<?xpacket begin=\"%s\" id=\"W5M0MpCehiHzreSzNTczkc9d\"?>\n"
+      "<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"Adobe XMP Core 4.0-c316 44.253921, Sun Oct 01 2006 17:08:23\">\n"
+      "   <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n"
+      "      <rdf:Description rdf:about=\"\"\n"
+      "            xmlns:xap=\"http://ns.adobe.com/xap/1.0/\">\n"
+      "         <xap:ModifyDate>%s</xap:ModifyDate>\n"
+      "         <xap:CreateDate>%s</xap:CreateDate>\n"
+      "         <xap:MetadataDate>%s</xap:MetadataDate>\n"
+      "         <xap:CreatorTool>%s</xap:CreatorTool>\n"
+      "      </rdf:Description>\n"
+      "      <rdf:Description rdf:about=\"\"\n"
+      "            xmlns:dc=\"http://purl.org/dc/elements/1.1/\">\n"
+      "         <dc:format>application/pdf</dc:format>\n"
+      "      </rdf:Description>\n"
+      "      <rdf:Description rdf:about=\"\"\n"
+      "            xmlns:xapMM=\"http://ns.adobe.com/xap/1.0/mm/\">\n"
+      "         <xapMM:DocumentID>uuid:6ec119d7-7982-4f56-808d-dfe64f5b35cf</xapMM:DocumentID>\n"
+      "         <xapMM:InstanceID>uuid:a79b99b4-6235-447f-9f6c-ec18ef7555cb</xapMM:InstanceID>\n"
+      "      </rdf:Description>\n"
+      "      <rdf:Description rdf:about=\"\"\n"
+      "            xmlns:pdf=\"http://ns.adobe.com/pdf/1.3/\">\n"
+      "         <pdf:Producer>%s</pdf:Producer>\n"
+      "      </rdf:Description>\n"
+      "      <rdf:Description rdf:about=\"\"\n"
+      "            xmlns:pdfaid=\"http://www.aiim.org/pdfa/ns/id/\">\n"
+      "         <pdfaid:part>1</pdfaid:part>\n"
+      "         <pdfaid:conformance>B</pdfaid:conformance>\n"
+      "      </rdf:Description>\n"
+      "   </rdf:RDF>\n"
+      "</x:xmpmeta>\n"
+      "<?xpacket end=\"w\"?>\n"
+    },
+    XMPProfileMagick[4]= { (char) 0xef, (char) 0xbb, (char) 0xbf, (char) 0x00 };
+
   char
     buffer[MaxTextExtent],
     date[MaxTextExtent],
@@ -877,30 +959,12 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     else
       if (next->matte != MagickFalse)
         version=(unsigned long) MagickMax(version,4);
+  if (LocaleCompare(image_info->magick,"PDFA") == 0)
+    version=(unsigned long) MagickMax(version,6);
   (void) FormatMagickString(buffer,MaxTextExtent,"%%PDF-1.%lu \n",version);
   (void) WriteBlobString(image,buffer);
-  xref[object++]=TellBlob(image);
-  info_id=object;
-  (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
-  (void) WriteBlobString(image,buffer);
-  (void) WriteBlobString(image,"<<\n");
-  (void) FormatMagickString(buffer,MaxTextExtent,"/Title (%s)\n",
-    EscapeParenthesis(image->filename));
-  (void) WriteBlobString(image,buffer);
-  seconds=time((time_t *) NULL);
-  time_meridian=localtime(&seconds);
-  (void) FormatMagickString(date,MaxTextExtent,"D:%04d%02d%02d%02d%02d%02d",
-    time_meridian->tm_year+1900,time_meridian->tm_mon+1,time_meridian->tm_mday,
-    time_meridian->tm_hour,time_meridian->tm_min,time_meridian->tm_sec);
-  (void) FormatMagickString(buffer,MaxTextExtent,"/CreationDate (%s)\n",date);
-  (void) WriteBlobString(image,buffer);
-  (void) FormatMagickString(buffer,MaxTextExtent,"/ModDate (%s)\n",date);
-  (void) WriteBlobString(image,buffer);
-  (void) FormatMagickString(buffer,MaxTextExtent,"/Producer (%s)\n",
-    EscapeParenthesis(GetMagickVersion((unsigned long *) NULL)));
-  (void) WriteBlobString(image,buffer);
-  (void) WriteBlobString(image,">>\n");
-  (void) WriteBlobString(image,"endobj\n");
+  if (LocaleCompare(image_info->magick,"PDFA") == 0)
+    (void) WriteBlobString(image,"%\n");
   /*
     Write Catalog object.
   */
@@ -909,11 +973,60 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
   (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
   (void) WriteBlobString(image,buffer);
   (void) WriteBlobString(image,"<<\n");
-  (void) WriteBlobString(image,"/Type /Catalog\n");
-  (void) FormatMagickString(buffer,MaxTextExtent,"/Pages %lu 0 R\n",object+1);
+  if (LocaleCompare(image_info->magick,"PDFA") != 0)
+    (void) FormatMagickString(buffer,MaxTextExtent,"/Pages %lu 0 R\n",
+      object+1);
+  else
+    {
+      (void) FormatMagickString(buffer,MaxTextExtent,"/Metadata %lu 0 R\n",
+        object+1);
+      (void) WriteBlobString(image,buffer);
+      (void) FormatMagickString(buffer,MaxTextExtent,"/Pages %lu 0 R\n",
+        object+2);
+    }
   (void) WriteBlobString(image,buffer);
+  (void) WriteBlobString(image,"/Type /Catalog\n");
   (void) WriteBlobString(image,">>\n");
   (void) WriteBlobString(image,"endobj\n");
+  if (LocaleCompare(image_info->magick,"PDFA") == 0)
+    {
+      char
+        create_date[MaxTextExtent],
+        modify_date[MaxTextExtent],
+        timestamp[MaxTextExtent],
+        xmp_profile[MaxTextExtent];
+
+      unsigned long
+        version;
+
+      /*
+        Write XMP object.
+      */
+      xref[object++]=TellBlob(image);
+      (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
+      (void) WriteBlobString(image,buffer);
+      (void) WriteBlobString(image,"<<\n");
+      (void) WriteBlobString(image,"/Subtype /XML\n");
+      *modify_date='\0';
+      value=GetImageProperty(image,"modify-date");
+      if (value != (const char *) NULL)
+        (void) CopyMagickString(modify_date,value,MaxTextExtent);
+      *create_date='\0';
+      value=GetImageProperty(image,"create-date");
+      if (value != (const char *) NULL)
+        (void) CopyMagickString(create_date,value,MaxTextExtent);
+      (void) FormatMagickTime(time((time_t *) NULL),MaxTextExtent,timestamp);
+      i=FormatMagickString(xmp_profile,MaxTextExtent,XMPProfile,
+        XMPProfileMagick,modify_date,create_date,timestamp,
+        GetMagickVersion(&version),GetMagickVersion(&version));
+      (void) FormatMagickString(buffer,MaxTextExtent,"/Length %lu\n",1UL*i);
+      (void) WriteBlobString(image,buffer);
+      (void) WriteBlobString(image,"/Type /Metadata\n");
+      (void) WriteBlobString(image,">>\nstream\n");
+      (void) WriteBlobString(image,xmp_profile);
+      (void) WriteBlobString(image,"endstream\n");
+      (void) WriteBlobString(image,"endobj\n");
+    }
   /*
     Write Pages object.
   */
@@ -955,7 +1068,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
   scene=0;
   do
   {
-    compression=image->compression;
+    compression=image_info->compression;
     switch (compression)
     {
       case FaxCompression:
@@ -971,7 +1084,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       {
         compression=RLECompression;
         (void) ThrowMagickException(&image->exception,GetMagickModule(),
-          MissingDelegateError,"JPEGLibraryIsNotAvailable","`%s'",
+          MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (JPEG)",
           image->filename);
         break;
       }
@@ -981,7 +1094,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       {
         compression=RLECompression;
         (void) ThrowMagickException(&image->exception,GetMagickModule(),
-          MissingDelegateError,"JP2LibraryIsNotAvailable","`%s'",image->filename);
+          MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (JP2)",
+          image->filename);
         break;
       }
 #endif
@@ -990,17 +1104,29 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       {
         compression=RLECompression;
         (void) ThrowMagickException(&image->exception,GetMagickModule(),
-          MissingDelegateError,"ZipLibraryIsNotAvailable","`%s'",
+          MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (ZLIB)",
           image->filename);
         break;
       }
 #endif
+      case LZWCompression:
+      {
+        if (LocaleCompare(image_info->magick,"PDFA") == 0)
+          compression=RLECompression;  /* LZW compression is forbidden */
+        break;
+      }
+      case NoCompression:
+      {
+        if (LocaleCompare(image_info->magick,"PDFA") == 0)
+          compression=RLECompression; /* ASCII 85 compression is forbidden */
+        break;
+      }
       default:
         break;
     }
     if (compression == JPEG2000Compression)
       {
-        if (image_info->colorspace == UndefinedColorspace)
+        if (image->colorspace != RGBColorspace)
           (void) SetImageColorspace(image,RGBColorspace);
       }
     /*
@@ -1076,9 +1202,16 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       pages_id);
     (void) WriteBlobString(image,buffer);
     (void) WriteBlobString(image,"/Resources <<\n");
-    (void) FormatMagickString(buffer,MaxTextExtent,
-      "/Font << /F%lu %lu 0 R >>\n",image->scene,object+4);
-    (void) WriteBlobString(image,buffer);
+    labels=(char **) NULL;
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      labels=StringToList(value);
+    if (labels != (char **) NULL)
+      {
+        (void) FormatMagickString(buffer,MaxTextExtent,
+          "/Font << /F%lu %lu 0 R >>\n",image->scene,object+4);
+        (void) WriteBlobString(image,buffer);
+      }
     (void) FormatMagickString(buffer,MaxTextExtent,
       "/XObject << /Im%lu %lu 0 R >>\n",image->scene,object+5);
     (void) WriteBlobString(image,buffer);
@@ -1114,28 +1247,20 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobString(image,"stream\n");
     offset=TellBlob(image);
     (void) WriteBlobString(image,"q\n");
-    labels=(char **) NULL;
-    value=GetImageProperty(image,"Label");
-    if (value != (const char *) NULL)
-      labels=StringToList(value);
     if (labels != (char **) NULL)
+      for (i=0; labels[i] != (char *) NULL; i++)
       {
-        for (i=0; labels[i] != (char *) NULL; i++)
-        {
-          (void) WriteBlobString(image,"BT\n");
-          (void) FormatMagickString(buffer,MaxTextExtent,"/F%lu %g Tf\n",
-            image->scene,pointsize);
-          (void) WriteBlobString(image,buffer);
-          (void) FormatMagickString(buffer,MaxTextExtent,"%ld %ld Td\n",
-            geometry.x,(long) (geometry.y+geometry.height+i*pointsize+12));
-          (void) WriteBlobString(image,buffer);
-          (void) FormatMagickString(buffer,MaxTextExtent,"(%s) Tj\n",
-            labels[i]);
-          (void) WriteBlobString(image,buffer);
-          (void) WriteBlobString(image,"ET\n");
-          labels[i]=DestroyString(labels[i]);
-        }
-        labels=(char **) RelinquishMagickMemory(labels);
+        (void) WriteBlobString(image,"BT\n");
+        (void) FormatMagickString(buffer,MaxTextExtent,"/F%lu %g Tf\n",
+          image->scene,pointsize);
+        (void) WriteBlobString(image,buffer);
+        (void) FormatMagickString(buffer,MaxTextExtent,"%ld %ld Td\n",
+          geometry.x,(long) (geometry.y+geometry.height+i*pointsize+12));
+        (void) WriteBlobString(image,buffer);
+        (void) FormatMagickString(buffer,MaxTextExtent,"(%s) Tj\n",labels[i]);
+        (void) WriteBlobString(image,buffer);
+        (void) WriteBlobString(image,"ET\n");
+        labels[i]=DestroyString(labels[i]);
       }
     (void) FormatMagickString(buffer,MaxTextExtent,"%g 0 0 %g %ld %ld cm\n",
       scale.x,scale.y,geometry.x,geometry.y);
@@ -1179,13 +1304,17 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
     (void) WriteBlobString(image,buffer);
     (void) WriteBlobString(image,"<<\n");
-    (void) WriteBlobString(image,"/Type /Font\n");
-    (void) WriteBlobString(image,"/Subtype /Type1\n");
-    (void) FormatMagickString(buffer,MaxTextExtent,"/Name /F%lu\n",
-      image->scene);
-    (void) WriteBlobString(image,buffer);
-    (void) WriteBlobString(image,"/BaseFont /Helvetica\n");
-    (void) WriteBlobString(image,"/Encoding /MacRomanEncoding\n");
+    if (labels != (char **) NULL)
+      {
+        (void) WriteBlobString(image,"/Type /Font\n");
+        (void) WriteBlobString(image,"/Subtype /Type1\n");
+        (void) FormatMagickString(buffer,MaxTextExtent,"/Name /F%lu\n",
+          image->scene);
+        (void) WriteBlobString(image,buffer);
+        (void) WriteBlobString(image,"/BaseFont /Helvetica\n");
+        (void) WriteBlobString(image,"/Encoding /MacRomanEncoding\n");
+        labels=(char **) RelinquishMagickMemory(labels);
+      }
     (void) WriteBlobString(image,">>\n");
     (void) WriteBlobString(image,"endobj\n");
     /*
@@ -1271,7 +1400,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     if (image->matte != MagickFalse)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,"/SMask %lu 0 R\n",
-          object+6);
+          object+7);
         (void) WriteBlobString(image,buffer);
       }
     (void) FormatMagickString(buffer,MaxTextExtent,"/Length %lu 0 R\n",
@@ -1362,7 +1491,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             break;
@@ -1474,7 +1603,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             break;
@@ -1569,7 +1698,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               pixels=(unsigned char *) RelinquishMagickMemory(pixels);
               if (status == MagickFalse)
                 {
-                  CloseBlob(image);
+                  (void) CloseBlob(image);
                   return(MagickFalse);
                 }
               break;
@@ -1807,7 +1936,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             break;
@@ -1905,7 +2034,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             break;
@@ -1985,7 +2114,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               pixels=(unsigned char *) RelinquishMagickMemory(pixels);
               if (status == MagickFalse)
                 {
-                  CloseBlob(image);
+                  (void) CloseBlob(image);
                   return(MagickFalse);
                 }
               break;
@@ -2183,7 +2312,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             break;
@@ -2237,6 +2366,31 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
+  /*
+    Write Metadata object.
+  */
+  xref[object++]=TellBlob(image);
+  info_id=object;
+  (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
+  (void) WriteBlobString(image,buffer);
+  (void) WriteBlobString(image,"<<\n");
+  (void) FormatMagickString(buffer,MaxTextExtent,"/Title (%s)\n",
+    EscapeParenthesis(image->filename));
+  (void) WriteBlobString(image,buffer);
+  seconds=time((time_t *) NULL);
+  time_meridian=localtime(&seconds);
+  (void) FormatMagickString(date,MaxTextExtent,"D:%04d%02d%02d%02d%02d%02d",
+    time_meridian->tm_year+1900,time_meridian->tm_mon+1,time_meridian->tm_mday,
+    time_meridian->tm_hour,time_meridian->tm_min,time_meridian->tm_sec);
+  (void) FormatMagickString(buffer,MaxTextExtent,"/CreationDate (%s)\n",date);
+  (void) WriteBlobString(image,buffer);
+  (void) FormatMagickString(buffer,MaxTextExtent,"/ModDate (%s)\n",date);
+  (void) WriteBlobString(image,buffer);
+  (void) FormatMagickString(buffer,MaxTextExtent,"/Producer (%s)\n",
+    EscapeParenthesis(GetMagickVersion((unsigned long *) NULL)));
+  (void) WriteBlobString(image,buffer);
+  (void) WriteBlobString(image,">>\n");
+  (void) WriteBlobString(image,"endobj\n");
   /*
     Write Xref object.
   */
@@ -2266,6 +2420,6 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobString(image,buffer);
   (void) WriteBlobString(image,"%%EOF\n");
   xref=(MagickOffsetType *) RelinquishMagickMemory(xref);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
