@@ -52,7 +52,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/random_.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -79,7 +79,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -94,18 +94,22 @@ static inline size_t MagickMax(const size_t x,const size_t y)
 
 static inline void PlasmaPixel(Image *image,double x,double y)
 {
+  QuantumAny
+    scale;
+
   register PixelPacket
     *q;
 
   q=GetImagePixels(image,(long) ceil(x-0.5),(long) ceil(y-0.5),1,1);
   if (q == (PixelPacket *) NULL)
     return;
-  q->red=ScaleAnyToQuantum((unsigned long)
-    (65535.0*GetRandomValue()+0.5),16UL);
-  q->green=ScaleAnyToQuantum((unsigned long)
-    (65535.0*GetRandomValue()+0.5),16UL);
-  q->blue=ScaleAnyToQuantum((unsigned long)
-    (65535.0*GetRandomValue()+0.5),16UL);
+  scale=GetQuantumScale(16UL);
+  q->red=ScaleAnyToQuantum((unsigned long) (65535.0*GetPseudoRandomValue()+
+    0.5),16UL,scale);
+  q->green=ScaleAnyToQuantum((unsigned long) (65535.0*GetPseudoRandomValue()+
+    0.5),16UL,scale);
+  q->blue=ScaleAnyToQuantum((unsigned long) (65535.0*GetPseudoRandomValue()+
+    0.5),16UL,scale);
   (void) SyncImagePixels(image);
 }
 
