@@ -153,7 +153,7 @@ ModuleExport void UnregisterPREVIEWImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
