@@ -56,6 +56,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/resource_.h"
 #include "magick/property.h"
 #include "magick/quantum-private.h"
@@ -166,9 +167,9 @@ ModuleExport void UnregisterPS2Image(void)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
@@ -356,6 +357,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
     stop;
 
   MagickBooleanType
+    progress,
     status;
 
   MagickOffsetType
@@ -417,7 +419,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  compression=image->compression;
+  compression=image_info->compression;
   switch (compression)
   {
 #if !defined(MAGICKCORE_JPEG_DELEGATE)
@@ -425,7 +427,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
     {
       compression=RLECompression;
       (void) ThrowMagickException(&image->exception,GetMagickModule(),
-        MissingDelegateError,"JPEGLibraryIsNotAvailable","`%s'",
+        MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (JPEG)",
         image->filename);
       break;
     }
@@ -741,16 +743,11 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 *q++=ScaleQuantumToChar(PixelIntensityToQuantum(p));
                 p++;
               }
-              if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+              progress=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (progress == MagickFalse)
+                break;
             }
+            length=(size_t) (q-pixels);
             if (compression == LZWCompression)
               status=LZWEncodeImage(image,length,pixels);
             else
@@ -758,7 +755,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             break;
@@ -781,15 +778,9 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                   ScaleQuantumToChar(PixelIntensityToQuantum(p)));
                 p++;
               }
-              if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+              progress=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (progress == MagickFalse)
+                break;
             }
             Ascii85Flush(image);
             break;
@@ -867,23 +858,18 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                       }
                   p++;
                 }
-                if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                progress=SetImageProgress(image,SaveImageTag,y,image->rows);
+                if (progress == MagickFalse)
+                  break;
               }
+              length=(size_t) (q-pixels);
               if (compression == LZWCompression)
                 status=LZWEncodeImage(image,length,pixels);
               else
                 status=PackbitsEncodeImage(image,length,pixels);
               if (status == MagickFalse)
                 {
-                  CloseBlob(image);
+                  (void) CloseBlob(image);
                   return(MagickFalse);
                 }
               pixels=(unsigned char *) RelinquishMagickMemory(pixels);
@@ -930,15 +916,9 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                       }
                   p++;
                 }
-                if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                progress=SetImageProgress(image,SaveImageTag,y,image->rows);
+                if (progress == MagickFalse)
+                  break;
               }
               Ascii85Flush(image);
               break;
@@ -997,16 +977,11 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 indexes=GetIndexes(image);
                 for (x=0; x < (long) image->columns; x++)
                   *q++=(unsigned char) indexes[x];
-                if (image->previous == (Image *) NULL)
-                  if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                      (QuantumTick(y,image->rows) != MagickFalse))
-                    {
-                      status=image->progress_monitor(SaveImageTag,y,image->rows,
-                        image->client_data);
-                      if (status == MagickFalse)
-                        break;
-                    }
-                }
+                progress=SetImageProgress(image,SaveImageTag,y,image->rows);
+                if (progress == MagickFalse)
+                  break;
+              }
+              length=(size_t) (q-pixels);
               if (compression == LZWCompression)
                 status=LZWEncodeImage(image,length,pixels);
               else
@@ -1014,7 +989,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               pixels=(unsigned char *) RelinquishMagickMemory(pixels);
               if (status == MagickFalse)
                 {
-                  CloseBlob(image);
+                  (void) CloseBlob(image);
                   return(MagickFalse);
                 }
               break;
@@ -1034,15 +1009,9 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 indexes=GetIndexes(image);
                 for (x=0; x < (long) image->columns; x++)
                   Ascii85Encode(image,(unsigned char) indexes[x]);
-                if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                progress=SetImageProgress(image,SaveImageTag,y,image->rows);
+                if (progress == MagickFalse)
+                  break;
               }
               Ascii85Flush(image);
               break;
@@ -1089,6 +1058,6 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
       (void) WriteBlobString(image,buffer);
     }
   (void) WriteBlobString(image,"%%EOF\n");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
