@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -59,14 +59,15 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resource_.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/token.h"
 #include "magick/utility.h"
-#include "magick/version.h"
-#if defined(HasTIFF)
+#include "magick/module.h"
+#if defined(MAGICKCORE_TIFF_DELEGATE)
 #define CCITTParam  "-1"
 #else
 #define CCITTParam  "0"
@@ -113,24 +114,25 @@ static MagickBooleanType
 %
 %  The format of the RegisterPS3Image method is:
 %
-%      RegisterPS3Image(void)
+%      unsigned long RegisterPS3Image(void)
 %
 */
-ModuleExport void RegisterPS3Image(void)
+ModuleExport unsigned long RegisterPS3Image(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPS3");
-  entry->encoder=(EncoderHandler *) WritePS3Image;
+  entry->encoder=(EncodeImageHandler *) WritePS3Image;
   entry->description=ConstantString("Level III Encapsulated PostScript");
   entry->module=ConstantString("PS3");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PS3");
-  entry->encoder=(EncoderHandler *) WritePS3Image;
+  entry->encoder=(EncodeImageHandler *) WritePS3Image;
   entry->description=ConstantString("Level III PostScript");
   entry->module=ConstantString("PS3");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -182,7 +184,7 @@ ModuleExport void UnregisterPS3Image(void)
 %
 %    o image_info: Specifies a pointer to a ImageInfo structure.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 
@@ -214,7 +216,7 @@ static MagickBooleanType SerializeImage(const ImageInfo *image_info,
   status=MagickTrue;
   *length=(image->colorspace == CMYKColorspace ? 4 : 3)*
     (size_t) image->columns*image->rows;
-  *pixels=(unsigned char *) AcquireMagickMemory(*length*sizeof(**pixels));
+  *pixels=(unsigned char *) AcquireQuantumMemory(*length,sizeof(**pixels));
   if (*pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   q=(*pixels);
@@ -287,11 +289,10 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=MagickTrue;
-  pack=(unsigned long) (IsMonochromeImage(image,&image->exception) !=
-    MagickFalse ? 1 : 8);
+  pack=IsMonochromeImage(image,&image->exception) == MagickFalse ? 1UL : 8UL;
   padded_columns=((image->columns+pack-1)/pack)*pack;
   *length=(size_t) padded_columns*image->rows/pack;
-  *pixels=(unsigned char *) AcquireMagickMemory(*length);
+  *pixels=(unsigned char *) AcquireQuantumMemory(*length,sizeof(**pixels));
   if (*pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   q=(*pixels);
@@ -314,7 +315,7 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
           bit=(unsigned char) 0x00;
           if (x < (long) image->columns)
             bit=(unsigned char) (PixelIntensityToQuantum(p) ==
-              TransparentOpacity ? 0x01 : 0x00);
+              (Quantum) TransparentOpacity ? 0x01 : 0x00);
           code=(code << 1)+bit;
           if (((x+1) % pack) == 0)
             {
@@ -366,7 +367,7 @@ static MagickBooleanType SerializeImageIndexes(const ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=MagickTrue;
   *length=(size_t) image->columns*image->rows;
-  *pixels=(unsigned char *) AcquireMagickMemory(*length);
+  *pixels=(unsigned char *) AcquireQuantumMemory(*length,sizeof(**pixels));
   if (*pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   q=(*pixels);
@@ -849,7 +850,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(MagickFalse);
-  compression=image->compression;
+  compression=image_info->compression;
   switch (compression)
   {
     case FaxCompression:
@@ -860,22 +861,23 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         compression=RLECompression;
       break;
     }
-#if !defined(HasJPEG)
+#if !defined(MAGICKCORE_JPEG_DELEGATE)
     case JPEGCompression:
     {
       compression=RLECompression;
       (void) ThrowMagickException(&image->exception,GetMagickModule(),
-        MissingDelegateError,"JPEGLibraryIsNotAvailable","`%s'",
+        MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (JPEG)",
         image->filename);
       break;
     }
 #endif
-#if !defined(HasZLIB)
+#if !defined(MAGICKCORE_ZLIB_DELEGATE)
     case ZipCompression:
     {
       compression=RLECompression;
       (void) ThrowMagickException(&image->exception,GetMagickModule(),
-        MissingDelegateError,"ZipLibraryIsNotAvailable","`%s'",image->filename);
+        MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (ZLIB)",
+        image->filename);
       break;
     }
 #endif
@@ -945,7 +947,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     if (image_info->pointsize != 0.0)
       pointsize=image_info->pointsize;
     text_size=0;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     page++;
@@ -1004,7 +1006,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           Font resources
         */
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Helvetica\n");
@@ -1038,7 +1040,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           One label line for each line in label string.
         */
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value != (const char *) NULL)
           {
               (void) WriteBlobString(image,"\n  %% Labels.\n  /Helvetica "
@@ -1094,7 +1096,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     /*
       Page font resource if there's a label.
     */
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       (void) WriteBlobString(image,"%%PageResources: font Helvetica\n");
     /*
@@ -1125,7 +1127,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     if ((image->matte != MagickFalse) &&
         (WritePS3MaskImage(image_info,image,compression) == MagickFalse))
       {
-        CloseBlob(image);
+        (void) CloseBlob(image);
         return(MagickFalse);
       }
     /*
@@ -1148,7 +1150,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       Output labels.
     */
     labels=(char **) NULL;
-    value=GetImageProperty(image,"Label");
+    value=GetImageProperty(image,"label");
     if (value != (const char *) NULL)
       labels=StringToList(value);
     if (labels != (char **) NULL)
@@ -1286,7 +1288,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
               status=SerializeImageChannel(image_info,image,&pixels,&length);
               if (status == MagickFalse)
                 {
-                  CloseBlob(image);
+                  (void) CloseBlob(image);
                   return(MagickFalse);
                 }
               switch (compression)
@@ -1370,7 +1372,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
               status=SerializeImage(image_info,image,&pixels,&length);
               if (status == MagickFalse)
                 {
-                  CloseBlob(image);
+                  (void) CloseBlob(image);
                   return(MagickFalse);
                 }
               switch (compression)
@@ -1448,7 +1450,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
             /*
               Color map - uncompressed.
             */
-            if (compression != NoCompression)
+            if ((compression != NoCompression) &&
+                (compression != UndefinedCompression))
               {
                 for (i=0; i < (long) image->colors; i++)
                 {
@@ -1477,7 +1480,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
             status=SerializeImageIndexes(image_info,image,&pixels,&length);
             if (status == MagickFalse)
               {
-                CloseBlob(image);
+                (void) CloseBlob(image);
                 return(MagickFalse);
               }
             switch (compression)
@@ -1518,7 +1521,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     (void) WriteBlobByte(image,'\n');
     if (status == MagickFalse)
       {
-        CloseBlob(image);
+        (void) CloseBlob(image);
         return(MagickFalse);
       }
     /*
@@ -1566,6 +1569,6 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       (void) WriteBlobString(image,buffer);
     }
   (void) WriteBlobString(image,"%%EOF\n");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
