@@ -88,7 +88,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image,image: The address of a structure of type Image.
+%    o image,image: the address of a structure of type Image.
 %
 %    o channel:  Specifies which channel: red, green, blue, or index to
 %      decode the pixel values into.
@@ -321,7 +321,7 @@ static MagickBooleanType IsPSD(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -458,8 +458,11 @@ static MagickBooleanType ParseImageResourceBlocks(const ImageInfo *image_info,
 
   unsigned long
     count,
+    long_sans;
+
+  unsigned short
     id,
-    sans;
+    short_sans;
 
   if (length < 16)
     return(MagickFalse);
@@ -467,36 +470,36 @@ static MagickBooleanType ParseImageResourceBlocks(const ImageInfo *image_info,
   InitializeQuantumState(&quantum_info,LSBEndian,&quantum_state);
   profile=AcquireStringInfo(length);
   SetStringInfoDatum(profile,blocks);
-  (void) SetImageProfile(image,"iptc",profile);
+  (void) SetImageProfile(image,"8bim",profile);
   profile=DestroyStringInfo(profile);
   for (p=blocks; (p >= blocks) && (p < (blocks+length-16)); )
   {
     if (LocaleNCompare((char *) p,"8BIM",4) != 0)
       break;
-    sans=PushLongPixel(&quantum_state,&p);
-    id=PushShortPixel(&quantum_state,&p);
-    sans=PushShortPixel(&quantum_state,&p);
-    count=PushLongPixel(&quantum_state,&p);
+    p=PushLongPixel(quantum_state.endian,p,&long_sans);
+    p=PushShortPixel(quantum_state.endian,p,&id);
+    p=PushShortPixel(quantum_state.endian,p,&short_sans);
+    p=PushLongPixel(quantum_state.endian,p,&count);
     switch (id)
     {
       case 0x03ed:
       {
-        unsigned long
+        unsigned short
           resolution;
 
         /*
           Resolution info.
         */
-        resolution=PushShortPixel(&quantum_state,&p);
+        p=PushShortPixel(quantum_state.endian,p,&resolution);
         image->x_resolution=(double) resolution;
-        sans=PushShortPixel(&quantum_state,&p);
-        sans=PushShortPixel(&quantum_state,&p);
-        sans=PushShortPixel(&quantum_state,&p);
-        resolution=PushShortPixel(&quantum_state,&p);
+        p=PushShortPixel(quantum_state.endian,p,&short_sans);
+        p=PushShortPixel(quantum_state.endian,p,&short_sans);
+        p=PushShortPixel(quantum_state.endian,p,&short_sans);
+        p=PushShortPixel(quantum_state.endian,p,&resolution);
         image->y_resolution=(double) resolution;
-        sans=PushShortPixel(&quantum_state,&p);
-        sans=PushShortPixel(&quantum_state,&p);
-        sans=PushShortPixel(&quantum_state,&p);
+        p=PushShortPixel(quantum_state.endian,p,&short_sans);
+        p=PushShortPixel(quantum_state.endian,p,&short_sans);
+        p=PushShortPixel(quantum_state.endian,p,&short_sans);
         break;
       }
       default:
@@ -647,7 +650,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -693,7 +696,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((psd_info.mode == BitmapMode) || (psd_info.mode == GrayscaleMode) ||
       (psd_info.mode == DuotoneMode))
     {
-      if (AllocateImageColormap(image,256) == MagickFalse)
+      if (AcquireImageColormap(image,256) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       image->matte=psd_info.channels >= 2 ? MagickTrue : MagickFalse;
       if (image->debug != MagickFalse)
@@ -728,7 +731,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           /*
             Read PSD raster colormap.
           */
-          if (AllocateImageColormap(image,(unsigned long) (length/3)) == MagickFalse)
+          if (AcquireImageColormap(image,(unsigned long) (length/3)) == MagickFalse)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           for (i=0; i < (long) image->colors; i++)
             image->colormap[i].red=ScaleCharToQuantum((unsigned char)
@@ -772,7 +775,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   if (SetImageExtent(image,0,0) == MagickFalse)
@@ -1212,8 +1215,8 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   indexes=GetIndexes(layer_info[i].image);
                   for (x=0; x < (long) layer_info[i].image->columns; x++)
                   {
-                    q->opacity=QuantumRange-(Quantum)
-                      (QuantumScale*(q->opacity*layer_info[i].opacity));
+                    q->opacity=(Quantum) (QuantumRange-(Quantum)
+                      (QuantumScale*(q->opacity*layer_info[i].opacity)));
                     q++;
                   }
                   if (SyncImagePixels(layer_info[i].image) == MagickFalse)
@@ -1401,7 +1404,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   if (image->colorspace == CMYKColorspace)
     (void) NegateImage(image,MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -1487,7 +1490,7 @@ ModuleExport void UnregisterPSDImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -1518,7 +1521,7 @@ static void WriteOneChannel(const ImageInfo *image_info,Image *image,
     p=AcquireImagePixels(tmp_image,0,y,tmp_image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
     break;
-    (void) ImportQuantumPixels(tmp_image,&quantum_info,quantum_type,pixels);
+    (void) ExportQuantumPixels(tmp_image,&quantum_info,quantum_type,pixels);
     (void) WriteBlob(image,packet_size*tmp_image->columns,pixels);
   }
 }
@@ -1727,18 +1730,18 @@ static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobMSBLong(image,image->columns);
   (void) WriteBlobMSBShort(image,(unsigned short)
     (image->storage_class == PseudoClass ? 8 : image->depth > 8 ? 16 : 8));
-  if (((image_info->colorspace != UndefinedColorspace) ||
+  if (((image->colorspace != UndefinedColorspace) ||
        (image->colorspace != CMYKColorspace)) &&
-       (image_info->colorspace != CMYKColorspace))
+       (image->colorspace != CMYKColorspace))
     {
-      if (image_info->colorspace == UndefinedColorspace)
+      if (image->colorspace != RGBColorspace)
         (void) SetImageColorspace(image,RGBColorspace);
       (void) WriteBlobMSBShort(image,(unsigned short)
         (image->storage_class == PseudoClass ? 2 : 3));
     }
   else
     {
-      if (image_info->colorspace == UndefinedColorspace)
+      if (image->colorspace != RGBColorspace)
         (void) SetImageColorspace(image,CMYKColorspace);
       (void) WriteBlobMSBShort(image,4);
     }
@@ -1763,15 +1766,18 @@ static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
       for ( ; i < 256; i++)
         (void) WriteBlobByte(image,0);
     }
-
-  /* image resource block */
-  profile=GetImageProfile(image,"iptc");
+  /*
+    Image resource block.
+  */
+  profile=GetImageProfile(image,"8bim");
   if (profile == (StringInfo *) NULL)
     (void) WriteBlobMSBLong(image,0);
   else
     {
-      (void) WriteBlobMSBLong(image,(unsigned long) GetStringInfoLength(profile));
-      (void) WriteBlob( image, GetStringInfoLength(profile), GetStringInfoDatum(profile) );
+      (void) WriteBlobMSBLong(image,(unsigned long) GetStringInfoLength(
+        profile));
+      (void) WriteBlob(image,GetStringInfoLength(profile),GetStringInfoDatum(
+        profile));
     }
 
 compute_layer_info:
@@ -1922,6 +1928,6 @@ compute_layer_info:
    else
   status=WriteImageChannels(image_info,image,image);
 
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(status);
 }
