@@ -86,30 +86,43 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
 */
-static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
+static Image *ReadRAWImage(const ImageInfo *image_info,
+  ExceptionInfo *exception)
 {
   Image
+    *canvas_image,
     *image;
 
   long
-    j,
     y;
 
   MagickBooleanType
     status;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
+
+  QuantumType
+    quantum_type;
+
+  register const IndexPacket
+    *canvas_indexes;
+
+  register const PixelPacket
+    *p;
 
   register long
     i,
     x;
 
+  register IndexPacket
+    *indexes;
+
   register PixelPacket
     *q;
 
@@ -117,14 +130,11 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   size_t
-    packet_size;
+    length;
 
   unsigned char
     *pixels;
 
-  unsigned long
-    width;
-
   /*
     Open image file.
   */
@@ -135,7 +145,7 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
@@ -144,33 +154,22 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
-  switch (*image->magick)
-  {
-    case 'C':
-    case 'c':
-    case 'M':
-    case 'm':
-    case 'Y':
-    case 'y':
-    case 'K':
-    case 'k':
-    {
-      image->colorspace=CMYKColorspace;
-      break;
-    }
-    default:
-      break;
-  }
   for (i=0; i < image->offset; i++)
-    (void) ReadBlobByte(image);
+    if (ReadBlobByte(image) == EOF)
+      {
+        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          image->filename);
+        break;
+      }
   /*
-    Allocate memory for a pixels.
+    Create virtual canvas to support cropping (i.e. image.gray[100x100+10+20]).
   */
-  packet_size=(size_t) (image->depth+7)/8;
-  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
-    packet_size*sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+  canvas_image=CloneImage(image,image->extract_info.width,1,MagickTrue,
+    exception);
+  (void) SetImageVirtualPixelMethod(canvas_image,BlackVirtualPixelMethod);
+  quantum_type=GrayQuantum;
+  quantum_info=AcquireQuantumInfo(image_info,canvas_image);
+  pixels=GetQuantumPixels(quantum_info);
   if (image_info->number_scenes != 0)
     while (image->scene < image_info->scene)
     {
@@ -178,36 +177,59 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
         Skip to next image.
       */
       image->scene++;
+      length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
       for (y=0; y < (long) image->rows; y++)
-        count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
+      {
+        count=ReadBlob(image,length,pixels);
+        if (count != (ssize_t) length)
+          break;
+      }
     }
-  x=(long) (packet_size*image->extract_info.x);
   do
   {
     /*
-      Convert raster image to pixel packets.
+      Read pixels to virtual canvas image then push to image.
     */
-    GetQuantumInfo(image_info,&quantum_info);
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-      if (SetImageExtent(image,0,0) == MagickFalse)
-        {
-          InheritException(exception,&image->exception);
-          return(DestroyImageList(image));
-        }
-    for (y=0; y < image->extract_info.y; y++)
-      count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-    for (y=0; y < (long) image->rows; y++)
+    if ((SetImageExtent(image,0,0) == MagickFalse) ||
+        (SetImageExtent(canvas_image,0,0) == MagickFalse))
+      break;
+    length=GetQuantumExtent(canvas_image,quantum_info,GrayQuantum);
+    count=ReadBlob(image,length,pixels);
+    if (count != (ssize_t) length)
+      break;
+    for (y=0; y < (long) image->extract_info.height; y++)
     {
-      if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
-        count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-      q=SetImagePixels(image,0,y,image->columns,1);
+      q=GetImagePixels(canvas_image,0,0,canvas_image->columns,1);
       if (q == (PixelPacket *) NULL)
         break;
-      (void) ExportQuantumPixels(image,&quantum_info,GrayQuantum,pixels+x);
-      if (SyncImagePixels(image) == MagickFalse)
+      length=ImportQuantumPixels(canvas_image,quantum_info,quantum_type,pixels);
+      if (SyncImagePixels(canvas_image) == MagickFalse)
         break;
+      count=ReadBlob(image,length,pixels);
+      if (((y-image->extract_info.y) >= 0) && 
+          ((y-image->extract_info.y) < (long) image->rows))
+        {
+          p=AcquireImagePixels(canvas_image,canvas_image->extract_info.x,0,
+            canvas_image->columns,1,exception);
+          q=SetImagePixels(image,0,y-image->extract_info.y,image->columns,1);
+          if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+            break;
+          canvas_indexes=AcquireIndexes(canvas_image);
+          indexes=GetIndexes(image);
+          for (x=0; x < (long) image->columns; x++)
+          {
+            q->red=p->red;
+            q->green=p->green;
+            q->blue=p->blue;
+            p++;
+            q++;
+          }
+          if (SyncImagePixels(image) == MagickFalse)
+            break;
+        }
       if (image->previous == (Image *) NULL)
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
             (QuantumTick(y,image->rows) != MagickFalse))
@@ -218,30 +240,19 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
     }
-    width=image->extract_info.height-image->rows-image->extract_info.y;
-    for (j=0; j < (long) width; j++)
-      count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-    if (EOFBlob(image) != MagickFalse)
-      {
-        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
-          image->filename);
-        break;
-      }
-    if (image->colorspace == CMYKColorspace)
-      image->storage_class=DirectClass;
+    SetQuantumImageType(image,quantum_type);
     /*
       Proceed to next image.
     */
     if (image_info->number_scenes != 0)
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
-    if (count != 0)
+    if (count == (ssize_t) length)
       {
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -256,9 +267,11 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
       }
-  } while (count != 0);
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  CloseBlob(image);
+  } while (count == (ssize_t) length);
+  quantum_info=DestroyQuantumInfo(quantum_info);
+  InheritException(exception,&canvas_image->exception);
+  canvas_image=DestroyImage(canvas_image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -415,7 +428,7 @@ ModuleExport void UnregisterRAWImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -430,7 +443,7 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
     scene;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -441,8 +454,11 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
   register const PixelPacket
     *p;
 
+  ssize_t
+    count;
+
   size_t
-    packet_size;
+    length;
 
   unsigned char
     *pixels;
@@ -539,24 +555,19 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
   do
   {
     /*
-      Allocate memory for pixels.
-    */
-    GetQuantumInfo(image_info,&quantum_info);
-    packet_size=(size_t) (image->depth+7)/8;
-    pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
-      sizeof(*pixels));
-    if (pixels == (unsigned char *) NULL)
-      ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    /*
-      Convert MIFF to RAW raster pixels.
+      Convert image to RAW raster pixels.
     */
+    quantum_info=AcquireQuantumInfo(image_info,image);
+    pixels=GetQuantumPixels(quantum_info);
     for (y=0; y < (long) image->rows; y++)
     {
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
-      (void) WriteBlob(image,packet_size*image->columns,pixels);
+      length=ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
+      count=WriteBlob(image,length,pixels);
+      if (count != (ssize_t) length)
+        break;
       if (image->previous == (Image *) NULL)
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
             (QuantumTick(y,image->rows) != MagickFalse))
@@ -567,7 +578,7 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
               break;
           }
     }
-    pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+    quantum_info=DestroyQuantumInfo(quantum_info);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
@@ -580,6 +591,6 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
