@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -112,7 +113,7 @@ static MagickBooleanType IsRLE(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -188,7 +189,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -273,7 +274,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
             count=ReadBlob(image,length-1,(unsigned char *) comment);
             comment[length-1]='\0';
-            (void) SetImageProperty(image,"Comment",comment);
+            (void) SetImageProperty(image,"comment",comment);
             comment=DestroyString(comment);
             if ((length & 0x01) == 0)
               (void) ReadBlobByte(image);
@@ -470,7 +471,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         if (number_colormaps == 0)
           map_length=256;
-        if (AllocateImageColormap(image,map_length) == MagickFalse)
+        if (AcquireImageColormap(image,map_length) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         p=colormap;
         if (number_colormaps == 1)
@@ -578,7 +579,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -594,7 +595,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
       }
   } while ((count != 0) && (memcmp(magick,"\122\314",2) == 0));
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -618,21 +619,22 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterRLEImage method is:
 %
-%      RegisterRLEImage(void)
+%      unsigned long RegisterRLEImage(void)
 %
 */
-ModuleExport void RegisterRLEImage(void)
+ModuleExport unsigned long RegisterRLEImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("RLE");
-  entry->decoder=(DecoderHandler *) ReadRLEImage;
-  entry->magick=(MagickHandler *) IsRLE;
+  entry->decoder=(DecodeImageHandler *) ReadRLEImage;
+  entry->magick=(IsImageFormatHandler *) IsRLE;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Utah Run length encoded image");
   entry->module=ConstantString("RLE");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
