@@ -17,7 +17,7 @@
 %                               October 2003                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -50,9 +50,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -75,7 +76,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -143,7 +144,7 @@ static Image *ReadSCRImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -216,13 +217,13 @@ static Image *ReadSCRImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
               if(binar[z])
             {
-                q->red=QuantumRange*(colour_palette[3*ink]);
-                q->green=QuantumRange*(colour_palette[1+(3*ink)]);
-                q->blue=QuantumRange*(colour_palette[2+(3*ink)]);
+                q->red=(Quantum) QuantumRange*(colour_palette[3*ink]);
+                q->green=(Quantum) QuantumRange*(colour_palette[1+(3*ink)]);
+                q->blue=(Quantum) QuantumRange*(colour_palette[2+(3*ink)]);
             } else {
-                q->red=QuantumRange*(colour_palette[3*paper]);
-                q->green=QuantumRange*(colour_palette[1+(3*paper)]);
-                q->blue=QuantumRange*(colour_palette[2+(3*paper)]);
+                q->red=(Quantum) QuantumRange*(colour_palette[3*paper]);
+                q->green=(Quantum) QuantumRange*(colour_palette[1+(3*paper)]);
+                q->blue=(Quantum) QuantumRange*(colour_palette[2+(3*paper)]);
             }
 
               pix++;
@@ -231,7 +232,7 @@ static Image *ReadSCRImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -255,20 +256,21 @@ static Image *ReadSCRImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterSCRImage method is:
 %
-%      RegisterSCRImage(void)
+%      unsigned long RegisterSCRImage(void)
 %
 */
-ModuleExport void RegisterSCRImage(void)
+ModuleExport unsigned long RegisterSCRImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("SCR");
-  entry->decoder=(DecoderHandler *) ReadSCRImage;
+  entry->decoder=(DecodeImageHandler *) ReadSCRImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("ZX-Spectrum SCREEN$");
   entry->module=ConstantString("SCR");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
