@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,9 +54,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Typedef declaractions.
@@ -153,7 +154,7 @@ static MagickBooleanType IsSGI(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -308,7 +309,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -357,10 +358,10 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count=ReadBlob(image,sizeof(iris_info.filler),iris_info.filler);
     image->columns=iris_info.columns;
     image->rows=iris_info.rows;
-    image->depth=(unsigned long) MagickMin(iris_info.depth,QuantumDepth);
+    image->depth=(unsigned long) MagickMin(iris_info.depth,MAGICKCORE_QUANTUM_DEPTH);
     if (iris_info.pixel_format == 0)
       image->depth=(unsigned long) MagickMin((size_t) 8*
-        iris_info.bytes_per_pixel,QuantumDepth);
+        iris_info.bytes_per_pixel,MAGICKCORE_QUANTUM_DEPTH);
     if (iris_info.depth < 3)
       {
         image->storage_class=PseudoClass;
@@ -619,7 +620,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Create grayscale map.
         */
-        if (AllocateImageColormap(image,image->colors) == MagickFalse)
+        if (AcquireImageColormap(image,image->colors) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         /*
           Convert SGI image to PseudoClass pixel packets.
@@ -701,7 +702,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -717,7 +718,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
       }
   } while (iris_info.magic == 0x01DA);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -741,22 +742,23 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterSGIImage method is:
 %
-%      RegisterSGIImage(void)
+%      unsigned long RegisterSGIImage(void)
 %
 */
-ModuleExport void RegisterSGIImage(void)
+ModuleExport unsigned long RegisterSGIImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("SGI");
-  entry->decoder=(DecoderHandler *) ReadSGIImage;
-  entry->encoder=(EncoderHandler *) WriteSGIImage;
-  entry->magick=(MagickHandler *) IsSGI;
+  entry->decoder=(DecodeImageHandler *) ReadSGIImage;
+  entry->encoder=(EncodeImageHandler *) WriteSGIImage;
+  entry->magick=(IsImageFormatHandler *) IsSGI;
   entry->description=ConstantString("Irix RGB image");
   entry->module=ConstantString("SGI");
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -802,7 +804,7 @@ ModuleExport void UnregisterSGIImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -916,7 +918,7 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize SGI raster file header.
     */
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     (void) ResetMagickMemory(&iris_info,0,sizeof(iris_info));
     iris_info.magic=0x01DA;
@@ -945,8 +947,8 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       }
     iris_info.minimum_value=0;
     iris_info.maximum_value=(unsigned long) (image->depth <= 8 ?
-      1UL*ScaleQuantumToChar(QuantumRange) :
-      1UL*ScaleQuantumToShort(QuantumRange));
+      1UL*ScaleQuantumToChar((Quantum) QuantumRange) :
+      1UL*ScaleQuantumToShort((Quantum) QuantumRange));
     /*
       Write SGI header.
     */
@@ -1110,7 +1112,7 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlobMSBLong(image,runlength[i]);
         (void) WriteBlob(image,number_packets,packets);
         /*
-          Free resources.
+          Relinquish resources.
         */
         runlength=(unsigned long *) RelinquishMagickMemory(runlength);
         packets=(unsigned char *) RelinquishMagickMemory(packets);
@@ -1131,6 +1133,6 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
