@@ -197,7 +197,7 @@ static MagickBooleanType DecodeImage(const unsigned char *compressed_pixels,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -280,7 +280,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -329,7 +329,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Create linear color ramp.
             */
-            if (AllocateImageColormap(image,image->colors) == MagickFalse)
+            if (AcquireImageColormap(image,image->colors) == MagickFalse)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
         break;
@@ -342,7 +342,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read SUN raster colormap.
         */
-        if (AllocateImageColormap(image,image->colors) == MagickFalse)
+        if (AcquireImageColormap(image,image->colors) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         sun_colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
           sizeof(*sun_colormap));
@@ -384,7 +384,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->rows=sun_info.height;
     if (image_info->ping != MagickFalse)
       {
-        CloseBlob(image);
+        (void) CloseBlob(image);
         return(GetFirstImageInList(image));
       }
     if (SetImageExtent(image,0,0) == MagickFalse)
@@ -576,7 +576,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -592,7 +592,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
       }
   } while (sun_info.magic == 0x59a66a95);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -684,7 +684,7 @@ ModuleExport void UnregisterSUNImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -755,7 +755,7 @@ static MagickBooleanType WriteSUNImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize SUN raster file header.
     */
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     sun_info.magic=0x59a66a95;
     sun_info.width=image->columns;
@@ -887,7 +887,7 @@ static MagickBooleanType WriteSUNImage(const ImageInfo *image_info,Image *image)
             for (x=0; x < (long) image->columns; x++)
             {
               byte<<=1;
-              if (PixelIntensity(p) < (QuantumRange/2.0))
+              if (PixelIntensity(p) < (MagickRealType) (QuantumRange/2.0))
                 byte|=0x01;
               bit++;
               if (bit == 8)
@@ -967,6 +967,6 @@ static MagickBooleanType WriteSUNImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
