@@ -85,11 +85,10 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -178,7 +177,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -213,6 +212,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     tga_info.height=(unsigned short) ReadBlobLSBShort(image);
     tga_info.bits_per_pixel=(unsigned char) ReadBlobByte(image);
     tga_info.attributes=(unsigned char) ReadBlobByte(image);
+    if (EOFBlob(image) != MagickFalse)
+      ThrowReaderException(CorruptImageError,"UnableToReadImageData");
     /*
       Initialize image structure.
     */
@@ -246,7 +247,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         else
           {
             image->colors=0x01U << tga_info.bits_per_pixel;
-            if (AllocateImageColormap(image,image->colors) == MagickFalse)
+            if (AcquireImageColormap(image,image->colors) == MagickFalse)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
       }
@@ -274,13 +275,13 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         comment=DestroyString(comment);
       }
     (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
-    pixel.opacity=(Quantum) TransparentOpacity;
+    pixel.opacity=(Quantum) OpaqueOpacity;
     if (tga_info.colormap_type != 0)
       {
         /*
           Read TGA raster colormap.
         */
-        if (AllocateImageColormap(image,image->colors) == MagickFalse)
+        if (AcquireImageColormap(image,image->colors) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (i=0; i < (long) image->colors; i++)
         {
@@ -300,15 +301,19 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
             case 15:
             case 16:
             {
+              QuantumAny
+                scale;
+
               /*
                 5 bits each of red green and blue.
               */
               j=(unsigned char) ReadBlobByte(image);
               k=(unsigned char) ReadBlobByte(image);
-              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,5);
+              scale=GetQuantumScale(5UL);
+              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,5UL,scale);
               pixel.green=ScaleAnyToQuantum((1UL*(k & 0x03) << 3)+
-                (1UL*(j & 0xe0) >> 5),5);
-              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5);
+                (1UL*(j & 0xe0) >> 5),5UL,scale);
+              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5UL,scale);
               break;
             }
             case 24:
@@ -403,15 +408,19 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
             case 15:
             case 16:
             {
+              QuantumAny
+                scale;
+
               /*
                 5 bits each of red green and blue.
               */
               j=(unsigned char) ReadBlobByte(image);
               k=(unsigned char) ReadBlobByte(image);
-              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,5);
+              scale=GetQuantumScale(5UL);
+              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,5UL,scale);
               pixel.green=ScaleAnyToQuantum((1UL*(k & 0x03) << 3)+
-                (1UL*(j & 0xe0) >> 5),5);
-              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5);
+                (1UL*(j & 0xe0) >> 5),5UL,scale);
+              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5UL,scale);
               if (image->matte != MagickFalse)
                 pixel.opacity=(k & 0x80) != 0 ? (Quantum) OpaqueOpacity :
                   (Quantum) TransparentOpacity; 
@@ -497,7 +506,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -513,7 +522,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
       }
   } while (status == MagickTrue);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -619,7 +628,7 @@ ModuleExport void UnregisterTGAImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -722,7 +731,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     */
     if ((image->columns > 65535L) || (image->rows > 65535L))
       ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     targa_info.id_length=0;
     value=GetImageProperty(image,"comment");
@@ -868,6 +877,6 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
