@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -50,13 +50,14 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/type.h"
 #include "wand/MagickWand.h"
-#if defined(HasFREETYPE)
-#if defined(HAVE_FT2BUILD_H)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+#if defined(MAGICKCORE_HAVE_FT2BUILD_H)
 #  include <ft2build.h>
 #endif
 #if defined(FT_FREETYPE_H)
@@ -140,7 +141,7 @@ static MagickBooleanType IsTTF(const unsigned char *magick,const size_t length)
   return(MagickFalse);
 }
 
-#if defined(HasFREETYPE)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -162,7 +163,7 @@ static MagickBooleanType IsTTF(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -214,7 +215,7 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   image->columns=800;
   image->rows=480;
   type_info=GetTypeInfo(image_info->filename,exception);
@@ -282,13 +283,13 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ConcatenateString(&draw_info->primitive,"pop graphic-context");
   (void) DrawImage(image,draw_info);
   /*
-    Free resources.
+    Relinquish resources.
   */
   draw_info=DestroyDrawInfo(draw_info);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
-#endif /* HasFREETYPE */
+#endif /* MAGICKCORE_FREETYPE_DELEGATE */
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -310,10 +311,10 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterTTFImage method is:
 %
-%      RegisterTTFImage(void)
+%      unsigned long RegisterTTFImage(void)
 %
 */
-ModuleExport void RegisterTTFImage(void)
+ModuleExport unsigned long RegisterTTFImage(void)
 {
   char
     version[MaxTextExtent];
@@ -327,10 +328,10 @@ ModuleExport void RegisterTTFImage(void)
     FREETYPE_MAJOR,FREETYPE_MINOR,FREETYPE_PATCH);
 #endif
   entry=SetMagickInfo("DFONT");
-#if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Multi-face font package");
   if (*version != '\0')
@@ -338,10 +339,10 @@ ModuleExport void RegisterTTFImage(void)
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFA");
-#if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsPFA;
+  entry->magick=(IsImageFormatHandler *) IsPFA;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Postscript Type 1 font (ASCII)");
   if (*version != '\0')
@@ -349,10 +350,10 @@ ModuleExport void RegisterTTFImage(void)
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFB");
-#if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsPFA;
+  entry->magick=(IsImageFormatHandler *) IsPFA;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Postscript Type 1 font (binary)");
   if (*version != '\0')
@@ -360,10 +361,10 @@ ModuleExport void RegisterTTFImage(void)
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("OTF");
-#if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Open Type font");
   if (*version != '\0')
@@ -371,10 +372,10 @@ ModuleExport void RegisterTTFImage(void)
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TTC");
-#if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("TrueType font collection");
   if (*version != '\0')
@@ -382,16 +383,17 @@ ModuleExport void RegisterTTFImage(void)
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TTF");
-#if defined(HasFREETYPE)
-  entry->decoder=(DecoderHandler *) ReadTTFImage;
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadTTFImage;
 #endif
-  entry->magick=(MagickHandler *) IsTTF;
+  entry->magick=(IsImageFormatHandler *) IsTTF;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("TrueType font");
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
