@@ -96,7 +96,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 {
@@ -146,11 +145,10 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTEXTImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -193,7 +191,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -308,7 +306,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
     */
     *draw_info->text='\0';
     offset=2*page.y;
-    AllocateNextImage(image_info,image);
+    AcquireNextImage(image_info,image);
     if (GetNextImageInList(image) == (Image *) NULL)
       {
         image=DestroyImageList(image);
@@ -341,7 +339,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
   if (texture != (Image *) NULL)
     texture=DestroyImage(texture);
   draw_info=DestroyDrawInfo(draw_info);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -366,7 +364,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -394,6 +392,9 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
+  QuantumAny
+    scale;
+
   register long
     i;
 
@@ -404,6 +405,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   unsigned long
+    depth,
     max_value;
 
   /*
@@ -416,7 +418,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -431,10 +433,8 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     &image->rows,&max_value,colorspace);
   if (count != 4)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  if (max_value == 4294967295UL)
-    image->depth=32;
-  else
-    for (image->depth=1; (1UL << image->depth)-1 < max_value; image->depth++);
+  for (depth=1; (GetQuantumRange(depth)+1) < max_value; depth++) ;
+  image->depth=depth;
   LocaleLower(colorspace);
   i=(long) strlen(colorspace)-1;
   image->matte=MagickFalse;
@@ -449,6 +449,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->colorspace=(ColorspaceType) type;
   (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
   (void) SetImageBackgroundColor(image);
+  scale=GetQuantumScale(image->depth);
   while (ReadBlobString(image,text) != (char *) NULL)
   {
     if (image->colorspace == CMYKColorspace)
@@ -472,16 +473,16 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     q=GetImagePixels(image,x,y,1,1);
     if (q == (PixelPacket *) NULL)
       continue;
-    q->red=ScaleAnyToQuantum(pixel.red,image->depth);
-    q->green=ScaleAnyToQuantum(pixel.green,image->depth);
-    q->blue=ScaleAnyToQuantum(pixel.blue,image->depth);
+    q->red=ScaleAnyToQuantum(pixel.red,image->depth,scale);
+    q->green=ScaleAnyToQuantum(pixel.green,image->depth,scale);
+    q->blue=ScaleAnyToQuantum(pixel.blue,image->depth,scale);
     if (image->colorspace == CMYKColorspace)
       {
         indexes=GetIndexes(image);
-        *indexes=ScaleAnyToQuantum(pixel.index,image->depth);
+        *indexes=ScaleAnyToQuantum(pixel.index,image->depth,scale);
       }
     if (image->matte != MagickFalse)
-      q->opacity=(Quantum) ScaleAnyToQuantum(pixel.opacity,image->depth);
+      q->opacity=(Quantum) ScaleAnyToQuantum(pixel.opacity,image->depth,scale);
     if (SyncImagePixels(image) == MagickFalse)
       break;
   }
@@ -520,6 +521,7 @@ ModuleExport unsigned long RegisterTXTImage(void)
   entry->decoder=(DecodeImageHandler *) ReadTEXTImage;
   entry->encoder=(EncodeImageHandler *) WriteTXTImage;
   entry->raw=MagickTrue;
+  entry->adjoin=MagickFalse;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Text");
   entry->module=ConstantString("TXT");
@@ -527,6 +529,7 @@ ModuleExport unsigned long RegisterTXTImage(void)
   entry=SetMagickInfo("TXT");
   entry->decoder=(DecodeImageHandler *) ReadTXTImage;
   entry->encoder=(EncodeImageHandler *) WriteTXTImage;
+  entry->adjoin=MagickFalse;
   entry->description=ConstantString("Text");
   entry->magick=(IsImageFormatHandler *) IsTXT;
   entry->module=ConstantString("TXT");
@@ -578,7 +581,7 @@ ModuleExport void UnregisterTXTImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -596,9 +599,6 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
-  MagickOffsetType
-    scene;
-
   MagickPixelPacket
     pixel;
 
@@ -625,86 +625,65 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
     return(status);
   (void) CopyMagickString(colorspace,MagickOptionToMnemonic(
     MagickColorspaceOptions,(long) image->colorspace),MaxTextExtent);
+  LocaleLower(colorspace);
   image->depth=GetImageQuantumDepth(image,MagickTrue);
   if (image->matte != MagickFalse)
     (void) ConcatenateMagickString(colorspace,"a",MaxTextExtent);
-  LocaleLower(colorspace);
   (void) FormatMagickString(buffer,MaxTextExtent,
     "# ImageMagick pixel enumeration: %lu,%lu,%lu,%s\n",image->columns,
-    image->rows,image->depth == 32 ? 4294967295UL : (1UL << image->depth)-1,
-    colorspace);
+    image->rows,(unsigned long) GetQuantumRange(image->depth),colorspace);
   (void) WriteBlobString(image,buffer);
-  scene=0;
-  do
+  GetMagickPixelPacket(image,&pixel);
+  for (y=0; y < (long) image->rows; y++)
   {
-    /*
-      Convert MIFF to TXT raster pixels.
-    */
-    GetMagickPixelPacket(image,&pixel);
-    for (y=0; y < (long) image->rows; y++)
-    {
-      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
-      if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=GetIndexes(image);
-      for (x=0; x < (long) image->columns; x++)
-      {
-        (void) FormatMagickString(buffer,MaxTextExtent,"%ld,%ld: ",x,y);
-        (void) WriteBlobString(image,buffer);
-        SetMagickPixelPacket(image,p,indexes+x,&pixel);
-        (void) CopyMagickString(tuple,"(",MaxTextExtent);
-        ConcatenateColorComponent(&pixel,RedChannel,X11Compliance,tuple);
-        (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-        ConcatenateColorComponent(&pixel,GreenChannel,X11Compliance,tuple);
-        (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-        ConcatenateColorComponent(&pixel,BlueChannel,X11Compliance,tuple);
-        if (pixel.colorspace == CMYKColorspace)
-          {
-            (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-            ConcatenateColorComponent(&pixel,IndexChannel,X11Compliance,tuple);
-          }
-        if (pixel.matte != MagickFalse)
-          {
-            (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
-            ConcatenateColorComponent(&pixel,OpacityChannel,X11Compliance,
-              tuple);
-          }
-        (void) ConcatenateMagickString(tuple,")",MaxTextExtent);
-        (void) WriteBlobString(image,tuple);
-        (void) WriteBlobString(image,"  ");
-        (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickTrue,
-          tuple,&image->exception);
-        (void) FormatMagickString(buffer,MaxTextExtent,"%s",tuple);
-        (void) WriteBlobString(image,buffer);
-        (void) WriteBlobString(image,"  ");
-        (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickFalse,
-          tuple,&image->exception);
-        (void) WriteBlobString(image,tuple);
-        (void) WriteBlobString(image,"\n");
-        p++;
-      }
-      if (image->previous == (Image *) NULL)
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SaveImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
-    }
-    if (GetNextImageInList(image) == (Image *) NULL)
+    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    if (p == (const PixelPacket *) NULL)
       break;
-    image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
-    scene++;
-  } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+    indexes=GetIndexes(image);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      (void) FormatMagickString(buffer,MaxTextExtent,"%ld,%ld: ",x,y);
+      (void) WriteBlobString(image,buffer);
+      SetMagickPixelPacket(image,p,indexes+x,&pixel);
+      (void) CopyMagickString(tuple,"(",MaxTextExtent);
+      ConcatenateColorComponent(&pixel,RedChannel,X11Compliance,tuple);
+      (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
+      ConcatenateColorComponent(&pixel,GreenChannel,X11Compliance,tuple);
+      (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
+      ConcatenateColorComponent(&pixel,BlueChannel,X11Compliance,tuple);
+      if (pixel.colorspace == CMYKColorspace)
+        {
+          (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
+          ConcatenateColorComponent(&pixel,IndexChannel,X11Compliance,tuple);
+        }
+      if (pixel.matte != MagickFalse)
+        {
+          (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
+          ConcatenateColorComponent(&pixel,OpacityChannel,X11Compliance,tuple);
+        }
+      (void) ConcatenateMagickString(tuple,")",MaxTextExtent);
+      (void) WriteBlobString(image,tuple);
+      (void) WriteBlobString(image,"  ");
+      GetColorTuple(&pixel,MagickTrue,tuple);
+      (void) FormatMagickString(buffer,MaxTextExtent,"%s",tuple);
+      (void) WriteBlobString(image,buffer);
+      (void) WriteBlobString(image,"  ");
+      (void) QueryMagickColorname(image,&pixel,SVGCompliance,tuple,
+        &image->exception);
+      (void) WriteBlobString(image,tuple);
+      (void) WriteBlobString(image,"\n");
+      p++;
+    }
+    if (image->previous == (Image *) NULL)
+      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+          (QuantumTick(y,image->rows) != MagickFalse))
+        {
+          status=image->progress_monitor(SaveImageTag,y,image->rows,
+            image->client_data);
+          if (status == MagickFalse)
+            break;
+        }
+  }
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
