@@ -145,7 +145,7 @@ ModuleExport void UnregisterUILImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -208,7 +208,7 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   transparent=MagickFalse;
   i=0;
@@ -298,8 +298,7 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
     pixel.colorspace=RGBColorspace;
     pixel.depth=8;
     pixel.opacity=(MagickRealType) OpaqueOpacity;
-    (void) QueryMagickColorname(image,&pixel,X11Compliance,MagickTrue,name,
-      &image->exception);
+    GetColorTuple(&pixel,MagickTrue,name);
     if (transparent != MagickFalse)
       if (i == (long) (colors-1))
         (void) CopyMagickString(name,"None",MaxTextExtent);
@@ -367,6 +366,6 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
           break;
       }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
