@@ -18,7 +18,7 @@
 %                                March 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,16 +51,18 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
-#if defined(HasXML)
+#include "magick/module.h"
+#if defined(MAGICKCORE_XML_DELEGATE)
 #  if defined(__WINDOWS__)
 #    if defined(__MINGW32__)
 #      define _MSC_VER
+#    else
+#      include <win32config.h>
 #    endif
-#    include <win32config.h>
 #  endif
 #  include <libxml/parser.h>
 #  include <libxml/xmlmemory.h>
@@ -89,7 +91,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -164,7 +166,7 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) CopyMagickString(read_info->filename,image_info->filename+2,
         MaxTextExtent);
     }
-#if defined(HasXML) && defined(LIBXML_FTP_ENABLED)
+#if defined(MAGICKCORE_XML_DELEGATE) && defined(LIBXML_FTP_ENABLED)
   if (LocaleCompare(read_info->magick,"ftp") == 0)
     {
       void
@@ -181,7 +183,7 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
     }
 #endif
-#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED)
+#if defined(MAGICKCORE_XML_DELEGATE) && defined(LIBXML_HTTP_ENABLED)
   if (LocaleCompare(read_info->magick,"http") == 0)
     {
       char
@@ -239,36 +241,37 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterURLImage method is:
 %
-%      RegisterURLImage(void)
+%      unsigned long RegisterURLImage(void)
 %
 */
-ModuleExport void RegisterURLImage(void)
+ModuleExport unsigned long RegisterURLImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("HTTP");
-#if defined(HasXML) && defined(LIBXML_HTTP_ENABLED)
-  entry->decoder=(DecoderHandler *) ReadURLImage;
+#if defined(MAGICKCORE_XML_DELEGATE) && defined(LIBXML_HTTP_ENABLED)
+  entry->decoder=(DecodeImageHandler *) ReadURLImage;
 #endif
   entry->description=ConstantString("Uniform Resource Locator (http://)");
   entry->module=ConstantString("URL");
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FTP");
-#if defined(HasXML) && defined(LIBXML_FTP_ENABLED)
-  entry->decoder=(DecoderHandler *) ReadURLImage;
+#if defined(MAGICKCORE_XML_DELEGATE) && defined(LIBXML_FTP_ENABLED)
+  entry->decoder=(DecodeImageHandler *) ReadURLImage;
 #endif
   entry->description=ConstantString("Uniform Resource Locator (ftp://)");
   entry->module=ConstantString("URL");
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FILE");
-  entry->decoder=(DecoderHandler *) ReadURLImage;
+  entry->decoder=(DecodeImageHandler *) ReadURLImage;
   entry->description=ConstantString("Uniform Resource Locator (file://)");
   entry->module=ConstantString("URL");
   entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
