@@ -85,7 +85,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -128,7 +128,7 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   if ((image->columns % 2) != 0)
@@ -147,7 +147,7 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
   image->depth=8;
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   if (SetImageExtent(image,0,0) == MagickFalse)
@@ -190,12 +190,10 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
       }
   }
   image->colorspace=YCbCrColorspace;
-  if (image_info->colorspace == UndefinedColorspace)
-    (void) SetImageColorspace(image,RGBColorspace);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -295,7 +293,7 @@ ModuleExport void UnregisterUYVYImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %      Implicit assumption: number of columns is even.
@@ -343,8 +341,7 @@ static MagickBooleanType WriteUYVYImage(const ImageInfo *image_info,
   uyvy_image=CloneImage(image,0,0,MagickTrue,&image->exception);
   if (uyvy_image == (Image *) NULL)
     ThrowWriterException(ResourceLimitError,image->exception.reason);
-  if (image_info->colorspace == UndefinedColorspace)
-    (void) SetImageColorspace(uyvy_image,YCbCrColorspace);
+  (void) SetImageColorspace(uyvy_image,YCbCrColorspace);
   full=MagickFalse;
   (void) ResetMagickMemory(&pixel,0,sizeof(MagickPixelPacket));
   for (y=0; y < (long) image->rows; y++)
@@ -379,6 +376,6 @@ static MagickBooleanType WriteUYVYImage(const ImageInfo *image_info,
       }
   }
   uyvy_image=DestroyImage(uyvy_image);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
