@@ -67,7 +67,7 @@
 #include "magick/module.h"
 #include "wand/MagickWand.h"
 
-#if defined(MAGICKCORE_WMF_DELEGATE) || defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMF_DELEGATE) || defined(MAGICKCORE_WMFLITE_DELEGATE)
 
 #define ERR(API)  ((API)->err != wmf_E_None)
 #define XC(x) ((double) x)
@@ -132,7 +132,7 @@
 #define CENTIMETERS_PER_INCH  2.54
 #define POINTS_PER_INCH       72
 
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
 # define wmf_api_create(api,flags,options) wmf_lite_create(api,flags,options)
 # define wmf_api_destroy(api) wmf_lite_destroy(api)
 # undef WMF_FONT_PSNAME
@@ -217,7 +217,7 @@ typedef enum
 }
 magick_arc_t;
 
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
 static void  lite_font_init (wmfAPI* API, wmfAPI_Options* options);
 static void  lite_font_map(wmfAPI* API,wmfFont* font);
 static float lite_font_stringwidth(wmfAPI* API, wmfFont* font, char* str);
@@ -243,7 +243,7 @@ static void         ipa_draw_line(wmfAPI * API, wmfDrawLine_t * draw_line);
 static void         ipa_draw_pie(wmfAPI * API, wmfDrawArc_t * draw_arc);
 static void         ipa_draw_pixel(wmfAPI * API, wmfDrawPixel_t * draw_pixel);
 static void         ipa_draw_polygon(wmfAPI * API, wmfPolyLine_t * poly_line);
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
 static void         ipa_draw_polypolygon(wmfAPI * API, wmfPolyPoly_t* polypolygon);
 #endif
 static void         ipa_draw_rectangle(wmfAPI * API, wmfDrawRectangle_t * draw_rect);
@@ -262,7 +262,7 @@ static void         ipa_udata_init(wmfAPI * API, wmfUserData_t * userdata);
 static void         ipa_udata_set(wmfAPI * API, wmfUserData_t * userdata);
 static int          magick_progress_callback(void* wand,float quantum);
 static void         util_draw_arc(wmfAPI * API, wmfDrawArc_t * draw_arc,magick_arc_t finish);
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
 /*static int          util_font_weight( const char* font );*/
 #endif
 static double       util_pointsize( wmfAPI* API, wmfFont* font, char* str, double font_height);
@@ -1049,7 +1049,7 @@ static void ipa_draw_polygon(wmfAPI * API, wmfPolyLine_t * polyline)
 }
 
 /* Draw a polypolygon.  A polypolygon is a list of polygons */
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
 static void ipa_draw_polypolygon(wmfAPI * API, wmfPolyPoly_t* polypolygon)
 {
   if (TO_FILL(polypolygon) || TO_DRAW(polypolygon))
@@ -1242,7 +1242,7 @@ static void ipa_functions(wmfAPI *API)
   FR->draw_line = ipa_draw_line;
   FR->poly_line = ipa_poly_line;
   FR->draw_polygon = ipa_draw_polygon;
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
   FR->draw_polypolygon = ipa_draw_polypolygon;
 #endif
   FR->draw_rectangle = ipa_draw_rectangle;
@@ -1383,7 +1383,7 @@ static void ipa_draw_text(wmfAPI * API, wmfDrawText_t * draw_text)
               double
                 text_width = metrics.width * (ddata->scale_y / ddata->scale_x);
 
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
               point.x -= text_width / 2;
 #else
               point.x += bbox_width / 2 - text_width / 2;
@@ -2056,7 +2056,7 @@ static double util_pointsize( wmfAPI* API, wmfFont* font, char* str, double font
   return floor(pointsize);
 }
 
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
 /* Estimate weight based on font name */
 /*
 static int util_font_weight( const char* font )
@@ -2342,7 +2342,7 @@ static void lite_font_init( wmfAPI* API, wmfAPI_Options* options)
   ((wmf_magick_font_t*)font_data->user_data)->pointsize = 0;
 }
 
-#endif /* MAGICKCORE_WMF_DELEGATElite */
+#endif /* MAGICKCORE_WMFLITE_DELEGATE */
 
 /* BLOB read byte */
 static int ipa_blob_read(void* wand)
@@ -2400,7 +2400,7 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
   wmfD_Rect
     bbox;
 
-  image = AllocateImage(image_info);
+  image = AcquireImage(image_info);
   if (OpenBlob(image_info,image,ReadBinaryBlobMode,exception) == MagickFalse)
     {
       if (image->debug != MagickFalse)
@@ -2449,7 +2449,7 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
   ddata->image = image;
   ddata->image_info = image_info;
 
-#if defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)
   /* Must initialize font subystem for WMFlite interface */
   lite_font_init (API,&wmf_api_options); /* similar to wmf_ipa_font_init in src/font.c */
   /* wmf_arg_fontdirs (API,options); */ /* similar to wmf_arg_fontdirs in src/wmf.c */
@@ -2639,7 +2639,7 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
     printf("dc->Window.height = %d\n", dc->Window.height);
     printf("dc->pixel_width   = %g\n", dc->pixel_width);
     printf("dc->pixel_height  = %g\n", dc->pixel_height);
-#if defined(MAGICKCORE_WMF_DELEGATElite)  /* Only in libwmf 0.3 */
+#if defined(MAGICKCORE_WMFLITE_DELEGATE)  /* Only in libwmf 0.3 */
     printf("dc->Ox            = %.d\n", dc->Ox);
     printf("dc->Oy            = %.d\n", dc->Oy);
     printf("dc->width         = %.d\n", dc->width);
@@ -2661,7 +2661,7 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
   if (image_info->ping != MagickFalse)
     {
       wmf_api_destroy(API);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       if (image->debug != MagickFalse)
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),
           "leave ReadWMFImage()");
@@ -2749,13 +2749,13 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
 
   /* Cleanup allocated data */
   wmf_api_destroy(API);
-  CloseBlob(image);
+  (void) CloseBlob(image);
 
   /* Return image */
   return image;
 }
 /* #endif */
-#endif /* MAGICKCORE_WMF_DELEGATE || MAGICKCORE_WMF_DELEGATElite */
+#endif /* MAGICKCORE_WMF_DELEGATE || MAGICKCORE_WMFLITE_DELEGATE */
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -2786,7 +2786,7 @@ ModuleExport unsigned long RegisterWMFImage(void)
     *entry;
 
   entry = SetMagickInfo("WMZ");
-#if defined(MAGICKCORE_WMF_DELEGATE) || defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMF_DELEGATE) || defined(MAGICKCORE_WMFLITE_DELEGATE)
   entry->decoder=ReadWMFImage;
 #endif
   entry->description=ConstantString("Compressed Windows Meta File");
@@ -2795,7 +2795,7 @@ ModuleExport unsigned long RegisterWMFImage(void)
   entry->module=ConstantString("WMZ");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("WMF");
-#if defined(MAGICKCORE_WMF_DELEGATE) || defined(MAGICKCORE_WMF_DELEGATElite)
+#if defined(MAGICKCORE_WMF_DELEGATE) || defined(MAGICKCORE_WMFLITE_DELEGATE)
   entry->decoder=ReadWMFImage;
 #endif
   entry->description=ConstantString("Windows Meta File");
