@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -79,7 +80,7 @@
 %
 %    o image:  The image.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -117,7 +118,7 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if (image->columns == 0)
     image->columns=1;
   if (image->rows == 0)
@@ -133,7 +134,7 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->matte=color.matte;
   if ((image->colorspace == RGBColorspace) && (image->matte == MagickFalse))
     {
-      if (AllocateImageColormap(image,1) == MagickFalse)
+      if (AcquireImageColormap(image,1) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       (void) QueryColorDatabase((char *) image_info->filename,
         &image->background_color,exception);
@@ -189,22 +190,23 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXCImage method is:
 %
-%      RegisterXCImage(void)
+%      unsigned long RegisterXCImage(void)
 %
 */
-ModuleExport void RegisterXCImage(void)
+ModuleExport unsigned long RegisterXCImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("XC");
-  entry->decoder=(DecoderHandler *) ReadXCImage;
+  entry->decoder=(DecodeImageHandler *) ReadXCImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Constant image uniform color");
   entry->module=ConstantString("XC");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
