@@ -104,51 +104,67 @@ typedef enum
   COMPRESS_FRACTAL           =  3   /* unused */
 } XcfCompressionType;
 
-typedef struct {
+typedef struct
+{
   unsigned long
     width,
     height,
     image_type,
-    bpp;  /* BYTES per pixel!! */
+    bytes_per_pixel;
 
   int
     compression;
 
-  /* not really part of the doc, but makes it easy to pass around! */
+  size_t
+    file_size;
+
   ExceptionInfo
     *exception;
 } XCFDocInfo;
 
-typedef struct {
-  char      name[1024];
-  unsigned int  active;
-  unsigned long  width,
-          height,
-          type,
-          opacity,
-          visible,
-          linked,
-          preserve_trans,
-          apply_mask,
-          show_mask,
-          edit_mask,
-          floating_offset;
-  long offset_x,
-          offset_y;
-  unsigned long mode,
-          tattoo;
-  Image*      image;
+typedef struct
+{
+  char
+    name[1024];
+
+  unsigned int
+    active;
+
+  unsigned long
+    width,
+    height,
+    type,
+    opacity,
+    visible,
+    linked,
+    preserve_trans,
+    apply_mask,
+    show_mask,
+    edit_mask,
+    floating_offset;
+
+  ssize_t
+    offset_x,
+    offset_y;
+
+  unsigned long
+    mode,
+    tattoo;
+
+  Image
+    *image;
 } XCFLayerInfo;
 
 #define TILE_WIDTH   64
 #define TILE_HEIGHT  64
 
-typedef struct {
+typedef struct
+{
   unsigned char
     red,
     green,
     blue,
-    opacity;  /* NOTE: reversed from IM! */
+    opacity;
 } XCFPixelPacket;
 
 /*
@@ -186,7 +202,6 @@ static MagickBooleanType IsXCF(const unsigned char *magick,const size_t length)
     return(MagickTrue);
   return(MagickFalse);
 }
-
 
 typedef enum
 {
@@ -215,9 +230,11 @@ typedef enum
   Simple utility routine to convert between PSD blending modes and
   ImageMagick compositing operators
 */
-static CompositeOperator GIMPBlendModeToCompositeOperator( unsigned long blendMode )
+static CompositeOperator GIMPBlendModeToCompositeOperator(
+  unsigned long blendMode)
 {
-  switch ( blendMode ) {
+  switch ( blendMode )
+  {
     case GIMP_NORMAL_MODE:    return( OverCompositeOp );
     case GIMP_DISSOLVE_MODE:  return( DissolveCompositeOp );
     case GIMP_MULTIPLY_MODE:  return( MultiplyCompositeOp );
@@ -239,10 +256,9 @@ static CompositeOperator GIMPBlendModeToCompositeOperator( unsigned long blendMo
     case GIMP_VALUE_MODE:    return( OverCompositeOp );
     case GIMP_DIVIDE_MODE:    return( OverCompositeOp );
     default:
-        return( OverCompositeOp );
+      return(OverCompositeOp);
   }
 }
-
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -264,9 +280,9 @@ static CompositeOperator GIMPBlendModeToCompositeOperator( unsigned long blendMo
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o string: The address of a character buffer.
+%    o string: the address of a character buffer.
 %
 */
 
@@ -312,279 +328,326 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
   return(string);
 }
 
-
-static int load_tile (Image* image, Image* tile_image, XCFDocInfo* inDocInfo,
-            XCFLayerInfo*  inLayerInfo, size_t data_length)
+static MagickBooleanType load_tile(Image *image,Image *tile_image,
+  XCFDocInfo *inDocInfo,XCFLayerInfo *inLayerInfo,size_t data_length)
 {
-  long i;
-  ssize_t nmemb_read_successfully;
-  PixelPacket*  q;
-  XCFPixelPacket *xcfdata, *xcfodata;
-  unsigned char  *graydata;
+  long
+    y;
 
-  xcfdata = xcfodata = (XCFPixelPacket *) AcquireQuantumMemory(data_length,
-    sizeof(*xcfdata));
-  graydata = (unsigned char *)xcfdata;  /* used by gray and indexed */
-  nmemb_read_successfully = ReadBlob(image, data_length, (unsigned char *) xcfdata);
-  if (nmemb_read_successfully > (ssize_t) (tile_image->columns*tile_image->rows))
-    ThrowBinaryException(CorruptImageError,"NotEnoughPixelData",image->filename);
+  register long
+    x;
 
-  q=SetImagePixels(tile_image,0,0,tile_image->columns,tile_image->rows);
+  register PixelPacket
+    *q;
 
-  /* we have to copy the pixels individually since IM uses a different
-     format PixelPacket on different platforms - not to mention
-     different MAGICKCORE_QUANTUM_DEPTHs!
-  */
-  for ( i=0; i < (long) nmemb_read_successfully;i++ ) {
-    if ( inDocInfo->image_type == GIMP_GRAY ) {
-      q->red    = ScaleCharToQuantum(*graydata);
-      q->green  = ScaleCharToQuantum(*graydata);
-      q->blue    = ScaleCharToQuantum(*graydata);
-      q->opacity  = ScaleCharToQuantum((unsigned char) (255-inLayerInfo->opacity));
-      graydata++;
-    } else if ( inDocInfo->image_type == GIMP_RGB ) {
-      q->red    = ScaleCharToQuantum(xcfdata->red);
-      q->green  = ScaleCharToQuantum(xcfdata->green);
-      q->blue    = ScaleCharToQuantum(xcfdata->blue);
-      q->opacity  = (Quantum) ((int) xcfdata->opacity==0 ? TransparentOpacity : ScaleCharToQuantum((unsigned char) (255-inLayerInfo->opacity)));
+  ssize_t
+    count;
 
-      xcfdata++;
-    };
+  unsigned char
+    *graydata;
 
-    q++;
+  XCFPixelPacket
+    *xcfdata,
+    *xcfodata;
+
+  xcfdata=(XCFPixelPacket *) AcquireQuantumMemory(data_length,sizeof(*xcfdata));
+  if (xcfdata == (XCFPixelPacket *) NULL)
+    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
+      image->filename);
+  xcfodata=xcfdata;
+  graydata=(unsigned char *) xcfdata;  /* used by gray and indexed */
+  count=ReadBlob(image,data_length,(unsigned char *) xcfdata);
+  if (count != (ssize_t) data_length)
+    ThrowBinaryException(CorruptImageError,"NotEnoughPixelData",
+      image->filename);
+  for (y=0; y < (long) tile_image->rows; y++)
+  {
+    q=SetImagePixels(tile_image,0,y,tile_image->columns,1);
+    if (q == (PixelPacket *) NULL)
+      break;
+    if (inDocInfo->image_type == GIMP_GRAY)
+      {
+        for (x=0; x < (long) tile_image->columns; x++)
+        {
+          q->red=ScaleCharToQuantum(*graydata);
+          q->green=q->red;
+          q->blue=q->red;
+          q->opacity=ScaleCharToQuantum(255-inLayerInfo->opacity);
+          graydata++;
+          q++;
+        }
+      }
+    else
+      if (inDocInfo->image_type == GIMP_RGB)
+        {
+          for (x=0; x < (long) tile_image->columns; x++)
+          {
+            q->red=ScaleCharToQuantum(xcfdata->red);
+            q->green=ScaleCharToQuantum(xcfdata->green);
+            q->blue=ScaleCharToQuantum(xcfdata->blue);
+            q->opacity=(Quantum) (xcfdata->opacity == 0U ? TransparentOpacity :
+              ScaleCharToQuantum(255-inLayerInfo->opacity));
+            xcfdata++;
+            q++;
+          }
+        }
+     if (SyncImagePixels(tile_image) == MagickFalse)
+       break;
   }
-
   xcfodata=(XCFPixelPacket *) RelinquishMagickMemory(xcfodata);
   return MagickTrue;
 }
 
-static int load_tile_rle (Image* image, Image* tile_image, XCFDocInfo* inDocInfo,
-              XCFLayerInfo*  inLayerInfo, int data_length)
+static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
+  XCFDocInfo *inDocInfo,XCFLayerInfo *inLayerInfo,size_t data_length)
 {
-  unsigned char data, val;
-  MagickOffsetType size;
-  size_t length;
-  int bpp;    /* BYTES per pixel! */
-  long i, j;
-  ssize_t nmemb_read_successfully;
-  unsigned char *xcfdata, *xcfodata, *xcfdatalimit;
-  PixelPacket*  q;
+  long
+    i,
+    j;
 
-  bpp = (int) inDocInfo->bpp;
+  MagickOffsetType
+    size;
 
-  xcfdata = xcfodata = (unsigned char *) AcquireQuantumMemory((size_t)
-    data_length,sizeof(*xcfdata));
+  register PixelPacket
+    *q;
 
-  nmemb_read_successfully = ReadBlob(image, (size_t) data_length, xcfdata);
+  ssize_t
+    bytes_per_pixel,
+    count;
 
-  xcfdatalimit = xcfodata+nmemb_read_successfully-1;
+  size_t
+    length;
 
-  for (i=0; i < bpp; i++)
+  unsigned char
+    data,
+    pixel,
+    *xcfdata,
+    *xcfodata,
+    *xcfdatalimit;
+
+  bytes_per_pixel=(ssize_t) inDocInfo->bytes_per_pixel;
+  xcfdata=(unsigned char *) AcquireQuantumMemory(data_length,sizeof(*xcfdata));
+  if (xcfdata == (unsigned char *) NULL)
+    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
+      image->filename);
+  xcfodata=xcfdata;
+  count=ReadBlob(image, (size_t) data_length, xcfdata);
+  xcfdatalimit = xcfodata+count-1;
+  for (i=0; i < (long) bytes_per_pixel; i++)
   {
     q=GetImagePixels(tile_image,0,0,tile_image->columns,tile_image->rows);
     size=(MagickOffsetType) tile_image->rows*tile_image->columns;
     while (size > 0)
     {
       if (xcfdata > xcfdatalimit)
-        {
-          goto bogus_rle;
-        }
-      val=(*xcfdata++);
-      length=(size_t) val;
+        goto bogus_rle;
+      pixel=(*xcfdata++);
+      length=(size_t) pixel;
       if (length >= 128)
         {
-          length = 255 - (length - 1);
+          length=255-(length-1);
           if (length == 128)
             {
-                if (xcfdata >= xcfdatalimit)
-                  {
-                    goto bogus_rle;
-                  }
-
-                length = (size_t) ((*xcfdata << 8) + xcfdata[1]);
-                xcfdata += 2;
-              }
-
-            size -= length;
-
+              if (xcfdata >= xcfdatalimit)
+                goto bogus_rle;
+              length=(size_t) ((*xcfdata << 8) + xcfdata[1]);
+              xcfdata+=2;
+            }
+            size-=length;
             if (size < 0)
-              {
-                goto bogus_rle;
-              }
-
+              goto bogus_rle;
             if (&xcfdata[length-1] > xcfdatalimit)
-              {
-                goto bogus_rle;
-              }
-
+              goto bogus_rle;
             while (length-- > 0)
             {
-              data = *xcfdata++;
-              switch (i) {
+              data=(*xcfdata++);
+              switch (i)
+              {
                 case 0:
-                q->red=ScaleCharToQuantum(data);
-                q->green=q->red;
-                q->blue=q->red;
-                q->opacity=ScaleCharToQuantum((unsigned char) (255-inLayerInfo->opacity));
-                break;
-                case 1: q->green=ScaleCharToQuantum(data);  break;
-                case 2: q->blue=ScaleCharToQuantum(data);  break;
+                {
+                  q->red=ScaleCharToQuantum(data);
+                  if (inDocInfo->image_type == GIMP_GRAY)
+                    {
+                      q->green=ScaleCharToQuantum(data);
+                      q->blue=ScaleCharToQuantum(data);
+                      q->opacity=ScaleCharToQuantum(255-inLayerInfo->opacity);
+                    }
+                  else
+                    {
+                      q->green= q->red;
+                      q->blue= q->red;
+                      q->opacity=ScaleCharToQuantum(255-inLayerInfo->opacity);
+                    }
+                  break;
+                }
+                case 1:
+                {
+                  q->green=ScaleCharToQuantum(data);
+                  break;
+                }
+                case 2:
+                {
+                  q->blue=ScaleCharToQuantum(data);
+                  break;
+                }
                 case 3:
-                  q->opacity=(Quantum) (ScaleCharToQuantum((unsigned char) (255UL-data)));
-                break;
+                {
+                  q->opacity=(Quantum) (data == 0 ? TransparentOpacity :
+                    ScaleCharToQuantum(255-inLayerInfo->opacity));
+                  break;
+                }
               }
               q++;
             }
           }
         else
           {
-            length += 1;
+            length+=1;
             if (length == 128)
               {
                 if (xcfdata >= xcfdatalimit)
-                  {
-                    goto bogus_rle;
-                  }
-
-                length = (size_t) ((*xcfdata << 8) + xcfdata[1]);
-                xcfdata += 2;
+                  goto bogus_rle;
+                length=(size_t) ((*xcfdata << 8) + xcfdata[1]);
+                xcfdata+=2;
               }
-
-            size -= length;
-
+            size-=length;
             if (size < 0)
-              {
-                goto bogus_rle;
-              }
-
+              goto bogus_rle;
             if (xcfdata > xcfdatalimit)
-              {
-                goto bogus_rle;
-              }
-
-            val = *xcfdata++;
-
-            for (j = 0; j < (long) length; j++)
+              goto bogus_rle;
+            pixel=(*xcfdata++);
+            for (j= 0; j < (long) length; j++)
             {
-              data = val;
+              data=pixel;
               switch (i)
               {
                 case 0:
+                {
                   q->red=ScaleCharToQuantum(data);
-                  q->green=q->red;
-                  q->blue=q->red;
-                  q->opacity=ScaleCharToQuantum((unsigned char) (255-inLayerInfo->opacity));
+                  if (inDocInfo->image_type == GIMP_GRAY)
+                    {
+                      q->green=ScaleCharToQuantum(data);
+                      q->blue=ScaleCharToQuantum(data);
+                      q->opacity=ScaleCharToQuantum(255-inLayerInfo->opacity);
+                    }
+                  else
+                    {
+                      q->green=q->red;
+                      q->blue=q->red;
+                      q->opacity=ScaleCharToQuantum(255-inLayerInfo->opacity);
+                    }
                   break;
-                case 1: q->green=ScaleCharToQuantum(data);  break;
-                case 2: q->blue=ScaleCharToQuantum(data);  break;
+                }
+                case 1:
+                {
+                  q->green=ScaleCharToQuantum(data);
+                  break;
+                }
+                case 2:
+                {
+                  q->blue=ScaleCharToQuantum(data);
+                  break;
+                }
                 case 3:
-                  q->opacity=(Quantum) (ScaleCharToQuantum((unsigned char) (255-data)));
+                {
+                  q->opacity=(Quantum) (data == 0 ? TransparentOpacity :
+                    ScaleCharToQuantum(255-inLayerInfo->opacity));
                   break;
+                }
               }
               q++;
             }
           }
       }
-      (void) SyncImagePixels(tile_image);
+      if (SyncImagePixels(tile_image) == MagickFalse)
+        break;
     }
   xcfodata=(unsigned char *) RelinquishMagickMemory(xcfodata);
-  return MagickTrue;
+  return(MagickTrue);
 
- bogus_rle:
-  if (xcfodata)
-    xcfodata=(unsigned char *) RelinquishMagickMemory(xcfodata);
-  return MagickFalse;
+  bogus_rle:
+    if (xcfodata != (unsigned char *) NULL)
+      xcfodata=(unsigned char *) RelinquishMagickMemory(xcfodata);
+  return(MagickFalse);
 }
 
-static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
-  inLayerInfo)
+static MagickBooleanType load_level(Image *image,XCFDocInfo *inDocInfo,
+  XCFLayerInfo *inLayerInfo)
 {
-  MagickOffsetType
-    saved_pos,
-    offset,
-    offset2;
-
-  unsigned long
-    ntiles,
-    ntile_rows,
-    ntile_cols,
-    junk_width,
-    junk_height;
-
-  Image*
-    tile_image;
+  ExceptionInfo
+    *exception;
 
   int
     destLeft = 0,
     destTop = 0;
 
-  long
-    i;
+  Image*
+    tile_image;
 
   MagickBooleanType
-    fail;
+    status;
+
+  MagickOffsetType
+    saved_pos,
+    offset,
+    offset2;
+
+  register long
+    i;
 
   unsigned long
+    width,
+    height,
+    ntiles,
+    ntile_rows,
+    ntile_cols,
     tile_image_width,
     tile_image_height;
 
-  ExceptionInfo
-    *exception = inDocInfo->exception;
-
   /* start reading the data */
-  junk_width = ReadBlobMSBLong(image);
-  junk_height = ReadBlobMSBLong(image);
+  exception=inDocInfo->exception;
+  width=ReadBlobMSBLong(image);
+  height=ReadBlobMSBLong(image);
 
   /* read in the first tile offset.
    *  if it is '0', then this tile level is empty
    *  and we can simply return.
    */
-
-  offset = (MagickOffsetType) ReadBlobMSBLong(image);
+  offset=(MagickOffsetType) ReadBlobMSBLong(image);
   if (offset == 0)
-    return 1;
-
+    return(MagickTrue);
   /* Initialise the reference for the in-memory tile-compression
    */
-  ntile_rows = (junk_height + TILE_HEIGHT - 1) / TILE_HEIGHT;
-  ntile_cols = (junk_width  + TILE_WIDTH  - 1) / TILE_WIDTH;
-  ntiles = ntile_rows * ntile_cols;
+  ntile_rows=(height+TILE_HEIGHT-1)/TILE_HEIGHT;
+  ntile_cols=(width+TILE_WIDTH-1)/TILE_WIDTH;
+  ntiles=ntile_rows*ntile_cols;
   for (i = 0; i < (long) ntiles; i++)
-    {
-      fail = MagickFalse;
-
-      if (offset == 0)
-        ThrowBinaryException(CorruptImageError,"NotEnoughTiles",
-          image->filename);
-
-      /* save the current position as it is where the
-       *  next tile offset is stored.
-       */
-      saved_pos = TellBlob(image);
-
-      /* read in the offset of the next tile so we can calculate the amount
-         of data needed for this tile*/
-      offset2 = (MagickOffsetType) ReadBlobMSBLong(image);
-
-      /* if the offset is 0 then we need to read in the maximum possible
-         allowing for negative compression */
-
-      if (offset2 == 0)
-      offset2 = (MagickOffsetType) (offset + TILE_WIDTH * TILE_WIDTH * 4* 1.5);
-                      /* 1.5 is probably more
-                         than we need to allow */
-
-      /* seek to the tile offset */
-      offset=SeekBlob(image, offset, SEEK_SET);
+  {
+    status=MagickFalse;
+    if (offset == 0)
+      ThrowBinaryException(CorruptImageError,"NotEnoughTiles",image->filename);
+    /* save the current position as it is where the
+     *  next tile offset is stored.
+     */
+    saved_pos=TellBlob(image);
+    /* read in the offset of the next tile so we can calculate the amount
+       of data needed for this tile*/
+    offset2=(MagickOffsetType)ReadBlobMSBLong(image);
+    /* if the offset is 0 then we need to read in the maximum possible
+       allowing for negative compression */
+    if (offset2 == 0)
+      offset2=(MagickOffsetType) (offset + TILE_WIDTH * TILE_WIDTH * 4* 1.5);
+    /* seek to the tile offset */
+    offset=SeekBlob(image, offset, SEEK_SET);
 
       /* allocate the image for the tile
         NOTE: the last tile in a row or column may not be a full tile!
       */
       tile_image_width=(unsigned long) (destLeft == (int) ntile_cols-1 ?
-        (int) junk_width % TILE_WIDTH : TILE_WIDTH);
+        (int) width % TILE_WIDTH : TILE_WIDTH);
       if (tile_image_width == 0) tile_image_width=TILE_WIDTH;
       tile_image_height = (unsigned long) (destTop == (int) ntile_rows-1 ?
-        (int) junk_height % TILE_HEIGHT : TILE_HEIGHT);
+        (int) height % TILE_HEIGHT : TILE_HEIGHT);
       if (tile_image_height == 0) tile_image_height=TILE_HEIGHT;
       tile_image=CloneImage(inLayerInfo->image,tile_image_width,
         tile_image_height,MagickTrue,exception);
@@ -594,12 +657,12 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
       {
         case COMPRESS_NONE:
           if (load_tile(image,tile_image,inDocInfo,inLayerInfo,(size_t) (offset2-offset)) == 0)
-            fail = MagickTrue;
+            status=MagickTrue;
           break;
         case COMPRESS_RLE:
           if (load_tile_rle (image,tile_image,inDocInfo,inLayerInfo,
               (int) (offset2-offset)) == 0)
-            fail = MagickTrue;
+            status=MagickTrue;
           break;
         case COMPRESS_ZLIB:
           ThrowBinaryException(CoderError,"ZipCompressNotSupported",
@@ -610,9 +673,9 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
       }
 
       /* composite the tile onto the layer's image, and then destroy it */
-        (void) CompositeImage(inLayerInfo->image,CopyCompositeOp,tile_image,
-                  destLeft * TILE_WIDTH,destTop*TILE_HEIGHT);
-        tile_image=DestroyImage(tile_image);
+      (void) CompositeImage(inLayerInfo->image,CopyCompositeOp,tile_image,
+        destLeft * TILE_WIDTH,destTop*TILE_HEIGHT);
+      tile_image=DestroyImage(tile_image);
 
       /* adjust tile position */
       destLeft++;
@@ -621,78 +684,69 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
           destLeft = 0;
           destTop++;
         }
-
-      if (fail != MagickFalse)
-          return MagickFalse;
-
+      if (status != MagickFalse)
+        return(MagickFalse);
       /* restore the saved position so we'll be ready to
        *  read the next offset.
        */
       offset=SeekBlob(image, saved_pos, SEEK_SET);
-
       /* read in the offset of the next tile */
-      offset = (MagickOffsetType) ReadBlobMSBLong(image);
+      offset=(MagickOffsetType) ReadBlobMSBLong(image);
     }
-
-
   if (offset != 0)
     ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename)
-
-  return 1;
+  return(MagickTrue);
 }
 
-static int load_hierarchy (Image *image, XCFDocInfo* inDocInfo, XCFLayerInfo*
-    inLayer)
+static MagickBooleanType load_hierarchy(Image *image,XCFDocInfo *inDocInfo,
+   XCFLayerInfo *inLayer)
 {
   MagickOffsetType
-  saved_pos,
-  offset,
-  junk;
+    saved_pos,
+    offset,
+    junk;
 
   unsigned long
-  junk_width,
-  junk_height,
-  junk_bpp;
+    width,
+    height,
+    bytes_per_pixel;
 
-  junk_width = ReadBlobMSBLong(image);
-  junk_height = ReadBlobMSBLong(image);
-  junk_bpp = inDocInfo->bpp = ReadBlobMSBLong(image);
+  width=ReadBlobMSBLong(image);
+  height=ReadBlobMSBLong(image);
+  bytes_per_pixel=inDocInfo->bytes_per_pixel=ReadBlobMSBLong(image);
 
   /* load in the levels...we make sure that the number of levels
    *  calculated when the TileManager was created is the same
    *  as the number of levels found in the file.
    */
-  offset = (MagickOffsetType) ReadBlobMSBLong(image);  /* top level */
+  offset=(MagickOffsetType) ReadBlobMSBLong(image);  /* top level */
 
   /* discard offsets for layers below first, if any.
    */
   do
   {
-    junk = (MagickOffsetType) ReadBlobMSBLong(image);
+    junk=(MagickOffsetType) ReadBlobMSBLong(image);
   }
   while (junk != 0);
 
   /* save the current position as it is where the
    *  next level offset is stored.
    */
-  saved_pos = TellBlob(image);
+  saved_pos=TellBlob(image);
 
   /* seek to the level offset */
   offset=SeekBlob(image, offset, SEEK_SET);
 
   /* read in the level */
   if (load_level (image, inDocInfo, inLayer) == 0)
-    return 0;
-
+    return(MagickFalse);
   /* restore the saved position so we'll be ready to
    *  read the next offset.
    */
   offset=SeekBlob(image, saved_pos, SEEK_SET);
-
-  return 1;
+  return(MagickTrue);
 }
 
-
 static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   XCFLayerInfo *outLayer )
 {
@@ -711,26 +765,22 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
 
   /* clear the block! */
   (void) ResetMagickMemory( outLayer, 0, sizeof( XCFLayerInfo ) );
-
   /* read in the layer width, height, type and name */
   outLayer->width = ReadBlobMSBLong(image);
   outLayer->height = ReadBlobMSBLong(image);
   outLayer->type = ReadBlobMSBLong(image);
   (void) ReadBlobStringWithLongSize(image, outLayer->name,
     sizeof(outLayer->name));
-
   /* allocate the image for this layer */
   outLayer->image=CloneImage(image,outLayer->width, outLayer->height,MagickTrue,
      &image->exception);
   if (outLayer->image == (Image *) NULL)
     return MagickFalse;
-
   /* read the layer properties! */
   foundPropEnd = 0;
   while ( (foundPropEnd == MagickFalse) && (EOFBlob(image) == MagickFalse) ) {
   PropType    prop_type = (PropType) ReadBlobMSBLong(image);
   unsigned long  prop_size = ReadBlobMSBLong(image);
-
     switch (prop_type)
     {
     case PROP_END:
@@ -899,7 +949,7 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -947,7 +997,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -971,6 +1021,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->columns=doc_info.width;
   image->rows=doc_info.height;
   image_type=doc_info.image_type;
+  doc_info.file_size=GetBlobSize(image);
   image->compression=NoCompression;
   image->depth=8;
   if (image_type == GIMP_RGB)
@@ -987,27 +1038,26 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       return(DestroyImageList(image));
     }
   (void) SetImageBackgroundColor(image);
+  image->matte=MagickTrue;
   /*
     Read properties.
   */
-  while (foundPropEnd == MagickFalse)
+  while ((foundPropEnd == MagickFalse) && (EOFBlob(image) == MagickFalse))
   {
     PropType prop_type = (PropType) ReadBlobMSBLong(image);
-    unsigned long  prop_size = ReadBlobMSBLong(image);
+    unsigned long prop_size = ReadBlobMSBLong(image);
 
     switch (prop_type)
     {
       case PROP_END:
         foundPropEnd=1;
         break;
-
       case PROP_COLORMAP:
       {
         /* Cannot rely on prop_size here--the value is set incorrectly
            by some Gimp versions.
         */
         unsigned long num_colours = ReadBlobMSBLong(image);
-
         for (i=0; i < (long) (3L*num_colours); i++ )
           (void) ReadBlobByte(image);
     /*
@@ -1039,26 +1089,26 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                    (guint8*) gimage->cmap, gimage->num_cols*3);
       }
      */
-      break;
+        break;
       }
-
       case PROP_COMPRESSION:
       {
         doc_info.compression = ReadBlobByte(image);
-
         if ((doc_info.compression != COMPRESS_NONE) &&
-        (doc_info.compression != COMPRESS_RLE) &&
-        (doc_info.compression != COMPRESS_ZLIB) &&
-        (doc_info.compression != COMPRESS_FRACTAL))
+            (doc_info.compression != COMPRESS_RLE) &&
+            (doc_info.compression != COMPRESS_ZLIB) &&
+            (doc_info.compression != COMPRESS_FRACTAL))
           ThrowReaderException(CorruptImageError,"UnrecognizedImageCompression");
       }
       break;
 
       case PROP_GUIDES:
       {
-      /* just skip it - we don't care about guides */
+         /* just skip it - we don't care about guides */
         for (i=0; i < (long) prop_size; i++ )
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
       }
       break;
 
@@ -1097,7 +1147,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       {
         /* BOGUS: we may need these for IPTC stuff */
         for (i=0; i < (long) prop_size; i++ )
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
 
         /*
       glong         base = info->cp;
@@ -1126,7 +1178,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       {
       /* BOGUS: just skip it for now */
         for (i=0; i< (long) prop_size; i++ )
-          (void) ReadBlobByte(image);
+          if (ReadBlobByte(image) == EOF)
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
 
         /*
       PathList *paths = xcf_load_bzpaths (gimage, info);
@@ -1155,54 +1209,56 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /* read over it... */
       while ((prop_size > 0) && (EOFBlob(image) == MagickFalse))
       {
-        amount = (long) MagickMin(16, prop_size);
-        amount = (long) ReadBlob(image,(size_t) amount, (unsigned char *) &buf);
+        amount=(long) MagickMin(16, prop_size);
+        amount=(long) ReadBlob(image,(size_t) amount,(unsigned char *) &buf);
         if (!amount)
           ThrowReaderException(CorruptImageError,"CorruptImage");
-        prop_size -= (unsigned long) MagickMin(16, (size_t) amount);
+        prop_size -= (unsigned long) MagickMin(16,(size_t) amount);
       }
     }
     break;
   }
   }
-
-  
   if (foundPropEnd == MagickFalse)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
-  if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0)) {
-  ; /* do nothing, we were just pinging! */
-  } else {
-    XCFLayerInfo*  layer_info;
-      int  number_layers = 0,
-      current_layer = 0,
-      foundAllLayers = MagickFalse;
+  if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
+    {
+      ; /* do nothing, we were just pinging! */
+    }
+  else
+    {
+      int
+        current_layer = 0,
+        foundAllLayers = MagickFalse,
+        number_layers = 0;
 
-      /* BIG HACK
-        because XCF doesn't include the layer count, and we
-        want to know it in advance in order to allocate memory,
-        we have to scan the layer offset list, and then reposition
+      MagickOffsetType
+        oldPos=TellBlob(image);
+
+      XCFLayerInfo
+        *layer_info;
+
+      /* 
         the read pointer
-    */
-    MagickOffsetType  oldPos = TellBlob(image);
-    do {
-      long  offset = (long) ReadBlobMSBLong(image);
-      if ( offset == 0 )
-        foundAllLayers = MagickTrue;
-      else
-        number_layers++;
-      if (EOFBlob(image) != MagickFalse)
-        {
-          ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
-            image->filename);
-          break;
-        }
-    } while (foundAllLayers  == MagickFalse);
-    offset=SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
+      */
+      do
+      {
+        long offset = (long) ReadBlobMSBLong(image);
+        if (offset == 0)
+          foundAllLayers=MagickTrue;
+        else
+          number_layers++;
+        if (EOFBlob(image) != MagickFalse)
+          {
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
+            break;
+          }
+    } while (foundAllLayers == MagickFalse);
+    offset=SeekBlob(image,oldPos,SEEK_SET); /* restore the position! */
     if (offset < 0)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-
-
     /* allocate our array of layer info blocks */
     length=(size_t) number_layers;
     layer_info=(XCFLayerInfo *) AcquireQuantumMemory(length,
@@ -1210,65 +1266,55 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (layer_info == (XCFLayerInfo *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(layer_info,0,number_layers*sizeof(XCFLayerInfo));
-
     for ( ; ; )
     {
+      MagickBooleanType
+        layer_ok;
+
       MagickOffsetType
         offset,
         saved_pos;
-      int
-        layer_ok;
 
       /* read in the offset of the next layer */
-      offset = (MagickOffsetType) ReadBlobMSBLong(image);
-
+      offset=(MagickOffsetType) ReadBlobMSBLong(image);
       /* if the offset is 0 then we are at the end
       *  of the layer list.
       */
       if (offset == 0)
         break;
-
       /* save the current position as it is where the
       *  next layer offset is stored.
       */
-      saved_pos = TellBlob(image);
-
+      saved_pos=TellBlob(image);
       /* seek to the layer offset */
-      offset=SeekBlob(image, offset, SEEK_SET);
-
+      offset=SeekBlob(image,offset,SEEK_SET);
       /* read in the layer */
-      layer_ok = ReadOneLayer( image, &doc_info, &layer_info[current_layer] );
-      if (layer_ok == MagickFalse) {
-        int j;
-        for (j=0; j < current_layer; j++)
-          layer_info[j].image=DestroyImage(layer_info[j].image);
+      layer_ok=ReadOneLayer(image,&doc_info,&layer_info[current_layer]);
+      if (layer_ok == MagickFalse)
+        {
+          int j;
+
+          for (j=0; j < current_layer; j++)
+            layer_info[j].image=DestroyImage(layer_info[j].image);
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       }
-
       /* restore the saved position so we'll be ready to
       *  read the next offset.
       */
       offset=SeekBlob(image, saved_pos, SEEK_SET);
-
       current_layer++;
     }
-
-    if ( number_layers == 1 ) {
-      /* composite the layer data onto the main image & then dispose the layer */
-      (void) CompositeImage(image, OverCompositeOp, layer_info[0].image,
-               layer_info[0].offset_x, layer_info[0].offset_y );
-       layer_info[0].image =DestroyImage( layer_info[0].image );
-
-      /* Bob says that if we do this, we'll get REAL gray images! */
-      if ( image_type == GIMP_GRAY ) {
-        QuantizeInfo  qi;
-        GetQuantizeInfo(&qi);
-        qi.dither=IsPaletteImage(image,&image->exception) == MagickFalse ?
-          MagickTrue : MagickFalse;
-        qi.colorspace = GRAYColorspace;
-        (void) QuantizeImage( &qi, image );
+    if (number_layers == 1)
+      {
+        /*
+          Composite the layer data onto the main image, dispose the layer.
+        */
+        (void) CompositeImage(image,OverCompositeOp,layer_info[0].image,
+          layer_info[0].offset_x,layer_info[0].offset_y);
+        layer_info[0].image =DestroyImage( layer_info[0].image);
       }
-    } else {
+    else
+      {
 #if 0
         {
         /* NOTE: XCF layers are REVERSED from composite order! */
@@ -1297,18 +1343,12 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         signed int  j;
 
         /* first we copy the last layer on top of the main image */
-        (void) CompositeImage(image, CopyCompositeOp, layer_info[number_layers-1].image,
-                 layer_info[number_layers-1].offset_x,
-                 layer_info[number_layers-1].offset_y );
-         layer_info[number_layers-1].image =DestroyImage( layer_info[number_layers-1].image );
-
-        /* Bob says that if we do this, we'll get REAL gray images! */
-        if ( image_type == GIMP_GRAY ) {
-          QuantizeInfo  qi;
-          GetQuantizeInfo(&qi);
-          qi.colorspace = GRAYColorspace;
-          (void) QuantizeImage( &qi, image );
-        }
+        (void) CompositeImage(image,CopyCompositeOp,
+          layer_info[number_layers-1].image,
+          layer_info[number_layers-1].offset_x,
+          layer_info[number_layers-1].offset_y);
+          layer_info[number_layers-1].image=DestroyImage(
+            layer_info[number_layers-1].image);
 
         /* now reverse the order of the layers as they are put
            into subimages
@@ -1316,28 +1356,20 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         j=number_layers-2;
         image->next=layer_info[j].image;
         layer_info[j].image->previous=image;
-        layer_info[j].image->page.x = layer_info[j].offset_x;
-        layer_info[j].image->page.y = layer_info[j].offset_y;
-        layer_info[j].image->page.width = layer_info[j].width;
-        layer_info[j].image->page.height = layer_info[j].height;
+        layer_info[j].image->page.x=layer_info[j].offset_x;
+        layer_info[j].image->page.y=layer_info[j].offset_y;
+        layer_info[j].image->page.width=layer_info[j].width;
+        layer_info[j].image->page.height=layer_info[j].height;
         for (j=number_layers-3; j>=0; j--)
         {
           if (j > 0)
             layer_info[j].image->next=layer_info[j-1].image;
           if (j < (number_layers-1))
             layer_info[j].image->previous=layer_info[j+1].image;
-          layer_info[j].image->page.x = layer_info[j].offset_x;
-          layer_info[j].image->page.y = layer_info[j].offset_y;
-          layer_info[j].image->page.width = layer_info[j].width;
-          layer_info[j].image->page.height = layer_info[j].height;
-
-          /* Bob says that if we do this, we'll get REAL gray images! */
-          if ( image_type == GIMP_GRAY ) {
-            QuantizeInfo  qi;
-            GetQuantizeInfo(&qi);
-            qi.colorspace = GRAYColorspace;
-            (void) QuantizeImage( &qi, layer_info[j].image );
-          }
+          layer_info[j].image->page.x=layer_info[j].offset_x;
+          layer_info[j].image->page.y=layer_info[j].offset_y;
+          layer_info[j].image->page.width=layer_info[j].width;
+          layer_info[j].image->page.height=layer_info[j].height;
         }
       }
 #endif
@@ -1384,7 +1416,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #endif
   }
 
-  CloseBlob(image);
+  (void) CloseBlob(image);
+  if (image_type == GIMP_GRAY)
+    image->type=GrayscaleType;
   return(GetFirstImageInList(image));
 }
 
