@@ -30,6 +30,12 @@ extern "C" {
 # else
 #  include "magick-config.h"
 # endif
+#if defined(_magickcore_const) && !defined(const)
+# define const _magickcore_const
+#endif
+#if defined(_magickcore_inline) && !defined(inline)
+# define inline _magickcore_inline
+#endif
 # if defined(__cplusplus) || defined(c_plusplus)
 #  undef inline
 # endif
@@ -145,8 +151,9 @@ extern "C" {
 #include "magick/blob.h"
 #include "magick/cache.h"
 #include "magick/cache-view.h"
-#include "magick/coder.h"
+#include "magick/cipher.h"
 #include "magick/client.h"
+#include "magick/coder.h"
 #include "magick/color.h"
 #include "magick/colorspace.h"
 #include "magick/compare.h"
