@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -60,6 +60,7 @@
 #include "magick/image-private.h"
 #include "magick/log.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/property.h"
 #include "magick/resource_.h"
 #include "magick/statistic.h"
@@ -68,11 +69,11 @@
 #include "magick/type.h"
 #include "magick/utility.h"
 #include "magick/xwindow-private.h"
-#if defined(HasFREETYPE)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
 #if defined(__MINGW32__)
 #  undef interface
 #endif
-#if defined(HAVE_FT2BUILD_H)
+#if defined(MAGICKCORE_HAVE_FT2BUILD_H)
 #  include <ft2build.h>
 #endif
 #if defined(FT_FREETYPE_H)
@@ -151,9 +152,9 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 */
 MagickExport MagickBooleanType AnnotateImage(Image *image,
@@ -398,21 +399,20 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
       }
     annotate_info->affine.tx=offset.x;
     annotate_info->affine.ty=offset.y;
-    (void) FormatMagickString(primitive,MaxTextExtent,
-      "stroke-width %g line 0,0 %g,0",metrics.underline_thickness,
-      metrics.width);
+    (void) FormatMagickString(primitive,MaxTextExtent,"stroke-width %g "
+      "line 0,0 %g,0",metrics.underline_thickness,metrics.width);
     if (annotate->decorate == OverlineDecoration)
       {
-        annotate_info->affine.ty-=(draw_info->affine.sy*
-          (metrics.ascent+metrics.descent-metrics.underline_position+2));
+        annotate_info->affine.ty-=(draw_info->affine.sy*(metrics.ascent+
+          metrics.descent-metrics.underline_position+2));
         (void) CloneString(&annotate_info->primitive,primitive);
         (void) DrawImage(image,annotate_info);
       }
     else
       if (annotate->decorate == UnderlineDecoration)
         {
-          annotate_info->affine.ty-=
-            (draw_info->affine.sy*metrics.underline_position+2);
+          annotate_info->affine.ty-=(draw_info->affine.sy*
+            metrics.underline_position+2);
           (void) CloneString(&annotate_info->primitive,primitive);
           (void) DrawImage(image,annotate_info);
         }
@@ -431,7 +431,7 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
       }
   }
   /*
-    Free resources.
+    Relinquish resources.
   */
   annotate_info=DestroyDrawInfo(annotate_info);
   annotate=DestroyDrawInfo(annotate);
@@ -441,7 +441,7 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
   return(status);
 }
 
-#if defined(HasFREETYPE)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -466,9 +466,9 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o text: The text.
+%    o text: the text.
 %
 %    o count: return the number of characters generated by the encoding.
 %
@@ -545,7 +545,7 @@ static unsigned long *EncodeSJIS(const char *text,size_t *count)
 }
 #endif
 
-#if defined(HasFREETYPE)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -566,7 +566,7 @@ static unsigned long *EncodeSJIS(const char *text,size_t *count)
 %
 %  A description of each parameter follows:
 %
-%    o text: The text.
+%    o text: the text.
 %
 %    o count: return the number of characters generated by the encoding.
 %
@@ -603,7 +603,7 @@ static unsigned long *EncodeText(const char *text,size_t *count)
 }
 #endif
 
-#if defined(HasFREETYPE)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -628,7 +628,7 @@ static unsigned long *EncodeText(const char *text,size_t *count)
 %    o unicode:  EncodeUnicode() returns a pointer to an unsigned short array
 %      representing the encoded version of the ASCII string.
 %
-%    o text: The text.
+%    o text: the text.
 %
 %    o count: return the number of characters generated by the encoding.
 %
@@ -755,7 +755,7 @@ static unsigned long *EncodeUnicode(const char *text,size_t *count)
 %
 %    o image:  The image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 %    o metrics: Return the font metrics in this structure.
 %
@@ -847,9 +847,9 @@ MagickExport long FormatMagickCaption(Image *image,DrawInfo *draw_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 %    o metrics: Return the font metrics in this structure.
 %
@@ -912,7 +912,7 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
   metrics->height=(double) number_lines*(long) (metrics->ascent-
     metrics->descent+0.5);
   /*
-    Free resources.
+    Relinquish resources.
   */
   annotate_info->text=(char *) NULL;
   annotate_info=DestroyDrawInfo(annotate_info);
@@ -953,9 +953,9 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 %    o metrics: Return the font metrics in this structure.
 %
@@ -1010,9 +1010,9 @@ MagickExport MagickBooleanType GetTypeMetrics(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 %    o offset: (x,y) location of text relative to image.
 %
@@ -1101,11 +1101,11 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
-%    o encoding: The font encoding.
+%    o encoding: the font encoding.
 %
 %    o offset: (x,y) location of text relative to image.
 %
@@ -1113,7 +1113,7 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
 %
 */
 
-#if defined(HasFREETYPE)
+#if defined(MAGICKCORE_FREETYPE_DELEGATE)
 static int TraceCubicBezier(FT_Vector *p,FT_Vector *q,FT_Vector *to,
   DrawInfo *draw_info)
 {
@@ -1285,7 +1285,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       image->filename);
   args.flags=FT_OPEN_PATHNAME;
   if (draw_info->font == (char *) NULL)
-    args.pathname="helvetica";
+    args.pathname=(char *) "helvetica";
   else
     if (*draw_info->font != '@')
       args.pathname=draw_info->font;
@@ -1296,7 +1296,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   if (status != 0)
     {
       (void) FT_Done_FreeType(library);
-      ThrowBinaryException(TypeError,"UnableToReadFont",draw_info->font);
+      (void) ThrowMagickException(&image->exception,GetMagickModule(),
+        TypeError,"UnableToReadFont","`%s'",draw_info->font);
+      return(RenderPostscript(image,draw_info,offset,metrics));
     }
   if ((draw_info->metrics != (char *) NULL) &&
       (IsAccessible(draw_info->metrics) != MagickFalse))
@@ -1468,9 +1470,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   (void) CloneString(&annotate_info->primitive,"path '");
   if (draw_info->render != MagickFalse)
     {
-  	  if (image->storage_class != DirectClass)
+      if (image->storage_class != DirectClass)
         (void) SetImageStorageClass(image,DirectClass);
-  	  if (image->matte == MagickFalse)
+      if (image->matte == MagickFalse)
         (void) SetImageOpacity(image,OpaqueOpacity);
     }
   point.x=0.0;
@@ -1546,7 +1548,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           Rasterize the glyph.
         */
         p=bitmap->bitmap.buffer;
-        image_view=OpenCacheView(image);
+        image_view=AcquireCacheView(image);
         for (y=0; y < (long) bitmap->bitmap.rows; y++)
         {
           x_offset=(long) (point.x+0.5);
@@ -1592,7 +1594,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           if (SyncCacheView(image_view) == MagickFalse)
             break;
         }
-        image_view=CloseCacheView(image_view);
+        image_view=DestroyCacheView(image_view);
       }
     if ((bitmap->left+bitmap->bitmap.width) > metrics->width)
       metrics->width=bitmap->left+bitmap->bitmap.width;
@@ -1654,7 +1656,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   metrics->origin.x/=64.0;
   metrics->origin.y/=64.0;
   /*
-    Free resources.
+    Relinquish resources.
   */
   text=(unsigned long *) RelinquishMagickMemory(text);
   annotate_info=DestroyDrawInfo(annotate_info);
@@ -1668,7 +1670,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   TypeMetric *metrics)
 {
   (void) ThrowMagickException(&image->exception,GetMagickModule(),
-    MissingDelegateWarning,"FreeTypeLibraryIsNotAvailable","`%s'",
+    MissingDelegateWarning,"DelegateLibrarySupportNotBuiltIn","`%s' (Freetype)",
     draw_info->font);
   return(RenderPostscript(image,draw_info,offset,metrics));
 }
@@ -1695,9 +1697,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 %    o offset: (x,y) location of text relative to image.
 %
@@ -1927,7 +1929,7 @@ static MagickBooleanType RenderPostscript(Image *image,
       if (annotate_image->matte == MagickFalse)
         (void) SetImageOpacity(annotate_image,OpaqueOpacity);
       fill_color=draw_info->fill;
-      annotate_view=OpenCacheView(annotate_image);
+      annotate_view=AcquireCacheView(annotate_image);
       for (y=0; y < (long) annotate_image->rows; y++)
       {
         q=GetCacheViewPixels(annotate_view,0,y,annotate_image->columns,1);
@@ -1947,7 +1949,7 @@ static MagickBooleanType RenderPostscript(Image *image,
         if (SyncCacheView(annotate_view) == MagickFalse)
           break;
       }
-      annotate_view=CloseCacheView(annotate_view);
+      annotate_view=DestroyCacheView(annotate_view);
       (void) CompositeImage(image,OverCompositeOp,annotate_image,
         (long) (offset->x+0.5),(long) (offset->y-(metrics->ascent+
         metrics->descent)+0.5));
@@ -1977,16 +1979,16 @@ static MagickBooleanType RenderPostscript(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
 %    o offset: (x,y) location of text relative to image.
 %
 %    o metrics: bounding box of text.
 %
 */
-#if defined(HasX11)
+#if defined(MAGICKCORE_X11_DELEGATE)
 static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
   const PointInfo *offset,TypeMetric *metrics)
 {
@@ -2026,6 +2028,9 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
 
   if (display == (Display *) NULL)
     {
+      ImageInfo
+        *image_info;
+
       /*
         Open X server connection.
       */
@@ -2040,8 +2045,10 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
         Get user defaults from X resource database.
       */
       (void) XSetErrorHandler(XError);
+      image_info=AcquireImageInfo();
       resource_database=XGetResourceDatabase(display,GetClientName());
-      XGetResourceInfo(resource_database,GetClientName(),&resource_info);
+      XGetResourceInfo(image_info,resource_database,GetClientName(),
+        &resource_info);
       resource_info.close_server=MagickFalse;
       resource_info.colormap=PrivateColormap;
       resource_info.font=AcquireString(draw_info->font);
@@ -2174,7 +2181,9 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
 static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
   const PointInfo *offset,TypeMetric *metrics)
 {
-  ThrowBinaryException(MissingDelegateError,"XWindowLibraryIsNotAvailable",
-    draw_info->font);
+  (void) ThrowMagickException(&image->exception,GetMagickModule(),
+    MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (X11)",
+    image->filename);
+  return(MagickFalse);
 }
 #endif
