@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -36,6 +36,9 @@ typedef enum
 typedef void
   *Cache;
 
+typedef const IndexPacket
+  *(*AcquireIndexesFromHandler)(const Image *);
+
 typedef IndexPacket
   *(*GetIndexesFromHandler)(const Image *);
 
@@ -43,12 +46,12 @@ typedef MagickBooleanType
   (*SyncPixelHandler)(Image *);
 
 typedef const PixelPacket
-  *(*AcquirePixelHandler)(const Image *,const long,const long,
-    const unsigned long,const unsigned long,ExceptionInfo *);
+  *(*AcquirePixelHandler)(const Image *,const VirtualPixelMethod,const long,
+    const long,const unsigned long,const unsigned long,ExceptionInfo *);
 
 typedef PixelPacket
-  (*AcquireOnePixelFromHandler)(const Image *,const long,const long,
-    ExceptionInfo *);
+  (*AcquireOnePixelFromHandler)(const Image *,const VirtualPixelMethod,
+    const long,const long,ExceptionInfo *);
 
 typedef PixelPacket
   (*GetOnePixelFromHandler)(Image *,const long,const long);
@@ -69,6 +72,9 @@ typedef void
 
 typedef struct _CacheMethods
 {
+  AcquireIndexesFromHandler
+    acquire_indexes_from_handler;
+
   AcquireOnePixelFromHandler
     acquire_one_pixel_from_handler;
 
@@ -97,13 +103,11 @@ typedef struct _CacheMethods
     sync_pixel_handler;
 } CacheMethods;
 
-typedef struct _NexusInfo NexusInfo;
+typedef struct _NexusInfo
+   NexusInfo;
 
 typedef struct _CacheInfo
 {
-  unsigned long
-    id;
-
   NexusInfo
     *nexus_info;
 
@@ -183,6 +187,9 @@ extern MagickExport ClassType
 extern MagickExport ColorspaceType
   GetCacheColorspace(const Cache);
 
+extern MagickExport const IndexPacket
+  *AcquireNexusIndexes(const Cache,const unsigned long);
+
 extern MagickExport IndexPacket
   *GetNexusIndexes(const Cache,const unsigned long);
 
