@@ -17,7 +17,7 @@
 %                                 May 2001                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -73,6 +73,8 @@ static const char
     "  <coder magick=\"8BIM\" name=\"META\" />"
     "  <coder magick=\"8BIMTEXT\" name=\"META\" />"
     "  <coder magick=\"8BIMWTEXT\" name=\"META\" />"
+    "  <coder magick=\"A\" name=\"RAW\" />"
+    "  <coder magick=\"AI\" name=\"PDF\" />"
     "  <coder magick=\"AFM\" name=\"TTF\" />"
     "  <coder magick=\"APP1JPEG\" name=\"META\" />"
     "  <coder magick=\"APP1\" name=\"META\" />"
@@ -80,9 +82,13 @@ static const char
     "  <coder magick=\"BMP2\" name=\"BMP\" />"
     "  <coder magick=\"BMP3\" name=\"BMP\" />"
     "  <coder magick=\"B\" name=\"GRAY\" />"
+    "  <coder magick=\"BRF\" name=\"BRAILLE\" />"
     "  <coder magick=\"CMYKA\" name=\"CMYK\" />"
     "  <coder magick=\"C\" name=\"GRAY\" />"
+    "  <coder magick=\"CR2\" name=\"DNG\" />"
+    "  <coder magick=\"CRW\" name=\"DNG\" />"
     "  <coder magick=\"CUR\" name=\"ICON\" />"
+    "  <coder magick=\"DCR\" name=\"DNG\" />"
     "  <coder magick=\"DCX\" name=\"PCX\" />"
     "  <coder magick=\"DFONT\" name=\"TTF\" />"
     "  <coder magick=\"EMF\" name=\"EMF\" />"
@@ -93,6 +99,9 @@ static const char
     "  <coder magick=\"EPSF\" name=\"PS\" />"
     "  <coder magick=\"EPSI\" name=\"PS\" />"
     "  <coder magick=\"EPS\" name=\"PS\" />"
+    "  <coder magick=\"EPT2\" name=\"EPT\" />"
+    "  <coder magick=\"EPT3\" name=\"EPT\" />"
+    "  <coder magick=\"EXIF\" name=\"META\" />"
     "  <coder magick=\"FILE\" name=\"URL\" />"
     "  <coder magick=\"FRACTAL\" name=\"PLASMA\" />"
     "  <coder magick=\"FTP\" name=\"URL\" />"
@@ -101,7 +110,6 @@ static const char
     "  <coder magick=\"GIF87\" name=\"GIF\" />"
     "  <coder magick=\"G\" name=\"GRAY\" />"
     "  <coder magick=\"GRANITE\" name=\"MAGICK\" />"
-    "  <coder magick=\"H5\" name=\"HDF\" />"
     "  <coder magick=\"H\" name=\"MAGICK\" />"
     "  <coder magick=\"HTM\" name=\"HTML\" />"
     "  <coder magick=\"HTTP\" name=\"URL\" />"
@@ -109,9 +117,11 @@ static const char
     "  <coder magick=\"ICC\" name=\"META\" />"
     "  <coder magick=\"ICM\" name=\"META\" />"
     "  <coder magick=\"ICO\" name=\"ICON\" />"
+    "  <coder magick=\"IMPLICIT\" name=\"***\" />"
     "  <coder magick=\"IPTC\" name=\"META\" />"
     "  <coder magick=\"IPTCTEXT\" name=\"META\" />"
     "  <coder magick=\"IPTCWTEXT\" name=\"META\" />"
+    "  <coder magick=\"ISOBRL\" name=\"BRAILLE\" />"
     "  <coder magick=\"JBG\" name=\"JBIG\" />"
     "  <coder magick=\"JNG\" name=\"PNG\" />"
     "  <coder magick=\"JPC\" name=\"JP2\" />"
@@ -124,9 +134,12 @@ static const char
     "  <coder magick=\"MNG\" name=\"PNG\" />"
     "  <coder magick=\"MPG\" name=\"MPEG\" />"
     "  <coder magick=\"MPRI\" name=\"MPR\" />"
+    "  <coder magick=\"MRW\" name=\"DNG\" />"
     "  <coder magick=\"MSVG\" name=\"SVG\" />"
+    "  <coder magick=\"NEF\" name=\"DNG\" />"
     "  <coder magick=\"NETSCAPE\" name=\"MAGICK\" />"
     "  <coder magick=\"O\" name=\"GRAY\" />"
+    "  <coder magick=\"ORF\" name=\"DNG\" />"
     "  <coder magick=\"OTF\" name=\"TTF\" />"
     "  <coder magick=\"P7\" name=\"PNM\" />"
     "  <coder magick=\"PAL\" name=\"UYVY\" />"
@@ -134,6 +147,8 @@ static const char
     "  <coder magick=\"PBM\" name=\"PNM\" />"
     "  <coder magick=\"PCDS\" name=\"PCD\" />"
     "  <coder magick=\"PCT\" name=\"PICT\" />"
+    "  <coder magick=\"PDFA\" name=\"PDF\" />"
+    "  <coder magick=\"PEF\" name=\"DNG\" />"
     "  <coder magick=\"PFA\" name=\"TTF\" />"
     "  <coder magick=\"PFB\" name=\"TTF\" />"
     "  <coder magick=\"PFM\" name=\"PNM\" />"
@@ -146,21 +161,24 @@ static const char
     "  <coder magick=\"PNG32\" name=\"PNG\" />"
     "  <coder magick=\"PNG8\" name=\"PNG\" />"
     "  <coder magick=\"PPM\" name=\"PNM\" />"
-    "  <coder magick=\"PSD\" name=\"PSD\" />"
     "  <coder magick=\"PTIF\" name=\"TIFF\" />"
+    "  <coder magick=\"RAF\" name=\"DNG\" />"
     "  <coder magick=\"RAS\" name=\"SUN\" />"
     "  <coder magick=\"RGBA\" name=\"RGB\" />"
+    "  <coder magick=\"RGBO\" name=\"RGB\" />"
     "  <coder magick=\"R\" name=\"GRAY\" />"
     "  <coder magick=\"ROSE\" name=\"MAGICK\" />"
     "  <coder magick=\"SHTML\" name=\"HTML\" />"
     "  <coder magick=\"SVGZ\" name=\"SVG\" />"
     "  <coder magick=\"TEXT\" name=\"TXT\" />"
-    "  <coder magick=\"TIF\" name=\"TIFF\" />"
     "  <coder magick=\"TIFF64\" name=\"TIFF\" />"
+    "  <coder magick=\"TIF\" name=\"TIFF\" />"
     "  <coder magick=\"TTC\" name=\"TTF\" />"
+    "  <coder magick=\"UBRL\" name=\"BRAILLE\" />"
     "  <coder magick=\"VDA\" name=\"TGA\" />"
     "  <coder magick=\"VST\" name=\"TGA\" />"
     "  <coder magick=\"WMFWIN32\" name=\"EMF\" />"
+    "  <coder magick=\"X3F\" name=\"DNG\" />"
     "  <coder magick=\"XTRNARRAY\" name=\"XTRN\" />"
     "  <coder magick=\"XTRNBLOB\" name=\"XTRN\" />"
     "  <coder magick=\"XTRNBSTR\" name=\"XTRN\" />"
@@ -169,6 +187,7 @@ static const char
     "  <coder magick=\"XTRNSTREAM\" name=\"XTRN\" />"
     "  <coder magick=\"XV\" name=\"VIFF\" />"
     "  <coder magick=\"Y\" name=\"GRAY\" />"
+    "  <coder magick=\"YCbCrA\" name=\"YCbCr\" />"
     "</codermap>";
 
 /*
@@ -215,7 +234,7 @@ MagickExport void DestroyCoderList(void)
     coder_list=DestroySplayTree(coder_list);
   instantiate_coder=MagickFalse;
   RelinquishSemaphoreInfo(coder_semaphore);
-  coder_semaphore=DestroySemaphoreInfo(coder_semaphore);
+  DestroySemaphoreInfo(&coder_semaphore);
 }
 
 /*
@@ -238,7 +257,7 @@ MagickExport void DestroyCoderList(void)
 %
 %  A description of each parameter follows:
 %
-%    o name: The coder name.
+%    o name: the coder name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -324,8 +343,8 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
   p=GetCoderInfo("*",exception);
   if (p == (const CoderInfo *) NULL)
     return((const CoderInfo **) NULL);
-  coder_map=(const CoderInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(coder_list)+1)*sizeof(*coder_map));
+  coder_map=(const CoderInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(coder_list)+1UL,sizeof(*coder_map));
   if (coder_map == (const CoderInfo **) NULL)
     return((const CoderInfo **) NULL);
   /*
@@ -409,8 +428,8 @@ MagickExport char **GetCoderList(const char *pattern,
   p=GetCoderInfo("*",exception);
   if (p == (const CoderInfo *) NULL)
     return((char **) NULL);
-  coder_map=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(coder_list)+1)*sizeof(*coder_map));
+  coder_map=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(coder_list)+1UL,sizeof(*coder_map));
   if (coder_map == (char **) NULL)
     return((char **) NULL);
   /*
@@ -622,8 +641,8 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
         DestroyCoderNode);
       if (coder_list == (SplayTreeInfo *) NULL)
         {
-          ThrowFileException(exception,ResourceLimitError,
-            "MemoryAllocationFailed",filename);
+          (void) ThrowMagickException(exception,GetMagickModule(),
+             ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
           return(MagickFalse);
         }
     }
@@ -672,8 +691,7 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
     */
     coder_info=(CoderInfo *) AcquireMagickMemory(sizeof(*coder_info));
     if (coder_info == (CoderInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(coder_info,0,sizeof(*coder_info));
     coder_info->path=ConstantString(filename);
     coder_info->signature=MagickSignature;
@@ -717,7 +735,7 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The font file name.
+%    o filename: the font file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -725,7 +743,7 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
 static MagickBooleanType LoadCoderLists(const char *filename,
   ExceptionInfo *exception)
 {
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
   return(LoadCoderList(CoderMap,"built-in",0,exception));
 #else
   const StringInfo
