@@ -82,7 +82,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o colorspace: the colorspace to transform the image to.
 %
@@ -221,6 +221,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         if (SyncImagePixels(image) == MagickFalse)
           break;
       }
+      image->type=image->matte == MagickFalse ? ColorSeparationType :
+        ColorSeparationMatteType;
       return(MagickTrue);
     }
     case CMYKColorspace:
@@ -255,6 +257,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         if (SyncImagePixels(image) == MagickFalse)
           break;
       }
+      image->type=image->matte == MagickFalse ? ColorSeparationType :
+        ColorSeparationMatteType;
       return(MagickTrue);
     }
     case HSBColorspace:
@@ -299,7 +303,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     {
       double
         hue,
-        luminosity,
+        lightness,
         saturation;
 
       /*
@@ -314,7 +318,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         }
       hue=0.0;
       saturation=0.0;
-      luminosity=0.0;
+      lightness=0.0;
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -322,10 +326,10 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           break;
         for (x=0; x < (long) image->columns; x++)
         {
-          ConvertRGBToHSL(q->red,q->green,q->blue,&hue,&saturation,&luminosity);
+          ConvertRGBToHSL(q->red,q->green,q->blue,&hue,&saturation,&lightness);
           q->red=RoundToQuantum((MagickRealType) QuantumRange*hue);
           q->green=RoundToQuantum((MagickRealType) QuantumRange*saturation);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange*luminosity);
+          q->blue=RoundToQuantum((MagickRealType) QuantumRange*lightness);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -513,6 +517,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.33333*i;
@@ -535,6 +540,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 
           G = 0.29900*R+0.58700*G+0.11400*B
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.29900*i;
@@ -547,6 +553,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         y_map[i].z=0.58700*i;
         z_map[i].z=0.11400*i;
       }
+      image->type=GrayscaleType;
       break;
     }
     case Rec601YCbCrColorspace:
@@ -564,6 +571,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.299000*i;
@@ -585,6 +593,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 
           G = 0.21260*R+0.71520*G+0.07220*B
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.21260*i;
@@ -613,6 +622,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.212600*i;
@@ -629,9 +639,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
     case sRGBColorspace:
     {
-      double
-        v;
-
       /*
         Linear RGB to nonlinear sRGB (http://www.w3.org/Graphics/Color/sRGB):
 
@@ -639,8 +646,12 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           G = 0.0*R+0.1*G+0.0*B
           B = 0.0*R+0.0*G+1.0*B
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
+        double
+          v;
+
         v=(double) i/MaxMap;
         if (((double) i/MaxMap) <= 0.03928)
           v/=12.92;
@@ -667,6 +678,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           Y = 0.2126560*R+0.7151580*G+0.0721856*B
           Z = 0.0193324*R+0.1191930*G+0.9504440*B
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.4124240*i;
@@ -734,6 +746,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.29900*i;
@@ -762,6 +775,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.299000*i;
@@ -791,6 +805,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=0.29900*i;
@@ -876,7 +891,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
   }
   /*
-    Free resources.
+    Relinquish resources.
   */
   z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
   y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
@@ -904,9 +919,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o colorspace: The colorspace.
+%    o colorspace: the colorspace.
 %
 */
 MagickExport MagickBooleanType SetImageColorspace(Image *image,
@@ -961,7 +976,7 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o colorspace: the colorspace to transform the image to.
 %
@@ -1230,7 +1245,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     {
       double
         hue,
-        luminosity,
+        lightness,
         saturation;
 
       /*
@@ -1252,8 +1267,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         {
           hue=(double) (QuantumScale*q->red);
           saturation=(double) (QuantumScale*q->green);
-          luminosity=(double) (QuantumScale*q->blue);
-          ConvertHSLToRGB(hue,saturation,luminosity,&q->red,&q->green,&q->blue);
+          lightness=(double) (QuantumScale*q->blue);
+          ConvertHSLToRGB(hue,saturation,lightness,&q->red,&q->green,&q->blue);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -1441,6 +1456,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         I and Q, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=(double) i;
@@ -1468,6 +1484,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Cb and Cr, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=(double) i;
@@ -1494,6 +1511,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Cb and Cr, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=(double) i;
@@ -1517,6 +1535,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           G = 0.0*R+1.0*G+0.0*B
           B = 0.0*R+0.0*G+1.0*B
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=1.0*i;
@@ -1540,6 +1559,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           G = -0.9692580*X+1.8759900*Y+0.0415557*Z
           B =  0.0556352*X-0.2039960*Y+1.0570700*Z
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=3.2407100*i;
@@ -1565,6 +1585,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
 
         YCC is scaled by 1.3584.  C1 zero is 156 and C2 is at 137.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=1.3584000*i;
@@ -1595,6 +1616,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         I and Q, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=(double) i;
@@ -1621,6 +1643,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Pb and Pr, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=(double) i;
@@ -1648,6 +1671,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         U and V, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
+      #pragma omp parallel for
       for (i=0; i <= (long) MaxMap; i++)
       {
         x_map[i].x=(double) i;
@@ -1694,9 +1718,9 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           {
             case YCCColorspace:
             {
-              pixel.red/=1.3584000;
-              pixel.green/=1.3584000;
-              pixel.blue/=1.3584000;
+              pixel.red/=1.3584000f;
+              pixel.green/=1.3584000f;
+              pixel.blue/=1.3584000f;
               break;
             }
             case sRGBColorspace:
@@ -1808,7 +1832,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   }
   image->colorspace=RGBColorspace;
   /*
-    Free resources.
+    Relinquish resources.
   */
   z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
   y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
