@@ -17,7 +17,7 @@
 %                               December 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
@@ -85,15 +86,15 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o reconstruct_image: The reconstruct image.
+%    o reconstruct_image: the reconstruct image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
-%    o metric: The metric.
+%    o metric: the metric.
 %
-%    o distortion: The computed distortion between the images.
+%    o distortion: the computed distortion between the images.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -114,6 +115,9 @@ MagickExport Image *CompareImageChannels(Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   const MetricType metric,double *distortion,ExceptionInfo *exception)
 {
+  const char
+    *artifact;
+
   Image
     *difference_image;
 
@@ -122,9 +126,9 @@ MagickExport Image *CompareImageChannels(Image *image,
 
   MagickPixelPacket
     composite,
-    red,
+    highlight,
     source,
-    white;
+    transparent;
 
   MagickStatusType
     difference;
@@ -174,27 +178,30 @@ MagickExport Image *CompareImageChannels(Image *image,
       difference_image=DestroyImage(difference_image);
       return((Image *) NULL);
     }
-  (void) QueryMagickColor("#f1001e",&red,exception);
-  (void) QueryMagickColor("#ffffff",&white,exception);
+  (void) QueryMagickColor("#f1001e",&highlight,exception);
+  artifact=GetImageArtifact(image,"highlight-color");
+  if (artifact != (const char *) NULL)
+    (void) QueryMagickColor(artifact,&highlight,exception);
+  (void) QueryMagickColor("#ffffff",&transparent,exception);
   if (difference_image->colorspace == CMYKColorspace)
     {
-      ConvertRGBToCMYK(&red);
-      ConvertRGBToCMYK(&white);
+      ConvertRGBToCMYK(&highlight);
+      ConvertRGBToCMYK(&transparent);
     }
   /*
     Generate difference image.
   */
   GetMagickPixelPacket(reconstruct_image,&source);
   GetMagickPixelPacket(difference_image,&composite);
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
-  difference_view=OpenCacheView(difference_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
+  difference_view=AcquireCacheView(difference_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
     q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
-    r=SetCacheView(difference_view,0,y,difference_image->columns,1);
+    r=SetCacheViewPixels(difference_view,0,y,difference_image->columns,1);
     if ((p == (const PixelPacket *) NULL) ||
         (q == (const PixelPacket *) NULL) || (r == (PixelPacket *) NULL))
       break;
@@ -204,30 +211,26 @@ MagickExport Image *CompareImageChannels(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       difference=MagickFalse;
-      if ((channel & RedChannel) != 0)
-        if (p->red != q->red)
-          difference=MagickTrue;
-      if ((channel & GreenChannel) != 0)
-        if (p->green != q->green)
-          difference=MagickTrue;
-      if ((channel & BlueChannel) != 0)
-        if (p->blue != q->blue)
-          difference=MagickTrue;
-      if ((channel & OpacityChannel) != 0)
-        if (p->opacity != q->opacity)
-          difference=MagickTrue;
-      if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace) &&
-          (reconstruct_image->colorspace == CMYKColorspace))
-        if (indexes[x] != reconstruct_indexes[x])
-          difference=MagickTrue;
+      if (((channel & RedChannel) != 0) && (p->red != q->red))
+        difference=MagickTrue;
+      if (((channel & GreenChannel) != 0) && (p->green != q->green))
+        difference=MagickTrue;
+      if (((channel & BlueChannel) != 0) && (p->blue != q->blue))
+        difference=MagickTrue;
+      if (((channel & OpacityChannel) != 0) && (p->opacity != q->opacity))
+        difference=MagickTrue;
+      if ((((channel & IndexChannel) != 0) &&
+           (image->colorspace == CMYKColorspace) &&
+           (reconstruct_image->colorspace == CMYKColorspace)) &&
+          (indexes[x] != reconstruct_indexes[x]))
+        difference=MagickTrue;
       SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,&source);
       if (difference != MagickFalse)
-        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&red,
-          (MagickRealType) red.opacity,&composite);
+        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&highlight,
+          (MagickRealType) highlight.opacity,&composite);
       else
-        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&white,
-          (MagickRealType) white.opacity,&composite);
+        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&transparent,
+          (MagickRealType) transparent.opacity,&composite);
       SetPixelPacket(difference_image,&composite,r,difference_indexes+x);
       p++;
       q++;
@@ -236,9 +239,9 @@ MagickExport Image *CompareImageChannels(Image *image,
     if (SyncCacheView(difference_view) == MagickFalse)
       break;
   }
-  difference_view=CloseCacheView(difference_view);
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  difference_view=DestroyCacheView(difference_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   (void) GetImageChannelDistortion(image,reconstruct_image,channel,metric,
     distortion,exception);
   return(difference_image);
@@ -266,15 +269,15 @@ MagickExport Image *CompareImageChannels(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o reconstruct_image: The reconstruct image.
+%    o reconstruct_image: the reconstruct image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
-%    o metric: The metric.
+%    o metric: the metric.
 %
-%    o distortion: The computed distortion between the images.
+%    o distortion: the computed distortion between the images.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -326,8 +329,8 @@ static MagickRealType GetAbsoluteError(const Image *image,
   GetMagickPixelPacket(image,&image_pixel);
   GetMagickPixelPacket(reconstruct_image,&reconstruct_pixel);
   distortion=0.0;
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
@@ -348,8 +351,8 @@ static MagickRealType GetAbsoluteError(const Image *image,
       q++;
     }
   }
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   return(distortion);
 }
 
@@ -381,8 +384,8 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
 
   area=0.0;
   distortion=0.0;
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
@@ -424,8 +427,8 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
       q++;
     }
   }
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   return(distortion/area);
 }
 
@@ -433,7 +436,10 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  double
+  long
+    y;
+
+  MagickRealType
     alpha,
     area,
     beta,
@@ -442,9 +448,6 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
     mean_error,
     mean_error_per_pixel;
 
-  long
-    y;
-
   register const IndexPacket
     *indexes,
     *reconstruct_indexes;
@@ -466,8 +469,8 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
   maximum_error=0.0;
   mean_error_per_pixel=0.0;
   mean_error=0.0;
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
@@ -482,9 +485,9 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
       if ((channel & OpacityChannel) != 0)
         {
           if (image->matte != MagickFalse)
-            alpha=QuantumScale*(QuantumRange-(double) p->opacity);
+            alpha=(MagickRealType) (QuantumScale*(QuantumRange-p->opacity));
           if (reconstruct_image->matte != MagickFalse)
-            beta=QuantumScale*(QuantumRange-(double) q->opacity);
+            beta=(MagickRealType) (QuantumScale*(QuantumRange-q->opacity));
         }
       if ((channel & RedChannel) != 0)
         {
@@ -537,8 +540,8 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
       q++;
     }
   }
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   image->error.mean_error_per_pixel=mean_error_per_pixel/area;
   image->error.normalized_mean_error=QuantumScale*QuantumScale*mean_error/area;
   image->error.normalized_maximum_error=QuantumScale*maximum_error;
@@ -574,8 +577,8 @@ static MagickRealType GetMeanSquaredError(const Image *image,
 
   area=0.0;
   distortion=0.0;
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
@@ -623,8 +626,8 @@ static MagickRealType GetMeanSquaredError(const Image *image,
       q++;
     }
   }
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   return(distortion/area);
 }
 
@@ -655,8 +658,8 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
     *reconstruct_view;
 
   distortion=0.0;
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
@@ -704,8 +707,8 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
       q++;
     }
   }
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   return(distortion);
 }
 
@@ -841,9 +844,9 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o reconstruct_image: The reconstruct image.
+%    o reconstruct_image: the reconstruct image.
 %
 */
 MagickExport MagickBooleanType IsImagesEqual(Image *image,
@@ -888,8 +891,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   maximum_error=0.0;
   mean_error_per_pixel=0.0;
   mean_error=0.0;
-  image_view=OpenCacheView(image);
-  reconstruct_view=OpenCacheView(reconstruct_image);
+  image_view=AcquireCacheView(image);
+  reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,&image->exception);
@@ -939,8 +942,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       q++;
     }
   }
-  reconstruct_view=CloseCacheView(reconstruct_view);
-  image_view=CloseCacheView(image_view);
+  reconstruct_view=DestroyCacheView(reconstruct_view);
+  image_view=DestroyCacheView(image_view);
   image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
   image->error.normalized_mean_error=(double) (QuantumScale*QuantumScale*
     mean_error/area);
