@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
@@ -94,19 +95,19 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
 %    o compose: This operator affects how the composite is applied to
 %      the image.  The operators and how they are utilized are listed here
 %      http://www.w3.org/TR/SVG12/#compositing.
 %
-%    o composite_image: The composite image.
+%    o composite_image: the composite image.
 %
-%    o x_offset: The column offset of the composited image.
+%    o x_offset: the column offset of the composited image.
 %
-%    o y_offset: The row offset of the composited image.
+%    o y_offset: the row offset of the composited image.
 %
 */
 
@@ -1147,11 +1148,10 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         Shift image pixels as defined by a displacement map.
       */
       GetMagickPixelPacket(displace_image,&pixel);
-      resample_filter=AcquireResampleFilter(image,
-        GetImageVirtualPixelMethod(image),&image->exception);
-      image_view=OpenCacheView(image);
-      displace_view=OpenCacheView(displace_image);
-      composite_view=OpenCacheView(composite_image);
+      resample_filter=AcquireResampleFilter(image,&image->exception);
+      image_view=AcquireCacheView(image);
+      displace_view=AcquireCacheView(displace_image);
+      composite_view=AcquireCacheView(composite_image);
       for (y=0; y < (long) composite_image->rows; y++)
       {
         if (((y+y_offset) < 0) || ((y+y_offset) >= (long) image->rows))
@@ -1195,9 +1195,9 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           break;
       }
       resample_filter=DestroyResampleFilter(resample_filter);
-      composite_view=CloseCacheView(composite_view);
-      displace_view=CloseCacheView(displace_view);
-      image_view=CloseCacheView(image_view);
+      composite_view=DestroyCacheView(composite_view);
+      displace_view=DestroyCacheView(displace_view);
+      image_view=DestroyCacheView(image_view);
       composite_image=displace_image;
       break;
     }
@@ -1210,14 +1210,24 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           */
           flags=ParseGeometry(composite_image->geometry,&geometry_info);
           source_dissolve=geometry_info.rho/100.0;
-          destination_dissolve=1.0-source_dissolve;
-          if (source_dissolve > 1.0)
-            destination_dissolve=2.0-source_dissolve;
+          destination_dissolve=1.0;
+          if ((source_dissolve-MagickEpsilon) < 0.0)
+            source_dissolve=0.0;
+          if ((source_dissolve+MagickEpsilon) > 1.0)
+            {
+              destination_dissolve=2.0-source_dissolve;
+              source_dissolve=1.0;
+            }
           if ((flags & SigmaValue) != 0)
             destination_dissolve=geometry_info.sigma/100.0;
+          if ((destination_dissolve-MagickEpsilon) < 0.0)
+            destination_dissolve=0.0;
           modify_outside_overlay=MagickTrue;
           if ((destination_dissolve+MagickEpsilon) > 1.0 )
-            modify_outside_overlay=MagickFalse;
+            {
+              destination_dissolve=1.0;
+              modify_outside_overlay=MagickFalse;
+            }
         }
       break;
     }
@@ -1269,7 +1279,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     default:
       break;
   }
-  value=GetImageProperty(composite_image,"[modify-outside-overlay]");
+  value=GetImageArtifact(composite_image,"modify-outside-overlay");
   if (value != (const char *) NULL)
     modify_outside_overlay=MagickFalse;
   /*
@@ -1281,8 +1291,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   midpoint=((MagickRealType) QuantumRange+1.0)/2;
   GetMagickPixelPacket(composite_image,&source);
   GetMagickPixelPacket(image,&destination);
-  image_view=OpenCacheView(image);
-  composite_view=OpenCacheView(composite_image);
+  image_view=AcquireCacheView(image);
+  composite_view=AcquireCacheView(composite_image);
   for (y=0; y < (long) image->rows; y++)
   {
     if (modify_outside_overlay == MagickFalse)
@@ -1780,8 +1790,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     if (SyncCacheView(image_view) == MagickFalse)
       break;
   }
-  composite_view=CloseCacheView(composite_view);
-  image_view=CloseCacheView(image_view);
+  composite_view=DestroyCacheView(composite_view);
+  image_view=DestroyCacheView(image_view);
   if (displace_image != (Image * ) NULL)
     displace_image=DestroyImage(displace_image);
   return(MagickTrue);
