@@ -17,7 +17,7 @@
 %                                 July 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -128,7 +128,7 @@ MagickExport void DestroyConfigureList(void)
   configure_list=(LinkedListInfo *) NULL;
   instantiate_configure=MagickFalse;
   RelinquishSemaphoreInfo(configure_semaphore);
-  configure_semaphore=DestroySemaphoreInfo(configure_semaphore);
+  DestroySemaphoreInfo(&configure_semaphore);
 }
 
 /*
@@ -151,7 +151,7 @@ MagickExport void DestroyConfigureList(void)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 
@@ -191,7 +191,7 @@ MagickExport LinkedListInfo *DestroyConfigureOptions(LinkedListInfo *options)
 %    o configure_info: GetConfigureInfo() searches the configure list for the
 %      specified name and if found returns attributes for that element.
 %
-%    o name: The configure name.
+%    o name: the configure name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -426,6 +426,52 @@ MagickExport char **GetConfigureList(const char *pattern,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t C o n f i g u r e O p t i o n                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetConfigureOption() returns the value associated with the configure option.
+%
+%  The format of the GetConfigureOption method is:
+%
+%      char *GetConfigureOption(const char *option)
+%
+%  A description of each parameter follows:
+%
+%    o configure_info:  The configure info.
+%
+*/
+MagickExport char *GetConfigureOption(const char *option)
+{
+  const char
+    *value;
+
+  const ConfigureInfo
+    *configure_info;
+
+  ExceptionInfo
+    *exception;
+
+  assert(option != (const char *) NULL);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",option);
+  exception=AcquireExceptionInfo();
+  configure_info=GetConfigureInfo(option,exception);
+  exception=DestroyExceptionInfo(exception);
+  if (configure_info == (ConfigureInfo *) NULL)
+    return((char *) NULL);
+  value=GetConfigureValue(configure_info);
+  if ((value == (const char *) NULL) || (*value == '\0'))
+    return((char *) NULL);
+  return(ConstantString(value));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %  G e t C o n f i g u r e O p t i o n s                                      %
 %                                                                             %
 %                                                                             %
@@ -442,7 +488,7 @@ MagickExport char **GetConfigureList(const char *pattern,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The configure file name.
+%    o filename: the configure file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -531,7 +577,7 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The configure file name.
+%    o filename: the configure file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -580,23 +626,28 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
         configure_path=DestroyString(configure_path);
       }
   }
-#if defined(UseInstalledMagick)
-#if defined(MagickLibConfigPath)
-  (void) AppendValueToLinkedList(paths,ConstantString(MagickLibConfigPath));
+#if defined(MAGICKCORE_INSTALLED_SUPPORT)
+#if defined(MAGICKCORE_SHARE_CONFIGURE_PATH)
+  (void) AppendValueToLinkedList(paths,ConstantString(
+    MAGICKCORE_SHARE_CONFIGURE_PATH));
 #endif
-#if defined(MagickShareConfigPath)
-  (void) AppendValueToLinkedList(paths,ConstantString(MagickShareConfigPath));
+#if defined(MAGICKCORE_CONFIGURE_PATH)
+  (void) AppendValueToLinkedList(paths,ConstantString(
+    MAGICKCORE_CONFIGURE_PATH));
 #endif
-#if defined(MagickDocumentPath)
-  (void) AppendValueToLinkedList(paths,ConstantString(MagickDocumentPath));
+#if defined(MAGICKCORE_DOCUMENTATION_PATH)
+  (void) AppendValueToLinkedList(paths,ConstantString(
+    MAGICKCORE_DOCUMENTATION_PATH));
 #endif
-#if defined(MagickSharePath)
-  (void) AppendValueToLinkedList(paths,ConstantString(MagickSharePath));
+#if defined(MAGICKCORE_SHARE_PATH)
+  (void) AppendValueToLinkedList(paths,ConstantString(MAGICKCORE_SHARE_PATH));
 #endif
-#if defined(__WINDOWS__) && !(defined(MagickLibConfigPath) || defined(MagickShareConfigPath))
+#if defined(__WINDOWS__) && !(defined(MAGICKCORE_CONFIGURE_PATH) || defined(MAGICKCORE_SHARE_CONFIGURE_PATH))
   {
     char
-      *registry_key,
+      *registry_key;
+
+    unsigned char
       *key_value;
 
     /*
@@ -604,11 +655,15 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
     */
     registry_key="ConfigurePath";
     key_value=NTRegistryKeyLookup(registry_key);
-    if (key_value != (char *) NULL)
+    if (key_value == (unsigned char *) NULL)
+      ThrowMagickException(exception,GetMagickModule(),ConfigureError,
+        "RegistryKeyLookupFailed","`%s'",registry_key);
+    else
       {
-        (void) FormatMagickString(path,MaxTextExtent,"%s%s",key_value,
+        (void) FormatMagickString(path,MaxTextExtent,"%s%s",(char *) key_value,
           DirectorySeparator);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
+        key_value=(unsigned char *) RelinquishMagickMemory(key_value);
       }
   }
 #endif
@@ -623,16 +678,16 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
     home=GetEnvironmentValue("MAGICK_HOME");
     if (home != (char *) NULL)
       {
-#if !defined(POSIX)
+#if !defined(MAGICKCORE_POSIX_SUPPORT)
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",home,
           DirectorySeparator);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
 #else
         (void) FormatMagickString(path,MaxTextExtent,"%s/lib/%s/",home,
-          MagickLibConfigSubDir);
+          MAGICKCORE_CONFIGURE_RELATIVE_PATH);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
         (void) FormatMagickString(path,MaxTextExtent,"%s/share/%s/",home,
-          MagickShareConfigSubDir);
+          MAGICKCORE_SHARE_CONFIGURE_RELATIVE_PATH);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
 #endif
         home=DestroyString(home);
@@ -640,7 +695,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
     }
   if (*GetClientPath() != '\0')
     {
-#if !defined(POSIX)
+#if !defined(MAGICKCORE_POSIX_SUPPORT)
       (void) FormatMagickString(path,MaxTextExtent,"%s%s",GetClientPath(),
         DirectorySeparator);
       (void) AppendValueToLinkedList(paths,ConstantString(path));
@@ -653,11 +708,11 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
       */
       (void) CopyMagickString(prefix,GetClientPath(),MaxTextExtent);
       ChopPathComponents(prefix,1);
-      (void) FormatMagickString(path,MaxTextExtent,"%s/lib/%s/",prefix,
-        MagickLibConfigSubDir);
-      (void) AppendValueToLinkedList(paths,ConstantString(path));
       (void) FormatMagickString(path,MaxTextExtent,"%s/share/%s/",prefix,
-        MagickShareConfigSubDir);
+        MAGICKCORE_SHARE_CONFIGURE_RELATIVE_PATH);
+      (void) AppendValueToLinkedList(paths,ConstantString(path));
+      (void) FormatMagickString(path,MaxTextExtent,"%s/lib/%s/",prefix,
+        MAGICKCORE_CONFIGURE_RELATIVE_PATH);
       (void) AppendValueToLinkedList(paths,ConstantString(path));
 #endif
     }
@@ -1030,7 +1085,7 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The font file name.
+%    o filename: the font file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1038,7 +1093,7 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
 static MagickBooleanType LoadConfigureLists(const char *filename,
   ExceptionInfo *exception)
 {
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
   return(LoadConfigureList(ConfigureMap,"built-in",0,exception));
 #else
   const StringInfo
