@@ -17,7 +17,7 @@
 %                               October 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -59,6 +59,7 @@
 #include "magick/pixel.h"
 #include "magick/profile.h"
 #include "magick/property.h"
+#include "magick/quantum.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
@@ -126,7 +127,6 @@ static Image
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ConstituteImage(const unsigned long columns,
   const unsigned long rows,const char *map,const StorageType storage,
@@ -146,7 +146,7 @@ MagickExport Image *ConstituteImage(const unsigned long columns,
   assert(pixels != (void *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage((ImageInfo *) NULL);
+  image=AcquireImage((ImageInfo *) NULL);
   if (image == (Image *) NULL)
     return((Image *) NULL);
   if ((columns == 0) || (rows == 0))
@@ -180,12 +180,11 @@ MagickExport Image *ConstituteImage(const unsigned long columns,
 %
 %      DestroyConstitute(void)
 %
-%
 */
 MagickExport void DestroyConstitute(void)
 {
   if (constitute_semaphore != (SemaphoreInfo *) NULL)
-    constitute_semaphore=DestroySemaphoreInfo(constitute_semaphore);
+    DestroySemaphoreInfo(&constitute_semaphore);
 }
 
 /*
@@ -286,7 +285,6 @@ MagickExport Image *PingImage(const ImageInfo *image_info,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ReadImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -350,7 +348,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       MagickBooleanType
         status;
 
-      image=AllocateImage(read_info);
+      image=AcquireImage(read_info);
       (void) CopyMagickString(image->filename,read_info->filename,
         MaxTextExtent);
       status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
@@ -369,23 +367,23 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
           status=ImageToFile(image,read_info->filename,exception);
           if (status == MagickFalse)
             {
-              CloseBlob(image);
+              (void) CloseBlob(image);
               read_info=DestroyImageInfo(read_info);
               image=DestroyImage(image);
               return((Image *) NULL);
             }
           read_info->temporary=MagickTrue;
         }
-      CloseBlob(image);
+      (void) CloseBlob(image);
       image=DestroyImage(image);
     }
   image=NewImageList();
   if ((magick_info != (const MagickInfo *) NULL) &&
-      (GetMagickDecoder(magick_info) != (DecoderHandler *) NULL))
+      (GetImageDecoder(magick_info) != (DecodeImageHandler *) NULL))
     {
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
-      image=GetMagickDecoder(magick_info)(read_info,exception);
+      image=GetImageDecoder(magick_info)(read_info,exception);
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
@@ -406,7 +404,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       /*
         Let our decoding delegate process the image.
       */
-      image=AllocateImage(read_info);
+      image=AcquireImage(read_info);
       if (image == (Image *) NULL)
         {
           read_info=DestroyImageInfo(read_info);
@@ -426,29 +424,21 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       (void) SetImageInfo(read_info,MagickFalse,exception);
       magick_info=GetMagickInfo(read_info->magick,exception);
       if ((magick_info == (const MagickInfo *) NULL) ||
-          (GetMagickDecoder(magick_info) == (DecoderHandler *) NULL))
+          (GetImageDecoder(magick_info) == (DecodeImageHandler *) NULL))
         {
           if (IsAccessible(read_info->filename) != MagickFalse)
             (void) ThrowMagickException(exception,GetMagickModule(),
               MissingDelegateError,"NoDecodeDelegateForThisImageFormat","`%s'",
               read_info->filename);
           else
-            {
-              char
-                *message;
-
-              message=GetExceptionMessage(errno);
-              (void) ThrowMagickException(exception,GetMagickModule(),
-                FileOpenError,"UnableToOpenFile","`%s': %s",read_info->filename,
-                message);
-              message=DestroyString(message);
-            }
+            ThrowFileException(exception,FileOpenError,"UnableToOpenFile",
+              read_info->filename);
           read_info=DestroyImageInfo(read_info);
           return((Image *) NULL);
         }
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
-      image=(Image *) (GetMagickDecoder(magick_info))(read_info,exception);
+      image=(Image *) (GetImageDecoder(magick_info))(read_info,exception);
       if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
@@ -488,20 +478,17 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     }
   if (GetBlobError(image) != MagickFalse)
     {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageError,
-        "AnErrorHasOccurredReadingFromFile","`%s': %s",read_info->filename,
-        message);
-      message=DestroyString(message);
+      ThrowFileException(exception,FileOpenError,
+        "AnErrorHasOccurredReadingFromFile",read_info->filename);
       image=DestroyImageList(image);
       read_info=DestroyImageInfo(read_info);
       return((Image *) NULL);
     }
   for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
   {
+    char
+      timestamp[MaxTextExtent];
+
     const StringInfo
       *profile;
 
@@ -510,20 +497,22 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       next->magick_columns=next->columns;
     if (next->magick_rows == 0)
       next->magick_rows=next->rows;
-    (void) CopyMagickString(next->magick,magick,MaxTextExtent);
+    if ((LocaleCompare(magick,"HTTP") != 0) &&
+        (LocaleCompare(magick,"FTP") != 0))
+      (void) CopyMagickString(next->magick,magick,MaxTextExtent);
     (void) CopyMagickString(next->magick_filename,magick_filename,
       MaxTextExtent);
     if (IsBlobTemporary(image) != MagickFalse)
       (void) CopyMagickString(next->filename,filename,MaxTextExtent);
-    value=GetImageProperty(next,"EXIF:Orientation");
+    value=GetImageProperty(next,"exif:Orientation");
     if (value != (char *) NULL)
       {
         next->orientation=(OrientationType) atol(value);
-        (void) DeleteImageProperty(next,"EXIF:Orientation");
+        (void) DeleteImageProperty(next,"exif:Orientation");
       }
-    value=GetImageProperty(next,"TIFF:XResolution");
+    value=GetImageProperty(next,"tiff:XResolution");
     if (value == (char *) NULL)
-      value=GetImageProperty(next,"EXIF:XResolution");
+      value=GetImageProperty(next,"exif:XResolution");
     if (value != (char *) NULL)
       {
         geometry_info.rho=next->x_resolution;
@@ -531,12 +520,12 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         flags=ParseGeometry(value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->x_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) DeleteImageProperty(next,"EXIF:XResolution");
-        (void) DeleteImageProperty(next,"TIFF:XResolution");
+        (void) DeleteImageProperty(next,"exif:XResolution");
+        (void) DeleteImageProperty(next,"tiff:XResolution");
       }
-    value=GetImageProperty(next,"TIFF:YResolution");
+    value=GetImageProperty(next,"tiff:YResolution");
     if (value == (char *) NULL)
-      value=GetImageProperty(next,"EXIF:YResolution");
+      value=GetImageProperty(next,"exif:YResolution");
     if (value != (char *) NULL)
       {
         geometry_info.rho=next->y_resolution;
@@ -544,17 +533,17 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         flags=ParseGeometry(value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->y_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) DeleteImageProperty(next,"EXIF:YResolution");
-        (void) DeleteImageProperty(next,"TIFF:YResolution");
+        (void) DeleteImageProperty(next,"exif:YResolution");
+        (void) DeleteImageProperty(next,"tiff:YResolution");
       }
-    value=GetImageProperty(next,"TIFF:ResolutionUnit");
+    value=GetImageProperty(next,"tiff:ResolutionUnit");
     if (value == (char *) NULL)
-      value=GetImageProperty(next,"EXIF:YResolution");
+      value=GetImageProperty(next,"exif:ResolutionUnit");
     if (value != (char *) NULL)
       {
         next->units=(ResolutionType) (atoi(value)-1);
-        (void) DeleteImageProperty(next,"EXIF:ResolutionUnit");
-        (void) DeleteImageProperty(next,"TIFF:ResolutionUnit");
+        (void) DeleteImageProperty(next,"exif:ResolutionUnit");
+        (void) DeleteImageProperty(next,"tiff:ResolutionUnit");
       }
     if (next->page.width == 0)
       next->page.width=next->columns;
@@ -619,17 +608,23 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       profile=GetImageProfile(next,"icm");
     if (profile != (const StringInfo *) NULL)
       {
-        image->color_profile.length=GetStringInfoLength(profile);
-        image->color_profile.info=GetStringInfoDatum(profile);
+        next->color_profile.length=GetStringInfoLength(profile);
+        next->color_profile.info=GetStringInfoDatum(profile);
       }
     profile=GetImageProfile(next,"iptc");
     if (profile == (const StringInfo *) NULL)
       profile=GetImageProfile(next,"8bim");
     if (profile != (const StringInfo *) NULL)
       {
-        image->iptc_profile.length=GetStringInfoLength(profile);
-        image->iptc_profile.info=GetStringInfoDatum(profile);
+        next->iptc_profile.length=GetStringInfoLength(profile);
+        next->iptc_profile.info=GetStringInfoDatum(profile);
       }
+    (void) FormatMagickTime(GetBlobProperties(next)->st_mtime,MaxTextExtent,
+      timestamp);
+    (void) SetImageProperty(next,"modify-date",timestamp);
+    (void) FormatMagickTime(GetBlobProperties(next)->st_ctime,MaxTextExtent,
+      timestamp);
+    (void) SetImageProperty(next,"create-date",timestamp);
     if (read_info->verbose != MagickFalse)
       (void) IdentifyImage(next,stdout,MagickFalse);
     image=next;
@@ -662,12 +657,11 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: The list of filenames are defined in the filename member of
+%    o image_info: the list of filenames are defined in the filename member of
 %      this structure.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -748,13 +742,12 @@ static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o content: The image encoded in Base64.
+%    o content: the image encoded in Base64.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
   const char *content,ExceptionInfo *exception)
@@ -775,7 +768,7 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
     *p;
 
   image=NewImageList();
-  for (p=content; (*p != ',') && (*p != '\0'); p++);
+  for (p=content; (*p != ',') && (*p != '\0'); p++) ;
   if (*p == '\0')
     ThrowReaderException(CorruptImageWarning,"CorruptImage");
   p++;
@@ -815,13 +808,13 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 
-static void SyncImageInfo(const ImageInfo *image_info,Image *image,
+static void SyncImageInfo(ImageInfo *image_info,Image *image,
   ExceptionInfo *exception)
 {
   const MagickInfo
@@ -832,9 +825,6 @@ static void SyncImageInfo(const ImageInfo *image_info,Image *image,
     (void) ParseAbsoluteGeometry(image_info->extract,&image->extract_info);
   if (image_info->depth != 0)
     (void) SetImageDepth(image,image_info->depth);
-  else
-    if (image->taint != MagickFalse)
-      image->depth=QuantumDepth;
   if (image_info->compression != UndefinedCompression)
     image->compression=image_info->compression;
   if (image_info->quality != UndefinedCompressionQuality)
@@ -951,18 +941,18 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               (void) AcquireUniqueFilename(image->filename);
               temporary=MagickTrue;
             }
-          CloseBlob(image);
+          (void) CloseBlob(image);
         }
     }
   if ((magick_info != (const MagickInfo *) NULL) &&
-      (GetMagickEncoder(magick_info) != (EncoderHandler *) NULL))
+      (GetImageEncoder(magick_info) != (EncodeImageHandler *) NULL))
     {
       /*
         Call appropriate image writer based on image type.
       */
       if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
-      status=GetMagickEncoder(magick_info)(write_info,image);
+      status=GetImageEncoder(magick_info)(write_info,image);
       if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
@@ -995,7 +985,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               magick_info=GetMagickInfo(write_info->magick,&image->exception);
             }
           if ((magick_info == (const MagickInfo *) NULL) ||
-              (GetMagickEncoder(magick_info) == (EncoderHandler *) NULL))
+              (GetImageEncoder(magick_info) == (EncodeImageHandler *) NULL))
             (void) ThrowMagickException(&image->exception,GetMagickModule(),
               MissingDelegateError,"NoEncodeDelegateForThisImageFormat","`%s'",
               image->filename);
@@ -1006,23 +996,15 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               */
               if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
                 AcquireSemaphoreInfo(&constitute_semaphore);
-              status=GetMagickEncoder(magick_info)(write_info,image);
+              status=GetImageEncoder(magick_info)(write_info,image);
               if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
                 RelinquishSemaphoreInfo(constitute_semaphore);
             }
         }
     }
   if (GetBlobError(image) != MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      (void) ThrowMagickException(&image->exception,GetMagickModule(),
-        CorruptImageError,"AnErrorHasOccurredWritingToFile","`%s': %s",
-          image->filename,message);
-      message=DestroyString(message);
-    }
+    ThrowFileException(&image->exception,FileOpenError,
+      "AnErrorHasOccurredWritingToFile",image->filename);
   if (temporary == MagickTrue)
     {
       /*
@@ -1034,7 +1016,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       (void) RelinquishUniqueFileResource(image->filename);
       (void) CopyMagickString(image->filename,write_info->filename,
         MaxTextExtent);
-      CloseBlob(image);
+      (void) CloseBlob(image);
     }
   if ((LocaleCompare(write_info->magick,"info") != 0) &&
       (write_info->verbose != MagickFalse))
@@ -1064,11 +1046,11 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o images: The image list.
+%    o images: the image list.
 %
-%    o filename: The image filename.
+%    o filename: the image filename.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1076,6 +1058,9 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
 MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   Image *images,const char *filename,ExceptionInfo *exception)
 {
+  BlobInfo
+    *blob;
+
   ExceptionInfo
     *sans_exception;
 
@@ -1100,6 +1085,9 @@ MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   assert(exception != (ExceptionInfo *) NULL);
   write_info=CloneImageInfo(image_info);
   images=GetFirstImageInList(images);
+  blob=CloneBlobInfo(images->blob);  /* thread specific I/O handler */
+  DestroyBlob(images);
+  images->blob=blob;
   if (filename != (const char *) NULL)
     for (p=images; p != (Image *) NULL; p=GetNextImageInList(p))
       (void) CopyMagickString(p->filename,filename,MaxTextExtent);
