@@ -38,7 +38,7 @@ typedef enum
 
 extern MagickExport Image
   *DistortImage(Image *image,const DistortImageMethod,const unsigned long,
-    const double *,const MagickBooleanType,ExceptionInfo *exception);
+    const double *,MagickBooleanType,ExceptionInfo *exception);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
