@@ -38,7 +38,8 @@ typedef enum
   RightShiftEvaluateOperator,
   SetEvaluateOperator,
   SubtractEvaluateOperator,
-  XorEvaluateOperator
+  XorEvaluateOperator,
+  PowEvaluateOperator
 } MagickEvaluateOperator;
 
 extern MagickExport Image
