@@ -17,7 +17,7 @@
 %                              January 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -47,6 +47,7 @@
 #include "magick/geometry.h"
 #include "magick/memory_.h"
 #include "magick/string_.h"
+#include "magick/token.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -133,6 +134,12 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
         (void) CopyMagickString(p,p+1,MaxTextExtent);
         break;
       }
+      case '^':
+      {
+        flags|=MinimumValue;
+        (void) CopyMagickString(p,p+1,MaxTextExtent);
+        break;
+      }
       case '@':
       {
         flags|=AreaValue;
@@ -147,6 +154,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       }
       case '-':
       case '.':
+      case ',':
       case '+':
       case '0':
       case '1':
@@ -179,7 +187,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
   (void) strtod(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
     (void) strtol(p,&q,10);
-  if ((*q == -41) || (*q == 'x') || (*q == 'X') || (*q == '\0'))
+  if (((int) *q == -41) || (*q == 'x') || (*q == 'X') || (*q == '\0'))
     {
       /*
         Parse width.
@@ -192,7 +200,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       if (p != q)
         flags|=WidthValue;
     }
-  if ((*p == -41) || (*p == 'x') || (*p == 'X'))
+  if (((int) *p == -41) || (*p == 'x') || (*p == 'X'))
     {
       p++;
       if ((*p != '+') && (*p != '-'))
@@ -415,7 +423,7 @@ MagickExport void GravityAdjustGeometry(const unsigned long width,
     case EastGravity:
     case SouthEastGravity:
     {
-      region->x = (long) (width - region->width - region->x);
+      region->x=(long) (width-region->width-region->x);
       break;
     }
     case NorthGravity:
@@ -423,7 +431,7 @@ MagickExport void GravityAdjustGeometry(const unsigned long width,
     case CenterGravity:
     case StaticGravity:
     {
-      region->x += (long) (width/2 - region->width/2);
+      region->x+=(long) (width/2-region->width/2);
       break;
     }
     case ForgetGravity:
@@ -439,7 +447,7 @@ MagickExport void GravityAdjustGeometry(const unsigned long width,
     case SouthGravity:
     case SouthEastGravity:
     {
-      region->y = (long) (height - region->height - region->y);
+      region->y=(long) (height-region->height-region->y);
       break;
     }
     case EastGravity:
@@ -447,7 +455,7 @@ MagickExport void GravityAdjustGeometry(const unsigned long width,
     case CenterGravity:
     case StaticGravity:
     {
-      region->y += (long) (height/2 - region->height/2);
+      region->y+=(long) (height/2-region->height/2);
       break;
     }
     case ForgetGravity:
@@ -464,6 +472,7 @@ MagickExport void GravityAdjustGeometry(const unsigned long width,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
 +     I s G e o m e t r y                                                     %
 %                                                                             %
 %                                                                             %
@@ -500,6 +509,7 @@ MagickExport MagickBooleanType IsGeometry(const char *geometry)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
 +     I s S c e n e G e o m e t r y                                           %
 %                                                                             %
 %                                                                             %
@@ -563,7 +573,7 @@ MagickExport MagickBooleanType IsSceneGeometry(const char *geometry,
 %
 %    o geometry:  The geometry (e.g. 100x100+10+10).
 %
-%    o region_info: The region as defined by the geometry string.
+%    o region_info: the region as defined by the geometry string.
 %
 */
 MagickExport MagickStatusType ParseAbsoluteGeometry(const char *geometry,
@@ -600,17 +610,17 @@ MagickExport MagickStatusType ParseAbsoluteGeometry(const char *geometry,
 %
 %    o geometry:  The geometry (e.g. 1.0,0.0,0.0,1.0,3.2,1.2).
 %
-%    o affine_matrix: The affine matrix as defined by the geometry string.
+%    o affine_matrix: the affine matrix as defined by the geometry string.
 %
 */
 MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
   AffineMatrix *affine_matrix)
 {
   char
-    *p;
+    token[MaxTextExtent];
 
-  double
-    value;
+  const char
+    *p;
 
   MagickStatusType
     flags;
@@ -623,19 +633,18 @@ MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
   p=(char *) geometry;
   for (i=0; i < 6; i++)
   {
-    value=strtod(p,&p);
+    GetMagickToken(p,&p,token);
+    if (*token == ',')
+      GetMagickToken(p,&p,token);
     switch (i)
     {
-      case 0: affine_matrix->sx=value; break;
-      case 1: affine_matrix->rx=value; break;
-      case 2: affine_matrix->ry=value; break;
-      case 3: affine_matrix->sy=value; break;
-      case 4: affine_matrix->tx=value; flags|=XValue; break;
-      case 5: affine_matrix->ty=value; flags|=YValue; break;
+      case 0: affine_matrix->sx=atof(token); break;
+      case 1: affine_matrix->rx=atof(token); break;
+      case 2: affine_matrix->ry=atof(token); break;
+      case 3: affine_matrix->sy=atof(token); break;
+      case 4: affine_matrix->tx=atof(token); flags|=XValue; break;
+      case 5: affine_matrix->ty=atof(token); flags|=YValue; break;
     }
-    if (*p !=',')
-      break;
-    p++;
   }
   return(flags);
 }
@@ -726,6 +735,12 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         (void) CopyMagickString(p,p+1,MaxTextExtent);
         break;
       }
+      case '^':
+      {
+        flags|=MinimumValue;
+        (void) CopyMagickString(p,p+1,MaxTextExtent);
+        break;
+      }
       case '@':
       {
         flags|=AreaValue;
@@ -740,6 +755,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       }
       case '-':
       case '+':
+      case ',':
       case '0':
       case '1':
       case '2':
@@ -753,7 +769,6 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       case -41:
       case 'x':
       case 'X':
-      case ',':
       case '/':
       case ':':
       {
@@ -780,7 +795,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
   (void) strtod(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
     (void) strtol(p,&q,10);
-  if ((*q == -41) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
+  if (((int) *q == -41) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
       (*q == '/') || (*q == ':') || (*q =='\0'))
     {
       /*
@@ -798,7 +813,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         }
     }
   q=p;
-  if ((*p == -41) || (*p == 'x') || (*p == 'X') || (*p == ',') ||
+  if (((int) *p == -41) || (*p == 'x') || (*p == 'X') || (*p == ',') ||
       (*p == '/') || (*p == ':'))
     {
       /*
@@ -807,7 +822,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       p++;
       while (isspace((int) ((unsigned char) *p)) != 0)
         p++;
-      if (((*q != -41) && (*q != 'x') && (*q != 'X')) ||
+      if ((((int) *q != -41) && (*q != 'x') && (*q != 'X')) ||
           ((*p != '+') && (*p != '-')))
         {
           q=p;
@@ -914,7 +929,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
 %
 %    o geometry:  The geometry (e.g. 100x100+10+10).
 %
-%    o region_info: The region as defined by the geometry string with
+%    o region_info: the region as defined by the geometry string with
 %      respect to the image dimensions and its gravity.
 %
 */
@@ -964,7 +979,11 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
       if ((status & SigmaValue) == 0)
         scale.y=scale.x;
       region_info->width=(unsigned long) ((scale.x*image->columns/100.0)+0.5);
+      if (region_info->width == 0)
+        region_info->width=1;
       region_info->height=(unsigned long) ((scale.y*image->rows/100.0)+0.5);
+      if (region_info->height == 0)
+        region_info->height=1;
     }
   /*
     If a region width of 0 is given by the user, use the images virtual canvas
@@ -1012,6 +1031,15 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
 %      specification.
 %
 */
+
+static inline unsigned long MagickMax(const unsigned long x,
+  const unsigned long y)
+{
+  if (x > y)
+    return(x);
+  return(y);
+}
+
 MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
   long *y,unsigned long *width,unsigned long *height)
 {
@@ -1060,13 +1088,17 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
       scale.y=geometry_info.sigma;
       if ((flags & SigmaValue) == 0)
         scale.y=scale.x;
-      *width=(unsigned long) ((scale.x*former_width/100.0)+0.5);
-      *height=(unsigned long) ((scale.y*former_height/100.0)+0.5);
+      *width=(unsigned long) (scale.x*former_width/100.0+0.5);
+      if (*width == 0)
+        *width=1;
+      *height=(unsigned long) (scale.y*former_height/100.0+0.5);
+      if (*height == 0)
+        *height=1;
       former_width=(*width);
       former_height=(*height);
     }
-  if (((flags & AspectValue) == 0) &&
-      ((*width != former_width) || (*height != former_height)))
+  if (((flags & AspectValue) == 0) && ((*width != former_width) ||
+      (*height != former_height)))
     {
       MagickRealType
         scale_factor;
@@ -1080,20 +1112,43 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
         if (((flags & RhoValue) != 0) && (flags & SigmaValue) != 0)
           {
             scale_factor=(MagickRealType) *width/(MagickRealType) former_width;
-            if (scale_factor > ((MagickRealType) *height/
-                (MagickRealType) former_height))
-              scale_factor=(MagickRealType)
-                *height/(MagickRealType) former_height;
+            if ((flags & MinimumValue) == 0)
+              {
+                if (scale_factor > ((MagickRealType) *height/
+                    (MagickRealType) former_height))
+                  scale_factor=(MagickRealType) *height/(MagickRealType)
+                    former_height;
+              }
+            else
+              if (scale_factor < ((MagickRealType) *height/
+                  (MagickRealType) former_height))
+                scale_factor=(MagickRealType) *height/(MagickRealType)
+                  former_height;
           }
         else
           if ((flags & RhoValue) != 0)
-            scale_factor=(MagickRealType) *width/(MagickRealType) former_width;
+            {
+              scale_factor=(MagickRealType) *width/(MagickRealType)
+                former_width;
+              if (((flags & MinimumValue) != 0) &&
+                  (scale_factor < ((MagickRealType) *width/
+                    (MagickRealType) former_height)))
+                scale_factor=(MagickRealType) *width/(MagickRealType)
+                  former_height;
+            }
           else
-            scale_factor=(MagickRealType)
-              *height/(MagickRealType) former_height;
-    *width=(unsigned long) (scale_factor*former_width+0.5);
-    *height=(unsigned long) (scale_factor*former_height+0.5);
-  }
+            {
+              scale_factor=(MagickRealType) *height/(MagickRealType)
+                former_height;
+              if (((flags & MinimumValue) != 0) &&
+                  (scale_factor < ((MagickRealType) *height/
+                    (MagickRealType) former_width)))
+                scale_factor=(MagickRealType) *height/(MagickRealType)
+                  former_width;
+            }
+      *width=MagickMax((unsigned long) (scale_factor*former_width+0.5),1UL);
+      *height=MagickMax((unsigned long) (scale_factor*former_height+0.5),1UL);
+    }
   if ((flags & GreaterValue) != 0)
     {
       if (former_width < *width)
@@ -1160,7 +1215,7 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
 %
 %    o geometry:  The geometry (e.g. 100x100+10+10).
 %
-%    o region_info: The region as defined by the geometry string with
+%    o region_info: the region as defined by the geometry string with
 %      respect to the image and its gravity.
 %
 */
@@ -1215,7 +1270,7 @@ MagickExport MagickStatusType ParsePageGeometry(Image *image,
 %
 %    o geometry:  The geometry (e.g. 100x100+10+10).
 %
-%    o region_info: The region as defined by the geometry string.
+%    o region_info: the region as defined by the geometry string.
 %
 */
 MagickExport MagickStatusType ParseSizeGeometry(Image *image,
@@ -1252,9 +1307,9 @@ MagickExport MagickStatusType ParseSizeGeometry(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o geometry: The geometry.
+%    o geometry: the geometry.
 %
 */
 MagickExport void SetGeometry(const Image *image,RectangleInfo *geometry)
@@ -1288,7 +1343,7 @@ MagickExport void SetGeometry(const Image *image,RectangleInfo *geometry)
 %
 %  A description of each parameter follows:
 %
-%    o geometry_info: The geometry info structure.
+%    o geometry_info: the geometry info structure.
 %
 */
 MagickExport void SetGeometryInfo(GeometryInfo *geometry_info)
