@@ -25,7 +25,7 @@ extern "C" {
 #include <magick/color.h>
 
 #define OpaqueOpacity  ((Quantum) 0UL)
-#define TransparentOpacity  (QuantumRange)
+#define TransparentOpacity  ((Quantum) QuantumRange)
 
 typedef enum
 {
@@ -318,6 +318,12 @@ struct _Image
   void
     *properties,
     *artifacts;
+
+  ImageType
+    type;
+
+  MagickBooleanType
+    dither;
 };
 
 struct _ImageInfo
@@ -381,7 +387,7 @@ struct _ImageInfo
     colors;
 
   ColorspaceType
-    colorspace;
+    colorspace;  /* deprecated */
 
   ImageType
     type;
@@ -471,7 +477,7 @@ extern MagickExport ExceptionType
   CatchImageException(Image *);
 
 extern MagickExport Image
-  *AllocateImage(const ImageInfo *),
+  *AcquireImage(const ImageInfo *),
   *AppendImages(const Image *,const MagickBooleanType,ExceptionInfo *),
   *AverageImages(const Image *,ExceptionInfo *),
   *CloneImage(const Image *,const unsigned long,const unsigned long,
@@ -500,10 +506,11 @@ extern MagickExport long
   InterpretImageFilename(char *,const size_t,const char *,int);
 
 extern MagickExport MagickBooleanType
-  AllocateImageColormap(Image *,const unsigned long),
+  AcquireImageColormap(Image *,const unsigned long),
   ClipImage(Image *),
   ClipImagePath(Image *,const char *,const MagickBooleanType),
   CycleColormapImage(Image *,const long),
+  GetImageAlphaChannel(const Image *),
   GradientImage(Image *,const PixelPacket *,const PixelPacket *),
   IsTaintImage(const Image *),
   IsMagickConflict(const char *),
@@ -548,7 +555,7 @@ extern MagickExport VirtualPixelMethod
   SetImageVirtualPixelMethod(const Image *,const VirtualPixelMethod);
 
 extern MagickExport void
-  AllocateNextImage(const ImageInfo *,Image *),
+  AcquireNextImage(const ImageInfo *,Image *),
   DestroyImagePixels(Image *),
   DisassociateImageStream(Image *),
   GetImageException(Image *,ExceptionInfo *),
