@@ -69,9 +69,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list to be appended to.
+%    o images: the image list to be appended to.
 %
-%    o image: The appended image or image list.
+%    o image: the appended image or image list.
 %
 */
 MagickExport void AppendImageToList(Image **images,const Image *image)
@@ -118,7 +118,7 @@ MagickExport void AppendImageToList(Image **images,const Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -189,7 +189,7 @@ MagickExport Image *CloneImageList(const Image *images,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image sequence.
+%    o images: the image sequence.
 %
 %    o scenes: This character string specifies which scenes to clone
 %      (e.g. 1,3-5,7-3,2).
@@ -286,7 +286,7 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport void DeleteImageFromList(Image **images)
@@ -327,7 +327,7 @@ MagickExport void DeleteImageFromList(Image **images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image sequence.
+%    o images: the image sequence.
 %
 %    o scenes: This character string specifies which scenes to delete
 %      (e.g. 1,3-5,-2-6,2).
@@ -438,7 +438,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image sequence.
+%    o image: the image sequence.
 %
 */
 MagickExport Image *DestroyImageList(Image *images)
@@ -472,7 +472,7 @@ MagickExport Image *DestroyImageList(Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *GetFirstImageInList(const Image *images)
@@ -483,7 +483,7 @@ MagickExport Image *GetFirstImageInList(const Image *images)
   if (images == (Image *) NULL)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
-  for (p=images; p->previous != (Image *) NULL; p=p->previous);
+  for (p=images; p->previous != (Image *) NULL; p=p->previous) ;
   return((Image *) p);
 }
 
@@ -506,9 +506,9 @@ MagickExport Image *GetFirstImageInList(const Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
-%    o index: The position within the list.
+%    o index: the position within the list.
 %
 */
 MagickExport Image *GetImageFromList(const Image *images,const long index)
@@ -522,15 +522,19 @@ MagickExport Image *GetImageFromList(const Image *images,const long index)
   register long
     i;
 
+  size_t
+    length;
+
   if (images == (Image *) NULL)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
-  for (p=images; p->previous != (Image *) NULL; p=p->previous);
-  offset=index < 0 ? index+(long) GetImageListLength(images) : index;
+  for (p=images; p->previous != (Image *) NULL; p=p->previous) ;
+  length=GetImageListLength(images);
+  for (offset=index; offset < 0; offset+=length) ;
   for (i=0; p != (Image *) NULL; p=p->next)
-    if (i++ == offset)
+    if (i++ == (long) (offset % length))
       break;
   if (p == (Image *) NULL)
     return((Image *) NULL);
@@ -556,7 +560,7 @@ MagickExport Image *GetImageFromList(const Image *images,const long index)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport long GetImageIndexInList(const Image *images)
@@ -592,7 +596,7 @@ MagickExport long GetImageIndexInList(const Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport unsigned long GetImageListLength(const Image *images)
@@ -631,7 +635,7 @@ MagickExport unsigned long GetImageListLength(const Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *GetLastImageInList(const Image *images)
@@ -642,7 +646,7 @@ MagickExport Image *GetLastImageInList(const Image *images)
   if (images == (Image *) NULL)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
-  for (p=images; p->next != (Image *) NULL; p=p->next);
+  for (p=images; p->next != (Image *) NULL; p=p->next) ;
   return((Image *) p);
 }
 
@@ -665,7 +669,7 @@ MagickExport Image *GetLastImageInList(const Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *GetNextImageInList(const Image *images)
@@ -697,7 +701,7 @@ MagickExport Image *GetNextImageInList(const Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *GetPreviousImageInList(const Image *images)
@@ -733,7 +737,7 @@ MagickExport Image *GetPreviousImageInList(const Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image list.
+%    o image: the image list.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -788,9 +792,9 @@ MagickExport Image **ImageListToArray(const Image *images,
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list to insert into.
+%    o images: the image list to insert into.
 %
-%    o image: The image list to insert.
+%    o image: the image list to insert.
 %
 */
 MagickExport void InsertImageInList(Image **images,Image *image)
@@ -853,9 +857,9 @@ MagickExport Image *NewImageList(void)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void PrependImageToList(Image **images,Image *image)
@@ -886,7 +890,7 @@ MagickExport void PrependImageToList(Image **images,Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *RemoveImageFromList(Image **images)
@@ -945,7 +949,7 @@ MagickExport Image *RemoveImageFromList(Image **images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *RemoveFirstImageFromList(Image **images)
@@ -996,7 +1000,7 @@ MagickExport Image *RemoveFirstImageFromList(Image **images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *RemoveLastImageFromList(Image **images)
@@ -1044,9 +1048,9 @@ MagickExport Image *RemoveLastImageFromList(Image **images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void ReplaceImageInList(Image **images,Image *image)
@@ -1089,7 +1093,7 @@ MagickExport void ReplaceImageInList(Image **images,Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport void ReverseImageList(Image **images)
@@ -1107,7 +1111,7 @@ MagickExport void ReverseImageList(Image **images)
   if ((*images)->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       (*images)->filename);
-  for (p=(*images); p->next != (Image *) NULL; p=p->next);
+  for (p=(*images); p->next != (Image *) NULL; p=p->next) ;
   *images=p;
   for ( ; p != (Image *) NULL; p=p->next)
   {
@@ -1138,9 +1142,9 @@ MagickExport void ReverseImageList(Image **images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
-%    o length: The length of the image list to remove.
+%    o length: the length of the image list to remove.
 %
 %    o splice: Replace the removed image list with this list.
 %
@@ -1193,7 +1197,7 @@ MagickExport Image *SpliceImageIntoList(Image **images,
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *SplitImageList(Image *images)
@@ -1225,7 +1229,7 @@ MagickExport Image *SplitImageList(Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport void SyncImageList(Image *images)
@@ -1271,7 +1275,7 @@ MagickExport void SyncImageList(Image *images)
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
+%    o images: the image list.
 %
 */
 MagickExport Image *SyncNextImageInList(const Image *images)
