@@ -17,7 +17,7 @@
 %                                September 1996                               %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -134,11 +134,11 @@ static MACErrorHookPtr
 %
 %    o picture: Specifies a pointer to a PicHandle structure.
 %
-%    o codec: The code type is returned in this CodecType pointer structure.
+%    o codec: the code type is returned in this CodecType pointer structure.
 %
-%    o depth: The image depth is returned as an integer pointer.
+%    o depth: the image depth is returned as an integer pointer.
 %
-%    o colormap_id: The colormap ID is returned in this short pointer.
+%    o colormap_id: the colormap ID is returned in this short pointer.
 %
 %
 */
@@ -278,7 +278,7 @@ static short BottleneckTest(PicHandle picture,CodecType *codec,int *depth,
 }
 #endif
 
-#if !defined(_POSIX_VERSION)
+#if !defined(_MAGICKCORE_POSIX_SUPPORT_VERSION)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -514,12 +514,12 @@ MagickExport void MACErrorHandler(const ExceptionType error,const char *reason,
     exception.hook(error,buffer);
   else
     {
-      DestroyMagick();
+      MagickCoreTerminus();
       exit(error);
     }
 #else
   puts(buffer);
-  DestroyMagick();
+  MagickCoreTerminus();
   exit(error);
 #endif
 }
@@ -573,7 +573,7 @@ static void MACFatalErrorHandler(const ExceptionType severity,
     exception.hook(severity, buffer);
   else
     {
-      DestroyMagick();
+      MagickCoreTerminus();
       exit(severity);
     }
 }
@@ -973,7 +973,7 @@ MagickExport void MACWarningHandler(const ExceptionType warning,
 #endif
 }
 
-#if !defined(_POSIX_VERSION)
+#if !defined(_MAGICKCORE_POSIX_SUPPORT_VERSION)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -1084,7 +1084,7 @@ MagickExport void ProcessPendingEvents(const char *text)
 #endif
 }
 
-#if !defined(_POSIX_VERSION)
+#if !defined(_MAGICKCORE_POSIX_SUPPORT_VERSION)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -1172,7 +1172,7 @@ MagickExport struct dirent *readdir(DIR *entry)
 %      reading.  A null image is returned if there is a a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: The image info..
+%    o image_info: the image info..
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1243,7 +1243,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
   /*
     Open image file.
   */
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     return(NULL);
@@ -1322,7 +1322,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
         Colormapped PICT image.
       */
       number_colors=(*(picture_info.theColorTable))->ctSize;
-      if (!AllocateImageColormap(image,number_colors))
+      if (!AcquireImageColormap(image,number_colors))
         {
           if (picture_info.theColorTable != nil)
             DisposeHandle((Handle) picture_info.theColorTable);
@@ -1387,7 +1387,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
   if (picture_info.theColorTable != nil)
     DisposeHandle((Handle) picture_info.theColorTable);
   DisposeGWorld(graphic_world);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(image);
 }
 
@@ -1479,7 +1479,7 @@ static Boolean SearchForFile(OSType creator_type,OSType file_type,FSSpec *file,
   return(error == eofErr);
 }
 
-#if !defined(_POSIX_VERSION)
+#if !defined(_MAGICKCORE_POSIX_SUPPORT_VERSION)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -1576,7 +1576,7 @@ MagickExport void SetApplicationType(const char *filename,const char *magick,
   FSpCreate(&file_specification,application,filetype,smSystemScript);
 }
 
-#if !defined(_POSIX_VERSION)
+#if !defined(_MAGICKCORE_POSIX_SUPPORT_VERSION)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
