@@ -69,10 +69,10 @@
 %
 %  A description of each parameter follows:
 %
-%    o nptrs: The number pointers for the array of pointers
+%    o nptrs: the number pointers for the array of pointers
 %             (first dimension)
 %
-%    o size: The size of the array of doubles each pointer points to.
+%    o size: the size of the array of doubles each pointer points to.
 %            (second dimension)
 %
 */
@@ -131,9 +131,9 @@ MagickExport double **AcquireMagickMatrix(const unsigned long nptrs,
 %
 %  A description of each parameter follows:
 %
-%    o matrix: The matrix to be reduced, as an 'array of row pointers'.
+%    o matrix: the matrix to be reduced, as an 'array of row pointers'.
 %
-%    o vectors: The additional matrix argumenting the matrix for row reduction.
+%    o vectors: the additional matrix argumenting the matrix for row reduction.
 %             Producing an 'array of column vectors'.
 %
 %    o rank:  The size of the matrix (both rows and columns).
@@ -307,17 +307,17 @@ MagickExport MagickBooleanType GaussJordanElimination(double **matrix,
 %
 %  A description of each parameter follows:
 %
-%    o matrix: The square matrix to add given terms/results to.
+%    o matrix: the square matrix to add given terms/results to.
 %
-%    o vectors: The result vectors to add terms/results to.
+%    o vectors: the result vectors to add terms/results to.
 %
-%    o terms: The pre-calculated terms (without the unknown coefficent
+%    o terms: the pre-calculated terms (without the unknown coefficent
 %             weights) that forms the equation being added.
 %
-%    o results: The result(s) that should be generated from the given terms
+%    o results: the result(s) that should be generated from the given terms
 %               weighted by the yet-to-be-solved coefficents.
 %
-%    o rank: The rank or size of the dimentions of the square matrix.
+%    o rank: the rank or size of the dimentions of the square matrix.
 %            Also the length of vectors, and number of terms being added.
 %
 %    o nvecs: Number of result vectors, and number or results being added.
@@ -326,15 +326,15 @@ MagickExport MagickBooleanType GaussJordanElimination(double **matrix,
 %
 %  Example of use...
 %
-%     // 2 dimentional Affine Equations (which are separable)
-%     //   c0*x + c2*y + c4*1 => u
-%     //   c1*x + c3*y + c5*1 => v
+%     2 dimentional Affine Equations (which are separable)
+%       c0*x + c2*y + c4*1 => u
+%      c1*x + c3*y + c5*1 => v
 %
 %     double **matrix = AcquireMagickMatrix(3UL,3UL);
 %     double **vectors = AcquireMagickMatrix(2UL,3UL);
 %     double terms[3], results[2];
 %     ...
-%     //for each given x,y -> u,v
+%     for each given x,y -> u,v
 %        terms[0] = x;
 %        terms[1] = y;
 %        terms[2] = 1;
@@ -397,7 +397,7 @@ MagickExport void LeastSquaresAddTerms(double **matrix,double **vectors,
 %
 %    o matrix: the matrix to relinquish
 %
-%    o nptrs: The first dimention of the acquired matrix (number of pointers)
+%    o nptrs: the first dimention of the acquired matrix (number of pointers)
 %
 */
 MagickExport double **RelinquishMagickMatrix(double **matrix,
