@@ -15,7 +15,7 @@
 
   MagickCore API methods prefix.
 
-  nm .libs/libMagick.a | grep ' T ' | \
+  nm .libs/libMagickCore.a | grep ' T ' | \
     awk '{ printf("#define %s  PrependMagickMethod(%s)\n", $3, $3); }' | \
     sort
 */
@@ -40,15 +40,21 @@ extern "C" {
 #define AcquireCacheNexus  PrependMagickMethod(AcquireCacheNexus)
 #define AcquireCacheViewIndexes  PrependMagickMethod(AcquireCacheViewIndexes)
 #define AcquireCacheViewPixels  PrependMagickMethod(AcquireCacheViewPixels)
+#define AcquireCacheView  PrependMagickMethod(AcquireCacheView)
+#define AcquireCacheViewThreadSet  PrependMagickMethod(AcquireCacheViewThreadSet)
 #define AcquireDrawInfo  PrependMagickMethod(AcquireDrawInfo)
 #define AcquireExceptionInfo  PrependMagickMethod(AcquireExceptionInfo)
 #define AcquireFxInfo  PrependMagickMethod(AcquireFxInfo)
+#define AcquireImageColormap  PrependMagickMethod(AcquireImageColormap)
 #define AcquireImageInfo  PrependMagickMethod(AcquireImageInfo)
 #define AcquireImagePixels  PrependMagickMethod(AcquireImagePixels)
+#define AcquireImage  PrependMagickMethod(AcquireImage)
 #define AcquireIndexes  PrependMagickMethod(AcquireIndexes)
+#define AcquireMagickMatrix  PrependMagickMethod(AcquireMagickMatrix)
 #define AcquireMagickMemory  PrependMagickMethod(AcquireMagickMemory)
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
+#define AcquireNextImage  PrependMagickMethod(AcquireNextImage)
 #define AcquireNexusIndexes  PrependMagickMethod(AcquireNexusIndexes)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
 #define AcquireOneMagickPixel  PrependMagickMethod(AcquireOneMagickPixel)
@@ -57,8 +63,11 @@ extern "C" {
 #define AcquireQuantizeInfo  PrependMagickMethod(AcquireQuantizeInfo)
 #define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
 #define AcquireQuantumMemory  PrependMagickMethod(AcquireQuantumMemory)
+#define AcquireRandomInfo  PrependMagickMethod(AcquireRandomInfo)
 #define AcquireResampleFilter  PrependMagickMethod(AcquireResampleFilter)
+#define AcquireResizeFilter  PrependMagickMethod(AcquireResizeFilter)
 #define AcquireSemaphoreInfo  PrependMagickMethod(AcquireSemaphoreInfo)
+#define AcquireSignatureInfo  PrependMagickMethod(AcquireSignatureInfo)
 #define AcquireStreamInfo  PrependMagickMethod(AcquireStreamInfo)
 #define AcquireStringInfo  PrependMagickMethod(AcquireStringInfo)
 #define AcquireString  PrependMagickMethod(AcquireString)
@@ -83,6 +92,7 @@ extern "C" {
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
 #define AllocateSemaphoreInfo  PrependMagickMethod(AllocateSemaphoreInfo)
 #define AllocateString  PrependMagickMethod(AllocateString)
+#define analyzeImage  PrependMagickMethod(analyzeImage)
 #define AnimateImages  PrependMagickMethod(AnimateImages)
 #define AnnotateImage  PrependMagickMethod(AnnotateImage)
 #define AppendImageFormat  PrependMagickMethod(AppendImageFormat)
@@ -115,12 +125,14 @@ extern "C" {
 #define ChopPathComponents  PrependMagickMethod(ChopPathComponents)
 #define ClearLinkedList  PrependMagickMethod(ClearLinkedList)
 #define ClearMagickException  PrependMagickMethod(ClearMagickException)
-#define ClipImage  PrependMagickMethod(ClipImage)
 #define ClipImagePath  PrependMagickMethod(ClipImagePath)
+#define ClipImage  PrependMagickMethod(ClipImage)
+#define ClipPathImage  PrependMagickMethod(ClipPathImage)
 #define CloneBlobInfo  PrependMagickMethod(CloneBlobInfo)
 #define CloneCacheMethods  PrependMagickMethod(CloneCacheMethods)
 #define CloneCacheView  PrependMagickMethod(CloneCacheView)
 #define CloneDrawInfo  PrependMagickMethod(CloneDrawInfo)
+#define CloneImageArtifacts  PrependMagickMethod(CloneImageArtifacts)
 #define CloneImageAttributes  PrependMagickMethod(CloneImageAttributes)
 #define CloneImageInfo  PrependMagickMethod(CloneImageInfo)
 #define CloneImageList  PrependMagickMethod(CloneImageList)
@@ -132,10 +144,12 @@ extern "C" {
 #define CloneMemory  PrependMagickMethod(CloneMemory)
 #define CloneMontageInfo  PrependMagickMethod(CloneMontageInfo)
 #define CloneQuantizeInfo  PrependMagickMethod(CloneQuantizeInfo)
+#define CloneSplayTree  PrependMagickMethod(CloneSplayTree)
 #define CloneStringInfo  PrependMagickMethod(CloneStringInfo)
 #define CloneString  PrependMagickMethod(CloneString)
 #define CloseBlob  PrependMagickMethod(CloseBlob)
 #define CloseCacheView  PrependMagickMethod(CloseCacheView)
+#define CloseMagickLog  PrependMagickMethod(CloseMagickLog)
 #define ClutImageChannel  PrependMagickMethod(ClutImageChannel)
 #define ClutImage  PrependMagickMethod(ClutImage)
 #define CoalesceImages  PrependMagickMethod(CoalesceImages)
@@ -178,12 +192,16 @@ extern "C" {
 #define CopyMagickString  PrependMagickMethod(CopyMagickString)
 #define CropImage  PrependMagickMethod(CropImage)
 #define CycleColormapImage  PrependMagickMethod(CycleColormapImage)
+#define DecipherImage  PrependMagickMethod(DecipherImage)
 #define DeconstructImages  PrependMagickMethod(DeconstructImages)
+#define DefineImageArtifact  PrependMagickMethod(DefineImageArtifact)
 #define DefineImageOption  PrependMagickMethod(DefineImageOption)
 #define DefineImageProperty  PrependMagickMethod(DefineImageProperty)
 #define DefineImageRegistry  PrependMagickMethod(DefineImageRegistry)
+#define DeleteImageArtifact  PrependMagickMethod(DeleteImageArtifact)
 #define DeleteImageAttribute  PrependMagickMethod(DeleteImageAttribute)
 #define DeleteImageFromList  PrependMagickMethod(DeleteImageFromList)
+#define DeleteImageList  PrependMagickMethod(DeleteImageList)
 #define DeleteImageOption  PrependMagickMethod(DeleteImageOption)
 #define DeleteImageProfile  PrependMagickMethod(DeleteImageProfile)
 #define DeleteImageProperty  PrependMagickMethod(DeleteImageProperty)
@@ -198,6 +216,8 @@ extern "C" {
 #define DestroyCacheInfo  PrependMagickMethod(DestroyCacheInfo)
 #define DestroyCacheNexus  PrependMagickMethod(DestroyCacheNexus)
 #define DestroyCacheResources  PrependMagickMethod(DestroyCacheResources)
+#define DestroyCacheView  PrependMagickMethod(DestroyCacheView)
+#define DestroyCacheViewSet  PrependMagickMethod(DestroyCacheViewSet)
 #define DestroyCoderList  PrependMagickMethod(DestroyCoderList)
 #define DestroyColorList  PrependMagickMethod(DestroyColorList)
 #define DestroyConfigureList  PrependMagickMethod(DestroyConfigureList)
@@ -208,6 +228,7 @@ extern "C" {
 #define DestroyExceptionInfo  PrependMagickMethod(DestroyExceptionInfo)
 #define DestroyFxInfo  PrependMagickMethod(DestroyFxInfo)
 #define DestroyHashmap  PrependMagickMethod(DestroyHashmap)
+#define DestroyImageArtifacts  PrependMagickMethod(DestroyImageArtifacts)
 #define DestroyImageAttributes  PrependMagickMethod(DestroyImageAttributes)
 #define DestroyImageInfo  PrependMagickMethod(DestroyImageInfo)
 #define DestroyImageList  PrependMagickMethod(DestroyImageList)
@@ -232,10 +253,13 @@ extern "C" {
 #define DestroyMontageInfo  PrependMagickMethod(DestroyMontageInfo)
 #define DestroyQuantizeInfo  PrependMagickMethod(DestroyQuantizeInfo)
 #define DestroyQuantumInfo  PrependMagickMethod(DestroyQuantumInfo)
+#define DestroyRandomInfo  PrependMagickMethod(DestroyRandomInfo)
 #define DestroyRandomReservoir  PrependMagickMethod(DestroyRandomReservoir)
 #define DestroyResampleFilter  PrependMagickMethod(DestroyResampleFilter)
+#define DestroyResizeFilter  PrependMagickMethod(DestroyResizeFilter)
 #define DestroySemaphoreInfo  PrependMagickMethod(DestroySemaphoreInfo)
 #define DestroySemaphore  PrependMagickMethod(DestroySemaphore)
+#define DestroySignatureInfo  PrependMagickMethod(DestroySignatureInfo)
 #define DestroySplayTree  PrependMagickMethod(DestroySplayTree)
 #define DestroyStreamInfo  PrependMagickMethod(DestroyStreamInfo)
 #define DestroyStringInfo  PrependMagickMethod(DestroyStringInfo)
@@ -252,7 +276,6 @@ extern "C" {
 #define DispatchImage  PrependMagickMethod(DispatchImage)
 #define DisplayImages  PrependMagickMethod(DisplayImages)
 #define DisposeImages  PrependMagickMethod(DisposeImages)
-#define DistillRandomEvent  PrependMagickMethod(DistillRandomEvent)
 #define DistortImage  PrependMagickMethod(DistortImage)
 #define DrawAffineImage  PrependMagickMethod(DrawAffineImage)
 #define DrawClipPath  PrependMagickMethod(DrawClipPath)
@@ -262,8 +285,10 @@ extern "C" {
 #define DrawPrimitive  PrependMagickMethod(DrawPrimitive)
 #define EdgeImage  PrependMagickMethod(EdgeImage)
 #define EmbossImage  PrependMagickMethod(EmbossImage)
+#define EncipherImage  PrependMagickMethod(EncipherImage)
 #define EnhanceImage  PrependMagickMethod(EnhanceImage)
 #define EOFBlob  PrependMagickMethod(EOFBlob)
+#define EqualizeImageChannel  PrependMagickMethod(EqualizeImageChannel)
 #define EqualizeImage  PrependMagickMethod(EqualizeImage)
 #define EscapeString  PrependMagickMethod(EscapeString)
 #define EvaluateImageChannel  PrependMagickMethod(EvaluateImageChannel)
@@ -282,6 +307,7 @@ extern "C" {
 #define FinalizeSignature  PrependMagickMethod(FinalizeSignature)
 #define FlattenImages  PrependMagickMethod(FlattenImages)
 #define FlipImage  PrependMagickMethod(FlipImage)
+#define FloodfillPaintImage  PrependMagickMethod(FloodfillPaintImage)
 #define FlopImage  PrependMagickMethod(FlopImage)
 #define FormatImageAttributeList  PrependMagickMethod(FormatImageAttributeList)
 #define FormatImageAttribute  PrependMagickMethod(FormatImageAttribute)
@@ -311,6 +337,7 @@ extern "C" {
 #define GetBlobError  PrependMagickMethod(GetBlobError)
 #define GetBlobFileHandle  PrependMagickMethod(GetBlobFileHandle)
 #define GetBlobInfo  PrependMagickMethod(GetBlobInfo)
+#define GetBlobProperties  PrependMagickMethod(GetBlobProperties)
 #define GetBlobSize  PrependMagickMethod(GetBlobSize)
 #define GetBlobStreamData  PrependMagickMethod(GetBlobStreamData)
 #define GetBlobStreamHandler  PrependMagickMethod(GetBlobStreamHandler)
@@ -357,6 +384,8 @@ extern "C" {
 #define GetExecutionPath  PrependMagickMethod(GetExecutionPath)
 #define GetFirstImageInList  PrependMagickMethod(GetFirstImageInList)
 #define GetGeometry  PrependMagickMethod(GetGeometry)
+#define GetImageAlphaChannel  PrependMagickMethod(GetImageAlphaChannel)
+#define GetImageArtifact  PrependMagickMethod(GetImageArtifact)
 #define GetImageAttribute  PrependMagickMethod(GetImageAttribute)
 #define GetImageBoundingBox  PrependMagickMethod(GetImageBoundingBox)
 #define GetImageChannelDepth  PrependMagickMethod(GetImageChannelDepth)
@@ -367,9 +396,11 @@ extern "C" {
 #define GetImageChannelStatistics  PrependMagickMethod(GetImageChannelStatistics)
 #define GetImageClipMask  PrependMagickMethod(GetImageClipMask)
 #define GetImageClippingPathAttribute  PrependMagickMethod(GetImageClippingPathAttribute)
+#define GetImageDecoder  PrependMagickMethod(GetImageDecoder)
 #define GetImageDepth  PrependMagickMethod(GetImageDepth)
 #define GetImageDistortion  PrependMagickMethod(GetImageDistortion)
 #define GetImageDynamicThreshold  PrependMagickMethod(GetImageDynamicThreshold)
+#define GetImageEncoder  PrependMagickMethod(GetImageEncoder)
 #define GetImageException  PrependMagickMethod(GetImageException)
 #define GetImageExtrema  PrependMagickMethod(GetImageExtrema)
 #define GetImageFromList  PrependMagickMethod(GetImageFromList)
@@ -405,6 +436,7 @@ extern "C" {
 #define GetLocaleList  PrependMagickMethod(GetLocaleList)
 #define GetLocaleMessage  PrependMagickMethod(GetLocaleMessage)
 #define GetLocaleOptions  PrependMagickMethod(GetLocaleOptions)
+#define GetLocaleValue  PrependMagickMethod(GetLocaleValue)
 #define GetLogInfoList  PrependMagickMethod(GetLogInfoList)
 #define GetLogInfo  PrependMagickMethod(GetLogInfo)
 #define GetLogList  PrependMagickMethod(GetLogList)
@@ -414,15 +446,14 @@ extern "C" {
 #define GetMagickAdjoin  PrependMagickMethod(GetMagickAdjoin)
 #define GetMagickBlobSupport  PrependMagickMethod(GetMagickBlobSupport)
 #define GetMagickCopyright  PrependMagickMethod(GetMagickCopyright)
-#define GetImageDecoder  PrependMagickMethod(GetImageDecoder)
 #define GetMagickDescription  PrependMagickMethod(GetMagickDescription)
-#define GetImageEncoder  PrependMagickMethod(GetImageEncoder)
 #define GetMagickEndianSupport  PrependMagickMethod(GetMagickEndianSupport)
 #define GetMagickGeometry  PrependMagickMethod(GetMagickGeometry)
 #define GetMagickHomeURL  PrependMagickMethod(GetMagickHomeURL)
 #define GetMagickInfoList  PrependMagickMethod(GetMagickInfoList)
 #define GetMagickInfo  PrependMagickMethod(GetMagickInfo)
 #define GetMagickList  PrependMagickMethod(GetMagickList)
+#define GetMagickMemoryMethods  PrependMagickMethod(GetMagickMemoryMethods)
 #define GetMagickOptions  PrependMagickMethod(GetMagickOptions)
 #define GetMagickPackageName  PrependMagickMethod(GetMagickPackageName)
 #define GetMagickPixelPacket  PrependMagickMethod(GetMagickPixelPacket)
@@ -446,6 +477,7 @@ extern "C" {
 #define GetMonitorHandler  PrependMagickMethod(GetMonitorHandler)
 #define GetMontageInfo  PrependMagickMethod(GetMontageInfo)
 #define GetMultilineTypeMetrics  PrependMagickMethod(GetMultilineTypeMetrics)
+#define GetNextImageArtifact  PrependMagickMethod(GetNextImageArtifact)
 #define GetNextImageAttribute  PrependMagickMethod(GetNextImageAttribute)
 #define GetNextImageInList  PrependMagickMethod(GetNextImageInList)
 #define GetNextImageOption  PrependMagickMethod(GetNextImageOption)
@@ -475,19 +507,28 @@ extern "C" {
 #define GetPageGeometry  PrependMagickMethod(GetPageGeometry)
 #define GetPathComponent  PrependMagickMethod(GetPathComponent)
 #define GetPathComponents  PrependMagickMethod(GetPathComponents)
-#define GetPixelCacheArea  PrependMagickMethod(GetPixelCacheArea)
+#define GetPixelCacheExtent  PrependMagickMethod(GetPixelCacheExtent)
 #define GetPixels  PrependMagickMethod(GetPixels)
 #define GetPreviousImageInList  PrependMagickMethod(GetPreviousImageInList)
 #define GetPreviousImage  PrependMagickMethod(GetPreviousImage)
+#define GetPseudoRandomValue  PrependMagickMethod(GetPseudoRandomValue)
 #define GetQuantizeInfo  PrependMagickMethod(GetQuantizeInfo)
+#define GetQuantumExtent  PrependMagickMethod(GetQuantumExtent)
 #define GetQuantumInfo  PrependMagickMethod(GetQuantumInfo)
+#define GetQuantumPixels  PrependMagickMethod(GetQuantumPixels)
+#define GetQuantumType  PrependMagickMethod(GetQuantumType)
 #define GetRandomKey  PrependMagickMethod(GetRandomKey)
 #define GetRandomValue  PrependMagickMethod(GetRandomValue)
-#define GetSignatureInfo  PrependMagickMethod(GetSignatureInfo)
+#define GetResizeFilterSupport  PrependMagickMethod(GetResizeFilterSupport)
+#define GetResizeFilterWeight  PrependMagickMethod(GetResizeFilterWeight)
+#define GetSignatureBlocksize  PrependMagickMethod(GetSignatureBlocksize)
+#define GetSignatureDigest  PrependMagickMethod(GetSignatureDigest)
+#define GetSignatureDigestsize  PrependMagickMethod(GetSignatureDigestsize)
 #define GetStreamInfoClientData  PrependMagickMethod(GetStreamInfoClientData)
 #define GetStringInfoDatum  PrependMagickMethod(GetStringInfoDatum)
 #define GetStringInfoLength  PrependMagickMethod(GetStringInfoLength)
 #define GetStringInfoPath  PrependMagickMethod(GetStringInfoPath)
+#define GetThresholdMapFile  PrependMagickMethod(GetThresholdMapFile)
 #define GetThresholdMap  PrependMagickMethod(GetThresholdMap)
 #define GetTimerInfo  PrependMagickMethod(GetTimerInfo)
 #define GetTypeInfoByFamily  PrependMagickMethod(GetTypeInfoByFamily)
@@ -514,6 +555,7 @@ extern "C" {
 #define HashPointerType  PrependMagickMethod(HashPointerType)
 #define HashStringInfoType  PrependMagickMethod(HashStringInfoType)
 #define HashStringType  PrependMagickMethod(HashStringType)
+#define HSLTransform  PrependMagickMethod(HSLTransform)
 #define Huffman2DEncodeImage  PrependMagickMethod(Huffman2DEncodeImage)
 #define HuffmanDecodeImage  PrependMagickMethod(HuffmanDecodeImage)
 #define HuffmanEncodeImage  PrependMagickMethod(HuffmanEncodeImage)
@@ -526,10 +568,12 @@ extern "C" {
 #define ImplodeImage  PrependMagickMethod(ImplodeImage)
 #define ImportImagePixels  PrependMagickMethod(ImportImagePixels)
 #define ImportQuantumPixels  PrependMagickMethod(ImportQuantumPixels)
+#define increase  PrependMagickMethod(increase)
 #define InheritException  PrependMagickMethod(InheritException)
 #define InitializeMagick  PrependMagickMethod(InitializeMagick)
 #define InitializeMagickResources  PrependMagickMethod(InitializeMagickResources)
 #define InitializeSemaphore  PrependMagickMethod(InitializeSemaphore)
+#define InitializeSignature  PrependMagickMethod(InitializeSignature)
 #define InjectImageBlob  PrependMagickMethod(InjectImageBlob)
 #define InsertImageInList  PrependMagickMethod(InsertImageInList)
 #define InsertTagIntoXMLTree  PrependMagickMethod(InsertTagIntoXMLTree)
@@ -569,12 +613,14 @@ extern "C" {
 #define IsSceneGeometry  PrependMagickMethod(IsSceneGeometry)
 #define IsSubimage  PrependMagickMethod(IsSubimage)
 #define IsTaintImage  PrependMagickMethod(IsTaintImage)
+#define LeastSquaresAddTerms  PrependMagickMethod(LeastSquaresAddTerms)
 #define LevelImageChannel  PrependMagickMethod(LevelImageChannel)
 #define LevelImage  PrependMagickMethod(LevelImage)
 #define LiberateMemory  PrependMagickMethod(LiberateMemory)
 #define LiberateSemaphoreInfo  PrependMagickMethod(LiberateSemaphoreInfo)
 #define LinearStretchImage  PrependMagickMethod(LinearStretchImage)
 #define LinkedListToArray  PrependMagickMethod(LinkedListToArray)
+#define LiquidRescaleImage  PrependMagickMethod(LiquidRescaleImage)
 #define ListCoderInfo  PrependMagickMethod(ListCoderInfo)
 #define ListColorInfo  PrependMagickMethod(ListColorInfo)
 #define ListConfigureInfo  PrependMagickMethod(ListConfigureInfo)
@@ -588,8 +634,10 @@ extern "C" {
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
 #define ListMimeInfo  PrependMagickMethod(ListMimeInfo)
 #define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
+#define ListThresholdMapFile  PrependMagickMethod(ListThresholdMapFile)
 #define ListThresholdMaps  PrependMagickMethod(ListThresholdMaps)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
+#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
 #define LoadMimeLists  PrependMagickMethod(LoadMimeLists)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
@@ -603,6 +651,7 @@ extern "C" {
 #define MagickCoreTerminus  PrependMagickMethod(MagickCoreTerminus)
 #define MagickError  PrependMagickMethod(MagickError)
 #define MagickFatalError  PrependMagickMethod(MagickFatalError)
+#define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
 #define MagickOpenStream  PrependMagickMethod(MagickOpenStream)
 #define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
@@ -614,6 +663,7 @@ extern "C" {
 #define MapImages  PrependMagickMethod(MapImages)
 #define MatteFloodfillImage  PrependMagickMethod(MatteFloodfillImage)
 #define MedianFilterImage  PrependMagickMethod(MedianFilterImage)
+#define MergeImageLayers  PrependMagickMethod(MergeImageLayers)
 #define MinifyImage  PrependMagickMethod(MinifyImage)
 #define ModifyImage  PrependMagickMethod(ModifyImage)
 #define ModulateImage  PrependMagickMethod(ModulateImage)
@@ -638,6 +688,8 @@ extern "C" {
 #define NormalizeImage  PrependMagickMethod(NormalizeImage)
 #define OilPaintImage  PrependMagickMethod(OilPaintImage)
 #define OpaqueImage  PrependMagickMethod(OpaqueImage)
+#define OpaquePaintImageChannel  PrependMagickMethod(OpaquePaintImageChannel)
+#define OpaquePaintImage  PrependMagickMethod(OpaquePaintImage)
 #define OpenBlob  PrependMagickMethod(OpenBlob)
 #define OpenCacheView  PrependMagickMethod(OpenCacheView)
 #define OpenStream  PrependMagickMethod(OpenStream)
@@ -649,10 +701,10 @@ extern "C" {
 #define OrderedPosterizeImageChannel  PrependMagickMethod(OrderedPosterizeImageChannel)
 #define OrderedPosterizeImage  PrependMagickMethod(OrderedPosterizeImage)
 #define PackbitsEncodeImage  PrependMagickMethod(PackbitsEncodeImage)
-#define FloodfillPaintImage  PrependMagickMethod(FloodfillPaintImage)
-#define OpaquePaintImageChannel  PrependMagickMethod(OpaquePaintImageChannel)
-#define OpaquePaintImage  PrependMagickMethod(OpaquePaintImage)
-#define TransparentPaintImage  PrependMagickMethod(TransparentPaintImage)
+#define PaintFloodfillImage  PrependMagickMethod(PaintFloodfillImage)
+#define PaintOpaqueImageChannel  PrependMagickMethod(PaintOpaqueImageChannel)
+#define PaintOpaqueImage  PrependMagickMethod(PaintOpaqueImage)
+#define PaintTransparentImage  PrependMagickMethod(PaintTransparentImage)
 #define ParseAbsoluteGeometry  PrependMagickMethod(ParseAbsoluteGeometry)
 #define ParseAffineGeometry  PrependMagickMethod(ParseAffineGeometry)
 #define ParseChannelOption  PrependMagickMethod(ParseChannelOption)
@@ -718,6 +770,7 @@ extern "C" {
 #define RegisterAVIImage  PrependMagickMethod(RegisterAVIImage)
 #define RegisterAVSImage  PrependMagickMethod(RegisterAVSImage)
 #define RegisterBMPImage  PrependMagickMethod(RegisterBMPImage)
+#define RegisterBRAILLEImage  PrependMagickMethod(RegisterBRAILLEImage)
 #define RegisterCAPTIONImage  PrependMagickMethod(RegisterCAPTIONImage)
 #define RegisterCINImage  PrependMagickMethod(RegisterCINImage)
 #define RegisterCIPImage  PrependMagickMethod(RegisterCIPImage)
@@ -725,8 +778,10 @@ extern "C" {
 #define RegisterCMYKImage  PrependMagickMethod(RegisterCMYKImage)
 #define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
 #define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
+#define RegisterDDSImage  PrependMagickMethod(RegisterDDSImage)
 #define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
 #define RegisterDNGImage  PrependMagickMethod(RegisterDNGImage)
+#define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
@@ -804,16 +859,17 @@ extern "C" {
 #define RegisterVIDImage  PrependMagickMethod(RegisterVIDImage)
 #define RegisterVIFFImage  PrependMagickMethod(RegisterVIFFImage)
 #define RegisterWBMPImage  PrependMagickMethod(RegisterWBMPImage)
-#define RegisterWMFImage  PrependMagickMethod(RegisterWMFImage)
 #define RegisterWPGImage  PrependMagickMethod(RegisterWPGImage)
 #define RegisterXBMImage  PrependMagickMethod(RegisterXBMImage)
 #define RegisterXCFImage  PrependMagickMethod(RegisterXCFImage)
 #define RegisterXCImage  PrependMagickMethod(RegisterXCImage)
 #define RegisterXImage  PrependMagickMethod(RegisterXImage)
 #define RegisterXPMImage  PrependMagickMethod(RegisterXPMImage)
+#define RegisterXPSImage  PrependMagickMethod(RegisterXPSImage)
 #define RegisterXWDImage  PrependMagickMethod(RegisterXWDImage)
 #define RegisterYCBCRImage  PrependMagickMethod(RegisterYCBCRImage)
 #define RegisterYUVImage  PrependMagickMethod(RegisterYUVImage)
+#define RelinquishMagickMatrix  PrependMagickMethod(RelinquishMagickMatrix)
 #define RelinquishMagickMemory  PrependMagickMethod(RelinquishMagickMemory)
 #define RelinquishMagickResource  PrependMagickMethod(RelinquishMagickResource)
 #define RelinquishSemaphoreInfo  PrependMagickMethod(RelinquishSemaphoreInfo)
@@ -824,6 +880,7 @@ extern "C" {
 #define RemoveElementFromLinkedList  PrependMagickMethod(RemoveElementFromLinkedList)
 #define RemoveEntryFromHashmap  PrependMagickMethod(RemoveEntryFromHashmap)
 #define RemoveFirstImageFromList  PrependMagickMethod(RemoveFirstImageFromList)
+#define RemoveImageArtifact  PrependMagickMethod(RemoveImageArtifact)
 #define RemoveImageFromList  PrependMagickMethod(RemoveImageFromList)
 #define RemoveImageOption  PrependMagickMethod(RemoveImageOption)
 #define RemoveImageProfile  PrependMagickMethod(RemoveImageProfile)
@@ -838,6 +895,7 @@ extern "C" {
 #define ResampleImage  PrependMagickMethod(ResampleImage)
 #define ResamplePixelColor  PrependMagickMethod(ResamplePixelColor)
 #define ResetHashmapIterator  PrependMagickMethod(ResetHashmapIterator)
+#define ResetImageArtifactIterator  PrependMagickMethod(ResetImageArtifactIterator)
 #define ResetImageAttributeIterator  PrependMagickMethod(ResetImageAttributeIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
 #define ResetImagePage  PrependMagickMethod(ResetImagePage)
@@ -859,7 +917,7 @@ extern "C" {
 #define SampleImage  PrependMagickMethod(SampleImage)
 #define ScaleImage  PrependMagickMethod(ScaleImage)
 #define ScaleResampleFilter  PrependMagickMethod(ScaleResampleFilter)
-#define SeedRandomReservoir  PrependMagickMethod(SeedRandomReservoir)
+#define SeedPseudoRandomGenerator  PrependMagickMethod(SeedPseudoRandomGenerator)
 #define SeekBlob  PrependMagickMethod(SeekBlob)
 #define SegmentImage  PrependMagickMethod(SegmentImage)
 #define SeparateImageChannel  PrependMagickMethod(SeparateImageChannel)
@@ -869,6 +927,7 @@ extern "C" {
 #define SetCacheMethods  PrependMagickMethod(SetCacheMethods)
 #define SetCacheNexus  PrependMagickMethod(SetCacheNexus)
 #define SetCacheThreshold  PrependMagickMethod(SetCacheThreshold)
+#define SetCacheViewPixels  PrependMagickMethod(SetCacheViewPixels)
 #define SetCacheView  PrependMagickMethod(SetCacheView)
 #define SetCacheViewStorageClass  PrependMagickMethod(SetCacheViewStorageClass)
 #define SetCacheViewVirtualPixelMethod  PrependMagickMethod(SetCacheViewVirtualPixelMethod)
@@ -880,6 +939,9 @@ extern "C" {
 #define SetFatalErrorHandler  PrependMagickMethod(SetFatalErrorHandler)
 #define SetGeometryInfo  PrependMagickMethod(SetGeometryInfo)
 #define SetGeometry  PrependMagickMethod(SetGeometry)
+#define SetHeaderFromIPL  PrependMagickMethod(SetHeaderFromIPL)
+#define SetImageAlphaChannel  PrependMagickMethod(SetImageAlphaChannel)
+#define SetImageArtifact  PrependMagickMethod(SetImageArtifact)
 #define SetImageAttribute  PrependMagickMethod(SetImageAttribute)
 #define SetImageBackgroundColor  PrependMagickMethod(SetImageBackgroundColor)
 #define SetImageChannelDepth  PrependMagickMethod(SetImageChannelDepth)
@@ -908,10 +970,18 @@ extern "C" {
 #define SetLogFormat  PrependMagickMethod(SetLogFormat)
 #define SetLogName  PrependMagickMethod(SetLogName)
 #define SetMagickInfo  PrependMagickMethod(SetMagickInfo)
+#define SetMagickMemoryMethods  PrependMagickMethod(SetMagickMemoryMethods)
 #define SetMagickRegistry  PrependMagickMethod(SetMagickRegistry)
 #define SetMagickResourceLimit  PrependMagickMethod(SetMagickResourceLimit)
 #define SetMonitorHandler  PrependMagickMethod(SetMonitorHandler)
+#define SetQuantumDepth  PrependMagickMethod(SetQuantumDepth)
+#define SetQuantumImageType  PrependMagickMethod(SetQuantumImageType)
+#define SetRandomKey  PrependMagickMethod(SetRandomKey)
+#define SetRandomTrueRandom  PrependMagickMethod(SetRandomTrueRandom)
+#define SetResampleFilterInterpolateMethod  PrependMagickMethod(SetResampleFilterInterpolateMethod)
 #define SetResampleFilterVirtualPixelMethod  PrependMagickMethod(SetResampleFilterVirtualPixelMethod)
+#define SetResizeFilterSupport  PrependMagickMethod(SetResizeFilterSupport)
+#define SetSignatureDigest  PrependMagickMethod(SetSignatureDigest)
 #define SetStreamInfoClientData  PrependMagickMethod(SetStreamInfoClientData)
 #define SetStreamInfoMap  PrependMagickMethod(SetStreamInfoMap)
 #define SetStreamInfoStorageType  PrependMagickMethod(SetStreamInfoStorageType)
@@ -946,6 +1016,7 @@ extern "C" {
 #define SteganoImage  PrependMagickMethod(SteganoImage)
 #define StereoImage  PrependMagickMethod(StereoImage)
 #define StreamImage  PrependMagickMethod(StreamImage)
+#define StringInfoToHexString  PrependMagickMethod(StringInfoToHexString)
 #define StringInfoToString  PrependMagickMethod(StringInfoToString)
 #define StringToArgv  PrependMagickMethod(StringToArgv)
 #define StringToDouble  PrependMagickMethod(StringToDouble)
@@ -978,11 +1049,13 @@ extern "C" {
 #define TintImage  PrependMagickMethod(TintImage)
 #define Tokenizer  PrependMagickMethod(Tokenizer)
 #define TransformColorspace  PrependMagickMethod(TransformColorspace)
+#define TransformHSL  PrependMagickMethod(TransformHSL)
 #define TransformImage  PrependMagickMethod(TransformImage)
 #define TransformImages  PrependMagickMethod(TransformImages)
 #define TransformRGBImage  PrependMagickMethod(TransformRGBImage)
 #define TranslateText  PrependMagickMethod(TranslateText)
 #define TransparentImage  PrependMagickMethod(TransparentImage)
+#define TransparentPaintImage  PrependMagickMethod(TransparentPaintImage)
 #define TransposeImage  PrependMagickMethod(TransposeImage)
 #define TransverseImage  PrependMagickMethod(TransverseImage)
 #define TrimImage  PrependMagickMethod(TrimImage)
@@ -993,6 +1066,7 @@ extern "C" {
 #define UnregisterAVIImage  PrependMagickMethod(UnregisterAVIImage)
 #define UnregisterAVSImage  PrependMagickMethod(UnregisterAVSImage)
 #define UnregisterBMPImage  PrependMagickMethod(UnregisterBMPImage)
+#define UnregisterBRAILLEImage  PrependMagickMethod(UnregisterBRAILLEImage)
 #define UnregisterCAPTIONImage  PrependMagickMethod(UnregisterCAPTIONImage)
 #define UnregisterCINImage  PrependMagickMethod(UnregisterCINImage)
 #define UnregisterCIPImage  PrependMagickMethod(UnregisterCIPImage)
@@ -1000,8 +1074,10 @@ extern "C" {
 #define UnregisterCMYKImage  PrependMagickMethod(UnregisterCMYKImage)
 #define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
 #define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
+#define UnregisterDDSImage  PrependMagickMethod(UnregisterDDSImage)
 #define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
 #define UnregisterDNGImage  PrependMagickMethod(UnregisterDNGImage)
+#define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
@@ -1079,13 +1155,13 @@ extern "C" {
 #define UnregisterVIDImage  PrependMagickMethod(UnregisterVIDImage)
 #define UnregisterVIFFImage  PrependMagickMethod(UnregisterVIFFImage)
 #define UnregisterWBMPImage  PrependMagickMethod(UnregisterWBMPImage)
-#define UnregisterWMFImage  PrependMagickMethod(UnregisterWMFImage)
 #define UnregisterWPGImage  PrependMagickMethod(UnregisterWPGImage)
 #define UnregisterXBMImage  PrependMagickMethod(UnregisterXBMImage)
 #define UnregisterXCFImage  PrependMagickMethod(UnregisterXCFImage)
 #define UnregisterXCImage  PrependMagickMethod(UnregisterXCImage)
 #define UnregisterXImage  PrependMagickMethod(UnregisterXImage)
 #define UnregisterXPMImage  PrependMagickMethod(UnregisterXPMImage)
+#define UnregisterXPSImage  PrependMagickMethod(UnregisterXPSImage)
 #define UnregisterXWDImage  PrependMagickMethod(UnregisterXWDImage)
 #define UnregisterYCBCRImage  PrependMagickMethod(UnregisterYCBCRImage)
 #define UnregisterYUVImage  PrependMagickMethod(UnregisterYUVImage)
@@ -1182,7 +1258,6 @@ extern "C" {
 #define XWindowByProperty  PrependMagickMethod(XWindowByProperty)
 #define ZLIBEncodeImage  PrependMagickMethod(ZLIBEncodeImage)
 #define ZoomImage  PrependMagickMethod(ZoomImage)
-
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
