@@ -141,7 +141,7 @@ MagickExport void DestroyModuleList(void)
 #endif
   instantiate_module=MagickFalse;
   RelinquishSemaphoreInfo(module_semaphore);
-  module_semaphore=DestroySemaphoreInfo(module_semaphore);
+  DestroySemaphoreInfo(&module_semaphore);
 }
 
 /*
@@ -418,7 +418,7 @@ MagickExport char **GetModuleList(const char *pattern,
   (void) closedir(directory);
   if (modules == (char **) NULL)
     {
-      ThrowMagickException(exception,GetMagickModule(),ConfigureError,
+      (void) ThrowMagickException(exception,GetMagickModule(),ConfigureError,
         "MemoryAllocationFauled","`%s'",pattern);
       return((char **) NULL);
     }
@@ -449,12 +449,12 @@ MagickExport char **GetModuleList(const char *pattern,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The module file name.
+%    o filename: the module file name.
 %
-%    o module_type: The module type: MagickImageCoderModule or
+%    o module_type: the module type: MagickImageCoderModule or
 %      MagickImageFilterModule.
 %
-%    o path: The path associated with the filename.
+%    o path: the path associated with the filename.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -559,8 +559,10 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
 #if defined(__WINDOWS__)
     {
       const char
-        *key,
-        *value;
+        *registery_key;
+
+      unsigned char
+        *key_value;
 
       /*
         Locate path via registry key.
@@ -570,24 +572,25 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
         case MagickImageCoderModule:
         default:
         {
-          key="CoderModulesPath";
+          registery_key="CoderModulesPath";
           break;
         }
         case MagickImageFilterModule:
         {
-          key="FilterModulesPath";
+          registery_key="FilterModulesPath";
           break;
         }
       }
-      value=NTRegistryKeyLookup(key);
-      if (value == (char *) NULL)
+      key_value=NTRegistryKeyLookup(registery_key);
+      if (key_value == (unsigned char *) NULL)
         {
           ThrowMagickException(exception,GetMagickModule(),ConfigureError,
-            "RegistryKeyLookupFailed","`%s'",key);
+            "RegistryKeyLookupFailed","`%s'",registery_key);
           return(MagickFalse);
         }
-      (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",value,
+      (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",(char *) key_value,
         DirectorySeparator,filename);
+      key_value=(unsigned char *) RelinquishMagickMemory(key_value); 
       if (IsAccessible(path) == MagickFalse)
         {
           ThrowFileException(exception,ConfigureWarning,
@@ -834,15 +837,14 @@ static MagickBooleanType InitializeModuleList(
 %    o tag: a character string that represents the name of the particular
 %      module.
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o argc: Specifies a pointer to an integer describing the number of
-%      elements in the argument vector.
+%    o argc: a pointer to an integer describing the number of elements in the
+%      argument vector.
 %
-%    o argv: Specifies a pointer to a text array containing the command line
-%      arguments.
+%    o argv: a pointer to a text array containing the command line arguments.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
@@ -855,9 +857,6 @@ MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
   ImageFilterHandler
     *image_filter;
 
-  MagickBooleanType
-    status;
-
   ModuleHandle
     handle;
 
@@ -873,11 +872,15 @@ MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       (*images)->filename);
 #if !defined(MAGICKCORE_BUILD_MODULES)
-  status=InvokeStaticImageFilter(tag,images,argc,argv,exception);
-  if (status != MagickFalse)
-    return(status);
+  {
+    MagickBooleanType
+      status;
+
+    status=InvokeStaticImageFilter(tag,images,argc,argv,exception);
+    if (status != MagickFalse)
+      return(status);
+  }
 #endif
-  status=MagickFalse;
   TagToFilterModuleName(tag,name);
   length=GetMagickModulePath(name,MagickImageFilterModule,path,exception);
   if (length == 0)
@@ -890,7 +893,7 @@ MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
         "UnableToLoadModule","`%s': %s",name,lt_dlerror());
-      return(status);
+      return(MagickFalse);
     }
   /*
     Locate the module.
@@ -932,7 +935,7 @@ MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
     Close the module.
   */
   (void) lt_dlclose(handle);
-  return(status);
+  return(MagickTrue);
 }
 
 /*
@@ -1064,7 +1067,7 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   if (GetValueFromSplayTree(module_list,module_name) != (void *) NULL)
     {
       RelinquishSemaphoreInfo(module_semaphore);
-      return(MagickTrue);  /* module alread opened, return */
+      return(MagickTrue);  /* module already opened, return */
     }
   /*
     Locate module.
@@ -1201,7 +1204,7 @@ MagickExport MagickBooleanType OpenModules(ExceptionInfo *exception)
   for (i=0; i < (long) number_modules; i++)
     (void) OpenModule(modules[i],exception);
   /*
-    Free resources.
+    Relinquish resources.
   */
   for (i=0; i < (long) number_modules; i++)
     modules[i]=DestroyString(modules[i]);
@@ -1416,7 +1419,7 @@ static void TagToModuleName(const char *tag,const char *format,char *module)
 %
 %  A description of each parameter follows:
 %
-%    o module_info: The module info.
+%    o module_info: the module info.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
