@@ -53,6 +53,10 @@
 #  include "ltdl.h"
 #endif
 #include "magick/nt-base.h"
+#if defined(MAGICKCORE_CIPHER_SUPPORT)
+#include <NTSecAPI.h>
+#include <wincrypt.h>
+#endif
 
 /*
   Define declarations.
@@ -482,6 +486,62 @@ MagickExport int NTExitLibrary(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   N T G a t h e r R a n d o m D a t a                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  NTGatherRandomData() gathers random data and returns it.
+%
+%  The format of the GatherRandomData method is:
+%
+%      MagickBooleanType NTGatherRandomData(const size_t length,
+%        unsigned char *random)
+%
+%  A description of each parameter follows:
+%
+%    length: the length of random data buffer
+%
+%    random: the random data is returned here.
+%
+*/
+MagickExport MagickBooleanType NTGatherRandomData(const size_t length,
+  unsigned char *random)
+{
+#if defined(MAGICKCORE_CIPHER_SUPPORT)
+  HCRYPTPROV
+    handle;
+
+  int
+    status;
+
+  handle=(HCRYPTPROV) NULL;
+  status=CryptAcquireContext(&handle,NULL,MS_DEF_PROV,PROV_RSA_FULL,
+    (CRYPT_VERIFYCONTEXT | CRYPT_MACHINE_KEYSET));
+  if (status == 0)
+    status=CryptAcquireContext(&handle,NULL,MS_DEF_PROV,PROV_RSA_FULL,
+      (CRYPT_VERIFYCONTEXT | CRYPT_MACHINE_KEYSET | CRYPT_NEWKEYSET));
+  if (status == 0)
+    return(MagickFalse);
+  status=CryptGenRandom(handle,(DWORD) length,random);
+  if (status == 0)
+    {
+      status=CryptReleaseContext(handle,0);
+      return(MagickFalse);
+    }
+  status=CryptReleaseContext(handle,0);
+  if (status == 0)
+    return(MagickFalse);
+#endif
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   N T G e t E x e c u t i o n P a t h                                       %
 %                                                                             %
 %                                                                             %
@@ -641,9 +701,9 @@ void *NTGetLibrarySymbol(void *handle,const char *name)
 %
 %  A description of each parameter follows:
 %
-%    modith: The module name.
+%    modith: the module name.
 %
-%    path: The module path is returned here.
+%    path: the module path is returned here.
 %
 */
 MagickExport MagickBooleanType NTGetModulePath(const char *module,char *path)
@@ -1520,7 +1580,7 @@ MagickExport struct dirent *NTReadDirectory(DIR *entry)
 %
 %  The format of the NTRegistryKeyLookup method is:
 %
-%      char *NTRegistryKeyLookup(const char *subkey)
+%      unsigned char *NTRegistryKeyLookup(const char *subkey)
 %
 %  A description of each parameter follows:
 %
@@ -1529,11 +1589,8 @@ MagickExport struct dirent *NTReadDirectory(DIR *entry)
 %      "LibPath", "CoderModulesPath", "FilterModulesPath", "SharePath".
 %
 */
-MagickExport char *NTRegistryKeyLookup(const char *subkey)
+MagickExport unsigned char *NTRegistryKeyLookup(const char *subkey)
 {
-  BYTE
-    *value;
-
   char
     package_key[MaxTextExtent];
 
@@ -1547,6 +1604,9 @@ MagickExport char *NTRegistryKeyLookup(const char *subkey)
   LONG
     status;
 
+  unsigned char
+    *value;
+
   /*
     Look-up base key.
   */
@@ -1558,34 +1618,34 @@ MagickExport char *NTRegistryKeyLookup(const char *subkey)
   if (status != ERROR_SUCCESS)
     {
       registry_key=(HKEY) INVALID_HANDLE_VALUE;
-      return((char *) NULL);
+      return((unsigned char *) NULL);
     }
   /*
     Look-up sub key.
   */
   size=32;
-  value=(BYTE *) AcquireQuantumMemory(size,sizeof(*value));
-  if (value == (BYTE *) NULL)
+  value=(unsigned char *) AcquireQuantumMemory(size,sizeof(*value));
+  if (value == (unsigned char *) NULL)
     {
       RegCloseKey(registry_key);
-      return((char *) NULL);
+      return((unsigned char *) NULL);
     }
   (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),"%s",subkey);
   status=RegQueryValueExA(registry_key,subkey,0,&type,value,&size);
   if ((status == ERROR_MORE_DATA) && (type == REG_SZ))
     {
-      value=(BYTE *) ResizeQuantumMemory(value,size,sizeof(*value));
+      value=(unsigned char *) ResizeQuantumMemory(value,size,sizeof(*value));
       if (value == (BYTE *) NULL)
         {
           RegCloseKey(registry_key);
-          return((char *) NULL);
+          return((unsigned char *) NULL);
         }
       status=RegQueryValueExA(registry_key,subkey,0,&type,value,&size);
     }
   RegCloseKey(registry_key);
   if ((type != REG_SZ) || (status != ERROR_SUCCESS))
-    value=(BYTE *) DestroyString((char *) value);
-  return((char *) value);
+    value=(unsigned char *) RelinquishMagickMemory(value);
+  return((unsigned char *) value);
 }
 
 /*
@@ -1608,7 +1668,7 @@ MagickExport char *NTRegistryKeyLookup(const char *subkey)
 %
 %  A description of each parameter follows:
 %
-%    o event: The event.
+%    o event: the event.
 %
 %    o error: MagickTrue the event is an error.
 %
@@ -1804,9 +1864,9 @@ MagickExport int NTSetSearchPath(const char *path)
 %
 %  A description of each parameter follows:
 %
-%    o address: The address of the binary large object.
+%    o address: the address of the binary large object.
 %
-%    o length: The length of the binary large object.
+%    o length: the length of the binary large object.
 %
 %    o flags: Option flags (ignored for Windows).
 %
@@ -2018,9 +2078,9 @@ MagickExport long NTTellDirectory(DIR *entry)
 %
 %  A description of each parameter follows:
 %
-%    o file: The file.
+%    o file: the file.
 %
-%    o length: The file length.
+%    o length: the file length.
 %
 */
 MagickExport int NTTruncateFile(int file,off_t length)
@@ -2065,9 +2125,9 @@ MagickExport int NTTruncateFile(int file,off_t length)
 %
 %  A description of each parameter follows:
 %
-%    o map: The address of the binary large object.
+%    o map: the address of the binary large object.
 %
-%    o length: The length of the binary large object.
+%    o length: the length of the binary large object.
 %
 */
 MagickExport int NTUnmapMemory(void *map,size_t length)
