@@ -23,6 +23,7 @@ extern "C" {
 #endif
 
 #include "magick/delegate.h"
+#include "magick/delegate-private.h"
 #include "magick/exception.h"
 
 #define WIN32_LEAN_AND_MEAN
@@ -93,6 +94,9 @@ extern "C" {
 #if !defined(hypot)
 #  define hypot  _hypot
 #endif
+#if !defined(inline)
+#  define inline __inline
+#endif
 #if !defined(isatty)
 #  define isatty _isatty
 #endif
@@ -119,6 +123,9 @@ extern "C" {
 #  define lt_dlsym(handle,name)  NTGetLibrarySymbol(handle,name)
 #endif
 #endif
+#if !defined(mkdir)
+#  define mkdir  _mkdir
+#endif
 #if !defined(mmap)
 #  define mmap(address,length,protection,access,file,offset) \
   NTMapMemory(address,length,protection,access,file,offset)
@@ -169,7 +176,9 @@ extern "C" {
 #  define tempnam  _tempnam
 #endif
 #if !defined(vsnprintf)
-#  define vsnprintf  _vsnprintf
+#if !defined(_MSC_VER) || (defined(_MSC_VER) && _MSC_VER < 1500)
+#define vsnprintf _vsnprintf 
+#endif
 #endif
 #if !defined(write)
 #  define write  _write
@@ -245,6 +254,12 @@ typedef UINT
 typedef long ssize_t;
 #endif
 
+#if defined(MAGICKCORE_BZLIB_DELEGATE)
+#  if defined(_WIN32)
+#    define BZ_IMPORT 1
+#  endif
+#endif
+
 extern MagickExport char
   *NTGetLastError(void);
 
@@ -257,9 +272,6 @@ extern MagickExport const char
 #endif
 
 #if !defined(XS_VERSION)
-extern MagickExport char
-  *NTRegistryKeyLookup(const char *);
-
 extern MagickExport const char
   *NTGetLibraryError(void);
 
@@ -294,6 +306,7 @@ extern MagickExport long
   NTTellDirectory(DIR *);
 
 extern MagickExport MagickBooleanType
+  NTGatherRandomData(const size_t,unsigned char *),
   NTGetExecutionPath(char *,const size_t),
   NTGetModulePath(const char *,char *),
   NTReportEvent(const char *,const MagickBooleanType),
@@ -303,6 +316,7 @@ extern MagickExport struct dirent
   *NTReadDirectory(DIR *);
 
 extern MagickExport unsigned char
+  *NTRegistryKeyLookup(const char *),
   *NTResourceToBlob(const char *);
 
 extern MagickExport void
