@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/artifact.h"
 #include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/compare.h"
@@ -114,7 +115,9 @@ static const OptionInfo
     { "Green", (long) GreenChannel },
     { "Hue", (long) RedChannel },
     { "Index", (long) IndexChannel },
-    { "Luminosity", (long) BlueChannel },
+    { "Lightness", (long) BlueChannel },
+    { "Luminance", (long) BlueChannel },
+    { "Luminosity", (long) BlueChannel },  /* deprecated */
     { "Magenta", (long) MagentaChannel },
     { "Matte", (long) OpacityChannel },
     { "Opacity", (long) OpacityChannel },
@@ -166,6 +169,8 @@ static const OptionInfo
     { "-backdrop", 1L },
     { "+background", 0L },
     { "-background", 1L },
+    { "+bench", 0L },
+    { "-bench", 1L },
     { "+bias", 0L },
     { "-bias", 1L },
     { "+black-threshold", 0L },
@@ -234,6 +239,8 @@ static const OptionInfo
     { "-cycle", 1L },
     { "+debug", 0L },
     { "-debug", 1L },
+    { "+decipher", 1L },
+    { "-decipher", 1L },
     { "+deconstruct", 0L },
     { "-deconstruct", 0L },
     { "+define", 1L },
@@ -268,6 +275,8 @@ static const OptionInfo
     { "-edge", 1L },
     { "+emboss", 0L },
     { "-emboss", 1L },
+    { "+encipher", 1L },
+    { "-encipher", 1L },
     { "+encoding", 0L },
     { "-encoding", 1L },
     { "+endian", 0L },
@@ -322,6 +331,8 @@ static const OptionInfo
     { "-green-primary", 1L },
     { "+help", 0L },
     { "-help", 0L },
+    { "+highlight-color", 1L },
+    { "-highlight-color", 1L },
     { "+iconGeometry", 0L },
     { "-iconGeometry", 1L },
     { "+iconic", 0L },
@@ -329,7 +340,7 @@ static const OptionInfo
     { "+identify", 0L },
     { "-identify", 0L },
     { "+immutable", 0L },
-    { "-immutable", 1L },
+    { "-immutable", 0L },
     { "+implode", 0L },
     { "-implode", 1L },
     { "+insert", 0L },
@@ -346,7 +357,7 @@ static const OptionInfo
     { "-lat", 1L },
     { "+layers", 0L },
     { "-layers", 1L },
-    { "+level", 0L },
+    { "+level", 1L },
     { "-level", 1L },
     { "+limit", 0L },
     { "-limit", 2L },
@@ -354,6 +365,8 @@ static const OptionInfo
     { "-linear-stretch", 1L },
     { "+linewidth", 0L },
     { "-linewidth", 1L },
+    { "+liquid-rescale", 0L },
+    { "-liquid-rescale", 1L },
     { "+list", 0L },
     { "-list", 1L },
     { "+log", 0L },
@@ -398,7 +411,7 @@ static const OptionInfo
     { "-noop", 0L },
     { "+normalize", 0L },
     { "-normalize", 0L },
-    { "+opaque", 0L },
+    { "+opaque", 1L },
     { "-opaque", 1L },
     { "+ordered-dither", 0L },
     { "-ordered-dither", 1L },
@@ -414,6 +427,8 @@ static const OptionInfo
     { "-path", 1L },
     { "+pause", 0L },
     { "-pause", 1L },
+    { "+passphrase", 0L },
+    { "-passphrase", 1L },
     { "+pen", 0L },
     { "-pen", 1L },
     { "+ping", 0L },
@@ -458,6 +473,8 @@ static const OptionInfo
     { "-resample", 1L },
     { "+resize", 0L },
     { "-resize", 1L },
+    { "+respect-parenthesis", 0L },
+    { "-respect-parenthesis", 0L },
     { "+reverse", 0L },
     { "-reverse", 0L },
     { "+roll", 0L },
@@ -534,8 +551,6 @@ static const OptionInfo
     { "-strokewidth", 1L },
     { "+style", 0L },
     { "-style", 1L },
-    { "+support", 0L },
-    { "-support", 1L },
     { "+swap", 0L },
     { "-swap", 1L },
     { "+swirl", 0L },
@@ -560,8 +575,10 @@ static const OptionInfo
     { "-title", 1L },
     { "+transform", 0L },
     { "-transform", 0L },
-    { "+transparent", 0L },
+    { "+transparent", 1L },
     { "-transparent", 1L },
+    { "+transparent-color", 1L },
+    { "-transparent-color", 1L },
     { "+transpose", 0L },
     { "-transpose", 0L },
     { "+transverse", 0L },
@@ -680,6 +697,9 @@ static const OptionInfo
   {
     { "Undefined", (long) UndefinedCompression },
     { "BZip", (long) BZipCompression },
+    { "DXT1", (long) DXT1Compression },
+    { "DXT3", (long) DXT3Compression },
+    { "DXT5", (long) DXT5Compression },
     { "Fax", (long) FaxCompression },
     { "Group4", (long) Group4Compression },
     { "JPEG", (long) JPEGCompression },
@@ -781,6 +801,7 @@ static const OptionInfo
     { "Min", (long) MinEvaluateOperator },
     { "Multiply", (long) MultiplyEvaluateOperator },
     { "Or", (long) OrEvaluateOperator },
+    { "Pow", (long) PowEvaluateOperator },
     { "RightShift", (long) RightShiftEvaluateOperator },
     { "Set", (long) SetEvaluateOperator },
     { "Subtract", (long) SubtractEvaluateOperator },
@@ -797,8 +818,10 @@ static const OptionInfo
   FilterOptions[] =
   {
     { "Undefined", (long) UndefinedFilter },
+    { "Bartlett", (long) BartlettFilter },
     { "Bessel", (long) BesselFilter },
     { "Blackman", (long) BlackmanFilter },
+    { "Bohman", (long) BohmanFilter },
     { "Box", (long) BoxFilter },
     { "Catrom", (long) CatromFilter },
     { "Cubic", (long) CubicFilter },
@@ -806,12 +829,16 @@ static const OptionInfo
     { "Hamming", (long) HammingFilter },
     { "Hanning", (long) HanningFilter },
     { "Hermite", (long) HermiteFilter },
+    { "Kaiser", (long) KaiserFilter },
+    { "Lagrange", (long) LagrangeFilter },
     { "Lanczos", (long) LanczosFilter },
     { "Mitchell", (long) MitchellFilter },
+    { "Parzen", (long) ParzenFilter },
     { "Point", (long) PointFilter },
     { "Quadratic", (long) QuadraticFilter },
     { "Sinc", (long) SincFilter },
     { "Triangle", (long) TriangleFilter },
+    { "Welsh", (long) WelshFilter },
     { (char *) NULL, (long) UndefinedFilter }
   },
   GravityOptions[] =
@@ -865,7 +892,7 @@ static const OptionInfo
     { "Spline", (long) SplineInterpolatePixel },
     { (char *) NULL, (long) UndefinedInterpolatePixel }
   },
-  LayersOptions[] =
+  LayerOptions[] =
   {
     { "Undefined", (long) UndefinedLayer },
     { "Coalesce", (long) CoalesceLayer },
@@ -880,6 +907,9 @@ static const OptionInfo
     { "RemoveDups", (long) RemoveDupsLayer },
     { "RemoveZero", (long) RemoveZeroLayer },
     { "Composite", (long) CompositeLayer },
+    { "Merge", (long) MergeLayer },
+    { "Flatten", (long) FlattenLayer },
+    { "Mosaic", (long) MosaicLayer },
     { (char *) NULL, (long) UndefinedLayer }
   },
   LineCapOptions[] =
@@ -925,7 +955,7 @@ static const OptionInfo
     { "Intent", (long) MagickIntentOptions },
     { "Interlace", (long) MagickInterlaceOptions },
     { "Interpolate", (long) MagickInterpolateOptions },
-    { "Layers", (long) MagickLayersOptions },
+    { "Layers", (long) MagickLayerOptions },
     { "LineCap", (long) MagickLineCapOptions },
     { "LineJoin", (long) MagickLineJoinOptions },
     { "List", (long) MagickListOptions },
@@ -1027,6 +1057,7 @@ static const OptionInfo
     { "flatten", MagickTrue },
     { "fx", MagickTrue },
     { "insert", MagickTrue },
+    { "layers", MagickTrue },
     { "limit", MagickTrue },
     { "map", MagickTrue },
     { "morph", MagickTrue },
@@ -1232,18 +1263,14 @@ static const OptionInfo
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o clone_info: The clone image info.
+%    o clone_info: the clone image info.
 %
 */
 MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
   const ImageInfo *clone_info)
 {
-  const char
-    *key,
-    *value;
-
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
@@ -1251,16 +1278,9 @@ MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
       image_info->filename);
   assert(clone_info != (const ImageInfo *) NULL);
   assert(clone_info->signature == MagickSignature);
-  if (clone_info->options == (void *) NULL)
-    return(MagickTrue);
-  ResetImageOptionIterator(clone_info);
-  for (key=GetNextImageOption(clone_info); key != (const char *) NULL; )
-  {
-    value=GetImageOption(clone_info,key);
-    if (value != (const char *) NULL)
-      (void) SetImageOption(image_info,key,value);
-    key=GetNextImageOption(clone_info);
-  }
+  if (clone_info->options != (void *) NULL)
+    image_info->options=CloneSplayTree((SplayTreeInfo *) clone_info->options,
+      (void *(*)(void *)) ConstantString,(void *(*)(void *)) ConstantString);
   return(MagickTrue);
 }
 
@@ -1284,9 +1304,9 @@ MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o option: The image option.
+%    o option: the image option.
 %
 */
 MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
@@ -1332,9 +1352,9 @@ MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o option: The image option.
+%    o option: the image option.
 %
 */
 MagickExport MagickBooleanType DeleteImageOption(ImageInfo *image_info,
@@ -1369,7 +1389,7 @@ MagickExport MagickBooleanType DeleteImageOption(ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 */
 MagickExport void DestroyImageOptions(ImageInfo *image_info)
@@ -1403,9 +1423,9 @@ MagickExport void DestroyImageOptions(ImageInfo *image_info)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o key: The key.
+%    o key: the key.
 %
 */
 MagickExport const char *GetImageOption(const ImageInfo *image_info,
@@ -1445,7 +1465,7 @@ MagickExport const char *GetImageOption(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o value: The value.
+%    o value: the value.
 %
 */
 
@@ -1476,7 +1496,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption option)
     case MagickIntentOptions: return(IntentOptions);
     case MagickInterlaceOptions: return(InterlaceOptions);
     case MagickInterpolateOptions: return(InterpolateOptions);
-    case MagickLayersOptions: return(LayersOptions);
+    case MagickLayerOptions: return(LayerOptions);
     case MagickLineCapOptions: return(LineCapOptions);
     case MagickLineJoinOptions: return(LineJoinOptions);
     case MagickListOptions: return(ListOptions);
@@ -1516,7 +1536,7 @@ MagickExport char **GetMagickOptions(const MagickOption value)
   option_info=GetOptionInfo(value);
   if (option_info == (const OptionInfo *) NULL)
     return((char **) NULL);
-  for (i=0; option_info[i].mnemonic != (const char *) NULL; i++);
+  for (i=0; option_info[i].mnemonic != (const char *) NULL; i++) ;
   values=(char **) AcquireQuantumMemory((size_t) i+1UL,sizeof(*values));
   if (values == (char **) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
@@ -1545,7 +1565,7 @@ MagickExport char **GetMagickOptions(const MagickOption value)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 */
 MagickExport char *GetNextImageOption(const ImageInfo *image_info)
@@ -1580,7 +1600,7 @@ MagickExport char *GetNextImageOption(const ImageInfo *image_info)
 %
 %  A description of each parameter follows:
 %
-%    o option: The option.
+%    o option: the option.
 %
 */
 MagickExport MagickBooleanType IsMagickOption(const char *option)
@@ -1616,7 +1636,7 @@ MagickExport MagickBooleanType IsMagickOption(const char *option)
 %
 %  A description of each parameter follows:
 %
-%    o option: The option.
+%    o option: the option.
 %
 %    o type: one or more values separated by commas.
 %
@@ -1924,9 +1944,9 @@ MagickExport long ParseMagickOption(const MagickOption option,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o option: The image option.
+%    o option: the image option.
 %
 */
 MagickExport char *RemoveImageOption(ImageInfo *image_info,const char *option)
@@ -1967,7 +1987,7 @@ MagickExport char *RemoveImageOption(ImageInfo *image_info,const char *option)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 */
 MagickExport void ResetImageOptionIterator(const ImageInfo *image_info)
@@ -2002,11 +2022,11 @@ MagickExport void ResetImageOptionIterator(const ImageInfo *image_info)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o option: The image option.
+%    o option: the image option.
 %
-%    o values: The image option values.
+%    o values: the image option values.
 %
 */
 MagickExport MagickBooleanType SetImageOption(ImageInfo *image_info,
@@ -2051,15 +2071,19 @@ MagickExport MagickBooleanType SetImageOption(ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
   Image *image)
 {
+  char
+    property[MaxTextExtent];
+
   const char
+    *value,
     *option;
 
   MagickStatusType
@@ -2104,6 +2128,10 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
   if (option != (const char *) NULL)
     image->dispose=(DisposeType) ParseMagickOption(MagickDisposeOptions,
       MagickFalse,option);
+  option=GetImageOption(image_info,"filter");
+  if (option != (const char *) NULL)
+    image->filter=(FilterTypes) ParseMagickOption(MagickFilterOptions,
+      MagickFalse,option);
   option=GetImageOption(image_info,"gravity");
   if (option != (const char *) NULL)
     image->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
@@ -2136,5 +2164,16 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
       flags=ParseAbsoluteGeometry(geometry,&image->page);
       geometry=DestroyString(geometry);
     }
+  ResetImageOptionIterator(image_info);
+  for (option=GetNextImageOption(image_info); option != (const char *) NULL; )
+  {
+    value=GetImageOption(image_info,option);
+    if (value != (const char *) NULL)
+      {
+        (void) FormatMagickString(property,MaxTextExtent,"%s",option);
+        (void) SetImageArtifact(image,property,value);
+      }
+    option=GetNextImageOption(image_info);
+  }
   return(MagickTrue);
 }
