@@ -50,6 +50,7 @@
 #include "magick/exception-private.h"
 #include "magick/gem.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/paint.h"
 #include "magick/pixel-private.h"
 #include "magick/string_.h"
@@ -86,15 +87,15 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel(s).
+%    o channel: the channel(s).
 %
-%    o draw_info: The draw info.
+%    o draw_info: the draw info.
 %
-%    o target: The RGB value of the target color.
+%    o target: the RGB value of the target color.
 %
-%    o x_offset,y_offset: The starting location of the operation.
+%    o x_offset,y_offset: the starting location of the operation.
 %
 %    o invert: paint any pixel that does not match the target color.
 %
@@ -364,45 +365,72 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o radius: The radius of the circular neighborhood.
+%    o radius: the radius of the circular neighborhood.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
 */
+
+static unsigned long **DestroyHistogramThreadSet(unsigned long **histogram)
+{
+  register long
+    i;
+
+  assert(histogram != (unsigned long **) NULL);
+  for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
+    if (histogram[i] != (unsigned long *) NULL)
+      histogram[i]=(unsigned long *) RelinquishMagickMemory(histogram[i]);
+  return((unsigned long **) RelinquishMagickMemory(histogram));
+}
+
+static unsigned long **AcquireHistogramThreadSet(const size_t count)
+{
+  register long
+    i;
+
+  unsigned long
+    **histogram;
+
+  histogram=(unsigned long **) AcquireQuantumMemory(GetCacheViewMaximumThreads(),
+    sizeof(*histogram));
+  if (histogram == (unsigned long **) NULL)
+    return((unsigned long **) NULL);
+  (void) ResetMagickMemory(histogram,0,GetCacheViewMaximumThreads()*
+    sizeof(*histogram));
+  for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
+  {
+    histogram[i]=AcquireQuantumMemory(count,sizeof(**histogram));
+    if (histogram[i] == (unsigned long *) NULL)
+      return(DestroyHistogramThreadSet(histogram));
+  }
+  return(histogram);
+}
+
 MagickExport Image *OilPaintImage(const Image *image,const double radius,
   ExceptionInfo *exception)
 {
+#define NumberPaintBins  256
 #define OilPaintImageTag  "OilPaint/Image"
 
   Image
     *paint_image;
 
   long
-    k,
     y;
 
   MagickBooleanType
     status;
 
-  register const PixelPacket
-    *pixels;
-
-  register long
-    i,
-    u,
-    v,
-    x;
-
-  register PixelPacket
-    *paint_pixels;
-
   unsigned long
-    count,
-    *histogram,
+    **histogram,
     width;
 
+  ViewInfo
+    **image_view,
+    **paint_view;
+
   /*
     Initialize painted image attributes.
   */
@@ -424,11 +452,8 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
       paint_image=DestroyImage(paint_image);
       return((Image *) NULL);
     }
-  /*
-    Allocate histogram and scanline.
-  */
-  histogram=(unsigned long *) AcquireQuantumMemory(256UL,sizeof(*histogram));
-  if (histogram == (unsigned long *) NULL)
+  histogram=AcquireHistogramThreadSet(NumberPaintBins);
+  if (histogram == (unsigned long **) NULL)
     {
       paint_image=DestroyImage(paint_image);
       ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
@@ -436,49 +461,89 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
   /*
     Paint each row of the image.
   */
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  paint_view=AcquireCacheViewThreadSet(paint_image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    pixels=AcquireImagePixels(image,-((long) width/2L),y-(long) (width/2L),
-      image->columns+width,width,exception);
-    paint_pixels=GetImagePixels(paint_image,0,y,paint_image->columns,1);
-    if ((pixels == (const PixelPacket *) NULL) ||
-        (paint_pixels == (PixelPacket *) NULL))
-      break;
+    const IndexPacket
+      *indexes;
+
+    IndexPacket
+      *paint_indexes;
+
+    register const PixelPacket
+      *p;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    id=GetCacheViewThreadId();
+    p=AcquireCacheViewPixels(image_view[id],-((long) width/2L),y-(long)
+      (width/2L),image->columns+width,width,exception);
+    q=GetCacheViewPixels(paint_view[id],0,y,paint_image->columns,1);
+    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=AcquireCacheViewIndexes(image_view[id]);
+    paint_indexes=GetCacheViewIndexes(paint_view[id]);
     for (x=0; x < (long) image->columns; x++)
     {
+      long
+        k,
+        v;
+
+      register long
+        i,
+        u;
+
+      unsigned long
+        count;
+
       /*
         Assign most frequent color.
       */
       i=0;
       count=0;
-      (void) ResetMagickMemory(histogram,0,256*sizeof(*histogram));
+      (void) ResetMagickMemory(histogram[id],0,NumberPaintBins*
+        sizeof(**histogram));
       for (v=0; v < (long) width; v++)
       {
         for (u=0; u < (long) width; u++)
         {
-          k=(long) ScaleQuantumToChar(PixelIntensityToQuantum(pixels+(x+u+i)));
-          histogram[k]++;
-          if (histogram[k] > count)
+          k=(long) ScaleQuantumToChar(PixelIntensityToQuantum(p+u+i));
+          histogram[id][k]++;
+          if (histogram[id][k] > count)
             {
-              paint_pixels[x]=pixels[x+u+i];
-              count=histogram[k];
+              *q=(*(p+u+i));
+              if ((indexes != (const IndexPacket *) NULL) &&
+                  (paint_indexes != (const IndexPacket *) NULL))
+                paint_indexes[x]=indexes[x+u+i];
+              count=histogram[id][k];
             }
         }
         i+=image->columns+width;
       }
+      p++;
+      q++;
     }
-    if (SyncImagePixels(paint_image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(OilPaintImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(paint_view[id]) == MagickFalse)
+      status=MagickFalse;
+    if (SetImageProgress(image,OilPaintImageTag,y,image->rows) == MagickFalse)
+      y=(long) image->rows;
   }
-  histogram=(unsigned long *) RelinquishMagickMemory(histogram);
+  paint_view=DestroyCacheViewThreadSet(paint_view);
+  image_view=DestroyCacheViewThreadSet(image_view);
+  histogram=(unsigned long **) DestroyHistogramThreadSet(histogram);
+  if (status == MagickFalse)
+    paint_image=DestroyImage(paint_image);
   return(paint_image);
 }
 
@@ -511,13 +576,13 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel(s).
+%    o channel: the channel(s).
 %
-%    o target: The RGB value of the target color.
+%    o target: the RGB value of the target color.
 %
-%    o fill: The replacement color.
+%    o fill: the replacement color.
 %
 %    o invert: paint any pixel that does not match the target color.
 %
@@ -527,7 +592,7 @@ MagickExport MagickBooleanType OpaquePaintImage(Image *image,
   const MagickPixelPacket *target,const MagickPixelPacket *fill,
   const MagickBooleanType invert)
 {
-  return(OpaquePaintImageChannel(image,DefaultChannels,target,fill,invert));
+  return(OpaquePaintImageChannel(image,AllChannels,target,fill,invert));
 }
 
 MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
@@ -542,17 +607,8 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
   MagickBooleanType
     status;
 
-  MagickPixelPacket
-    pixel;
-
-  register IndexPacket
-    *indexes;
-
-  register long
-    x;
-
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Make image color opaque.
@@ -565,13 +621,36 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
-  GetMagickPixelPacket(image,&pixel);
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    MagickBooleanType
+      progress;
+
+    MagickPixelPacket
+      pixel;
+
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
+    GetMagickPixelPacket(image,&pixel);
     for (x=0; x < (long) image->columns; x++)
     {
       SetMagickPixelPacket(image,q,indexes+x,&pixel);
@@ -591,18 +670,14 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
         }
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(OpaquePaintImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    progress=SetImageProgress(image,OpaquePaintImageTag,y,image->rows);
+    if (progress == MagickFalse)
+      y=(long) image->rows;
   }
-  return(MagickTrue);
+  image_view=DestroyCacheViewThreadSet(image_view);
+  return(status);
 }
 
 /*
@@ -654,17 +729,8 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
   MagickBooleanType
     status;
 
-  MagickPixelPacket
-    pixel;
-
-  register IndexPacket
-    *indexes;
-
-  register long
-    x;
-
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Make image color transparent.
@@ -678,13 +744,36 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
     return(MagickFalse);
   if (image->matte == MagickFalse)
     (void) SetImageOpacity(image,OpaqueOpacity);
-  GetMagickPixelPacket(image,&pixel);
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    MagickBooleanType
+      progress;
+
+    MagickPixelPacket
+      pixel;
+
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
+    GetMagickPixelPacket(image,&pixel);
     for (x=0; x < (long) image->columns; x++)
     {
       SetMagickPixelPacket(image,q,indexes+x,&pixel);
@@ -692,16 +781,12 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
         q->opacity=opacity;
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(TransparentPaintImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    progress=SetImageProgress(image,TransparentPaintImageTag,y,image->rows);
+    if (progress == MagickFalse)
+      y=(long) image->rows;
   }
-  return(MagickTrue);
+  image_view=AcquireCacheViewThreadSet(image);
+  return(status);
 }
