@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,11 +52,12 @@
 #include "magick/profile.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/splay-tree.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
-#if defined(HasLCMS)
-#if defined(HAVE_LCMS_LCMS_H)
+#if defined(MAGICKCORE_LCMS_DELEGATE)
+#if defined(MAGICKCORE_HAVE_LCMS_LCMS_H)
 #include <lcms/lcms.h>
 #else
 #include "lcms.h"
@@ -83,36 +84,27 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o clone_image: The clone image.
+%    o clone_image: the clone image.
 %
 */
 MagickExport MagickBooleanType CloneImageProfiles(Image *image,
   const Image *clone_image)
 {
-  const char
-    *name;
-
-  const StringInfo
-    *profile;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(clone_image != (const Image *) NULL);
   assert(clone_image->signature == MagickSignature);
-  if (clone_image->profiles == (SplayTreeInfo *) NULL)
-    return(MagickTrue);
-  ResetImageProfileIterator(clone_image);
-  for (name=GetNextImageProfile(clone_image); name != (char *) NULL; )
-  {
-    profile=GetImageProfile(clone_image,name);
-    if (profile != (StringInfo *) NULL)
-      (void) SetImageProfile(image,name,profile);
-    name=GetNextImageProfile(clone_image);
-  }
+  image->color_profile.length=clone_image->color_profile.length;
+  image->color_profile.info=clone_image->color_profile.info;
+  image->iptc_profile.length=clone_image->iptc_profile.length;
+  image->iptc_profile.info=clone_image->iptc_profile.info;
+  if (clone_image->profiles != (void *) NULL)
+    image->profiles=CloneSplayTree((SplayTreeInfo *) clone_image->profiles,
+      (void *(*)(void *)) ConstantString,(void *(*)(void *)) CloneStringInfo);
   return(MagickTrue);
 }
 
@@ -135,9 +127,9 @@ MagickExport MagickBooleanType CloneImageProfiles(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o name: The profile name.
+%    o name: the profile name.
 %
 */
 MagickExport MagickBooleanType DeleteImageProfile(Image *image,
@@ -187,7 +179,7 @@ MagickExport MagickBooleanType DeleteImageProfile(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void DestroyImageProfiles(Image *image)
@@ -215,9 +207,9 @@ MagickExport void DestroyImageProfiles(Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o name: The profile name.
+%    o name: the profile name.
 %
 */
 MagickExport const StringInfo *GetImageProfile(const Image *image,
@@ -260,7 +252,7 @@ MagickExport const StringInfo *GetImageProfile(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o hash_info: The hash info.
+%    o hash_info: the hash info.
 %
 */
 MagickExport char *GetNextImageProfile(const Image *image)
@@ -303,13 +295,13 @@ MagickExport char *GetNextImageProfile(const Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o name: Name of profile to add or remove: ICC, IPTC, or generic profile.
 %
-%    o datum: The profile data.
+%    o datum: the profile data.
 %
-%    o length: The length of the profile.
+%    o length: the length of the profile.
 %
 %    o clone: should be MagickFalse.
 %
@@ -699,7 +691,7 @@ static MagickBooleanType SetsRGBImageProfile(Image *image)
   profile=DestroyStringInfo(profile);
   return(status);
 }
-#if defined(HasLCMS)
+#if defined(MAGICKCORE_LCMS_DELEGATE)
 #if defined(LCMS_VERSION) && (LCMS_VERSION > 1010)
 static int LCMSErrorHandler(int severity,const char *context)
 {
@@ -758,13 +750,13 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           const char
             *value;
 
-          value=GetImageProperty(image,"EXIF:ColorSpace");
+          value=GetImageProperty(image,"exif:ColorSpace");
           if (LocaleCompare(value,"1") != 0)
             (void) SetsRGBImageProfile(image);
-          value=GetImageProperty(image,"EXIF:InteroperabilityIndex");
+          value=GetImageProperty(image,"exif:InteroperabilityIndex");
           if (LocaleCompare(value,"R98.") != 0)
             (void) SetsRGBImageProfile(image);
-          value=GetImageProperty(image,"EXIF:InteroperabilityIndex");
+          value=GetImageProperty(image,"exif:InteroperabilityIndex");
           if (LocaleCompare(value,"R03.") != 0)
             (void) SetAdobeRGB1998ImageProfile(image);
           icc_profile=GetImageProfile(image,"icc");
@@ -775,9 +767,9 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           profile=DestroyStringInfo(profile);
           return(MagickTrue);
         }
-#if !defined(HasLCMS)
+#if !defined(MAGICKCORE_LCMS_DELEGATE)
       (void) ThrowMagickException(&image->exception,GetMagickModule(),
-        MissingDelegateWarning,"LCMSLibraryIsNotAvailable","`%s'",
+        MissingDelegateWarning,"DelegateLibrarySupportNotBuiltIn","`%s' (LCMS)",
         image->filename);
 #else
       if (icc_profile != (StringInfo *) NULL)
@@ -1046,6 +1038,29 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               break;
           }
           image->colorspace=target_colorspace;
+          switch (cmsGetColorSpace(target_profile))
+          {
+            case icSigRgbData:
+            {
+              image->type=image->matte == MagickFalse ? TrueColorType :
+                TrueColorMatteType;
+              break;
+            }
+            case icSigCmykData:
+            {
+              image->type=image->matte == MagickFalse ? ColorSeparationType :
+                ColorSeparationMatteType;
+              break;
+            }
+            case icSigGrayData:
+            {
+              image->type=image->matte == MagickFalse ? GrayscaleType :
+                GrayscaleMatteType;
+              break;
+            }
+            default:
+              break;
+          }
           target_pixels=(unsigned short *) RelinquishMagickMemory(
             target_pixels);
           source_pixels=(unsigned short *) RelinquishMagickMemory(
@@ -1079,9 +1094,9 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o name: The profile name.
+%    o name: the profile name.
 %
 */
 MagickExport StringInfo *RemoveImageProfile(Image *image,const char *name)
@@ -1137,7 +1152,7 @@ MagickExport StringInfo *RemoveImageProfile(Image *image,const char *name)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void ResetImageProfileIterator(const Image *image)
@@ -1173,9 +1188,10 @@ MagickExport void ResetImageProfileIterator(const Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o name: The profile name.
+%    o name: the profile name, for example icc, exif, and 8bim (8bim is the
+%      Photoshop wrapper for iptc profiles).
 %
 %    o profile: A StringInfo structure that contains the named profile.
 %
@@ -1266,7 +1282,7 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 
