@@ -3,11 +3,11 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%           PPPP    RRRR     OOO   PPPP   EEEEE  RRRR   TTTTT  Y   Y          %
-%           P   P   R   R   O   O  P   P  E      R   R    T     Y Y           %
-%           PPPP    RRRR    O   O  PPPP   EEE    RRRR     T      Y            %
-%           P       R R     O   O  P      E      R R      T      Y            %
-%           P       R  R     OOO   P      EEEEE  R  R     T      Y            %
+%            PPPP    RRRR    OOO   PPPP   EEEEE  RRRR   TTTTT  Y   Y          %
+%            P   P   R   R  O   O  P   P  E      R   R    T     Y Y           %
+%            PPPP    RRRR   O   O  PPPP   EEE    RRRR     T      Y            %
+%            P       R R    O   O  P      E      R R      T      Y            %
+%            P       R  R    OOO   P      EEEEE  R  R     T      Y            %
 %                                                                             %
 %                                                                             %
 %                        ImageMagick Property Methods                         %
@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,7 +41,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/property.h"
 #include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/compare.h"
@@ -66,7 +65,7 @@
 #include "magick/quantum.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/token.h"
@@ -93,18 +92,14 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o clone_image: The clone image.
+%    o clone_image: the clone image.
 %
 */
 MagickExport MagickBooleanType CloneImageProperties(Image *image,
   const Image *clone_image)
 {
-  const char
-    *property,
-    *value;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -114,8 +109,6 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
   if (clone_image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       clone_image->filename);
-  assert(clone_image != (const Image *) NULL);
-  assert(clone_image->signature == MagickSignature);
   (void) CopyMagickString(image->filename,clone_image->filename,MaxTextExtent);
   (void) CopyMagickString(image->magick_filename,clone_image->magick_filename,
     MaxTextExtent);
@@ -141,9 +134,9 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
   image->tile_offset=clone_image->tile_offset;
   image->extract_info=clone_image->extract_info;
   image->bias=clone_image->bias;
+  image->filter=clone_image->filter;
   image->blur=clone_image->blur;
   image->fuzz=clone_image->fuzz;
-  image->filter=clone_image->filter;
   image->interlace=clone_image->interlace;
   image->interpolate=clone_image->interpolate;
   image->endian=clone_image->endian;
@@ -162,16 +155,9 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
   image->start_loop=clone_image->start_loop;
   image->error=clone_image->error;
   image->signature=clone_image->signature;
-  if (clone_image->properties == (void *) NULL)
-    return(MagickTrue);
-  ResetImagePropertyIterator(clone_image);
-  for (property=GetNextImageProperty(clone_image); property != (char *) NULL; )
-  {
-    value=GetImageProperty(clone_image,property);
-    if (value != (const char *) NULL)
-      (void) SetImageProperty(image,property,value);
-    property=GetNextImageProperty(clone_image);
-  }
+  if (clone_image->properties != (void *) NULL)
+    image->properties=CloneSplayTree((SplayTreeInfo *) clone_image->properties,
+      (void *(*)(void *)) ConstantString,(void *(*)(void *)) ConstantString);
   return(MagickTrue);
 }
 
@@ -195,9 +181,9 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o property: The image property.
+%    o property: the image property.
 %
 */
 MagickExport MagickBooleanType DefineImageProperty(Image *image,
@@ -212,7 +198,7 @@ MagickExport MagickBooleanType DefineImageProperty(Image *image,
 
   assert(image != (Image *) NULL);
   assert(property != (const char *) NULL);
-  (void) CopyMagickString(key,property,MaxTextExtent);
+  (void) CopyMagickString(key,property,MaxTextExtent-1);
   for (p=key; *p != '\0'; p++)
     if (*p == '=')
       break;
@@ -238,14 +224,13 @@ MagickExport MagickBooleanType DefineImageProperty(Image *image,
 %
 %  The format of the DeleteImageProperty method is:
 %
-%      MagickBooleanType DeleteImageProperty(Image *image,
-%        const char *key)
+%      MagickBooleanType DeleteImageProperty(Image *image,const char *property)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o property: The image property.
+%    o property: the image property.
 %
 */
 MagickExport MagickBooleanType DeleteImageProperty(Image *image,
@@ -281,7 +266,7 @@ MagickExport MagickBooleanType DeleteImageProperty(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void DestroyImageProperties(Image *image)
@@ -335,7 +320,7 @@ MagickExport MagickBooleanType FormatImagePropertyList(Image *image,
   int
     n;
 
-#if defined(HAVE_VSNPRINTF)
+#if defined(MAGICKCORE_HAVE_VSNPRINTF)
   n=vsnprintf(value,MaxTextExtent,format,operands);
 #else
   n=vsprintf(value,format,operands);
@@ -379,9 +364,9 @@ MagickExport MagickBooleanType FormatImageProperty(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o key: The key.
+%    o key: the key.
 %
 */
 
@@ -906,10 +891,7 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
       {  0x80e5, "exif:ImageDepth" },
       {  0x80e6, "exif:TileDepth" },
       {  0x828d, "exif:CFARepeatPatternDim" },
-      {  0x828e, "exif:CFAPattern" },
-      {  0x828f, "exif:BatteryLevel" },
-      {  0x828d, "exif:CFARepeatPatternDim" },
-      {  0x828e, "exif:CFAPattern" },
+      {  0x828e, "exif:CFAPattern2" },
       {  0x828f, "exif:BatteryLevel" },
       {  0x8298, "exif:Copyright" },
       {  0x829a, "exif:ExposureTime" },
@@ -951,7 +933,7 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
       {  0x9213, "exif:ImageHistory" },
       {  0x9214, "exif:SubjectArea" },
       {  0x9215, "exif:ExposureIndex" },
-      {  0x9216, "exif:TIFF/EPStandardID" },
+      {  0x9216, "exif:TIFF-EPStandardID" },
       {  0x927c, "exif:MakerNote" },
       {  0x9C9b, "exif:WinXP-Title" },
       {  0x9C9c, "exif:WinXP-Comments" },
@@ -1075,7 +1057,7 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
         Check for a hex based tag specification first.
       */
       tag=0;
-      property++;
+      property+=6;
       n=strlen(property);
       if (n != 4)
         return(MagickFalse);
@@ -1319,6 +1301,9 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
               char
                 key[MaxTextExtent];
 
+              register const char
+                *p;
+
               (void) CopyMagickString(key,property,MaxTextExtent);
               switch (all)
               {
@@ -1352,7 +1337,10 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
                   break;
                 }
               }
-              (void) SetImageProperty((Image *) image,key,value);
+              p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
+                image->properties,key);
+              if (p == (const char *) NULL)
+                (void) SetImageProperty((Image *) image,key,value);
               value=DestroyString(value);
             }
         }
@@ -1888,11 +1876,10 @@ MagickExport const char *GetImageProperty(const Image *image,
               (void) FormatMagickString(value,MaxTextExtent,"%g",(double)
                 alpha);
               (void) SetImageProperty((Image *) image,property,value);
-              return(GetImageProperty(image,property));
-              p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
-                image->properties,property);
-              return(p);
             }
+          p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
+            image->properties,property);
+          return(p);
         }
       break;
     }
@@ -1944,8 +1931,8 @@ MagickExport const char *GetImageProperty(const Image *image,
               char
                 name[MaxTextExtent];
 
-              (void) QueryMagickColorname(image,&pixel,SVGCompliance,
-                MagickFalse,name,exception);
+              (void) QueryMagickColorname(image,&pixel,SVGCompliance,name,
+                exception);
               (void) SetImageProperty((Image *) image,property,name);
               return(GetImageProperty(image,property));
             }
@@ -1989,7 +1976,7 @@ MagickExport const char *GetImageProperty(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport char *GetNextImageProperty(const Image *image)
@@ -2025,11 +2012,11 @@ MagickExport char *GetNextImageProperty(const Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o embed_text: The address of a character string containing the embedded
+%    o embed_text: the address of a character string containing the embedded
 %      formatting characters.
 %
 */
@@ -2054,6 +2041,38 @@ static const char *GetMagickProperty(const ImageInfo *image_info,Image *image,
         }
       break;
     }
+    case 'c':
+    {
+      if (LocaleNCompare("channels",property,8) == 0)
+        {
+          /*
+            Image channels.
+          */
+          (void) FormatMagickString(value,MaxTextExtent,"%s",
+            MagickOptionToMnemonic(MagickColorspaceOptions,(long)
+            image->colorspace));
+          LocaleLower(value);
+          if (image->matte != MagickFalse)
+            (void) ConcatenateMagickString(value,"a",MaxTextExtent);
+          break;
+        }
+      if (LocaleNCompare("colorspace",property,10) == 0)
+        {
+          ColorspaceType
+            colorspace;
+
+          /*
+            Image storage class and colorspace.
+          */
+          colorspace=image->colorspace;
+          if (IsGrayImage(image,&image->exception) != MagickFalse)
+            colorspace=GRAYColorspace;
+          (void) FormatMagickString(value,MaxTextExtent,"%s",
+            MagickOptionToMnemonic(MagickColorspaceOptions,(long) colorspace));
+          break;
+        }
+      break;
+    }
     case 'd':
     {
       if (LocaleNCompare("depth",property,5) == 0)
@@ -2115,6 +2134,39 @@ static const char *GetMagickProperty(const ImageInfo *image_info,Image *image,
           (void) CopyMagickString(value,image->magick,MaxTextExtent);
           break;
         }
+      if (LocaleNCompare("max",property,3) == 0)
+        {
+          double
+            maximum,
+            minimum;
+
+          (void) GetImageChannelRange(image,image_info->channel,&minimum,
+            &maximum,&image->exception);
+          (void) FormatMagickString(value,MaxTextExtent,"%g",maximum);
+          break;
+        }
+      if (LocaleNCompare("mean",property,4) == 0)
+        {
+          double
+            mean,
+            standard_deviation;
+
+          (void) GetImageChannelMean(image,image_info->channel,&mean,
+            &standard_deviation,&image->exception);
+          (void) FormatMagickString(value,MaxTextExtent,"%g",mean);
+          break;
+        }
+      if (LocaleNCompare("min",property,3) == 0)
+        {
+          double
+            maximum,
+            minimum;
+
+          (void) GetImageChannelRange(image,image_info->channel,&minimum,
+            &maximum,&image->exception);
+          (void) FormatMagickString(value,MaxTextExtent,"%g",minimum);
+          break;
+        }
       break;
     }
     case 'n':
@@ -2126,33 +2178,6 @@ static const char *GetMagickProperty(const ImageInfo *image_info,Image *image,
         }
      break;
     }
-    case 's':
-    {
-      if (LocaleNCompare("size",property,4) == 0)
-        {
-          char
-            format[MaxTextExtent];
-
-          (void) FormatMagickSize(GetBlobSize(image),format);
-          (void) FormatMagickString(value,MaxTextExtent,"%s",format);
-          break;
-        }
-      if (LocaleNCompare("scene",property,5) == 0)
-        {
-          (void) FormatMagickString(value,MaxTextExtent,"%lu",image->scene);
-          if (image_info->number_scenes != 0)
-            (void) FormatMagickString(value,MaxTextExtent,"%lu",
-              image_info->scene);
-          break;
-        }
-      if (LocaleNCompare("scenes",property,6) == 0)
-        {
-          (void) FormatMagickString(value,MaxTextExtent,"%lu",
-            (unsigned long) GetImageListLength(image));
-          break;
-        }
-       break;
-    }
     case 'o':
     {
       if (LocaleNCompare("output",property,6) == 0)
@@ -2180,6 +2205,45 @@ static const char *GetMagickProperty(const ImageInfo *image_info,Image *image,
         }
       break;
     }
+    case 's':
+    {
+      if (LocaleNCompare("size",property,4) == 0)
+        {
+          char
+            format[MaxTextExtent];
+
+          (void) FormatMagickSize(GetBlobSize(image),format);
+          (void) FormatMagickString(value,MaxTextExtent,"%s",format);
+          break;
+        }
+      if (LocaleNCompare("scene",property,5) == 0)
+        {
+          (void) FormatMagickString(value,MaxTextExtent,"%lu",image->scene);
+          if (image_info->number_scenes != 0)
+            (void) FormatMagickString(value,MaxTextExtent,"%lu",
+              image_info->scene);
+          break;
+        }
+      if (LocaleNCompare("scenes",property,6) == 0)
+        {
+          (void) FormatMagickString(value,MaxTextExtent,"%lu",
+            (unsigned long) GetImageListLength(image));
+          break;
+        }
+      if (LocaleNCompare("standard-deviation",property,18) == 0)
+        {
+          double
+            mean,
+            standard_deviation;
+
+          (void) GetImageChannelMean(image,image_info->channel,&mean,
+            &standard_deviation,&image->exception);
+          (void) FormatMagickString(value,MaxTextExtent,"%g",
+            standard_deviation);
+          break;
+        }
+       break;
+    }
     case 'u':
     {
       if (LocaleNCompare("unique",property,6) == 0)
@@ -2342,7 +2406,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image comment.
         */
-        value=GetImageProperty(image,"Comment");
+        value=GetImageProperty(image,"comment");
         if (value == (const char *) NULL)
           break;
         length=strlen(value);
@@ -2450,7 +2514,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image label.
         */
-        value=GetImageProperty(image,"Label");
+        value=GetImageProperty(image,"label");
         if (value == (const char *) NULL)
           break;
         length=strlen(value);
@@ -2591,10 +2655,9 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
       case 'z':
       {
         /*
-          Unique filename.
+          Image depth.
         */
-        q+=FormatMagickString(q,extent,"%lu",GetImageDepth(image,
-          &image->exception));
+        q+=FormatMagickString(q,extent,"%lu",image->depth);
         break;
       }
       case 'C':
@@ -2770,7 +2833,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           Image signature.
         */
         (void) SignatureImage(image);
-        value=GetImageProperty(image,"Signature");
+        value=GetImageProperty(image,"signature");
         if (value == (const char *) NULL)
           break;
         q+=CopyMagickString(q,value,extent);
@@ -2818,9 +2881,9 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o property: The image property.
+%    o property: the image property.
 %
 */
 MagickExport char *RemoveImageProperty(Image *image,
@@ -2852,7 +2915,7 @@ MagickExport char *RemoveImageProperty(Image *image,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ResetImagePropertyIterator() resets the image values iterator.  Use it
+%  ResetImagePropertyIterator() resets the image properties iterator.  Use it
 %  in conjunction with GetNextImageProperty() to iterate over all the values
 %  associated with an image property.
 %
@@ -2862,7 +2925,7 @@ MagickExport char *RemoveImageProperty(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void ResetImagePropertyIterator(const Image *image)
@@ -2897,11 +2960,11 @@ MagickExport void ResetImagePropertyIterator(const Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o property: The image property.
+%    o property: the image property.
 %
-%    o values: The image property values.
+%    o values: the image property values.
 %
 */
 MagickExport MagickBooleanType SetImageProperty(Image *image,
