@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -114,7 +114,7 @@
 %    and n2  will ultimately characterize the mean color of a set of
 %    pixels represented by this node.
 %
-%    E: The distance squared in RGB space between each pixel contained
+%    E: the distance squared in RGB space between each pixel contained
 %    within a node and the nodes' center.  This represents the
 %    quantization error for a node.
 %
@@ -186,11 +186,12 @@
 #include "magick/image-private.h"
 #include "magick/list.h"
 #include "magick/memory_.h"
+#include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/pixel-private.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
-#include "magick/monitor.h"
 #include "magick/string_.h"
 
 /*
@@ -272,7 +273,7 @@ typedef struct _CubeInfo
   long
     *cache;
 
-  MagickPixelPacket
+  RealPixelPacket
     error[ErrorQueueLength];
 
   MagickRealType
@@ -336,7 +337,7 @@ static void
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 */
 MagickExport QuantizeInfo *AcquireQuantizeInfo(const ImageInfo *image_info)
@@ -390,7 +391,7 @@ MagickExport QuantizeInfo *AcquireQuantizeInfo(const ImageInfo *image_info)
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -427,8 +428,7 @@ static inline RealPixelPacket AssociateAlphaPixel(const Image *image,
       alpha_pixel.opacity=(MagickRealType) pixel->opacity;
       return(alpha_pixel);
     }
-  alpha=(MagickRealType) (QuantumScale*(QuantumRange-(MagickRealType)
-    pixel->opacity));
+  alpha=(MagickRealType) (QuantumScale*(QuantumRange-pixel->opacity));
   alpha_pixel.red=alpha*pixel->red;
   alpha_pixel.green=alpha*pixel->green;
   alpha_pixel.blue=alpha*pixel->blue;
@@ -436,6 +436,15 @@ static inline RealPixelPacket AssociateAlphaPixel(const Image *image,
   return(alpha_pixel);
 }
 
+static inline Quantum ClipToQuantum(const MagickRealType value)
+{
+  if (value <= 0.0)
+    return((Quantum) 0);
+  if (value >= QuantumRange)
+    return((Quantum) QuantumRange);
+  return((Quantum) (value+0.5));
+}
+
 static inline unsigned long ColorToNodeId(const Image *image,
   const CubeInfo *cube_info,const RealPixelPacket *pixel,unsigned long index)
 {
@@ -443,12 +452,12 @@ static inline unsigned long ColorToNodeId(const Image *image,
     id;
 
   id=(unsigned long) (
-    ((ScaleQuantumToChar(RoundToQuantum(pixel->red)) >> index) & 0x01) |
-    ((ScaleQuantumToChar(RoundToQuantum(pixel->green)) >> index) & 0x01) << 1 |
-    ((ScaleQuantumToChar(RoundToQuantum(pixel->blue)) >> index) & 0x01) << 2);
+    ((ScaleQuantumToChar(ClipToQuantum(pixel->red)) >> index) & 0x01) |
+    ((ScaleQuantumToChar(ClipToQuantum(pixel->green)) >> index) & 0x01) << 1 |
+    ((ScaleQuantumToChar(ClipToQuantum(pixel->blue)) >> index) & 0x01) << 2);
   if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
-    id|=((ScaleQuantumToChar(RoundToQuantum(pixel->opacity)) >> index) &
-      0x01) << 3;
+    id|=((ScaleQuantumToChar(ClipToQuantum(pixel->opacity)) >> index) & 0x01)
+      << 3;
   return(id);
 }
 
@@ -459,9 +468,6 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
   long
     y;
 
-  MagickBooleanType
-    status;
-
   RealPixelPacket
     pixel;
 
@@ -478,6 +484,9 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
   register PixelPacket
     *q;
 
+  ssize_t
+    count;
+
   unsigned long
     id,
     index;
@@ -494,7 +503,7 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
         (image->colorspace != RGBColorspace) &&
         (image->colorspace != CMYColorspace))
       (void) SetImageColorspace((Image *) image,RGBColorspace);
-  if (AllocateImageColormap(image,cube_info->colors) == MagickFalse)
+  if (AcquireImageColormap(image,cube_info->colors) == MagickFalse)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
   image->colors=0;
@@ -511,18 +520,22 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
       ViewInfo
         *image_view;
 
-      image_view=OpenCacheView(image);
+      image_view=AcquireCacheView(image);
       for (y=0; y < (long) image->rows; y++)
       {
+
         q=GetCacheViewPixels(image_view,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
         indexes=GetCacheViewIndexes(image_view);
-        for (x=0; x < (long) image->columns; x++)
+        for (x=0; x < (long) image->columns; x+=count)
         {
           /*
             Identify the deepest node containing the pixel's color.
           */
+          for (count=1; (x+count) < (long) image->columns; count++)
+            if (IsColorEqual(q,q+count) == MagickFalse)
+              break;
           pixel=AssociateAlphaPixel(image,cube_info,q);
           node_info=cube_info->root;
           for (index=MaxTreeDepth-1; (long) index > 0; index--)
@@ -537,33 +550,30 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
           */
           cube_info->target=pixel;
           cube_info->distance=4.0*((MagickRealType) QuantumRange+1.0)*
-            ((MagickRealType) QuantumRange+1.0);
+            ((MagickRealType) QuantumRange+1.0)+1.0;
           ClosestColor(image,cube_info,node_info->parent);
           index=cube_info->color_number;
-          if (image->storage_class == PseudoClass)
-            indexes[x]=(IndexPacket) index;
-          if (cube_info->quantize_info->measure_error == MagickFalse)
-            {
-              q->red=image->colormap[index].red;
-              q->green=image->colormap[index].green;
-              q->blue=image->colormap[index].blue;
-              if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
-                q->opacity=image->colormap[index].opacity;
-            }
-          q++;
+          for (i=0; i < (long) count; i++)
+          {
+            if (image->storage_class == PseudoClass)
+              indexes[x+i]=(IndexPacket) index;
+            if (cube_info->quantize_info->measure_error == MagickFalse)
+              {
+                q->red=image->colormap[index].red;
+                q->green=image->colormap[index].green;
+                q->blue=image->colormap[index].blue;
+                if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
+                  q->opacity=image->colormap[index].opacity;
+              }
+            q++;
+          }
         }
         if (SyncCacheView(image_view) == MagickFalse)
           break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(AssignImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        if (SetImageProgress(image,AssignImageTag,y,image->rows) == MagickFalse)
+          break;
       }
-      image_view=CloseCacheView(image_view);
+      image_view=DestroyCacheView(image_view);
     }
   if (cube_info->quantize_info->measure_error != MagickFalse)
     (void) GetImageQuantizeError(image);
@@ -587,20 +597,6 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
         q++;
       }
     }
-  if (0 && (IsAssociatedAlpha(image,cube_info) != MagickFalse) &&
-      (cube_info->transparent_index >= 0))
-    {
-      /*
-        Introduces black bar:
-          convert -size 100x100 gradient:blue-none -colors 256 image.png
-      */
-      image->colormap[cube_info->transparent_index].red=
-        image->transparent_color.red;
-      image->colormap[cube_info->transparent_index].green=
-        image->transparent_color.green;
-      image->colormap[cube_info->transparent_index].blue=
-        image->transparent_color.blue;
-    }
   (void) SyncImage(image);
   image->storage_class=PseudoClass;
   if ((cube_info->quantize_info->colorspace != UndefinedColorspace) &&
@@ -653,7 +649,7 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
 %    these sums and n2  will ultimately characterize the mean color of a
 %    set of pixels represented by this node.
 %
-%    E: The distance squared in RGB space between each pixel contained
+%    E: the distance squared in RGB space between each pixel contained
 %    within a node and the nodes' center.  This represents the quantization
 %    error for a node.
 %
@@ -666,7 +662,7 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
 %
 %    o cube_info: A pointer to the Cube structure.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
@@ -677,9 +673,6 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
   long
     y;
 
-  MagickBooleanType
-    status;
-
   MagickRealType
     bisect;
 
@@ -697,6 +690,9 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
   register const PixelPacket
     *p;
 
+  size_t
+    count;
+
   unsigned long
     id,
     index,
@@ -718,7 +714,7 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         (image->colorspace != RGBColorspace))
       (void) SetImageColorspace((Image *) image,RGBColorspace);
   error.opacity=0.0;
-  image_view=OpenCacheView(image);
+  image_view=AcquireCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
@@ -732,11 +728,14 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         PruneLevel(image,cube_info,cube_info->root);
         cube_info->depth--;
       }
-    for (x=0; x < (long) image->columns; x++)
+    for (x=0; x < (long) image->columns; x+=count)
     {
       /*
         Start at the root and descend the color cube tree.
       */
+      for (count=1; (x+count) < image->columns; count++)
+        if (IsColorEqual(p,p+count) == MagickFalse)
+          break;
       pixel=AssociateAlphaPixel(image,cube_info,p);
       index=MaxTreeDepth-1;
       bisect=((MagickRealType) QuantumRange+1.0)/2.0;
@@ -775,31 +774,25 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         error.blue=QuantumScale*(pixel.blue-mid.blue);
         if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
           error.opacity=QuantumScale*(pixel.opacity-mid.opacity);
-        node_info->quantize_error+=sqrt((double) (error.red*error.red+
-          error.green*error.green+error.blue*error.blue+error.opacity*
-          error.opacity));
+        node_info->quantize_error+=sqrt((double) (count*error.red*error.red+
+          count*error.green*error.green+count*error.blue*error.blue+
+          count*error.opacity*error.opacity));
         cube_info->root->quantize_error+=node_info->quantize_error;
         index--;
       }
       /*
         Sum RGB for this leaf for later derivation of the mean cube color.
       */
-      node_info->number_unique++;
-      node_info->total_color.red+=QuantumScale*pixel.red;
-      node_info->total_color.green+=QuantumScale*pixel.green;
-      node_info->total_color.blue+=QuantumScale*pixel.blue;
+      node_info->number_unique+=count;
+      node_info->total_color.red+=count*QuantumScale*pixel.red;
+      node_info->total_color.green+=count*QuantumScale*pixel.green;
+      node_info->total_color.blue+=count*QuantumScale*pixel.blue;
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
-        node_info->total_color.opacity+=QuantumScale*pixel.opacity;
-      p++;
+        node_info->total_color.opacity+=count*QuantumScale*pixel.opacity;
+      p+=count;
     }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ClassifyImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,ClassifyImageTag,y,image->rows) == MagickFalse)
+      break;
     if (cube_info->colors > cube_info->maximum_colors)
       {
         PruneToCubeDepth(image,cube_info,cube_info->root);
@@ -819,11 +812,14 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         PruneLevel(image,cube_info,cube_info->root);
         cube_info->depth--;
       }
-    for (x=0; x < (long) image->columns; x++)
+    for (x=0; x < (long) image->columns; x+=count)
     {
       /*
         Start at the root and descend the color cube tree.
       */
+      for (count=1; (x+count) < image->columns; count++)
+        if (IsColorEqual(p,p+count) == MagickFalse)
+          break;
       pixel=AssociateAlphaPixel(image,cube_info,p);
       index=MaxTreeDepth-1;
       bisect=((MagickRealType) QuantumRange+1.0)/2.0;
@@ -861,33 +857,27 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         error.blue=QuantumScale*(pixel.blue-mid.blue);
         if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
           error.opacity=QuantumScale*(pixel.opacity-mid.opacity);
-        node_info->quantize_error+=sqrt((double) (error.red*error.red+
-          error.green*error.green+error.blue*error.blue+error.opacity*
-          error.opacity));
+        node_info->quantize_error+=sqrt((double) (count*error.red*error.red+
+          count*error.green*error.green+error.blue*error.blue+
+          count*error.opacity*error.opacity));
         cube_info->root->quantize_error+=node_info->quantize_error;
         index--;
       }
       /*
         Sum RGB for this leaf for later derivation of the mean cube color.
       */
-      node_info->number_unique++;
-      node_info->total_color.red+=QuantumScale*pixel.red;
-      node_info->total_color.green+=QuantumScale*pixel.green;
-      node_info->total_color.blue+=QuantumScale*pixel.blue;
+      node_info->number_unique+=count;
+      node_info->total_color.red+=count*QuantumScale*pixel.red;
+      node_info->total_color.green+=count*QuantumScale*pixel.green;
+      node_info->total_color.blue+=count*QuantumScale*pixel.blue;
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
-        node_info->total_color.opacity+=QuantumScale*pixel.opacity;
-      p++;
+        node_info->total_color.opacity+=count*QuantumScale*pixel.opacity;
+      p+=count;
     }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ClassifyImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,ClassifyImageTag,y,image->rows) == MagickFalse)
+      break;
   }
-  image_view=CloseCacheView(image_view);
+  image_view=DestroyCacheView(image_view);
   if ((cube_info->quantize_info->colorspace != UndefinedColorspace) &&
       (cube_info->quantize_info->colorspace != CMYKColorspace))
     (void) SetImageColorspace((Image *) image,RGBColorspace);
@@ -960,11 +950,11 @@ MagickExport QuantizeInfo *CloneQuantizeInfo(const QuantizeInfo *quantize_info)
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
-%    o node_info: The address of a structure of type NodeInfo which points to a
+%    o node_info: the address of a structure of type NodeInfo which points to a
 %      node in the color cube tree that is to be pruned.
 %
 */
@@ -988,44 +978,50 @@ static void ClosestColor(const Image *image,CubeInfo *cube_info,
   if (node_info->number_unique != 0)
     {
       MagickRealType
-        distance,
         pixel;
 
-      RealPixelPacket
-        color;
+      register MagickRealType
+        alpha,
+        beta,
+        distance;
+
+      register PixelPacket
+        *p;
+
+      register RealPixelPacket
+        *q;
 
       /*
         Determine if this color is "closest".
       */
-      color=AssociateAlphaPixel(image,cube_info,image->colormap+
-        node_info->color_number);
-      pixel=color.red-cube_info->target.red;
+      p=image->colormap+node_info->color_number;
+      q=(&cube_info->target);
+      alpha=1.0;
+      beta=1.0;
+      if (IsAssociatedAlpha(image,cube_info) == MagickFalse)
+        {
+          alpha=(MagickRealType) (QuantumScale*(QuantumRange-p->opacity));
+          beta=(MagickRealType) (QuantumScale*(QuantumRange-q->opacity));
+        }
+      pixel=alpha*p->red-beta*q->red;
       distance=pixel*pixel;
       if (distance < cube_info->distance)
         {
-          pixel=color.green-cube_info->target.green;
+          pixel=alpha*p->green-beta*q->green;
           distance+=pixel*pixel;
           if (distance < cube_info->distance)
             {
-              pixel=color.blue-cube_info->target.blue;
+              pixel=alpha*p->blue-beta*q->blue;
               distance+=pixel*pixel;
               if (distance < cube_info->distance)
                 {
-                  if (IsAssociatedAlpha(image,cube_info) == MagickFalse)
+                  pixel=alpha-beta;
+                  distance+=pixel*pixel;
+                  if (distance < cube_info->distance)
                     {
                       cube_info->distance=distance;
                       cube_info->color_number=node_info->color_number;
                     }
-                  else
-                    {
-                      pixel=color.opacity-cube_info->target.opacity;
-                      distance+=pixel*pixel;
-                      if (distance < cube_info->distance)
-                        {
-                          cube_info->distance=distance;
-                          cube_info->color_number=node_info->color_number;
-                        }
-                    }
                 }
             }
         }
@@ -1052,7 +1048,7 @@ static void ClosestColor(const Image *image,CubeInfo *cube_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport void CompressImageColormap(Image *image)
@@ -1095,11 +1091,11 @@ MagickExport void CompressImageColormap(Image *image)
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
-%    o node_info: The address of a structure of type NodeInfo which points to a
+%    o node_info: the address of a structure of type NodeInfo which points to a
 %      node in the color cube tree that is to be pruned.
 %
 */
@@ -1206,7 +1202,7 @@ static unsigned long DefineImageColormap(Image *image,CubeInfo *cube_info,
 %
 %  A description of each parameter follows:
 %
-%    o cube_info: The address of a structure of type CubeInfo.
+%    o cube_info: the address of a structure of type CubeInfo.
 %
 */
 static void DestroyCubeInfo(CubeInfo *cube_info)
@@ -1288,9 +1284,9 @@ MagickExport QuantizeInfo *DestroyQuantizeInfo(QuantizeInfo *quantize_info)
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o image_view: The image cache view.
+%    o image_view: the image cache view.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -1303,6 +1299,9 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
 {
 #define DitherImageTag  "Dither/Image"
 
+  MagickBooleanType
+    progress;
+
   RealPixelPacket
     color,
     pixel;
@@ -1347,12 +1346,12 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
       pixel.blue=ClipToQuantum(pixel.blue);
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
         pixel.opacity=ClipToQuantum(pixel.opacity);
-      i=(long) ((ScaleQuantumToChar(RoundToQuantum(pixel.red)) >> CacheShift) |
-        (ScaleQuantumToChar(RoundToQuantum(pixel.green)) >> CacheShift) << 6 |
-        (ScaleQuantumToChar(RoundToQuantum(pixel.blue)) >> CacheShift) << 12);
+      i=(long) ((ScaleQuantumToChar(ClipToQuantum(pixel.red)) >> CacheShift) |
+        (ScaleQuantumToChar(ClipToQuantum(pixel.green)) >> CacheShift) << 6 |
+        (ScaleQuantumToChar(ClipToQuantum(pixel.blue)) >> CacheShift) << 12);
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
-        i|=((ScaleQuantumToChar(RoundToQuantum(pixel.opacity)) >>
-          CacheShift) << 18);
+        i|=((ScaleQuantumToChar(ClipToQuantum(pixel.opacity)) >> CacheShift)
+          << 18);
       if (p->cache[i] < 0)
         {
           register NodeInfo
@@ -1377,7 +1376,7 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
           */
           p->target=pixel;
           p->distance=4.0*((MagickRealType) QuantumRange+1.0)*((MagickRealType)
-            QuantumRange+1.0);
+            QuantumRange+1.0)+1.0;
           ClosestColor(image,p,node_info->parent);
           p->cache[i]=(long) p->color_number;
         }
@@ -1408,17 +1407,7 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
       p->error[ErrorQueueLength-1].blue=pixel.blue-color.blue;
       if (IsAssociatedAlpha(image,cube_info) != MagickFalse)
         p->error[ErrorQueueLength-1].opacity=pixel.opacity-color.opacity;
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(p->offset,p->span) != MagickFalse))
-        {
-          MagickBooleanType
-            status;
-
-          status=image->progress_monitor(DitherImageTag,p->offset,p->span,
-            image->client_data);
-          if (status == MagickFalse)
-            return(MagickFalse);
-        }
+      progress=SetImageProgress(image,DitherImageTag,p->offset,p->span);
       p->offset++;
     }
   switch (direction)
@@ -1456,7 +1445,7 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -1503,11 +1492,11 @@ static MagickBooleanType DitherImage(Image *image,CubeInfo *cube_info)
     depth++;
   cube_info->offset=0;
   cube_info->span=(MagickSizeType) image->columns*image->rows;
-  image_view=OpenCacheView(image);
+  image_view=AcquireCacheView(image);
   if (depth > 1)
     HilbertCurve(image,image_view,cube_info,depth-1,NorthGravity);
   (void) Dither(image,image_view,cube_info,ForgetGravity);
-  image_view=CloseCacheView(image_view);
+  image_view=DestroyCacheView(image_view);
   return(MagickTrue);
 }
 
@@ -1723,12 +1712,18 @@ static NodeInfo *GetNodeInfo(CubeInfo *cube_info,const unsigned long id,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
 {
-  double
+  IndexPacket
+    *indexes;
+
+  long
+    y;
+
+  MagickRealType
     alpha,
     area,
     beta,
@@ -1737,12 +1732,6 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
     mean_error,
     mean_error_per_pixel;
 
-  IndexPacket
-    *indexes;
-
-  long
-    y;
-
   register const PixelPacket
     *p;
 
@@ -1769,7 +1758,7 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
   maximum_error=0.0;
   mean_error_per_pixel=0.0;
   mean_error=0.0;
-  image_view=OpenCacheView(image);
+  image_view=AcquireCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,&image->exception);
@@ -1781,9 +1770,9 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
       index=1UL*indexes[x];
       if (image->matte != MagickFalse)
         {
-          alpha=QuantumScale*(QuantumRange-(double) p->opacity);
-          beta=QuantumScale*(QuantumRange-(double)
-            image->colormap[index].opacity);
+          alpha=(MagickRealType) (QuantumScale*(QuantumRange-p->opacity));
+          beta=(MagickRealType) (QuantumScale*(QuantumRange-
+            image->colormap[index].opacity));
         }
       distance=fabs(alpha*p->red-beta*image->colormap[index].red);
       mean_error_per_pixel+=distance;
@@ -1803,10 +1792,11 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
       p++;
     }
   }
-  image_view=CloseCacheView(image_view);
-  image->error.mean_error_per_pixel=mean_error_per_pixel/area;
-  image->error.normalized_mean_error=QuantumScale*QuantumScale*mean_error/area;
-  image->error.normalized_maximum_error=QuantumScale*maximum_error;
+  image_view=DestroyCacheView(image_view);
+  image->error.mean_error_per_pixel=(double) mean_error_per_pixel/area;
+  image->error.normalized_mean_error=(double) QuantumScale*QuantumScale*
+    mean_error/area;
+  image->error.normalized_maximum_error=(double) QuantumScale*maximum_error;
   return(MagickTrue);
 }
 
@@ -1868,9 +1858,9 @@ MagickExport void GetQuantizeInfo(QuantizeInfo *quantize_info)
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o image_view: The image cache view.
+%    o image_view: the image cache view.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -1990,7 +1980,7 @@ static void HilbertCurve(const Image *image,ViewInfo *image_view,
 %
 %    o image: Specifies a pointer to an Image structure.
 %
-%    o map_image: The image.  Reduce image to a set of colors represented by
+%    o map_image: the image.  Reduce image to a set of colors represented by
 %      this image.
 %
 %    o dither: Set this integer value to something other than zero to
@@ -2062,7 +2052,7 @@ MagickExport MagickBooleanType MapImage(Image *image,const Image *map_image,
 %
 %    o image: Specifies a pointer to a set of Image structures.
 %
-%    o map_image: The image.  Reduce image to a set of colors represented by
+%    o map_image: the image.  Reduce image to a set of colors represented by
 %      this image.
 %
 %    o dither: Set this integer value to something other than zero to
@@ -2192,7 +2182,7 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  posterize_image=AllocateImage((ImageInfo *) NULL);
+  posterize_image=AcquireImage((ImageInfo *) NULL);
   if (posterize_image == (Image *) NULL)
     return(MagickFalse);
   l=1;
@@ -2204,17 +2194,17 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
       posterize_image=DestroyImage(posterize_image);
       return(MagickFalse);
     }
-  status=AllocateImageColormap(posterize_image,levels*levels*levels);
+  status=AcquireImageColormap(posterize_image,levels*levels*levels);
   if (status == MagickFalse)
     {
       posterize_image=DestroyImage(posterize_image);
       return(MagickFalse);
     }
-  posterize_view=OpenCacheView(posterize_image);
+  posterize_view=AcquireCacheView(posterize_image);
   q=SetCacheView(posterize_view,0,0,posterize_image->columns,1);
   if (q == (PixelPacket *) NULL)
     {
-      posterize_view=CloseCacheView(posterize_view);
+      posterize_view=DestroyCacheView(posterize_view);
       posterize_image=DestroyImage(posterize_image);
       return(MagickFalse);
     }
@@ -2237,11 +2227,11 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
       }
   if (SyncCacheView(posterize_view) == MagickFalse)
     {
-      posterize_view=CloseCacheView(posterize_view);
+      posterize_view=DestroyCacheView(posterize_view);
       posterize_image=DestroyImage(posterize_image);
       return(MagickFalse);
     }
-  posterize_view=CloseCacheView(posterize_view);
+  posterize_view=DestroyCacheView(posterize_view);
   status=MapImage(image,posterize_image,dither);
   posterize_image=DestroyImage(posterize_image);
   return(status);
@@ -2268,7 +2258,7 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -2329,7 +2319,7 @@ static void PruneChild(const Image *image,CubeInfo *cube_info,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -2430,7 +2420,7 @@ static void PruneToCubeDepth(const Image *image,CubeInfo *cube_info,
 %
 %    o quantize_info: Specifies a pointer to an QuantizeInfo structure.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport MagickBooleanType QuantizeImage(const QuantizeInfo *quantize_info,
@@ -2532,6 +2522,7 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
     *image;
 
   MagickBooleanType
+    progress,
     status;
 
   MagickProgressMonitor
@@ -2600,14 +2591,8 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
     if (status == MagickFalse)
       break;
     (void) SetImageProgressMonitor(image,progress_monitor,image->client_data);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(i,number_images) != MagickFalse))
-      {
-        status=image->progress_monitor(AssignImageTag,i,number_images,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,AssignImageTag,i,number_images) == MagickFalse)
+      break;
     image=GetNextImageInList(image);
   }
   if (status != MagickFalse)
@@ -2626,14 +2611,9 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
           break;
         (void) SetImageProgressMonitor(image,progress_monitor,
           image->client_data);
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(i,number_images) != MagickFalse))
-          {
-            status=image->progress_monitor(AssignImageTag,i,number_images,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        progress=SetImageProgress(image,AssignImageTag,i,number_images);
+        if (progress == MagickFalse)
+          break;
         image=GetNextImageInList(image);
       }
     }
@@ -2661,7 +2641,7 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -2748,7 +2728,7 @@ static void Reduce(const Image *image,CubeInfo *cube_info,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cube_info: A pointer to the Cube structure.
 %
@@ -2758,7 +2738,7 @@ static void ReduceImageColors(const Image *image,CubeInfo *cube_info)
 #define ReduceImageTag  "Reduce/Image"
 
   MagickBooleanType
-    status;
+    progress;
 
   MagickOffsetType
     offset;
@@ -2775,13 +2755,9 @@ static void ReduceImageColors(const Image *image,CubeInfo *cube_info)
     cube_info->colors=0;
     Reduce(image,cube_info,cube_info->root);
     offset=(MagickOffsetType) span-cube_info->colors;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(offset,span-cube_info->maximum_colors+1) != MagickFalse))
-      {
-        status=image->progress_monitor(ReduceImageTag,offset,span-
-          cube_info->maximum_colors+1,image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    progress=SetImageProgress(image,ReduceImageTag,offset,span-
+      cube_info->maximum_colors+1);
+    if (progress == MagickFalse)
+      break;
   }
 }
