@@ -57,7 +57,7 @@
 #include "magick/resize.h"
 #include "magick/resize-private.h"
 #include "magick/transform.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 /*
   Typedef declarations.
 */
@@ -143,7 +143,7 @@ static void
 %  output pixel, the ResampleFilter structure generated holds that information
 %  between individual image resampling.
 %
-%  This function will make the appropriate OpenCacheView() calls
+%  This function will make the appropriate AcquireCacheView() calls
 %  to view the image, calling functions do not need to open a cache view.
 %
 %  Usage Example...
@@ -165,7 +165,7 @@ static void
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -190,7 +190,7 @@ MagickExport ResampleFilter *AcquireResampleFilter(const Image *image,
   (void) ResetMagickMemory(resample_filter,0,sizeof(*resample_filter));
 
   resample_filter->image=ReferenceImage((Image *) image);
-  resample_filter->view=OpenCacheView(resample_filter->image);
+  resample_filter->view=AcquireCacheView(resample_filter->image);
   resample_filter->exception=exception;
 
   resample_filter->debug=IsEventLogging();
@@ -246,7 +246,7 @@ MagickExport ResampleFilter *DestroyResampleFilter(
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       resample_filter->image->filename);
 
-  resample_filter->view=CloseCacheView(resample_filter->view);
+  resample_filter->view=DestroyCacheView(resample_filter->view);
   resample_filter->image=DestroyImage(resample_filter->image);
   resample_filter->signature=(~MagickSignature);
 
@@ -277,9 +277,9 @@ MagickExport ResampleFilter *DestroyResampleFilter(
 %
 %  A description of each parameter follows:
 %
-%    o resample_filter: The resample filter.
+%    o resample_filter: the resample filter.
 %
-%    o method: The pixel clor interpolation method.
+%    o method: the pixel clor interpolation method.
 %
 %    o x,y: A double representing the current (x,y) position of the pixel.
 %
@@ -524,7 +524,7 @@ static MagickPixelPacket InterpolateResampleFilter(
     case FilterInterpolatePixel:
     {
       Image
-        *excert_image,
+        *excerpt_image,
         *filter_image;
 
       MagickPixelPacket
@@ -533,28 +533,31 @@ static MagickPixelPacket InterpolateResampleFilter(
       RectangleInfo
         geometry;
 
+      ViewInfo
+        *filter_view;
+
       geometry.width=4L;
       geometry.height=4L;
       geometry.x=(long) floor(x)-1L;
       geometry.y=(long) floor(y)-1L;
-      excert_image=ExcerptImage(resample_filter->image,&geometry,
+      excerpt_image=ExcerptImage(resample_filter->image,&geometry,
         resample_filter->exception);
-      if (excert_image == (Image *) NULL)
+      if (excerpt_image == (Image *) NULL)
         break;
-      filter_image=ResizeImage(excert_image,1,1,resample_filter->image->filter,
+      filter_image=ResizeImage(excerpt_image,1,1,resample_filter->image->filter,
         resample_filter->image->blur,resample_filter->exception);
-      excert_image=DestroyImage(excert_image);
+      excerpt_image=DestroyImage(excerpt_image);
       if (filter_image == (Image *) NULL)
         break;
-      p=AcquireImagePixels(filter_image,0,0,1,1,resample_filter->exception);
-      if (p == (const PixelPacket *) NULL)
+      filter_view=AcquireCacheView(filter_image);
+      p=AcquireCacheViewPixels(filter_view,0,0,1,1,resample_filter->exception);
+      if (p != (const PixelPacket *) NULL)
         {
-          filter_image=DestroyImage(filter_image);
-          break;
+          indexes=AcquireIndexes(filter_image);
+          GetMagickPixelPacket(resample_filter->image,pixels);
+          SetMagickPixelPacket(resample_filter->image,p,indexes,&pixel);
         }
-      indexes=AcquireIndexes(filter_image);
-      GetMagickPixelPacket(resample_filter->image,pixels);
-      SetMagickPixelPacket(resample_filter->image,p,indexes,&pixel);
+      filter_view=DestroyCacheView(filter_view);
       filter_image=DestroyImage(filter_image);
       break;
     }
@@ -804,7 +807,7 @@ static MagickPixelPacket InterpolateResampleFilter(
 %
 %  A description of each parameter follows:
 %
-%    o resample_filter: The Resampling Information Structure
+%    o resample_filter: the Resampling Information Structure
 %
 %    o u0,v0: A double representing the center of the area to resample,
 %             The distortion transformed transformed x,y coordinate.
@@ -925,6 +928,9 @@ MagickExport MagickPixelPacket ResamplePixelColor(
           Image
             *average_image;
 
+          ViewInfo
+            *average_view;
+
           GetMagickPixelPacket(resample_filter->image,
                 (MagickPixelPacket *)&(resample_filter->average_pixel));
           resample_filter->average_defined = MagickTrue;
@@ -934,15 +940,18 @@ MagickExport MagickPixelPacket ResamplePixelColor(
            resample_filter->exception);
           if (average_image == (Image *) NULL)
             return(resample_filter->average_pixel);
-          pixels=(PixelPacket *)AcquireImagePixels(average_image,0,0,1,1,
+          average_view=AcquireCacheView(average_image);
+          pixels=(PixelPacket *)AcquireCacheViewPixels(average_view,0,0,1,1,
             resample_filter->exception);
           if (pixels == (const PixelPacket *) NULL) {
+            average_view=DestroyCacheView(average_view);
             average_image=DestroyImage(average_image);
             return(resample_filter->average_pixel);
           }
           indexes=(IndexPacket *) GetIndexes(average_image);
           SetMagickPixelPacket(resample_filter->image,pixels,indexes,
             &(resample_filter->average_pixel));
+          average_view=DestroyCacheView(average_view);
           average_image=DestroyImage(average_image);
         }
         pixel = resample_filter->average_pixel;
@@ -1080,7 +1089,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
 %
 %  A description of each parameter follows:
 %
-%    o resample_filter: The resampling resample_filterrmation defining the
+%    o resample_filter: the resampling resample_filterrmation defining the
 %      image being resampled
 %
 %    o dux,duy,dvx,dvy:
@@ -1103,8 +1112,6 @@ MagickExport void ScaleResampleFilter(ResampleFilter *resample_filter,
   resample_filter->limit_reached = MagickFalse;
   resample_filter->do_interpolate = MagickFalse;
 
-//printf("dux = %.5lf;  dvx = %.5lf;    duy = %.5lf;  dvy = %.5lf\n",dux,dvx,duy,dvy);
-
   /* A 'point' filter forces use of interpolation instead of area sampling */
   if ( resample_filter->filter == PointFilter ) {
     resample_filter->do_interpolate = MagickTrue;
@@ -1371,9 +1378,9 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
 %
 %  A description of each parameter follows:
 %
-%    o resample_filter: The resample filter.
+%    o resample_filter: the resample filter.
 %
-%    o method: The interpolation method.
+%    o method: the interpolation method.
 %
 */
 MagickExport MagickBooleanType SetResampleFilterInterpolateMethod(
@@ -1410,9 +1417,9 @@ MagickExport MagickBooleanType SetResampleFilterInterpolateMethod(
 %
 %  A description of each parameter follows:
 %
-%    o resample_filter: The resample filter.
+%    o resample_filter: the resample filter.
 %
-%    o method: The virtual pixel method.
+%    o method: the virtual pixel method.
 %
 */
 MagickExport MagickBooleanType SetResampleFilterVirtualPixelMethod(
