@@ -17,7 +17,7 @@
 %                               September 2002                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -40,6 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/configure.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/hashmap.h"
@@ -48,23 +49,15 @@
 #include "magick/memory_.h"
 #include "magick/option.h"
 #include "magick/random_.h"
+#include "magick/registry.h"
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/string_.h"
 #include "magick/splay-tree.h"
 #include "magick/token.h"
 #include "magick/utility.h"
 
-/*
-  Define  declarations.
-*/
-#define ResourceInfinity  (~0UL)
-#define BytesToMegabytes(value) ((unsigned long) ((value)/1024/1024))
-#define BytesToGigabytes(value) ((unsigned long) ((value)/1024/1024/1024))
-#define GigabytesToBytes(value) ((MagickSizeType) (value)*1024*1024*1024)
-#define MegabytesToBytes(value) ((MagickSizeType) (value)*1024*1024)
-
 /*
   Typedef declarations.
 */
@@ -77,7 +70,7 @@ typedef struct _ResourceInfo
     disk,
     file;
 
-  unsigned long
+  MagickSizeType
     area_limit,
     memory_limit,
     map_limit,
@@ -88,9 +81,23 @@ typedef struct _ResourceInfo
 /*
   Global declarations.
 */
+static RandomInfo
+  *random_info = (RandomInfo *) NULL;
+
 static ResourceInfo
   resource_info =
-    { 0, 0, 0, 0, 0, 2048, 1536, 8192, ResourceInfinity, 768 };
+  {
+    MagickULLConstant(0),
+    MagickULLConstant(0),
+    MagickULLConstant(0),
+    MagickULLConstant(0),
+    MagickULLConstant(0),
+    MagickULLConstant(2048)*1024*1024,
+    MagickULLConstant(1536)*1024*1024,
+    MagickULLConstant(8192)*1024*1024,
+    MagickResourceInfinity,
+    MagickULLConstant(768)
+  };
 
 static SemaphoreInfo
   *resource_semaphore = (SemaphoreInfo *) NULL;
@@ -120,10 +127,9 @@ static SplayTreeInfo
 %
 %  A description of each parameter follows:
 %
-%    o type: The type of resource.
-%
-%    o size: The number of bytes needed from for this resource.
+%    o type: the type of resource.
 %
+%    o size: the number of bytes needed from for this resource.
 %
 */
 MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
@@ -148,59 +154,57 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
     case AreaResource:
     {
       resource_info.area=(MagickOffsetType) size;
-      limit=MegabytesToBytes(resource_info.area_limit);
-      status=(resource_info.area_limit == ResourceInfinity) || (size < limit) ?
-        MagickTrue : MagickFalse;
+      limit=resource_info.area_limit;
+      status=(resource_info.area_limit == MagickResourceInfinity) ||
+        (size < limit) ? MagickTrue : MagickFalse;
       (void) FormatMagickSize((MagickSizeType) resource_info.area,
         resource_current);
-      (void) FormatMagickSize(MegabytesToBytes(resource_info.area_limit),
-        resource_limit);
+      (void) FormatMagickSize(resource_info.area_limit,resource_limit);
       break;
     }
     case MemoryResource:
     {
       resource_info.memory+=size;
-      limit=MegabytesToBytes(resource_info.memory_limit);
-      status=(resource_info.memory_limit == ResourceInfinity) ||
+      limit=resource_info.memory_limit;
+      status=(resource_info.memory_limit == MagickResourceInfinity) ||
         ((MagickSizeType) resource_info.memory < limit) ?
         MagickTrue : MagickFalse;
       (void) FormatMagickSize((MagickSizeType) resource_info.memory,
         resource_current);
-      (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
+      (void) FormatMagickSize(resource_info.memory_limit,
         resource_limit);
       break;
     }
     case MapResource:
     {
       resource_info.map+=size;
-      limit=MegabytesToBytes(resource_info.map_limit);
-      status=(resource_info.map_limit == ResourceInfinity) ||
+      limit=resource_info.map_limit;
+      status=(resource_info.map_limit == MagickResourceInfinity) ||
         ((MagickSizeType) resource_info.map < limit) ?
         MagickTrue : MagickFalse;
       (void) FormatMagickSize((MagickSizeType) resource_info.map,
         resource_current);
-      (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),
+      (void) FormatMagickSize(resource_info.map_limit,
         resource_limit);
       break;
     }
     case DiskResource:
     {
       resource_info.disk+=size;
-      limit=GigabytesToBytes(resource_info.disk_limit);
-      status=(resource_info.disk_limit == ResourceInfinity) ||
+      limit=resource_info.disk_limit;
+      status=(resource_info.disk_limit == MagickResourceInfinity) ||
         ((MagickSizeType) resource_info.disk < limit) ?
         MagickTrue : MagickFalse;
       (void) FormatMagickSize((MagickSizeType) resource_info.disk,
         resource_current);
-      (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
-        resource_limit);
+      (void) FormatMagickSize(resource_info.disk_limit,resource_limit);
       break;
     }
     case FileResource:
     {
       resource_info.file+=size;
       limit=resource_info.file_limit;
-      status=(resource_info.file_limit == ResourceInfinity) ||
+      status=(resource_info.file_limit == MagickResourceInfinity) ||
         ((MagickSizeType) resource_info.file < limit) ?
         MagickTrue : MagickFalse;
       (void) FormatMagickSize((MagickSizeType) resource_info.file,
@@ -238,7 +242,6 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
 %
 %      DestroyMagickResources(void)
 %
-%
 */
 MagickExport void AsynchronousDestroyMagickResources(void)
 {
@@ -282,7 +285,6 @@ MagickExport void AsynchronousDestroyMagickResources(void)
 %   o  path:  Specifies a pointer to an array of characters.  The unique path
 %      name is returned in this array.
 %
-%
 */
 
 static void *DestroyTemporaryResources(void *temporary_resource)
@@ -306,7 +308,21 @@ static MagickBooleanType GetPathTemplate(char *path)
     file_info;
 
   (void) CopyMagickString(path,"magick-XXXXXXXX",MaxTextExtent);
-  directory=GetEnvironmentValue("MAGICK_TMPDIR");
+  directory=GetEnvironmentValue("MAGICK_TEMPORARY_PATH");
+  if (directory == (char *) NULL)
+    directory=GetConfigureOption("MAGICK_TEMPORARY_PATH");
+  if (directory == (char *) NULL)
+    {
+      ExceptionInfo
+        *exception;
+
+      exception=AcquireExceptionInfo();
+      directory=(char *) GetImageRegistry(StringRegistryType,"temporary-path",
+        exception);
+      exception=DestroyExceptionInfo(exception);
+    }
+  if (directory == (char *) NULL)
+    directory=GetEnvironmentValue("MAGICK_TMPDIR");
   if (directory == (char *) NULL)
     directory=GetEnvironmentValue("TMPDIR");
 #if defined(__WINDOWS__)
@@ -373,13 +389,18 @@ MagickExport int AcquireUniqueFileResource(char *path)
 
   static const char
     portable_filename[65] =
-      "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789._";
+      "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_-";
+
+  StringInfo
+    *key;
 
   unsigned char
-    key[8];
+    *datum;
 
   assert(path != (char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  (void) LogMagickEvent(ResourceEvent,GetMagickModule(),"%s",path);
+  if (random_info == (RandomInfo *) NULL)
+    random_info=AcquireRandomInfo();
   file=(-1);
   for (i=0; i < TMP_MAX; i++)
   {
@@ -387,18 +408,20 @@ MagickExport int AcquireUniqueFileResource(char *path)
       Get temporary pathname.
     */
     (void) GetPathTemplate(path);
-#if defined(HAVE_MKSTEMP)
+#if defined(MAGICKCORE_HAVE_MKSTEMP)
     file=mkstemp(path);
     if (file != -1)
       break;
 #endif
-    GetRandomKey(key,8);
+    key=GetRandomKey(random_info,8);
     p=path+strlen(path)-8;
+    datum=GetStringInfoDatum(key);
     for (i=0; i < 8; i++)
     {
-      c=(int) (key[i] & 0x3f);
+      c=(int) (datum[i] & 0x3f);
       *p++=portable_filename[c];
     }
+    key=DestroyStringInfo(key);
     file=open(path,O_RDWR | O_CREAT | O_EXCL | O_BINARY | O_NOFOLLOW,S_MODE);
     if ((file > 0) || (errno != EEXIST))
       break;
@@ -433,15 +456,16 @@ MagickExport int AcquireUniqueFileResource(char *path)
 %
 %      DestroyMagickResources(void)
 %
-%
 */
 MagickExport void DestroyMagickResources(void)
 {
   AcquireSemaphoreInfo(&resource_semaphore);
   if (temporary_resources != (SplayTreeInfo *) NULL)
     temporary_resources=DestroySplayTree(temporary_resources);
+  if (random_info != (RandomInfo *) NULL)
+    random_info=DestroyRandomInfo(random_info);
   RelinquishSemaphoreInfo(resource_semaphore);
-  resource_semaphore=DestroySemaphoreInfo(resource_semaphore);
+  DestroySemaphoreInfo(&resource_semaphore);
 }
 
 /*
@@ -455,21 +479,20 @@ MagickExport void DestroyMagickResources(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetMagickResource() returns the the specified resource in megabytes.
+%  GetMagickResource() returns the the specified resource.
 %
 %  The format of the GetMagickResource() method is:
 %
-%      unsigned long GetMagickResource(const ResourceType type)
+%      MagickSizeType GetMagickResource(const ResourceType type)
 %
 %  A description of each parameter follows:
 %
-%    o type: The type of resource.
-%
+%    o type: the type of resource.
 %
 */
-MagickExport unsigned long GetMagickResource(const ResourceType type)
+MagickExport MagickSizeType GetMagickResource(const ResourceType type)
 {
-  unsigned long
+  MagickSizeType
     resource;
 
   resource=0;
@@ -478,27 +501,27 @@ MagickExport unsigned long GetMagickResource(const ResourceType type)
   {
     case AreaResource:
     {
-      resource=BytesToMegabytes(resource_info.area);
+      resource=(MagickSizeType) resource_info.area;
       break;
     }
     case MemoryResource:
     {
-      resource=BytesToMegabytes(resource_info.memory);
+      resource=(MagickSizeType) resource_info.memory;
       break;
     }
     case MapResource:
     {
-      resource=BytesToMegabytes(resource_info.map);
+      resource=(MagickSizeType) resource_info.map;
       break;
     }
     case DiskResource:
     {
-      resource=BytesToGigabytes(resource_info.disk);
+      resource=(MagickSizeType) resource_info.disk;
       break;
     }
     case FileResource:
     {
-      resource=(unsigned long) resource_info.file;
+      resource=(MagickSizeType) resource_info.file;
       break;
     }
     default:
@@ -519,7 +542,7 @@ MagickExport unsigned long GetMagickResource(const ResourceType type)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetMagickResource() returns the the specified resource limit in megabytes.
+%  GetMagickResource() returns the the specified resource limit.
 %
 %  The format of the GetMagickResourceLimit() method is:
 %
@@ -527,12 +550,12 @@ MagickExport unsigned long GetMagickResource(const ResourceType type)
 %
 %  A description of each parameter follows:
 %
-%    o type: The type of resource.
+%    o type: the type of resource.
 %
 */
-MagickExport unsigned long GetMagickResourceLimit(const ResourceType type)
+MagickExport MagickSizeType GetMagickResourceLimit(const ResourceType type)
 {
-  unsigned long
+  MagickSizeType
     resource;
 
   resource=0;
@@ -588,10 +611,10 @@ MagickExport unsigned long GetMagickResourceLimit(const ResourceType type)
 %
 %      InitializeMagickResources(void)
 %
-%
 */
 
-static inline long MagickMax(const long x,const long y)
+static inline unsigned long MagickMax(const unsigned long x,
+  const unsigned long y)
 {
   if (x > y)
     return(x);
@@ -608,69 +631,89 @@ MagickExport void InitializeMagickResources(void)
     pages,
     pagesize;
 
-  unsigned long
+  MagickSizeType
     memory;
 
   /*
     Set Magick resource limits.
   */
   pagesize=(-1);
-#if defined(HAVE_SYSCONF) && defined(_SC_PAGESIZE)
+#if defined(MAGICKCORE_HAVE_SYSCONF) && defined(_SC_PAGESIZE)
   pagesize=sysconf(_SC_PAGESIZE);
-#elif defined(HAVE_GETPAGESIZE) && defined(POSIX)
+#elif defined(MAGICKCORE_HAVE_GETPAGESIZE) && defined(MAGICKCORE_POSIX_SUPPORT)
   pagesize=getpagesize();
 #endif
-  if (pagesize <= 0)
-    pagesize=4096;
   pages=(-1);
-#if defined(HAVE_SYSCONF) && defined(_SC_PHYS_PAGES)
+#if defined(MAGICKCORE_HAVE_SYSCONF) && defined(_SC_PHYS_PAGES)
   pages=sysconf(_SC_PHYS_PAGES);
 #endif
-  if (pages <= 0)
-    pages=62500;
-  memory=(unsigned long) ((pages+512)/1024)*((pagesize+512)/1024);
+  memory=(MagickSizeType) pages*pagesize;
+  if ((pagesize <= 0) || (pages <= 0))
+    memory=2048UL*1024UL*1024UL;
 #if defined(PixelCacheThreshold)
   memory=PixelCacheThreshold;
 #endif
-  (void) SetMagickResourceLimit(AreaResource,2*memory);
-  (void) SetMagickResourceLimit(MemoryResource,3*memory/2);
-  (void) SetMagickResourceLimit(MapResource,8*memory);
+  (void) SetMagickResourceLimit(AreaResource,2UL*memory);
+  (void) SetMagickResourceLimit(MemoryResource,3UL*memory/2UL);
+  (void) SetMagickResourceLimit(MapResource,4UL*memory);
   limit=GetEnvironmentValue("MAGICK_AREA_LIMIT");
+  if (limit == (char *) NULL)
+    limit=GetConfigureOption("MAGICK_AREA_LIMIT");
   if (limit != (char *) NULL)
     {
-      (void) SetMagickResourceLimit(AreaResource,(unsigned long) atol(limit));
+      (void) SetMagickResourceLimit(AreaResource,(MagickSizeType)
+        StringToDouble(limit,100.0));
       limit=DestroyString(limit);
     }
   limit=GetEnvironmentValue("MAGICK_MEMORY_LIMIT");
+  if (limit == (char *) NULL)
+    limit=GetConfigureOption("MAGICK_MEMORY_LIMIT");
   if (limit != (char *) NULL)
     {
-      (void) SetMagickResourceLimit(MemoryResource,(unsigned long) atol(limit));
+      (void) SetMagickResourceLimit(MemoryResource,(MagickSizeType)
+        StringToDouble(limit,100.0));
       limit=DestroyString(limit);
     }
   limit=GetEnvironmentValue("MAGICK_MAP_LIMIT");
+  if (limit == (char *) NULL)
+    limit=GetConfigureOption("MAGICK_MAP_LIMIT");
   if (limit != (char *) NULL)
     {
-      (void) SetMagickResourceLimit(MapResource,(unsigned long) atol(limit));
+      (void) SetMagickResourceLimit(MapResource,(MagickSizeType)
+        StringToDouble(limit,100.0));
       limit=DestroyString(limit);
     }
   limit=GetEnvironmentValue("MAGICK_DISK_LIMIT");
+  if (limit == (char *) NULL)
+    limit=GetConfigureOption("MAGICK_DISK_LIMIT");
   if (limit != (char *) NULL)
     {
-      (void) SetMagickResourceLimit(DiskResource,(unsigned long) atol(limit));
+      (void) SetMagickResourceLimit(DiskResource,(MagickSizeType)
+        StringToDouble(limit,100.0));
       limit=DestroyString(limit);
     }
   files=(-1);
-#if defined(HAVE_SYSCONF) && defined(_SC_OPEN_MAX)
+#if defined(MAGICKCORE_HAVE_SYSCONF) && defined(_SC_OPEN_MAX)
   files=sysconf(_SC_OPEN_MAX);
-#elif defined(HAVE_GETDTABLESIZE) && defined(POSIX)
+#elif defined(MAGICKCORE_HAVE_GETDTABLESIZE) && defined(MAGICKCORE_POSIX_SUPPORT)
   files=getdtablesize();
 #endif
-  (void) SetMagickResourceLimit(FileResource,(unsigned long)
-    MagickMax(3L*files/4L,64L));
+  (void) SetMagickResourceLimit(FileResource,MagickMax(3UL*files/4UL,64UL));
   limit=GetEnvironmentValue("MAGICK_FILE_LIMIT");
+  if (limit == (char *) NULL)
+    limit=GetConfigureOption("MAGICK_FILE_LIMIT");
   if (limit != (char *) NULL)
     {
-      (void) SetMagickResourceLimit(FileResource,(unsigned long) atol(limit));
+      (void) SetMagickResourceLimit(FileResource,(MagickSizeType)
+        StringToDouble(limit,100.0));
+      limit=DestroyString(limit);
+    }
+  limit=GetEnvironmentValue("MAGICK_THREAD_LIMIT");
+  if (limit == (char *) NULL)
+    limit=GetConfigureOption("MAGICK_THREAD_LIMIT");
+  if (limit != (char *) NULL)
+    {
+      SetCacheViewMaximumThreads((unsigned long) atol(limit));
       limit=DestroyString(limit);
     }
 }
@@ -699,7 +742,6 @@ MagickExport void InitializeMagickResources(void)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   ExceptionInfo *magick_unused(exception))
@@ -713,17 +755,14 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   if (file == (const FILE *) NULL)
     file=stdout;
   AcquireSemaphoreInfo(&resource_semaphore);
-  (void) FormatMagickSize(MegabytesToBytes(resource_info.area_limit),
-    area_limit);
-  (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
-    disk_limit);
-  (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),map_limit);
-  (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
-    memory_limit);
+  (void) FormatMagickSize(resource_info.area_limit,area_limit);
+  (void) FormatMagickSize(resource_info.disk_limit,disk_limit);
+  (void) FormatMagickSize(resource_info.map_limit,map_limit);
+  (void) FormatMagickSize(resource_info.memory_limit,memory_limit);
   (void) fprintf(file,"File       Area     Memory        Map       Disk\n");
   (void) fprintf(file,"------------------------------------------------\n");
-  (void) fprintf(file,"%4lu  %9s  %9s  %9s  %9s\n",resource_info.file_limit,
-    area_limit,memory_limit,map_limit,disk_limit);
+  (void) fprintf(file,"%4lu  %9s  %9s  %9s  %9s\n",(unsigned long)
+    resource_info.file_limit,area_limit,memory_limit,map_limit,disk_limit);
   (void) fflush(file);
   RelinquishSemaphoreInfo(resource_semaphore);
   return(MagickTrue);
@@ -749,10 +788,9 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
 %
 %  A description of each parameter follows:
 %
-%    o type: The type of resource.
-%
-%    o size: The size of the resource.
+%    o type: the type of resource.
 %
+%    o size: the size of the resource.
 %
 */
 MagickExport void RelinquishMagickResource(const ResourceType type,
@@ -772,8 +810,7 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
       resource_info.area=(MagickOffsetType) size;
       (void) FormatMagickSize((MagickSizeType) resource_info.area,
         resource_current);
-      (void) FormatMagickSize(MegabytesToBytes(resource_info.area_limit),
-        resource_limit);
+      (void) FormatMagickSize(resource_info.area_limit,resource_limit);
       break;
     }
     case MemoryResource:
@@ -781,8 +818,7 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
       resource_info.memory-=size;
       (void) FormatMagickSize((MagickSizeType) resource_info.memory,
         resource_current);
-      (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
-        resource_limit);
+      (void) FormatMagickSize(resource_info.memory_limit,resource_limit);
       break;
     }
     case MapResource:
@@ -790,8 +826,7 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
       resource_info.map-=size;
       (void) FormatMagickSize((MagickSizeType) resource_info.map,
         resource_current);
-      (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),
-        resource_limit);
+      (void) FormatMagickSize(resource_info.map_limit,resource_limit);
       break;
     }
     case DiskResource:
@@ -799,8 +834,7 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
       resource_info.disk-=size;
       (void) FormatMagickSize((MagickSizeType) resource_info.disk,
         resource_current);
-      (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
-        resource_limit);
+      (void) FormatMagickSize(resource_info.disk_limit,resource_limit);
       break;
     }
     case FileResource:
@@ -842,7 +876,6 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
 %
 %    o name: the name of the temporary resource.
 %
-%
 */
 MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
 {
@@ -865,7 +898,7 @@ MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
         p=(char *) GetNextKeyInSplayTree(temporary_resources);
       }
       if (p != (char *) NULL)
-        (void) RemoveNodeFromSplayTree(temporary_resources,p);
+        (void) DeleteNodeFromSplayTree(temporary_resources,p);
     }
   (void) CopyMagickString(cache_path,path,MaxTextExtent);
   AppendImageFormat("cache",cache_path);
@@ -884,24 +917,22 @@ MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  SetMagickResourceLimit() sets the limit for a particular resource in
-%  megabytes.
+%  SetMagickResourceLimit() sets the limit for a particular resource.
 %
 %  The format of the SetMagickResourceLimit() method is:
 %
 %      MagickBooleanType SetMagickResourceLimit(const ResourceType type,
-%        const unsigned long limit)
+%        const MagickSizeType limit)
 %
 %  A description of each parameter follows:
 %
-%    o type: The type of resource.
-%
-%    o limit: The maximum limit for the resource.
+%    o type: the type of resource.
 %
+%    o limit: the maximum limit for the resource.
 %
 */
 MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
-  const unsigned long limit)
+  const MagickSizeType limit)
 {
   AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
