@@ -17,7 +17,7 @@
 %                                April 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -93,6 +93,7 @@
 #include "magick/monitor.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/segment.h"
 #include "magick/string_.h"
 
@@ -216,7 +217,7 @@ static void
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o extrema:  Specifies a pointer to an array of integers.  They
 %      represent the peaks and valleys of the histogram for each color
@@ -490,7 +491,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
   /*
     Allocate image colormap.
   */
-  if (AllocateImageColormap(image,number_clusters) == MagickFalse)
+  if (AcquireImageColormap(image,number_clusters) == MagickFalse)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
   cluster=head;
@@ -595,7 +596,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
       }
   }
   /*
-    Free resources.
+    Relinquish resources.
   */
   for (cluster=head; cluster != (Cluster *) NULL; cluster=next_cluster)
   {
@@ -872,7 +873,7 @@ static void DerivativeHistogram(const MagickRealType *histogram,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o cluster_threshold:  This MagickRealType represents the minimum number of
 %      pixels contained in a hexahedra before it can be considered valid
@@ -1140,7 +1141,7 @@ MagickExport MagickPixelPacket GetImageDynamicThreshold(const Image *image,
   pixel.blue=(MagickRealType) ScaleCharToQuantum((unsigned char)
     (threshold+0.5));
   /*
-    Free resources.
+    Relinquish resources.
   */
   for (cluster=head; cluster != (Cluster *) NULL; cluster=next_cluster)
   {
@@ -1625,7 +1626,7 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
     average_tau+=list[i]->tau;
   average_tau/=(MagickRealType) number_nodes;
   /*
-    Free resources.
+    Relinquish resources.
   */
   FreeNodes(root);
   zero_crossing=(ZeroCrossing *) RelinquishMagickMemory(zero_crossing);
@@ -1718,7 +1719,7 @@ static void ScaleSpace(const long *histogram,const MagickRealType tau,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o colorspace: Indicate the colorspace.
 %
@@ -1791,7 +1792,7 @@ MagickExport MagickBooleanType SegmentImage(Image *image,
   if (colorspace != RGBColorspace)
     (void) SetImageColorspace(image,colorspace);
   /*
-    Free resources.
+    Relinquish resources.
   */
   for (i=0; i < MaxDimension; i++)
   {
