@@ -17,7 +17,7 @@
 %                                  July 1992                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -86,9 +86,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o affine_matrix: The affine matrix.
+%    o affine_matrix: the affine matrix.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -207,7 +207,7 @@ MagickExport Image *AffineTransformImage(const Image *image,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o x_shear, y_shear, width, height: Defines a region of the image to crop.
 %
@@ -305,7 +305,7 @@ static inline void CropToFitImage(Image **image,const MagickRealType x_shear,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o rotations: Specifies the number of 90 degree rotations.
 %
@@ -384,15 +384,14 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
         q=SetImagePixels(rotate_image,0,y,rotate_image->columns,1);
         if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
           break;
+        (void) CopyMagickMemory(q,p,image->columns*sizeof(*p));
         indexes=GetIndexes(image);
-        rotate_indexes=GetIndexes(rotate_image);
-        for (x=0; x < (long) image->columns; x++)
-        {
-          SetMagickPixelPacket(image,p,indexes+x,&pixel);
-          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
-          p++;
-          q++;
-        }
+        if (indexes != (IndexPacket *) NULL)
+          {
+            rotate_indexes=GetIndexes(rotate_image);
+            (void) CopyMagickMemory(rotate_indexes,indexes,image->columns*
+              sizeof(*indexes));
+          }
         if (SyncImagePixels(rotate_image) == MagickFalse)
           break;
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -431,17 +430,23 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
               tile_height),tile_x+y,tile_height,1);
             if (q == (PixelPacket *) NULL)
               break;
-            rotate_indexes=GetIndexes(rotate_image);
             p=tile_pixels+(tile_height-1)*tile_width+y;
-            indexes=GetIndexes(image)+(tile_height-1)*tile_width+y;
             for (x=0; x < (long) tile_height; x++)
             {
-              SetMagickPixelPacket(image,p,indexes,&pixel);
-              SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
+              *q++=(*p);
               p-=tile_width;
-              indexes-=tile_width;
-              q++;
             }
+            indexes=GetIndexes(image);
+            if (indexes != (IndexPacket *) NULL)
+              {
+                rotate_indexes=GetIndexes(rotate_image);
+                indexes+=(tile_height-1)*tile_width+y;
+                for (x=0; x < (long) tile_height; x++)
+                {
+                  *rotate_indexes++=(*indexes);
+                  indexes-=tile_width;
+                }
+              }
             if (SyncImagePixels(rotate_image) == MagickFalse)
               break;
           }
@@ -474,16 +479,15 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
         if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
           break;
         q+=image->columns;
-        indexes=GetIndexes(image);
-        rotate_indexes=GetIndexes(rotate_image);
         for (x=0; x < (long) image->columns; x++)
-        {
-          q--;
-          SetMagickPixelPacket(image,p,indexes+x,&pixel);
-          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+(image->columns-
-            x-1));
-          p++;
-        }
+          *--q=(*p++);
+        indexes=GetIndexes(image);
+        if (indexes != (IndexPacket *) NULL)
+          {
+            rotate_indexes=GetIndexes(rotate_image);
+            for (x=0; x < (long) image->columns; x++)
+              rotate_indexes[image->columns-x-1]=indexes[x];
+          }
         if (SyncImagePixels(rotate_image) == MagickFalse)
           break;
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -504,31 +508,53 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
     case 3:
     {
       /*
-        Rotate 90 degrees.
+        Rotate 270 degrees.
       */
-      for (y=0; y < (long) image->rows; y++)
+      for (tile_y=0; tile_y < (long) image->rows; tile_y+=TileHeight)
       {
-        p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-        q=SetImagePixels(rotate_image,y,0,1,rotate_image->rows);
-        if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-          break;
-        q+=image->columns;
-        indexes=GetIndexes(image);
-        rotate_indexes=GetIndexes(rotate_image);
-        for (x=0; x < (long) image->columns; x++)
+        for (tile_x=0; tile_x < (long) image->columns; tile_x+=TileWidth)
         {
-          q--;
-          SetMagickPixelPacket(image,p,indexes+x,&pixel);
-          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+(image->columns-
-            x-1));
-          p++;
-        }
-        if (SyncImagePixels(rotate_image) == MagickFalse)
-          break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
+          tile_width=TileWidth;
+          if ((tile_x+TileWidth) > (long) image->columns)
+            tile_width=1UL*(TileWidth-(tile_x+TileWidth-image->columns));
+          tile_height=TileHeight;
+          if ((tile_y+TileHeight) > (long) image->rows)
+            tile_height=1UL*(TileHeight-(tile_y+TileHeight-image->rows));
+          tile_pixels=AcquireImagePixels(image,tile_x,tile_y,tile_width,
+            tile_height,exception);
+          if (tile_pixels == (const PixelPacket *) NULL)
+            break;
+          for (y=0; y < (long) tile_width; y++)
           {
-            status=image->progress_monitor(RotateImageTag,y,image->rows,
+            q=SetImagePixels(rotate_image,tile_y,(long) rotate_image->rows-
+              (tile_x+tile_width)+y,tile_height,1);
+            if (q == (PixelPacket *) NULL)
+              break;
+            p=tile_pixels+(tile_width-1)-y;
+            for (x=0; x < (long) tile_height; x++)
+            {
+              *q++=(*p);
+              p+=tile_width;
+            }
+            indexes=GetIndexes(image);
+            if (indexes != (IndexPacket *) NULL)
+              {
+                rotate_indexes=GetIndexes(rotate_image);
+                indexes+=(tile_width-1)-y;
+                for (x=0; x < (long) tile_height; x++)
+                {
+                  *rotate_indexes++=(*indexes);
+                  indexes+=tile_width;
+                }
+              }
+            if (SyncImagePixels(rotate_image) == MagickFalse)
+              break;
+          }
+        }
+        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+            (QuantumTick(tile_y,image->rows) != MagickFalse))
+          {
+            status=image->progress_monitor(RotateImageTag,tile_y,image->rows,
               image->client_data);
             if (status == MagickFalse)
               break;
@@ -541,6 +567,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
       break;
     }
   }
+  rotate_image->type=image->type;
   rotate_image->page=page;
   return(rotate_image);
 }
@@ -570,7 +597,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o degrees: A MagickRealType representing the shearing angle along the X
 %      axis.
@@ -606,21 +633,21 @@ static inline void MagickCompositeBlend(const MagickPixelPacket *p,
   gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
   composite->red=gamma*Blend_((MagickRealType) p->red,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-    (MagickRealType) q->red,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta));
+    (MagickRealType) q->red,(MagickRealType) (QuantumRange-area*(QuantumRange-
+    beta)));
   composite->green=gamma*Blend_((MagickRealType) p->green,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-    (MagickRealType) q->green,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta));
+    (MagickRealType) q->green,(MagickRealType) (QuantumRange-area*(QuantumRange-
+    beta)));
   composite->blue=gamma*Blend_((MagickRealType) p->blue,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-    (MagickRealType) q->blue,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta));
+    (MagickRealType) q->blue,(MagickRealType) (QuantumRange-area*(QuantumRange-
+    beta)));
   if (q->colorspace == CMYKColorspace)
     composite->index=gamma*Blend_((MagickRealType) p->index,
       (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
-      (MagickRealType) q->index,(MagickRealType) QuantumRange-area*
-      (QuantumRange-beta));
+      (MagickRealType) q->index,(MagickRealType) (QuantumRange-area*
+      (QuantumRange-beta)));
 }
 
 static void XShearImage(Image *image,const MagickRealType degrees,
@@ -801,7 +828,7 @@ static void XShearImage(Image *image,const MagickRealType degrees,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o degrees: A MagickRealType representing the shearing angle along the Y
 %      axis.
@@ -992,7 +1019,7 @@ static void YShearImage(Image *image,const MagickRealType degrees,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o degrees: Specifies the number of degrees to rotate the image.
 %
@@ -1132,13 +1159,12 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
 %
 %  A description of each parameter follows.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o x_shear, y_shear: Specifies the number of degrees to shear the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ShearImage(const Image *image,const double x_shear,
   const double y_shear,ExceptionInfo *exception)
