@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -47,6 +47,7 @@
 #include "magick/blob-private.h"
 #include "magick/cache.h"
 #include "magick/cache-private.h"
+#include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
@@ -79,7 +80,7 @@
 #include "magick/random_.h"
 #include "magick/segment.h"
 #include "magick/semaphore.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/timer.h"
@@ -109,7 +110,7 @@
 %    o bounds: Method GetImageBoundingBox returns the bounding box of an
 %      image canvas.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -206,14 +207,15 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
 %
 %  The format of the GetImageChannelDepth method is:
 %
+%      unsigned long GetImageDepth(const Image *image,ExceptionInfo *exception)
 %      unsigned long GetImageChannelDepth(const Image *image,
 %        const ChannelType channel,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -231,89 +233,136 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
   long
     y;
 
-  MagickStatusType
-    status;
-
-  register const IndexPacket
-    *indexes;
-
-  register const PixelPacket
-    *p;
-
   register long
-    x;
+    id;
 
   unsigned long
+    *current_depth,
     depth;
-
+    
+  ViewInfo
+    **image_view;
+  
+  /*
+    Compute image depth.
+  */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  depth=1;
+  current_depth=(unsigned long *) AcquireQuantumMemory(
+    GetCacheViewMaximumThreads(),sizeof(*current_depth));
+  if (current_depth == (unsigned long *) NULL)
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+  for (id=0; id < (long) GetCacheViewMaximumThreads(); id++)
+    current_depth[id]=1;
   if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
     {
+      register const PixelPacket
+        *p;
+
+      register long
+        i;
+
       p=image->colormap;
-      for (x=0; x < (long) image->colors; )
-      {
-        status=MagickFalse;
-        if ((channel & RedChannel) != 0)
-          status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
-            depth),depth);
-        if ((channel & GreenChannel) != 0)
-          status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
-            depth),depth);
-        if ((channel & BlueChannel) != 0)
-          status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
-            depth),depth);
-        if (status != MagickFalse)
-          {
-            depth++;
-            if (depth == QuantumDepth)
-              return(depth);
-            continue;
-          }
-        x++;
+      #pragma omp parallel for
+      for (i=0; i < (long) image->colors; i++)
+      {  
+        id=GetCacheViewThreadId();
+        while (current_depth[id] < MAGICKCORE_QUANTUM_DEPTH)
+        {
+          MagickStatusType
+            status;
+
+          QuantumAny
+            scale;
+
+          status=0;
+          scale=GetQuantumScale(current_depth[id]);
+          if ((channel & RedChannel) != 0)
+            status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
+              current_depth[id],scale),current_depth[id],scale);
+          if ((channel & GreenChannel) != 0)
+            status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
+              current_depth[id],scale),current_depth[id],scale);
+          if ((channel & BlueChannel) != 0)
+            status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
+              current_depth[id],scale),current_depth[id],scale);
+          if (status == 0)
+            break;
+          current_depth[id]++;
+        }
         p++;
       }
+      depth=current_depth[0];
+      for (id=1; id < (long) GetCacheViewMaximumThreads(); id++)
+        if (depth < current_depth[id])
+          depth=current_depth[id];
+      current_depth=(unsigned long *) RelinquishMagickMemory(current_depth);
+      return(depth);
     }
-  else
-    for (y=0; y < (long) image->rows; y++)
-    {
-      p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-      if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireIndexes(image);
-      for (x=0; x < (long) image->columns; )
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
+  for (y=0; y < (long) image->rows; y++)
+  {
+    register const IndexPacket
+      *indexes;
+
+    register const PixelPacket
+      *p;
+
+    register long
+      id,
+      x;
+
+    id=GetCacheViewThreadId();
+    p=AcquireCacheViewPixels(image_view[id],0,y,image->columns,1,exception);
+    if (p == (const PixelPacket *) NULL)
+      continue;
+    indexes=AcquireCacheViewIndexes(image_view[id]);
+    for (x=0; x < (long) image->columns; x++)
+    {  
+      while (current_depth[id] < MAGICKCORE_QUANTUM_DEPTH)
       {
-        status=MagickFalse;
+        MagickStatusType
+          status;
+
+        QuantumAny
+          scale;
+
+        status=0;
+        scale=GetQuantumScale(current_depth[id]);
         if ((channel & RedChannel) != 0)
           status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
-            depth),depth);
+            current_depth[id],scale),current_depth[id],scale);
         if ((channel & GreenChannel) != 0)
           status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
-            depth),depth);
+            current_depth[id],scale),current_depth[id],scale);
         if ((channel & BlueChannel) != 0)
           status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
-            depth),depth);
-        if ((channel & OpacityChannel) != 0)
+            current_depth[id],scale),current_depth[id],scale);
+        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
           status|=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,
-            depth),depth);
+            current_depth[id],scale),current_depth[id],scale);
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace))
           status|=indexes[x] != ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],
-            depth),depth);
-        if (status != MagickFalse)
-          {
-            depth++;
-            if (depth == QuantumDepth)
-              return(depth);
-            continue;
-          }
-        x++;
-        p++;
+            current_depth[id],scale),current_depth[id],scale);
+        if (status == 0)
+          break;
+        current_depth[id]++;
       }
+      p++;
     }
+    if (current_depth[id] == MAGICKCORE_QUANTUM_DEPTH)
+      y=(long) image->rows;
+  }
+  image_view=DestroyCacheViewThreadSet(image_view);
+  depth=current_depth[0];
+  for (id=1; id < (long) GetCacheViewMaximumThreads(); id++)
+    if (depth < current_depth[id])
+      depth=current_depth[id];
+  current_depth=(unsigned long *) RelinquishMagickMemory(current_depth);
   return(depth);
 }
 
@@ -338,13 +387,13 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
-%    o minima: The minimum value in the channel.
+%    o minima: the minimum value in the channel.
 %
-%    o maxima: The maximum value in the channel.
+%    o maxima: the maximum value in the channel.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -399,13 +448,13 @@ MagickExport MagickBooleanType GetImageChannelExtrema(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
-%    o mean: The average value in the channel.
+%    o mean: the average value in the channel.
 %
-%    o standard_deviation: The standard deviation of the channel.
+%    o standard_deviation: the standard deviation of the channel.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -524,13 +573,13 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
-%    o minima: The minimum value in the channel.
+%    o minima: the minimum value in the channel.
 %
-%    o maxima: The maximum value in the channel.
+%    o maxima: the maximum value in the channel.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -568,87 +617,54 @@ MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
   *maxima=(-1.0E-37);
   *minima=1.0E+37;
   GetMagickPixelPacket(image,&pixel);
-  y=(long) image->rows;
-  if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
+    if (p == (const PixelPacket *) NULL)
+      break;
+    indexes=AcquireIndexes(image);
+    for (x=0; x < (long) image->columns; x++)
     {
-      p=image->colormap;
-      for (x=0; x < (long) image->colors; )
-      {
-        if ((channel & RedChannel) != 0)
-          {
-            if ((double) p->red < *minima)
-              *minima=(double) p->red;
-            if ((double) p->red > *maxima)
-              *maxima=(double) p->red;
-          }
-        if ((channel & GreenChannel) != 0)
-          {
-            if ((double) p->green < *minima)
-              *minima=(double) p->green;
-            if ((double) p->green > *maxima)
-              *maxima=(double) p->green;
-          }
-        if ((channel & BlueChannel) != 0)
-          {
-            if ((double) p->blue < *minima)
-              *minima=(double) p->blue;
-            if ((double) p->blue > *maxima)
-              *maxima=(double) p->blue;
-          }
-        x++;
-        p++;
-      }
-    }
-  else
-    for (y=0; y < (long) image->rows; y++)
-    {
-      p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-      if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireIndexes(image);
-      for (x=0; x < (long) image->columns; )
-      {
-        SetMagickPixelPacket(image,p,indexes+x,&pixel);
-        if ((channel & RedChannel) != 0)
-          {
-            if (pixel.red < *minima)
-              *minima=(double) pixel.red;
-            if (pixel.red > *maxima)
-              *maxima=(double) pixel.red;
-          }
-        if ((channel & GreenChannel) != 0)
-          {
-            if (pixel.green < *minima)
-              *minima=(double) pixel.green;
-            if (pixel.green > *maxima)
-              *maxima=(double) pixel.green;
-          }
-        if ((channel & BlueChannel) != 0)
-          {
-            if (pixel.blue < *minima)
-              *minima=(double) pixel.blue;
-            if (pixel.blue > *maxima)
-              *maxima=(double) pixel.blue;
-          }
-        if ((channel & OpacityChannel) != 0)
-          {
-            if (pixel.opacity < *minima)
-              *minima=(double) pixel.opacity;
-            if (pixel.opacity > *maxima)
-              *maxima=(double) pixel.opacity;
-          }
-        if (((channel & IndexChannel) != 0) &&
-            (image->colorspace == CMYKColorspace))
-          {
-            if ((double) indexes[x] < *minima)
-              *minima=(double) indexes[x];
-            if ((double) indexes[x] > *maxima)
-              *maxima=(double) indexes[x];
-          }
-        x++;
-        p++;
-      }
+      SetMagickPixelPacket(image,p,indexes+x,&pixel);
+      if ((channel & RedChannel) != 0)
+        {
+          if (pixel.red < *minima)
+            *minima=(double) pixel.red;
+          if (pixel.red > *maxima)
+            *maxima=(double) pixel.red;
+        }
+      if ((channel & GreenChannel) != 0)
+        {
+          if (pixel.green < *minima)
+            *minima=(double) pixel.green;
+          if (pixel.green > *maxima)
+            *maxima=(double) pixel.green;
+        }
+      if ((channel & BlueChannel) != 0)
+        {
+          if (pixel.blue < *minima)
+            *minima=(double) pixel.blue;
+          if (pixel.blue > *maxima)
+            *maxima=(double) pixel.blue;
+        }
+      if ((channel & OpacityChannel) != 0)
+        {
+          if (pixel.opacity < *minima)
+            *minima=(double) pixel.opacity;
+          if (pixel.opacity > *maxima)
+            *maxima=(double) pixel.opacity;
+        }
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        {
+          if ((double) indexes[x] < *minima)
+            *minima=(double) indexes[x];
+          if ((double) indexes[x] > *maxima)
+            *maxima=(double) indexes[x];
+        }
+      p++;
     }
+  }
   return(y == (long) image->rows ? MagickTrue : MagickFalse);
 }
 
@@ -680,7 +696,7 @@ MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -715,6 +731,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   MagickStatusType
     status;
 
+  QuantumAny
+    scale;
+
   register const IndexPacket
     *indexes;
 
@@ -759,44 +778,48 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     indexes=AcquireIndexes(image);
     for (x=0; x < (long) image->columns; )
     {
-      if (channel_statistics[RedChannel].depth != QuantumDepth)
+      if (channel_statistics[RedChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[RedChannel].depth;
-          status=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
-            depth),depth) ? MagickTrue : MagickFalse;
+          scale=GetQuantumScale(depth);
+          status=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,depth,
+            scale),depth,scale) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[RedChannel].depth++;
               continue;
             }
         }
-      if (channel_statistics[GreenChannel].depth != QuantumDepth)
+      if (channel_statistics[GreenChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[GreenChannel].depth;
+          scale=GetQuantumScale(depth);
           status=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
-            depth),depth) ? MagickTrue : MagickFalse;
+            depth,scale),depth,scale) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[GreenChannel].depth++;
               continue;
             }
         }
-      if (channel_statistics[BlueChannel].depth != QuantumDepth)
+      if (channel_statistics[BlueChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[BlueChannel].depth;
+          scale=GetQuantumScale(depth);
           status=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
-            depth),depth) ? MagickTrue : MagickFalse;
+            depth,scale),depth,scale) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[BlueChannel].depth++;
               continue;
             }
         }
-      if (channel_statistics[OpacityChannel].depth != QuantumDepth)
+      if (channel_statistics[OpacityChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[OpacityChannel].depth;
-          status=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(
-            p->opacity,depth),depth) ? MagickTrue : MagickFalse;
+          scale=GetQuantumScale(depth);
+          status=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,
+            depth,scale),depth,scale) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[OpacityChannel].depth++;
@@ -805,11 +828,12 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
         }
       if (image->colorspace == CMYKColorspace)
         {
-          if (channel_statistics[BlackChannel].depth != QuantumDepth)
+          if (channel_statistics[BlackChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
             {
               depth=channel_statistics[BlackChannel].depth;
+              scale=GetQuantumScale(depth);
               status=indexes[x] != ScaleAnyToQuantum(ScaleQuantumToAny(
-                indexes[x],depth),depth) ? MagickTrue : MagickFalse;
+                indexes[x],depth,scale),depth,scale) ? MagickTrue : MagickFalse;
               if (status != MagickFalse)
                 {
                   channel_statistics[BlackChannel].depth++;
@@ -911,10 +935,10 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o constrain: A value other than MagickFalse, constrains the depth to
-%      a maximum of QuantumDepth.
+%      a maximum of MAGICKCORE_QUANTUM_DEPTH.
 %
 */
 MagickExport unsigned long GetImageQuantumDepth(const Image *image,
@@ -930,7 +954,8 @@ MagickExport unsigned long GetImageQuantumDepth(const Image *image,
     if (depth <= 16)
       depth=16;
   if (constrain != MagickFalse)
-    depth=(unsigned long) MagickMin((double) depth,(double) QuantumDepth);
+    depth=(unsigned long) MagickMin((double) depth,(double)
+      MAGICKCORE_QUANTUM_DEPTH);
   return(depth);
 }
 
@@ -949,16 +974,17 @@ MagickExport unsigned long GetImageQuantumDepth(const Image *image,
 %
 %  The format of the SetImageChannelDepth method is:
 %
+%      MagickBooleanType SetImageDepth(Image *image,const unsigned long depth)
 %      MagickBooleanType SetImageChannelDepth(Image *image,
 %        const ChannelType channel,const unsigned long depth)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel.
+%    o channel: the channel.
 %
-%    o depth: The image depth.
+%    o depth: the image depth.
 %
 */
 
@@ -974,74 +1000,110 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
   long
     y;
 
-  register IndexPacket
-    *indexes;
+  MagickBooleanType
+    status;
 
-  register long
-    x;
-
-  register PixelPacket
-    *q;
+  QuantumAny
+    scale;
 
+  ViewInfo
+    **image_view;
+  
   assert(image != (Image *) NULL);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(image->signature == MagickSignature);
-  y=(long) image->rows;
-  if (GetImageDepth(image,&image->exception) >
-      (unsigned long) MagickMin((double) depth,(double) QuantumDepth))
+  if (GetImageDepth(image,&image->exception) <= (unsigned long)
+      MagickMin((double) depth,(double) MAGICKCORE_QUANTUM_DEPTH))
     {
-      /*
-        Scale pixels to desired depth.
-      */
-      for (y=0; y < (long) image->rows; y++)
-      {
-        q=GetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
-        for (x=0; x < (long) image->columns; x++)
-        {
-          if ((channel & RedChannel) != 0)
-            q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,depth),depth);
-          if ((channel & GreenChannel) != 0)
-            q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth),depth);
-          if ((channel & BlueChannel) != 0)
-            q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth),depth);
-          if ((channel & OpacityChannel) != 0)
-            q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth),
-              depth);
-          if (((channel & IndexChannel) != 0) &&
-              (image->colorspace == CMYKColorspace))
-            indexes[x]=ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],depth),
-              depth);
-          q++;
-        }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-      }
-      if (image->storage_class == PseudoClass)
-        {
-          register long
-            i;
+      image->depth=depth;
+      return(MagickTrue);
+    }
+  /*
+    Scale pixels to desired depth.
+  */
+  status=MagickTrue;
+  scale=GetQuantumScale(depth);
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
+  for (y=0; y < (long) image->rows; y++)
+  {
+    register IndexPacket
+      *indexes;
 
-          q=image->colormap;
-          for (i=0; i < (long) image->colors; i++)
-          {
-            if ((channel & RedChannel) != 0)
-              q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,depth),depth);
-            if ((channel & GreenChannel) != 0)
-              q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth),
-                depth);
-            if ((channel & BlueChannel) != 0)
-              q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth),depth);
-            if ((channel & OpacityChannel) != 0)
-              q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth),
-                depth);
-            q++;
-        }
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
+    if (q == (PixelPacket *) NULL)
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      if ((channel & RedChannel) != 0)
+        q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,depth,scale),depth,
+          scale);
+      if ((channel & GreenChannel) != 0)
+        q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth,scale),
+          depth,scale);
+      if ((channel & BlueChannel) != 0)
+        q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth,scale),
+          depth,scale);
+      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+        q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth,scale),
+          depth,scale);
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        indexes[x]=ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],depth,scale),
+          depth,scale);
+      q++;
+    }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      {
+        status=MagickFalse;
+        continue;
+      }
+  }
+  image_view=DestroyCacheViewThreadSet(image_view);
+  if (image->storage_class == PseudoClass)
+    {
+      QuantumAny
+        scale;
+
+      register long
+        i;
+
+      register PixelPacket
+        *p;
+
+      p=image->colormap;
+      scale=GetQuantumScale(depth);
+      #pragma omp parallel for
+      for (i=0; i < (long) image->colors; i++)
+      {
+        if ((channel & RedChannel) != 0)
+          p->red=ScaleAnyToQuantum(ScaleQuantumToAny(p->red,depth,
+            scale),depth,scale);
+        if ((channel & GreenChannel) != 0)
+          p->green=ScaleAnyToQuantum(ScaleQuantumToAny(p->green,depth,
+            scale),depth,scale);
+        if ((channel & BlueChannel) != 0)
+          p->blue=ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,depth,
+            scale),depth,scale);
+        if ((channel & OpacityChannel) != 0)
+          p->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,depth,
+            scale),depth,scale);
+        p++;
       }
     }
   image->depth=depth;
-  return(y == (long) image->rows ? MagickTrue : MagickFalse);
+  return(status);
 }
