@@ -17,7 +17,7 @@
 %                                 October 1996                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -72,7 +72,7 @@
 #include "magick/resource_.h"
 #include "magick/segment.h"
 #include "magick/shear.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/string_.h"
 #include "magick/transform.h"
 #include "magick/threshold.h"
@@ -123,13 +123,13 @@ struct _ThresholdMap
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o width: The width of the local neighborhood.
+%    o width: the width of the local neighborhood.
 %
-%    o height: The height of the local neighborhood.
+%    o height: the height of the local neighborhood.
 %
-%    o offset: The mean offset.
+%    o offset: the mean offset.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -279,9 +279,9 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel type.
+%    o channel: the channel type.
 %
 %    o threshold: define the threshold values.
 %
@@ -404,7 +404,7 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o threshold: Define the threshold value.
 %
@@ -942,9 +942,9 @@ MagickExport MagickBooleanType ListThresholdMaps(FILE *file,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel or channels to be thresholded.
+%    o channel: the channel or channels to be thresholded.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -998,9 +998,9 @@ MagickExport MagickBooleanType OrderedDitherImageChannel(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel or channels to be thresholded.
+%    o channel: the channel or channels to be thresholded.
 %
 %    o threshold_map: A string containing the name of the threshold dither
 %      map to use, followed by zero or more numbers representing the number
@@ -1261,9 +1261,9 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o channel: The channel or channels to be thresholded.
+%    o channel: the channel or channels to be thresholded.
 %
 %    o thresholds: a geometry string containing low,high thresholds.  If the
 %      string contains 2x2, 3x3, or 4x4, an ordered dither of order 2, 3, or 4
@@ -1328,7 +1328,6 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
   GetMagickPixelPacket(image,&threshold);
   min_threshold=0.0;
   max_threshold=(MagickRealType) QuantumRange;
-
   flags=ParseGeometry(thresholds,&geometry_info);
   min_threshold=geometry_info.rho;
   max_threshold=geometry_info.sigma;
@@ -1339,17 +1338,16 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
       max_threshold*=(0.01f*QuantumRange);
       min_threshold*=(0.01f*QuantumRange);
     }
-  else if ( min_threshold <= 8 && (max_threshold == min_threshold ||
-              max_threshold == 1 ) )
-    {
-      /*
-        Backward Compatibility -- ordered-dither -- IM v 6.2.9-6
-        outputing a WARNING here may be appropriate -- discontinue in future
-      */
-      status=OrderedPosterizeImageChannel(image,channel,thresholds,exception);
-      return(status);
-    }
-
+  else
+    if ((min_threshold <= 8) && ((max_threshold == min_threshold) ||
+        (max_threshold == 1)))
+      {
+        /*
+          Backward Compatibility -- ordered-dither -- IM v 6.2.9-6.
+        */
+        status=OrderedPosterizeImageChannel(image,channel,thresholds,exception);
+        return(status);
+      }
   if (channel == AllChannels)
     {
       IndexPacket
@@ -1358,7 +1356,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
       MagickRealType
         intensity;
 
-      if (AllocateImageColormap(image,2) == MagickFalse)
+      if (AcquireImageColormap(image,2) == MagickFalse)
         ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
           image->filename);
       for (y=0; y < (long) image->rows; y++)
@@ -1375,9 +1373,8 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
           else if (intensity > max_threshold)
             threshold.index=max_threshold;
           else
-            threshold.index=(MagickRealType)(QuantumRange*GetRandomValue());
-
-          index=(IndexPacket) (intensity < threshold.index ? 0 : 1);
+            threshold.index=(MagickRealType)(QuantumRange*GetPseudoRandomValue());
+          index=(IndexPacket) (intensity <= threshold.index ? 0 : 1);
           indexes[x]=index;
           *q++=image->colormap[(long) index];
         }
@@ -1416,7 +1413,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               threshold.red=max_threshold;
             else
               threshold.red=(MagickRealType) (QuantumRange*
-                GetRandomValue());
+                GetPseudoRandomValue());
         }
       if ((channel & GreenChannel) != 0)
         {
@@ -1427,7 +1424,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               threshold.green=max_threshold;
             else
               threshold.green=(MagickRealType) (QuantumRange*
-                GetRandomValue());
+                GetPseudoRandomValue());
         }
       if ((channel & BlueChannel) != 0)
         {
@@ -1438,7 +1435,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               threshold.blue=max_threshold;
             else
               threshold.blue=(MagickRealType) (QuantumRange*
-                GetRandomValue());
+                GetPseudoRandomValue());
         }
       if ((channel & OpacityChannel) != 0)
         {
@@ -1449,7 +1446,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               threshold.opacity=max_threshold;
             else
               threshold.opacity=(MagickRealType) (QuantumRange*
-                GetRandomValue());
+                GetPseudoRandomValue());
         }
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
@@ -1461,7 +1458,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               threshold.index=max_threshold;
             else
               threshold.index=(MagickRealType) (QuantumRange*
-                GetRandomValue());
+                GetPseudoRandomValue());
         }
       if ((channel & RedChannel) != 0)
         q->red=(Quantum) ((MagickRealType) q->red <= threshold.red ? 0 :
@@ -1516,7 +1513,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o threshold: Define the threshold value
 %
