@@ -153,7 +153,7 @@ MagickExport void DestroyTypeList(void)
     type_list=DestroySplayTree(type_list);
   instantiate_type=MagickFalse;
   RelinquishSemaphoreInfo(type_semaphore);
-  type_semaphore=DestroySemaphoreInfo(type_semaphore);
+  DestroySemaphoreInfo(&type_semaphore);
 }
 
 /*
@@ -176,7 +176,7 @@ MagickExport void DestroyTypeList(void)
 %
 %  A description of each parameter follows:
 %
-%    o name: The type name.
+%    o name: the type name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -224,13 +224,13 @@ MagickExport const TypeInfo *GetTypeInfo(const char *name,
 %
 %  A description of each parameter follows:
 %
-%    o family: The type family.
+%    o family: the type family.
 %
-%    o style: The type style.
+%    o style: the type style.
 %
-%    o stretch: The type stretch.
+%    o stretch: the type stretch.
 %
-%    o weight: The type weight.
+%    o weight: the type weight.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -862,16 +862,10 @@ MagickExport MagickBooleanType ListTypeInfo(FILE *file,ExceptionInfo *exception)
   {
     if (type_info[i]->stealth != MagickFalse)
       continue;
-    if ((path == (const char *) NULL) ||
-        (LocaleCompare(path,type_info[i]->path) != 0))
-      {
-        if (type_info[i]->path != (char *) NULL)
-          (void) fprintf(file,"\nPath: %s\n\n",type_info[i]->path);
-        (void) fprintf(file,"%-32.32s %-22.22s %-7.7s %-8.8s  %-3s\n",
-          "Name","Family","Style","Stretch","Weight");
-        (void) fprintf(file,"--------------------------------------------------"
-          "------------------------------\n");
-      }
+    if (((path == (const char *) NULL) ||
+         (LocaleCompare(path,type_info[i]->path) != 0)) &&
+         (type_info[i]->path != (char *) NULL))
+      (void) fprintf(file,"\nPath: %s\n",type_info[i]->path);
     path=type_info[i]->path;
     name="unknown";
     if (type_info[i]->name != (char *) NULL)
@@ -882,8 +876,11 @@ MagickExport MagickBooleanType ListTypeInfo(FILE *file,ExceptionInfo *exception)
     style=MagickOptionToMnemonic(MagickStyleOptions,type_info[i]->style);
     stretch=MagickOptionToMnemonic(MagickStretchOptions,type_info[i]->stretch);
     (void) FormatMagickString(weight,MaxTextExtent,"%lu",type_info[i]->weight);
-    (void) fprintf(file,"%-32.32s %-22.22s %-7.7s %-9.9s %6s\n",name,family,
-      style,stretch,weight);
+    (void) fprintf(file,"  Font: %s\n",name);
+    (void) fprintf(file,"    family: %s\n",family);
+    (void) fprintf(file,"    style: %s\n",style);
+    (void) fprintf(file,"    stretch: %s\n",stretch);
+    (void) fprintf(file,"    weight: %s\n",weight);
   }
   (void) fflush(file);
   type_info=(const TypeInfo **) RelinquishMagickMemory((void *) type_info);
@@ -1167,7 +1164,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The font file name.
+%    o filename: the font file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
