@@ -17,7 +17,7 @@
 %                              January 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,11 +52,15 @@
 #include "magick/option.h"
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
-#include "magick/signature.h"
+#include "magick/signature-private.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#if defined(MAGICKCORE_HAVE_MACH_O_DYLD_H)
+#include <mach-o/dyld.h>
+#endif
+
 /*
   Static declarations.
 */
@@ -133,6 +137,14 @@ MagickExport MagickBooleanType AcquireUniqueFilename(char *path)
 %   o  destination:  the destination path.
 %
 */
+
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
   char *destination)
 {
@@ -155,7 +167,7 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
 
   assert(source != (const char *) NULL);
   assert(destination != (char *) NULL);
-#if defined(HAVE_SYMLINK)
+#if defined(MAGICKCORE_HAVE_SYMLINK)
   (void) AcquireUniqueFilename(destination);
   (void) RelinquishUniqueFileResource(destination);
   if (*source == *DirectorySeparator)
@@ -187,11 +199,10 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
       (void) RelinquishUniqueFileResource(destination);
       return(MagickFalse);
     }
-  quantum=(size_t) (fstat(source_file,&file_info) < 0 ? 0 :
-    file_info.st_size);
-  if ((quantum == 0) || (quantum > MagickMaxBufferSize))
-    quantum=MagickMaxBufferSize;
-  buffer=(unsigned char *) AcquireMagickMemory(quantum*sizeof(*buffer));
+  quantum=(size_t) MagickMaxBufferSize;
+  if ((fstat(source_file,&file_info) == 0) && (file_info.st_size != 0))
+    quantum=MagickMin((size_t) file_info.st_size,MagickMaxBufferSize);
+  buffer=(unsigned char *) AcquireQuantumMemory(quantum,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     {
       (void) close(source_file);
@@ -287,8 +298,6 @@ MagickExport void AppendImageFormat(const char *format,char *filename)
 %  equivalent.  NULL is returned if the text is not valid Base64 data, or a
 %  memory allocation failure occurs.
 %
-%  Contributed by Bob Friesenhahn.
-%
 %  The format of the Base64Decode method is:
 %
 %      unsigned char *Base64Decode(const char *source,length_t *length)
@@ -297,7 +306,7 @@ MagickExport void AppendImageFormat(const char *format,char *filename)
 %
 %    o source:  A pointer to a Base64-encoded string.
 %
-%    o length: The number of bytes decoded.
+%    o length: the number of bytes decoded.
 %
 */
 MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
@@ -312,9 +321,6 @@ MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
   register size_t
     i;
 
-  size_t
-    quantum;
-
   unsigned char
     *decode;
 
@@ -322,8 +328,8 @@ MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
   assert(source != (char *) NULL);
   assert(length != (size_t *) NULL);
   *length=0;
-  quantum=3*strlen(source)/4+1;
-  decode=(unsigned char *) AcquireMagickMemory(quantum*sizeof(*decode));
+  decode=(unsigned char *) AcquireQuantumMemory(strlen(source)/4+4,
+    3*sizeof(*decode));
   if (decode == (unsigned char *) NULL)
     return((unsigned char *) NULL);
   i=0;
@@ -424,7 +430,6 @@ MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
       }
     }
   *length=i;
-  assert(*length < quantum);
   return(decode);
 }
 
@@ -453,7 +458,7 @@ MagickExport unsigned char *Base64Decode(const char *source,size_t *length)
 %
 %    o blob:  A pointer to binary data to encode.
 %
-%    o blob_length: The number of bytes to encode.
+%    o blob_length: the number of bytes to encode.
 %
 %    o encode_length:  The number of bytes encoded.
 %
@@ -471,7 +476,6 @@ MagickExport char *Base64Encode(const unsigned char *blob,
     i;
 
   size_t
-    quantum,
     remainder;
 
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
@@ -479,8 +483,7 @@ MagickExport char *Base64Encode(const unsigned char *blob,
   assert(blob_length != 0);
   assert(encode_length != (size_t *) NULL);
   *encode_length=0;
-  quantum=4*blob_length/3+4;
-  encode=(char *) AcquireMagickMemory(quantum*sizeof(*encode));
+  encode=(char *) AcquireQuantumMemory(blob_length/3+4,4*sizeof(*encode));
   if (encode == (char *) NULL)
     return((char *) NULL);
   i=0;
@@ -515,7 +518,6 @@ MagickExport char *Base64Encode(const unsigned char *blob,
     }
   *encode_length=i;
   encode[i++]='\0';
-  assert(i <= quantum);
   return(encode);
 }
 
@@ -608,7 +610,7 @@ MagickExport void ExpandFilename(char *path)
     }
   else
     {
-#if defined(POSIX)
+#if defined(MAGICKCORE_POSIX_SUPPORT)
       char
         username[MaxTextExtent];
 
@@ -696,7 +698,7 @@ MagickExport MagickBooleanType ExpandFilenames(int *argc,char ***argv)
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(argc != (int *) NULL);
   assert(argv != (char ***) NULL);
-  vector=(char **) AcquireMagickMemory((*argc+1)*sizeof(*vector));
+  vector=(char **) AcquireQuantumMemory(*argc+1UL,sizeof(*vector));
   if (vector == (char **) NULL)
     return(MagickFalse);
   /*
@@ -755,8 +757,8 @@ MagickExport MagickBooleanType ExpandFilenames(int *argc,char ***argv)
     /*
       Transfer file list to argument vector.
     */
-    vector=(char **) ResizeMagickMemory(vector,(size_t) (*argc+count+
-      number_files+1)*sizeof(*vector));
+    vector=(char **) ResizeQuantumMemory(vector,(size_t) *argc+count+
+      number_files+1,sizeof(*vector));
     if (vector == (char **) NULL)
       return(MagickFalse);
     count--;
@@ -829,22 +831,60 @@ MagickExport MagickBooleanType ExpandFilenames(int *argc,char ***argv)
 %
 %  The format of the GetExecutionPath method is:
 %
-%      MagickBooleanType GetExecutionPath(char *path)
+%      MagickBooleanType GetExecutionPath(char *path,const size_t extent)
 %
 %  A description of each parameter follows:
 %
-%    o path: The pathname of the executable that started the process.
+%    o path: the pathname of the executable that started the process.
+%
+%    o extent: the maximum extent of the path.
 %
 */
-MagickExport MagickBooleanType GetExecutionPath(char *path)
+MagickExport MagickBooleanType GetExecutionPath(char *path,const size_t extent)
 {
   *path='\0';
-  if (getcwd(path,MaxTextExtent) == (char *) NULL)
-    return(MagickFalse);
-#if defined(__WINDOWS__)
-  return(NTGetExecutionPath(path));
+  (void) getcwd(path,(unsigned long) extent);
+#if defined(MAGICKCORE_HAVE_GETPID) && defined(MAGICKCORE_HAVE_READLINK)
+  {
+    char
+      link_path[MaxTextExtent],
+      real_path[PATH_MAX+1];
+
+    ssize_t
+      count;
+
+    (void) FormatMagickString(link_path,MaxTextExtent,"/proc/%ld/exe",
+      (long) getpid());
+    count=readlink(link_path,real_path,PATH_MAX);
+    if (count == -1)
+      {
+        (void) FormatMagickString(link_path,MaxTextExtent,"/proc/%ld/file",
+          (long) getpid());
+        count=readlink(link_path,real_path,PATH_MAX);
+      }
+    if ((count > 0) && (count <= (ssize_t) PATH_MAX))
+      {
+        real_path[count]='\0';
+        (void) CopyMagickString(path,real_path,extent);
+      }
+  }
 #endif
-#if defined(HAVE_GETEXECNAME)
+#if defined(MAGICKCORE_HAVE__NSGETEXECUTABLEPATH)
+  {
+    char
+      executable_path[PATH_MAX << 1],
+      real_path[PATH_MAX+1];
+
+    size_t
+      length;
+
+    length=sizeof(executable_path);
+    if ((_NSGetExecutablePath(executable_path,&length) == 0) &&
+        (realpath(executable_path,real_path) != (char *) NULL))
+      (void) CopyMagickString(path,real_path,extent);
+  }
+#endif
+#if defined(MAGICKCORE_HAVE_GETEXECNAME)
   {
     const char
       *execution_path;
@@ -853,12 +893,15 @@ MagickExport MagickBooleanType GetExecutionPath(char *path)
     if (execution_path != (const char *) NULL)
       {
         if (*execution_path != *DirectorySeparator)
-          (void) ConcatenateMagickString(path,DirectorySeparator,MaxTextExtent);
-        (void) ConcatenateMagickString(path,execution_path,MaxTextExtent);
+          (void) ConcatenateMagickString(path,DirectorySeparator,extent);
+        (void) ConcatenateMagickString(path,execution_path,extent);
       }
   }
 #endif
-  return(MagickTrue);
+#if defined(__WINDOWS__)
+  NTGetExecutionPath(path,extent);
+#endif
+  return(IsAccessible(path));
 }
 
 /*
@@ -886,7 +929,7 @@ MagickExport MagickBooleanType GetExecutionPath(char *path)
 %
 %    o type: Specififies which file path component to return.
 %
-%    o component: The selected file path component is returned here.
+%    o component: the selected file path component is returned here.
 %
 */
 MagickExport void GetPathComponent(const char *path,PathType type,
@@ -929,7 +972,8 @@ MagickExport void GetPathComponent(const char *path,PathType type,
   p=component;
   if (*p != '\0')
     p=component+strlen(component)-1;
-  if ((*p == ']') && (strchr(component,'[') != (char *) NULL))
+  if ((*p == ']') && (strchr(component,'[') != (char *) NULL) &&
+      (IsAccessible(path) == MagickFalse))
     {
       /*
         Look for scene specification (e.g. img0001.pcd[4]).
@@ -1068,36 +1112,20 @@ MagickExport char **GetPathComponents(const char *path,
   for (p=path; *p != '\0'; p++)
     if (IsBasenameSeparator(*p))
       (*number_components)++;
-  components=(char **)
-    AcquireMagickMemory((size_t) (*number_components+1)*sizeof(*components));
+  components=(char **) AcquireQuantumMemory((size_t) *number_components+1UL,
+    sizeof(*components));
   if (components == (char **) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "memory allocation failed `%s'",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   p=path;
   for (i=0; i < (long) *number_components; i++)
   {
     for (q=(char *) p; *q != '\0'; q++)
       if (IsBasenameSeparator(*q))
         break;
-    components[i]=(char *) AcquireMagickMemory(((q-p)+MaxTextExtent)*
+    components[i]=(char *) AcquireQuantumMemory((size_t) (q-p)+MaxTextExtent,
       sizeof(*components));
     if (components[i] == (char *) NULL)
-      {
-        char
-          *message;
-
-        message=GetExceptionMessage(errno);
-        ThrowMagickFatalException(ResourceLimitFatalError,
-          "MemoryAllocationFailed",message);
-        message=DestroyString(message);
-      }
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) CopyMagickString(components[i],p,(size_t) (q-p+1));
     p=q+1;
   }
@@ -1163,7 +1191,7 @@ MagickExport MagickBooleanType IsAccessible(const char *path)
 %  IsDirectory() returns -1 if the directory does not exist,  1 is returned
 %  if the path represents a directory otherwise 0.
 %
-%  The format of the IsAccessible method is:
+%  The format of the IsDirectory method is:
 %
 %      int IsDirectory(const char *path)
 %
@@ -1321,7 +1349,7 @@ MagickExport char **ListFiles(const char *directory,const char *pattern,
     Allocate filelist.
   */
   max_entries=2048;
-  filelist=(char **) AcquireMagickMemory((size_t) max_entries*
+  filelist=(char **) AcquireQuantumMemory((size_t) max_entries,
     sizeof(*filelist));
   if (filelist == (char **) NULL)
     {
@@ -1352,8 +1380,8 @@ MagickExport char **ListFiles(const char *directory,const char *pattern,
               Extend the file list.
             */
             max_entries<<=1;
-            filelist=(char **) ResizeMagickMemory(filelist,(size_t)
-              max_entries*sizeof(*filelist));
+            filelist=(char **) ResizeQuantumMemory(filelist,(size_t)
+              max_entries,sizeof(*filelist));
             if (filelist == (char **) NULL)
               {
                 (void) closedir(current_directory);
@@ -1419,25 +1447,120 @@ MagickExport char **ListFiles(const char *directory,const char *pattern,
 %
 */
 
-#if defined(__WINDOWS__)
-static wchar_t *Latin1ToUnicodeString(const char *string)
+#if defined(MAGICKCORE_HAVE__WFOPEN)
+static size_t UTF8ToUTF16(const unsigned char *utf8,wchar_t *utf16)
 {
-  int
-    count;
+  register const unsigned char
+    *p;
 
+  if (utf16 != (wchar_t *) NULL)
+    {
+      register wchar_t
+        *q;
+
+      wchar_t
+        c;
+
+      /*
+        Convert UTF-8 to UTF-16.
+      */
+      q=utf16;
+      for (p=utf8; *p != '\0'; p++)
+      {
+        if ((*p & 0x80) == 0)
+          *q=(*p);
+        else
+          if ((*p & 0xE0) == 0xC0)
+            {
+              c=(*p);
+              *q=(c & 0x1F) << 6;
+              p++;
+              if ((*p & 0xC0) != 0x80)
+                return(0);
+              *q|=(*p & 0x3F);
+            }
+          else
+            if ((*p & 0xF0) == 0xE0)
+              {
+                c=(*p);
+                *q=c << 12;
+                p++;
+                if ((*p & 0xC0) != 0x80)
+                  return(0);
+                c=(*p);
+                *q|=(c & 0x3F) << 6;
+                p++;
+                if ((*p & 0xC0) != 0x80)
+                  return(0);
+                *q|=(*p & 0x3F);
+              }
+            else
+              return(0);
+        q++;
+      }
+      *q++='\0';
+      return(q-utf16);
+    }
+  /*
+    Compute UTF-16 string length.
+  */
+  for (p=utf8; *p != '\0'; p++)
+  {
+    if ((*p & 0x80) == 0)
+      ;
+    else
+      if ((*p & 0xE0) == 0xC0)
+        {
+          p++;
+          if ((*p & 0xC0) != 0x80)
+            return(0);
+        }
+      else
+        if ((*p & 0xF0) == 0xE0)
+          {
+            p++;
+            if ((*p & 0xC0) != 0x80)
+              return(0);
+            p++;
+            if ((*p & 0xC0) != 0x80)
+              return(0);
+         }
+       else
+         return(0);
+  }
+  return(p-utf8);
+}
+
+static wchar_t *ConvertUTF8ToUTF16(const unsigned char *source)
+{
   size_t
     length;
 
   wchar_t
-    *unicode_string;
+    *utf16;
 
-  length=strlen(string);
-  count=MultiByteToWideChar(CP_ACP,0,string,(int) length+1,NULL,0);
-  if (count == 0)
-    return((wchar_t *) "");
-  unicode_string=(wchar_t *) AcquireMagickMemory(count*sizeof(*unicode_string));
-  MultiByteToWideChar(CP_ACP,0,string,(int) length+1,unicode_string,count);
-  return(unicode_string);
+  length=UTF8ToUTF16(source,(wchar_t *) NULL);
+  if (length == 0)
+    {
+      register long
+        i;
+
+      /*
+        Not UTF-8, just copy.
+      */
+      length=strlen(source);
+      utf16=(wchar_t *) AcquireQuantumMemory(length+1,sizeof(*utf16));
+      if (utf16 == (wchar_t *) NULL)
+        return((wchar_t *) NULL);
+      for (i=0; i <= (long) length; i++)
+        utf16[i]=source[i];
+      return(utf16);
+    }
+  utf16=(wchar_t *) AcquireQuantumMemory(length+1,sizeof(*utf16));
+  if (utf16 == (wchar_t *) NULL)
+    return((wchar_t *) NULL);
+  length=UTF8ToUTF16(source,utf16);
+  return(utf16);
 }
 #endif
 
@@ -1446,15 +1569,27 @@ MagickExport FILE *MagickOpenStream(const char *path,const char *mode)
   FILE
     *file;
 
+  if ((path == (const char *) NULL) || (mode == (const char *) NULL))
+    {
+      errno=EINVAL;
+      return((FILE *) NULL);
+    }
   file=(FILE *) NULL;
-#if defined(__WINDOWS__)
+#if defined(MAGICKCORE_HAVE__WFOPEN)
   {
     wchar_t
       *unicode_mode,
       *unicode_path;
 
-    unicode_path=Latin1ToUnicodeString(path);
-    unicode_mode=Latin1ToUnicodeString(mode);
+    unicode_path=ConvertUTF8ToUTF16(path);
+    if (unicode_path == (wchar_t *) NULL)
+      return((FILE *) NULL);
+    unicode_mode=ConvertUTF8ToUTF16(mode);
+    if (unicode_path == (wchar_t *) NULL)
+      {
+        unicode_path=(wchar_t *) RelinquishMagickMemory(unicode_path);
+        return((FILE *) NULL);
+      }
     file=_wfopen(unicode_path,unicode_mode);
     unicode_mode=(wchar_t *) RelinquishMagickMemory(unicode_mode);
     unicode_path=(wchar_t *) RelinquishMagickMemory(unicode_path);
@@ -1530,7 +1665,6 @@ MagickExport unsigned long MultilineCensus(const char *label)
 %
 %    o command: This string is the command to execute.
 %
-%
 */
 MagickExport int SystemCommand(const MagickBooleanType verbose,
   const char *command)
@@ -1543,8 +1677,71 @@ MagickExport int SystemCommand(const MagickBooleanType verbose,
       (void) fprintf(stderr,"%s\n",command);
       (void) fflush(stderr);
     }
-#if defined(POSIX)
+  status=(-1);
+#if defined(MAGICKCORE_POSIX_SUPPORT)
+#if !defined(MAGICKCORE_HAVE_EXECVP)
   status=system(command);
+#else
+  if (strspn(command,"&;<>|") == 0)
+    status=system(command);
+  else
+    {
+      char
+        **argv;
+
+      int
+        argc;
+
+      argv=StringToArgv(command,&argc);
+      if (argv == (char **) NULL)
+        status=system(command);
+      else
+        {
+          pid_t
+            child_pid;
+
+          register long
+            i;
+
+          /*
+            Call application directly rather than from a shell.
+          */
+          child_pid=fork();
+          if (child_pid == (pid_t) -1)
+            status=system(command);
+          else
+            if (child_pid == 0)
+              {
+                status=execvp(argv[1],argv+1);
+                _exit(1);
+              }
+            else
+              {
+                int
+                  child_status;
+
+                pid_t
+                  pid;
+
+                child_status=0;
+                pid=waitpid(child_pid,&child_status,0);
+                if (pid == -1)
+                  status=(-1);
+                else
+                  {
+                    if (WIFEXITED(child_status) != 0)
+                      status=WEXITSTATUS(child_status);
+                    else
+                      if (WIFSIGNALED(child_status))
+                        status=(-1);
+                  }
+              }
+          for (i=1; i < argc; i++)
+            argv[i]=DestroyString(argv[i]);
+          argv=(char **) RelinquishMagickMemory(argv);
+        }
+    }
+#endif
 #elif defined(__WINDOWS__)
   status=NTSystemCommand(command);
 #elif defined(macintosh)
