@@ -27,9 +27,9 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2008 ImageMagick Studio LLC"
-#define MagickLibVersion  0x637
-#define MagickLibVersionText  "6.3.7"
-#define MagickLibVersionNumber  6,3,7,10
+#define MagickLibVersion  0x641
+#define MagickLibVersionText  "6.4.1"
+#define MagickLibVersionNumber  6,4,1,10
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -46,15 +46,22 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "01/13/08"
-#if !defined(UseHDRI)
-#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " http://www.imagemagick.org"
+#define MagickReleaseDate  "06/21/08"
+#if !defined(MAGICKCORE_HDRI_SUPPORT)
+#define MagickHDRISupport ""
 #else
-#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " HDRI http://www.imagemagick.org"
+#define MagickHDRISupport "HDRI "
 #endif
-#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.3.7/index.html"
+#if !defined(_OPENMP)
+#define MagickOPENMPSupport ""
+#else
+#define MagickOPENMPSupport "OpenMP "
+#endif
+#define MagickSupport MagickHDRISupport MagickOPENMPSupport
+#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
+  MagickReleaseDate " " MagickQuantumDepth " " MagickSupport \
+  "http://www.imagemagick.org"
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.4.1/index.html"
 
 extern MagickExport char
   *GetMagickHomeURL(void);
