@@ -245,7 +245,7 @@ int main ( int argc, char **argv )
   /*
    * Read image back from pixel array
    */
-  original = AllocateImage((ImageInfo *) NULL);
+  original = AcquireImage((ImageInfo *) NULL);
   SetImageExtent(original,columns,rows);
   if (strchr(map,'c') || strchr(map,'C') || strchr(map,'m') || strchr(map,'M') ||
       strchr(map,'y') || strchr(map,'y') || strchr(map,'k') || strchr(map,'k'))
@@ -283,7 +283,7 @@ int main ( int argc, char **argv )
    */
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                         "Reading image from pixel array");
-  final = AllocateImage((ImageInfo *) NULL);
+  final = AcquireImage((ImageInfo *) NULL);
   SetImageExtent(final,columns,rows);
   (void) SetImageBackgroundColor(final);
   status = ImportImagePixels(final,0,0,columns,rows,map,storage_type,pixels);
