@@ -99,21 +99,20 @@ int main(int argc,char **argv)
   image_info=AcquireImageInfo();
   text=(char *) NULL;
   status=IdentifyImageCommand(image_info,argc,argv,&text,exception);
-  if ((status == MagickFalse) || (exception->severity != UndefinedException))
+  if (exception->severity != UndefinedException)
     {
-      if ((exception->severity < ErrorException) &&
-          (regard_warnings == MagickFalse))
+      if ((exception->severity > ErrorException) ||
+          (regard_warnings != MagickFalse))
         status=MagickTrue;
       CatchException(exception);
     }
   if (text != (char *) NULL)
     {
       (void) fputs(text,stdout);
-      (void) fputc('\n',stdout);
       text=DestroyString(text);
     }
   image_info=DestroyImageInfo(image_info);
   exception=DestroyExceptionInfo(exception);
   MagickCoreTerminus();
-  return(status == MagickFalse ? 1 : 0);
+  return(status == MagickFalse ? 0 : 1);
 }
