@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -98,15 +98,15 @@ int main(int argc,char **argv)
   }
   image_info=AcquireImageInfo();
   status=MontageImageCommand(image_info,argc,argv,(char **) NULL,exception);
-  if ((status == MagickFalse) || (exception->severity != UndefinedException))
+  if (exception->severity != UndefinedException)
     {
-      if ((exception->severity < ErrorException) &&
-          (regard_warnings == MagickFalse))
+      if ((exception->severity > ErrorException) ||
+          (regard_warnings != MagickFalse))
         status=MagickTrue;
       CatchException(exception);
     }
   image_info=DestroyImageInfo(image_info);
   exception=DestroyExceptionInfo(exception);
   MagickCoreTerminus();
-  return(status == MagickFalse ? 1 : 0);
+  return(status == MagickFalse ? 0 : 1);
 }
