@@ -17,7 +17,7 @@
 %                               December 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -66,9 +66,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -84,33 +84,45 @@ static void CompareUsage(void)
     **p;
 
   static const char
+    *miscellaneous[]=
+    {
+      "-debug events        display copious debugging information",
+      "-help                print program options",
+      "-list type           print a list of supported option arguments",
+      "-log format          format of debugging information",
+      (char *) NULL
+    },
     *settings[]=
     {
-      "-authenticate value  decrypt image with this password",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
       "-compress type       type of pixel compression when writing the image",
-      "-debug events        display copious debugging information",
+      "-decipher filename   convert cipher pixels to plain pixels",
       "-define format:option",
       "                     define one or more image format options",
       "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
+      "-encipher filename   convert plain pixels to cipher pixels",
       "-extract geometry    extract area from image",
       "-format \"string\"     output formatted image characteristics",
       "-fuzz distance       colors within this distance are considered equal",
-      "-help                print program options",
+      "-highlight-color color",
+      "                     highlight pixel differences with this color",
       "-identify            identify the format and characteristics of the image",
       "-interlace type      type of image interlacing scheme",
       "-limit type value    pixel cache resource limit",
-      "-log format          format of debugging information",
-      "-matte               store matte channel if the image has one",
       "-metric type         measure differences between images with this metric",
       "-monitor             monitor progress",
+      "-passphrase filename get the passphrase from this file",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quiet               suppress all warning messages",
       "-quantize colorspace reduce colors in this colorspace",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-seed value          seed a new sequence of pseudo-random numbers",
@@ -133,6 +145,9 @@ static void CompareUsage(void)
   (void) printf("\nImage Settings:\n");
   for (p=settings; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf("\nMiscellaneous Options:\n");
+  for (p=miscellaneous; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
   (void) printf(
     "\nBy default, the image format of `file' is determined by its magic\n");
   (void) printf(
@@ -150,8 +165,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
 {
 #define DestroyCompare() \
 { \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -188,9 +202,11 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   Image
     *difference_image,
     *image,
-    *image_stack[MaxImageStackDepth+1],
     *reconstruct_image;
 
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
+
   long
     j,
     k;
@@ -225,7 +241,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   if (argc < 3)
@@ -236,8 +252,8 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   format=(char *) NULL;
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
   metric=UndefinedMetric;
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   reconstruct_image=NewImageList();
@@ -248,61 +264,81 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowCompareException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowCompareException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   for (i=1; i < (long) (argc-1); i++)
   {
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickTrue,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowCompareException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickTrue,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowCompareException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
+        Image
+          *images;
+
         /*
           Read input image.
         */
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
+        FireImageStack(MagickTrue,MagickTrue,pend);
         filename=argv[i];
         if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
           filename=argv[++i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
-        image=ReadImage(image_info,exception);
-        status&=(image != (Image *) NULL) &&
+        images=ReadImage(image_info,exception);
+        status&=(images != (Image *) NULL) &&
           (exception->severity < ErrorException);
-        if (image == (Image *) NULL)
+        if (images == (Image *) NULL)
           continue;
-        AppendImageToList(&image_stack[k],image);
+        AppendImageStack(images);
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
+      case 'a':
+      {
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowCompareException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
+        if (LocaleCompare("authenticate",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
+        ThrowCompareException(OptionError,"UnrecognizedOption",option);
+      }
       case 'c':
       {
         if (LocaleCompare("cache",option+1) == 0)
@@ -352,18 +388,18 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) (argc-1))
               ThrowCompareException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowCompareException(OptionError,
-                "UnrecognizedImageCompression",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowCompareException(OptionError,"UnrecognizedImageCompression",
+                argv[i]);
             break;
           }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
@@ -386,6 +422,15 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("decipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("define",option+1) == 0)
           {
             i++;
@@ -429,6 +474,15 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       }
       case 'e':
       {
+        if (LocaleCompare("encipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("extract",option+1) == 0)
           {
             if (*option == '+')
@@ -472,6 +526,15 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
         if ((LocaleCompare("help",option+1) == 0) ||
             (LocaleCompare("-help",option+1) == 0))
           CompareUsage();
+        if (LocaleCompare("highlight-color",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
       case 'i':
@@ -501,6 +564,9 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("limit",option+1) == 0)
           {
+            char
+              *p;
+
             long
               resource;
 
@@ -517,8 +583,8 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompareException(OptionError,"MissingArgument",option);
-            if ((LocaleCompare("unlimited",argv[i]) != 0) &&
-                (IsGeometry(argv[i]) == MagickFalse))
+            (void) strtod(argv[i],&p);
+            if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowCompareInvalidArgumentException(option,argv[i]);
             break;
           }
@@ -560,6 +626,15 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       }
       case 'p':
       {
+        if (LocaleCompare("passphrase",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("profile",option+1) == 0)
           {
             i++;
@@ -607,6 +682,11 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("regard-warnings",option+1) == 0)
           break;
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
       case 's':
@@ -630,7 +710,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -639,7 +719,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompareInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("set",option+1) == 0)
@@ -688,7 +768,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompareException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowCompareException(OptionError,"UnrecognizedImageType",
                 argv[i]);
@@ -732,21 +812,21 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       default:
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickTrue,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowCompareException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i-- != (long) (argc-1))
     ThrowCompareException(OptionError,"MissingAnImageFilename",argv[i]);
-  if ((image_stack[k] == (Image *) NULL) ||
-      (GetImageListLength(image_stack[k]) < 2))
+  if ((image == (Image *) NULL) ||
+      (GetImageListLength(image) < 2))
     ThrowCompareException(OptionError,"MissingAnImageFilename",argv[i]);
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-  image=GetImageFromList(image_stack[k],0);
-  reconstruct_image=GetImageFromList(image_stack[k],1);
+  FireImageStack(MagickTrue,MagickTrue,MagickTrue);
+  image=GetImageFromList(image,0);
+  reconstruct_image=GetImageFromList(image,1);
   difference_image=CompareImageChannels(image,reconstruct_image,channel,
     metric,&distortion,exception);
   if (difference_image == (Image *) NULL)
@@ -763,15 +843,8 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
 
           text=InterpretImageProperties(image_info,difference_image,format);
           if (text == (char *) NULL)
-            {
-              char
-                *message;
-
-              message=GetExceptionMessage(errno);
-              ThrowCompareException(ResourceLimitError,"MemoryAllocationFailed",
-                message);
-              message=DestroyString(message);
-            }
+            ThrowCompareException(ResourceLimitError,"MemoryAllocationFailed",
+              strerror(errno));
           (void) ConcatenateString(&(*metadata),text);
           (void) ConcatenateString(&(*metadata),"\n");
           text=DestroyString(text);
