@@ -17,7 +17,7 @@
 %                                April 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -83,9 +83,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -135,23 +135,33 @@ static MagickBooleanType ConcatenateImages(int argc,char **argv,
 static void ConvertUsage(void)
 {
   static const char
+    *miscellaneous[]=
+    {
+      "-debug events        display copious debugging information",
+      "-help                print program options",
+      "-list type           print a list of supported option arguments",
+      "-log format          format of debugging information",
+      "-version             print version information",
+      (char *) NULL
+    },
     *operators[]=
     {
       "-adaptive-blur geometry",
       "                     adaptively blur pixels; decrease effect near edges",
       "-adaptive-resize geometry",
-      "                     adaptively resize image with data dependent",
-      "                     triangulation",
+      "                     adaptively resize image with data dependent triangulation",
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-annotate geometry text",
       "                     annotate the image with text",
       "-auto-orient         automatically orient image",
+      "-bench iterations    measure performance",
       "-black-threshold value",
       "                     force all pixels below the threshold into black",
       "-blur geometry       reduce image noise and reduce detail levels",
       "-border geometry     surround image with a border of color",
+      "-bordercolor color   border color",
       "-charcoal radius     simulate a charcoal drawing",
       "-chop geometry       remove pixels from the image interior",
       "-clip                clip along the first path from the 8BIM profile",
@@ -164,11 +174,13 @@ static void ConvertUsage(void)
       "-convolve coefficients",
       "                     apply a convolution kernel to the image",
       "-cycle amount        cycle the image colormap",
+      "-decipher filename   convert cipher pixels to plain pixels",
       "-despeckle           reduce the speckles within an image",
       "-distort type coefficients",
       "                     distort the image",
       "-draw string         annotate the image with a graphic primitive",
       "-edge radius         apply a filter to detect edges in the image",
+      "-encipher filename   convert plain pixels to cipher pixels",
       "-emboss radius       emboss an image",
       "-enhance             apply a digital filter to enhance a noisy image",
       "-equalize            perform histogram equalization to an image",
@@ -186,14 +198,15 @@ static void ConvertUsage(void)
       "-gaussian-blur geometry",
       "                     reduce image noise and reduce detail levels",
       "-geometry geometry   perferred size or location of the image",
-      "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-implode amount      implode image pixels about the center",
       "-lat geometry        local adaptive thresholding",
-      "-layers method       optimize or compare image layers",
+      "-layers method       optimize, merge,  or compare image layers",
       "-level value         adjust the level of image contrast",
       "-linear-stretch geometry",
       "                     improve contrast by `stretching with saturation'",
+      "-liquid-rescale geometry",
+      "                     rescale image with seam-carving",
       "-median radius       apply a median filter to the image",
       "-modulate value      vary the brightness, saturation, and hue",
       "-monochrome          transform image to black and white",
@@ -236,12 +249,11 @@ static void ConvertUsage(void)
       "-shave geometry      shave pixels from the image edges",
       "-shear geometry      slide one edge of the image along the X or Y axis",
       "-sigmoidal-contrast geometry",
-      "                     lightness rescaling using sigmoidal contrast",
-      "                     enhancement",
+      "                     increase the contrast without saturating highlights or shadows",
       "-sketch geometry     simulate a pencil sketch",
       "-solarize threshold  negate all pixels above the threshold level",
       "-splice geometry     splice the background color into the image",
-      "-spread amount       displace image pixels by a random amount",
+      "-spread radius       displace image pixels by a random amount",
       "-strip               strip image of all profiles and comments",
       "-swirl degrees       swirl image pixels about the center",
       "-threshold value     threshold the image",
@@ -256,7 +268,6 @@ static void ConvertUsage(void)
       "-type type           image type",
       "-unique-colors       discard all but one of any pixel color",
       "-unsharp geometry    sharpen the image",
-      "-version             print version information",
       "-vignette geometry   soften the edges of the image in vignette style",
       "-wave geometry       alter an image along a sine wave",
       "-white-threshold value",
@@ -290,7 +301,8 @@ static void ConvertUsage(void)
       "-affine matrix       affine transform matrix",
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
-      "-authenticate value  decrypt image with this password",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-attenuate value     lessen (or intensify) when adding noise to an image",
       "-background color    background color",
       "-bias value          add bias when convolving an image",
@@ -305,14 +317,13 @@ static void ConvertUsage(void)
       "-comment string      annotate image with comment",
       "-compose operator    set image composite operator",
       "-compress type       type of pixel compression when writing the image",
-      "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
       "-delay value         display the next image after pausing",
       "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
       "-display server      get image or font from this X server",
-      "-dispose method      GIF disposal method",
+      "-dispose method      layer disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-encoding type       text encoding type",
       "-endian type         endianness (MSB or LSB) of the image",
@@ -329,7 +340,6 @@ static void ConvertUsage(void)
       "-interpolate method  pixel color interpolation method",
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
-      "-log format          format of debugging information",
       "-loop iterations     add Netscape loop extension to your GIF animation",
       "-mask filename       associate a mask with the image",
       "-mattecolor color    frame color",
@@ -343,6 +353,7 @@ static void ConvertUsage(void)
       "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
@@ -352,7 +363,6 @@ static void ConvertUsage(void)
       "-stroke color        graphic primitive stroke color",
       "-strokewidth value   graphic primitive stroke width",
       "-style type          render text with this font style",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-taint               image as ineligible for bi-modal delegate",
       "-texture filename    name of texture to tile onto the image background",
       "-tile-offset geometry",
@@ -398,6 +408,9 @@ static void ConvertUsage(void)
   (void) printf("\nImage Stack Operators:\n");
   for (p=stack_operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf("\nMiscellaneous Options:\n");
+  for (p=miscellaneous; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
   (void) printf(
     "\nBy default, the image format of `file' is determined by its magic\n");
   (void) printf(
@@ -416,8 +429,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
 #define NotInitialized  (unsigned int) (~0)
 #define DestroyConvert() \
 { \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -445,7 +457,10 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
     *format;
 
   Image
-    *image_stack[MaxImageStackDepth+1];
+    *image;
+
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
 
   long
     j,
@@ -487,7 +502,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   format="%w,%h,%m";
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   status=MagickTrue;
@@ -497,15 +512,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   if ((argc > 2) && (LocaleCompare("-concatenate",argv[1]) == 0))
     return(ConcatenateImages(argc,argv,exception));
   for (i=1; i < (long) (argc-1); i++)
@@ -513,51 +521,46 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickTrue,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowConvertException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickTrue,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowConvertException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
         Image
-          *image;
+          *images;
 
         /*
           Read input image.
         */
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
+        FireImageStack(MagickTrue,MagickTrue,pend);
         filename=argv[i];
         if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
           filename=argv[++i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
         if (image_info->ping != MagickFalse)
-          image=PingImage(image_info,exception);
+          images=PingImage(image_info,exception);
         else
-          image=ReadImage(image_info,exception);
-        status&=(image != (Image *) NULL) &&
+          images=ReadImage(image_info,exception);
+        status&=(images != (Image *) NULL) &&
           (exception->severity < ErrorException);
-        if (image == (Image *) NULL)
+        if (images == (Image *) NULL)
           continue;
-        AppendImageToList(&image_stack[k],image);
+        AppendImageStack(images);
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -662,6 +665,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("bench",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("bias",option+1) == 0)
           {
             if (*option == '+')
@@ -822,9 +836,9 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             Image
               *clone_images;
 
-            clone_images=image_stack[k];
+            clone_images=image;
             if (k != 0)
-              clone_images=image_stack[k-1];
+              clone_images=image_stack[k-1].image;
             if (clone_images == (Image *) NULL)
               ThrowConvertException(ImageError,"ImageSequenceRequired",option);
             if (*option == '+')
@@ -840,8 +854,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               }
             if (clone_images == (Image *) NULL)
               ThrowConvertException(OptionError,"NoSuchImage",option);
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k],clone_images);
+            FireImageStack(MagickTrue,MagickTrue,MagickTrue);
+            AppendImageStack(clone_images);
             break;
           }
         if (LocaleCompare("clut",option+1) == 0)
@@ -981,6 +995,15 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       }
       case 'd':
       {
+        if (LocaleCompare("decipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("deconstruct",option+1) == 0)
           break;
         if (LocaleCompare("debug",option+1) == 0)
@@ -1148,6 +1171,15 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("encipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("encoding",option+1) == 0)
           {
             if (*option == '+')
@@ -1253,8 +1285,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowConvertException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -1275,9 +1306,9 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowConvertInvalidArgumentException(option,argv[i]);
+            i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            i++;
             break;
           }
         if (LocaleCompare("font",option+1) == 0)
@@ -1512,7 +1543,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickLayersOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickLayerOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowConvertException(OptionError,"UnrecognizedLayerMethod",
                 argv[i]);
@@ -1538,8 +1569,20 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("liquid-rescale",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("limit",option+1) == 0)
           {
+            char
+              *p;
+
             long
               resource;
 
@@ -1556,8 +1599,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowConvertException(OptionError,"MissingArgument",option);
-            if ((LocaleCompare("unlimited",argv[i]) != 0) &&
-                (IsGeometry(argv[i]) == MagickFalse))
+            (void) strtod(argv[i],&p);
+            if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
@@ -1728,8 +1771,6 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("opaque",option+1) == 0)
           {
-            if (*option == '+')
-              break;
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
@@ -1999,6 +2040,11 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         if (LocaleCompare("reverse",option+1) == 0)
           break;
         if (LocaleCompare("roll",option+1) == 0)
@@ -2077,7 +2123,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -2086,7 +2132,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowConvertInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("segment",option+1) == 0)
@@ -2294,13 +2340,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) (argc-1))
-              ThrowConvertException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowConvertInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         if (LocaleCompare("swap",option+1) == 0)
@@ -2598,37 +2638,30 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       default:
         ThrowConvertException(OptionError,"UnrecognizedOption",option)
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ?
+      MagickFalse : MagickTrue;
     if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+      FireImageStack(MagickTrue,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowConvertException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i-- != (long) (argc-1))
     ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
-  if (image_stack[k] == (Image *) NULL)
+  if (image == (Image *) NULL)
     ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-  if (image_stack[k] == (Image *) NULL)
+  FireImageStack(MagickTrue,MagickTrue,MagickTrue);
+  if (image == (Image *) NULL)
     ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
-  status&=WriteImages(image_info,image_stack[k],argv[argc-1],exception);
+  status&=WriteImages(image_info,image,argv[argc-1],exception);
   if (metadata != (char **) NULL)
     {
       char
         *text;
 
-      text=InterpretImageProperties(image_info,image_stack[k],format);
+      text=InterpretImageProperties(image_info,image,format);
       if (text == (char *) NULL)
-        {
-          char
-            *message;
-
-          message=GetExceptionMessage(errno);
-          ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
-            message);
-          message=DestroyString(message);
-        }
+        ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
+          strerror(errno));
       (void) ConcatenateString(&(*metadata),text);
       text=DestroyString(text);
     }
