@@ -76,9 +76,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -119,6 +119,7 @@ static void DisplayUsage(void)
       "-colors value        preferred number of colors in the image",
       "-contrast            enhance or reduce the image contrast",
       "-crop geometry       preferred size and location of the cropped image",
+      "-decipher filename   convert cipher pixels to plain pixels",
       "-despeckle           reduce the speckles within an image",
       "-edge factor         apply a filter to detect edges in the image",
       "-enhance             apply a digital filter to enhance a noisy image",
@@ -145,7 +146,8 @@ static void DisplayUsage(void)
     {
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
-      "-authenticate value  decrypt image with this password",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-backdrop            display image centered on a backdrop",
       "-channel type        apply option to select image channels",
       "-colormap type       Shared or Private",
@@ -181,6 +183,7 @@ static void DisplayUsage(void)
       "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
       "-repage geometry     size and location of an image canvas (operator)",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
@@ -260,8 +263,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
       display=(Display *) NULL; \
     } \
   XDestroyResourceInfo(&resource_info); \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   if (image_marker != (unsigned long *) NULL) \
     image_marker=(unsigned long *) RelinquishMagickMemory(image_marker); \
   for (i=0; i < (long) argc; i++) \
@@ -294,8 +296,10 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
     *display;
 
   Image
-    *image,
-    *image_stack[MaxImageStackDepth+1];
+    *image;
+
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
 
   long
     first_scene,
@@ -307,6 +311,9 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
     last_scene,
     scene;
 
+  MagickBooleanType
+    fire;
+
   MagickStatusType
     pend,
     status;
@@ -346,7 +353,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   SetNotifyHandlers;
@@ -355,10 +362,10 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   j=1;
   k=0;
   image_marker=(unsigned long *) NULL;
-  image_stack[k]=NewImageList();
   image_number=0;
   last_image=0;
   last_scene=0;
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   resource_database=(XrmDatabase) NULL;
@@ -369,27 +376,13 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   image_marker=(unsigned long *) AcquireQuantumMemory((size_t) argc+1UL,
     sizeof(*image_marker));
   if (image_marker == (unsigned long *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   for (i=0; i <= argc; i++)
     image_marker[i]=(unsigned long) argc;
   /*
@@ -426,8 +419,8 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
       XDisplayName(server_name));
   (void) XSetErrorHandler(XError);
   resource_database=XGetResourceDatabase(display,GetClientName());
-  XGetResourceInfo(resource_database,GetClientName(),&resource_info);
-  image_info=resource_info.image_info;
+  XGetResourceInfo(image_info,resource_database,GetClientName(),
+    &resource_info);
   quantize_info=resource_info.quantize_info;
   image_info->density=XGetResourceInstance(resource_database,GetClientName(),
     "density",(char *) NULL);
@@ -458,7 +451,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
     if (i < (long) argc)
       option=argv[i];
     else
-      if (image_stack[k] != (Image *) NULL)
+      if (image != (Image *) NULL)
         break;
       else
         if (isatty(STDIN_FILENO) != MagickFalse)
@@ -479,24 +472,19 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
           }
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowDisplayException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowDisplayException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
@@ -504,12 +492,15 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
         /*
           Option is a file name.
         */
-        MogrifyImageStack(image_stack[k],MagickFalse,pend);
+        FireImageStack(MagickFalse,MagickFalse,pend);
         for (scene=first_scene; scene <= last_scene ; scene++)
         {
           const char
             *filename;
 
+          Image
+            *images;
+
           /*
             Read image.
           */
@@ -536,14 +527,14 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               (void) CopyMagickString(image_info->filename,filename,
                 MaxTextExtent);
             }
-          image=ReadImage(image_info,exception);
+          images=ReadImage(image_info,exception);
           CatchException(exception);
-          status&=(image != (Image *) NULL) &&
+          status&=(images != (Image *) NULL) &&
             (exception->severity < ErrorException);
-          if (image == (Image *) NULL)
+          if (images == (Image *) NULL)
             continue;
-          AppendImageToList(&image_stack[k],image);
-          MogrifyImageStack(image_stack[k],MagickFalse,MagickTrue);
+          AppendImageStack(images);
+          FireImageStack(MagickFalse,MagickFalse,MagickTrue);
           do
           {
             /*
@@ -551,14 +542,14 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             */
             resource_info.quantum=1;
             if (first_scene != last_scene)
-              image_stack[k]->scene=(unsigned long) scene;
+              image->scene=(unsigned long) scene;
             if (resource_info.window_id != (char *) NULL)
               {
                 /*
                   Display image to a specified X window.
                 */
                 status=XDisplayBackgroundImage(display,&resource_info,
-                  image_stack[k]);
+                  image);
                 if (status != MagickFalse)
                   state|=RetainColorsState;
               }
@@ -572,7 +563,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
                   Display image to X server.
                 */
                 nexus=XDisplayImage(display,&resource_info,argv,argc,
-                  image_stack+k,&state);
+                  &image,&state);
                 if (nexus == (Image *) NULL)
                   break;
                 while ((nexus != (Image *) NULL) && ((state & ExitState) == 0))
@@ -582,24 +573,24 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
                       /*
                         User selected a visual directory image (montage).
                       */
-                      image_stack[k]=DestroyImageList(image_stack[k]);
-                      image_stack[k]=nexus;
+                      RemoveAllImageStack()
+                      image=nexus;
                       break;
                     }
                   if (first_scene != last_scene)
-                    image_stack[k]->scene=(unsigned long) scene;
+                    image->scene=(unsigned long) scene;
                   image=XDisplayImage(display,&resource_info,argv,argc,&nexus,
                     &state);
                   if ((image == (Image *) NULL) &&
                       (GetNextImageInList(nexus) != (Image *) NULL))
                     {
-                      image_stack[k]=DestroyImageList(image_stack[k]);
-                      image_stack[k]=GetNextImageInList(nexus);
+                      RemoveAllImageStack()
+                      image=GetNextImageInList(nexus);
                       nexus=NewImageList();
                     }
                   else
                     {
-                      if (nexus != image_stack[k])
+                      if (nexus != image)
                         nexus=DestroyImageList(nexus);
                       nexus=image;
                     }
@@ -610,17 +601,17 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
                 /*
                   Write image.
                 */
-                (void) CopyMagickString(image_stack[k]->filename,
+                (void) CopyMagickString(image->filename,
                   resource_info.write_filename,MaxTextExtent);
                 (void) SetImageInfo(image_info,MagickTrue,
-                  &image_stack[k]->exception);
-                status&=WriteImage(image_info,image_stack[k]);
-                GetImageException(image_stack[k],exception);
+                  &image->exception);
+                status&=WriteImage(image_info,image);
+                GetImageException(image,exception);
               }
             /*
               Proceed to next/previous image.
             */
-            image=image_stack[k];
+            image=image;
             if ((state & FormerImageState) != 0)
               for (l=0; l < resource_info.quantum; l++)
               {
@@ -636,12 +627,12 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
                   break;
               }
             if (image != (Image *) NULL)
-              image_stack[k]=image;
+              image=image;
           } while ((image != (Image *) NULL) && ((state & ExitState) == 0));
           /*
             Free image resources.
           */
-          image_stack[k]=DestroyImageList(image_stack[k]);
+          RemoveAllImageStack()
           if ((state & FormerImageState) == 0)
             {
               last_image=(unsigned long) image_number;
@@ -685,7 +676,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
         iteration++;
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -922,6 +913,15 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             (void) SetLogEventMask(argv[i]);
             break;
           }
+        if (LocaleCompare("decipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("define",option+1) == 0)
           {
             i++;
@@ -1337,7 +1337,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowDisplayException(OptionError,"MissingArgument",option);
-            resource_info.name=argv[i];
+            resource_info.name=ConstantString(argv[i]);
             break;
           }
         if (LocaleCompare("negate",option+1) == 0)
@@ -1458,6 +1458,11 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         if (LocaleCompare("roll",option+1) == 0)
           {
             if (*option == '+')
@@ -1533,7 +1538,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -1542,7 +1547,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("segment",option+1) == 0)
@@ -1795,10 +1800,10 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
       default:
         ThrowDisplayException(OptionError,"UnrecognizedOption",option);
     }
-    status=(MagickStatusType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (status != 0)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowDisplayException(OptionError,"UnbalancedParenthesis",argv[i]);
@@ -1811,7 +1816,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   return(status != 0 ? MagickTrue : MagickFalse);
 #else
   (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
-    "XWindowLibraryIsNotAvailable","`%s'",image_info->filename);
+    "DelegateLibrarySupportNotBuiltIn","`%s' (X11)",image_info->filename);
   DisplayUsage();
   return(MagickFalse);
 #endif
