@@ -17,7 +17,7 @@
 %                            September 1994                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -72,9 +72,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -90,15 +90,24 @@ static void IdentifyUsage(void)
     **p;
 
   static const char
+    *miscellaneous[]=
+    {
+      "-debug events        display copious debugging information",
+      "-help                print program options",
+      "-list type           print a list of supported option arguments",
+      "-log format          format of debugging information",
+      "-version             print version information",
+      (char *) NULL
+    },
     *settings[]=
     {
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
-      "-authenticate value  decrypt image with this password",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
       "-crop geometry       cut out a rectangular region of the image",
-      "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
       "-density geometry    horizontal and vertical density of the image",
@@ -107,17 +116,14 @@ static void IdentifyUsage(void)
       "-format \"string\"     output formatted image characteristics",
       "-fuzz distance       colors within this distance are considered equal",
       "-gamma value         level of gamma correction",
-      "-help                print program options",
       "-interlace type      type of image interlacing scheme",
       "-interpolate method  pixel color interpolation method",
       "-limit type value    pixel cache resource limit",
-      "-list type           Color, Configure, Delegate, Format, Magic, Module,",
-      "                     Resource, or Type",
-      "-log format          format of debugging information",
       "-monitor             monitor progress",
       "-ping                efficiently determine image attributes",
       "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-seed value          seed a new sequence of pseudo-random numbers",
@@ -126,7 +132,6 @@ static void IdentifyUsage(void)
       "-strip               strip image of all profiles and comments",
       "-units type          the units of image resolution",
       "-verbose             print detailed information about the image",
-      "-version             print version information",
       "-virtual-pixel method",
       "                     virtual pixel access method",
       (char *) NULL
@@ -139,6 +144,9 @@ static void IdentifyUsage(void)
   (void) printf("\nImage Settings:\n");
   for (p=settings; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf("\nMiscellaneous Options:\n");
+  for (p=miscellaneous; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
   (void) printf(
     "\nBy default, the image format of `file' is determined by its magic\n");
   (void) printf(
@@ -156,17 +164,15 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
 {
 #define DestroyIdentify() \
 { \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
 }
 #define ThrowIdentifyException(asperity,tag,option) \
 { \
-  if (exception->severity == UndefinedException) \
-    (void) ThrowMagickException(exception,GetMagickModule(),asperity,tag, \
-      "`%s'",option); \
+  (void) ThrowMagickException(exception,GetMagickModule(),asperity,tag,"`%s'", \
+    option); \
   DestroyIdentify(); \
   return(MagickFalse); \
 }
@@ -183,7 +189,10 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
     *option;
 
   Image
-    *image_stack[MaxImageStackDepth+1];
+    *image;
+
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
 
   long
     j,
@@ -210,13 +219,25 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 2)
     IdentifyUsage();
   count=0;
   format=NULL;
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   status=MagickTrue;
@@ -226,38 +247,26 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowIdentifyException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowIdentifyException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowIdentifyException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowIdentifyException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
@@ -266,7 +275,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           *filename;
 
         Image
-          *image;
+          *images;
 
         ImageInfo
           *identify_info;
@@ -274,7 +283,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
         /*
           Read input image.
         */
-        MogrifyImageStack(image_stack[k],MagickFalse,pend);
+        FireImageStack(MagickFalse,MagickFalse,pend);
         identify_info=CloneImageInfo(image_info);
         identify_info->verbose=MagickFalse;
         filename=argv[i];
@@ -282,17 +291,16 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           filename=argv[++i];
         (void) CopyMagickString(identify_info->filename,filename,MaxTextExtent);
         if (identify_info->ping == MagickFalse)
-          image=ReadImage(identify_info,exception);
+          images=ReadImage(identify_info,exception);
         else
-          image=PingImage(identify_info,exception);
+          images=PingImage(identify_info,exception);
         identify_info=DestroyImageInfo(identify_info);
-        status&=(image != (Image *) NULL) &&
+        status&=(images != (Image *) NULL) &&
           (exception->severity < ErrorException);
-        if (image == (Image *) NULL)
+        if (images == (Image *) NULL)
           continue;
-        AppendImageToList(&image_stack[k],image);
-        MogrifyImageStack(image_stack[k],MagickFalse,MagickTrue);
-        image=image_stack[k];
+        AppendImageStack(images);
+        FireImageStack(MagickFalse,MagickFalse,MagickTrue);
         for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
         {
           if (image->scene == 0)
@@ -309,25 +317,18 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
 
               text=InterpretImageProperties(image_info,image,format);
               if (text == (char *) NULL)
-                {
-                  char
-                    *message;
-
-                  message=GetExceptionMessage(errno);
-                  ThrowIdentifyException(ResourceLimitError,
-                    "MemoryAllocationFailed",message);
-                  message=DestroyString(message);
-                }
+                ThrowIdentifyException(ResourceLimitError,
+                  "MemoryAllocationFailed",strerror(errno));
               (void) ConcatenateString(&(*metadata),text);
               text=DestroyString(text);
               if (LocaleCompare(format,"%n") == 0)
                 break;
             }
         }
-        image_stack[k]=DestroyImageList(image_stack[k]);
+        RemoveAllImageStack();
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -569,6 +570,9 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("limit",option+1) == 0)
           {
+            char
+              *p;
+
             long
               resource;
 
@@ -585,8 +589,8 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowIdentifyException(OptionError,"MissingArgument",option);
-            if ((LocaleCompare("unlimited",argv[i]) != 0) &&
-                (IsGeometry(argv[i]) == MagickFalse))
+            (void) strtod(argv[i],&p);
+            if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowIdentifyInvalidArgumentException(option,argv[i]);
             break;
           }
@@ -645,6 +649,11 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("regard-warnings",option+1) == 0)
           break;
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
       }
       case 's':
@@ -668,7 +677,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -677,7 +686,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowIdentifyInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("set",option+1) == 0)
@@ -743,14 +752,6 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("verbose",option+1) == 0)
           break;
-        if ((LocaleCompare("version",option+1) == 0) ||
-            (LocaleCompare("-version",option+1) == 0))
-          {
-            (void) fprintf(stdout,"Version: %s\n",
-              GetMagickVersion((unsigned long *) NULL));
-            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-            break;
-          }
         if (LocaleCompare("virtual-pixel",option+1) == 0)
           {
             long
@@ -775,10 +776,10 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       default:
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowIdentifyException(OptionError,"UnbalancedParenthesis",argv[i]);
