@@ -109,6 +109,7 @@ extern WandExport MagickBooleanType
   MagickCropImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickCycleColormapImage(MagickWand *,const long),
+  MagickDecipherImage(MagickWand *,const char *),
   MagickDespeckleImage(MagickWand *),
   MagickDisplayImage(MagickWand *,const char *),
   MagickDisplayImages(MagickWand *,const char *),
@@ -117,6 +118,7 @@ extern WandExport MagickBooleanType
   MagickDrawImage(MagickWand *,const DrawingWand *),
   MagickEdgeImage(MagickWand *,const double),
   MagickEmbossImage(MagickWand *,const double,const double),
+  MagickEncipherImage(MagickWand *,const char *),
   MagickEnhanceImage(MagickWand *),
   MagickEqualizeImage(MagickWand *),
   MagickEqualizeImageChannel(MagickWand *,const ChannelType),
@@ -137,6 +139,7 @@ extern WandExport MagickBooleanType
   MagickGaussianBlurImage(MagickWand *,const double,const double),
   MagickGaussianBlurImageChannel(MagickWand *,const ChannelType,const double,
     const double),
+  MagickGetImageAlphaChannel(MagickWand *),
   MagickGetImageBackgroundColor(MagickWand *,PixelWand *),
   MagickGetImageBluePrimary(MagickWand *,double *,double *),
   MagickGetImageBorderColor(MagickWand *,PixelWand *),
@@ -148,7 +151,6 @@ extern WandExport MagickBooleanType
   MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
-  MagickGetImageMatte(MagickWand *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
   MagickGetImageLength(MagickWand *,MagickSizeType *),
   MagickGetImagePage(MagickWand *,unsigned long *,unsigned long *,long *,
@@ -168,6 +170,8 @@ extern WandExport MagickBooleanType
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
   MagickLinearStretchImage(MagickWand *,const double,const double),
+  MagickLiquidRescaleImage(MagickWand *,const unsigned long,const unsigned long,
+    const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
   MagickMedianFilterImage(MagickWand *,const double),
