@@ -107,6 +107,10 @@ extern WandExport MagickBooleanType
 extern WandExport MagickProgressMonitor
   MagickSetProgressMonitor(MagickWand *,const MagickProgressMonitor,void *);
 
+extern WandExport MagickSizeType
+  MagickGetResource(const ResourceType),
+  MagickGetResourceLimit(const ResourceType);
+
 extern WandExport PixelWand
   *MagickGetBackgroundColor(MagickWand *);
 
@@ -118,9 +122,7 @@ extern WandExport unsigned char
   *MagickRemoveImageProfile(MagickWand *,const char *,size_t *);
 
 extern WandExport unsigned long
-  MagickGetCompressionQuality(MagickWand *),
-  MagickGetResource(const ResourceType),
-  MagickGetResourceLimit(const ResourceType);
+  MagickGetCompressionQuality(MagickWand *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
