@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -66,9 +66,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -84,6 +84,15 @@ static void MontageUsage(void)
     **p;
 
   static const char
+    *miscellaneous[]=
+    {
+      "-debug events        display copious debugging information",
+      "-help                print program options",
+      "-list type           print a list of supported option arguments",
+      "-log format          format of debugging information",
+			"-version             print version information",
+      (char *) NULL
+    },
     *operators[]=
     {
       " annotate geometry text",
@@ -104,7 +113,6 @@ static void MontageUsage(void)
       "-transform           affine transform image",
       "-transparent color   make this color transparent within the image",
       "-type type           image type",
-      "-version             print version information",
       (char *) NULL
     },
     *settings[]=
@@ -112,7 +120,8 @@ static void MontageUsage(void)
       "-adjoin              join images into a single multi-image file",
       "-affine matrix       affine transform matrix",
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
-      "-authenticate value  decrypt image with this password",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-blue-primary point  chromaticity blue primary point",
       "-bordercolor color   border color",
       "-caption string      assign a caption to an image",
@@ -122,13 +131,12 @@ static void MontageUsage(void)
       "-comment string      annotate image with comment",
       "-compose operator    composite operator",
       "-compress type       type of pixel compression when writing the image",
-      "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
       "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
       "-display server      query font from this X server",
-      "-dispose method      GIF disposal method",
+      "-dispose method      layer disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-draw string         annotate the image with a graphic primitive",
       "-encoding type       text encoding type",
@@ -142,13 +150,11 @@ static void MontageUsage(void)
       "-geometry geometry   preferred tile and border sizes",
       "-gravity direction   which direction to gravitate towards",
       "-green-primary point chromaticity green primary point",
-      "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-interlace type      type of image interlacing scheme",
       "-interpolate method  pixel color interpolation method",
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
-      "-log format          format of debugging information",
       "-mattecolor color    frame color",
       "-mode type           framing style",
       "-monitor             monitor progress",
@@ -161,6 +167,7 @@ static void MontageUsage(void)
       "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
@@ -169,7 +176,6 @@ static void MontageUsage(void)
       "-shadow              add a shadow beneath a tile to simulate depth",
       "-size geometry       width and height of image",
       "-stroke color        color to use when stroking a graphic primitive",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-texture filename    name of texture to tile onto the image background",
       "-thumbnail geometry  create a thumbnail of the image",
       "-tile geometry       number of tiles per row and column",
@@ -210,6 +216,9 @@ static void MontageUsage(void)
   (void) printf("\nImage Stack Operators:\n");
   for (p=stack_operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf("\nMiscellaneous Options:\n");
+  for (p=miscellaneous; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
   (void) printf(
     "\nIn addition to those listed above, you can specify these standard X\n");
   (void) printf(
@@ -235,8 +244,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
 { \
   if (montage_image != (Image *) NULL) \
     montage_image=DestroyImageList(montage_image); \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -264,9 +272,12 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
     *format;
 
   Image
-    *image_stack[MaxImageStackDepth+1],
+    *image,
     *montage_image;
 
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
+
   long
     first_scene,
     j,
@@ -307,7 +318,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   if (argc < 3)
@@ -316,10 +327,10 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   first_scene=0;
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
   last_scene=0;
   montage_image=NewImageList();
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   GetQuantizeInfo(&quantize_info);
@@ -333,46 +344,34 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   for (i=1; i < (long) (argc-1); i++)
   {
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickTrue,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowMontageException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickTrue,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowMontageException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
         Image
-         *image;
+          *images;
 
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
+        FireImageStack(MagickTrue,MagickTrue,pend);
         for (scene=first_scene; scene <= last_scene ; scene++)
         {
           char
@@ -402,16 +401,16 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
                 MaxTextExtent);
             }
           (void) CloneString(&image_info->font,montage_info->font);
-          image=ReadImage(image_info,exception);
-          status&=(image != (Image *) NULL) &&
+          images=ReadImage(image_info,exception);
+          status&=(images != (Image *) NULL) &&
             (exception->severity < ErrorException);
-          if (image == (Image *) NULL)
+          if (images == (Image *) NULL)
             continue;
-          AppendImageToList(&image_stack[k],image);
+          AppendImageStack(images);
         }
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -587,9 +586,9 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             Image
               *clone_images;
 
-            clone_images=image_stack[k];
+            clone_images=image;
             if (k != 0)
-              clone_images=image_stack[k-1];
+              clone_images=image_stack[k-1].image;
             if (clone_images == (Image *) NULL)
               ThrowMontageException(ImageError,"ImageSequenceRequired",option);
             if (*option == '+')
@@ -605,8 +604,8 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               }
             if (clone_images == (Image *) NULL)
               ThrowMontageException(OptionError,"NoSuchImage",option);
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k],clone_images);
+            FireImageStack(MagickTrue,MagickTrue,MagickTrue);
+            AppendImageStack(clone_images);
             break;
           }
         if (LocaleCompare("coalesce",option+1) == 0)
@@ -849,8 +848,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowMontageException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -1014,6 +1012,9 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("limit",option+1) == 0)
           {
+            char
+              *p;
+
             long
               resource;
 
@@ -1030,8 +1031,8 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            if ((LocaleCompare("unlimited",argv[i]) != 0) &&
-                (IsGeometry(argv[i]) == MagickFalse))
+            (void) strtod(argv[i],&p);
+            if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
@@ -1253,6 +1254,11 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         if (LocaleCompare("rotate",option+1) == 0)
           {
             i++;
@@ -1285,7 +1291,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -1294,7 +1300,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowMontageInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("scenes",option+1) == 0)
@@ -1306,7 +1312,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
+            if (IsSceneGeometry(argv[i],MagickFalse) == MagickFalse)
               ThrowMontageInvalidArgumentException(option,argv[i]);
             first_scene=atol(argv[i]);
             last_scene=first_scene;
@@ -1378,13 +1384,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("support",option+1) == 0)
           {
-            if (*option == '+')
-              break;
-            i++;
-            if (i == (long) argc)
-              ThrowMontageException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
-              ThrowMontageInvalidArgumentException(option,argv[i]);
+            i++;  /* deprecated */
             break;
           }
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
@@ -1591,21 +1591,20 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
       default:
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickTrue,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowMontageException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i-- != (long) (argc-1))
     ThrowMontageException(OptionError,"MissingAnImageFilename",argv[i]);
-  if (image_stack[k] == (Image *) NULL)
+  if (image == (Image *) NULL)
     ThrowMontageException(OptionError,"MissingAnImageFilename",argv[argc-1]);
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+  FireImageStack(MagickTrue,MagickTrue,MagickTrue);
   (void) CopyMagickString(montage_info->filename,argv[argc-1],MaxTextExtent);
-  montage_image=MontageImageList(image_info,montage_info,image_stack[k],
-    exception);
+  montage_image=MontageImageList(image_info,montage_info,image,exception);
   if (montage_image == (Image *) NULL)
     status=MagickFalse;
   else
@@ -1625,15 +1624,8 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
 
           text=InterpretImageProperties(image_info,montage_image,format);
           if (text == (char *) NULL)
-            {
-              char
-                *message;
-
-              message=GetExceptionMessage(errno);
-              ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
-                message);
-              message=DestroyString(message);
-            }
+            ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
+              strerror(errno));
           (void) ConcatenateString(&(*metadata),text);
           (void) ConcatenateString(&(*metadata),"\n");
           text=DestroyString(text);
