@@ -70,9 +70,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -100,7 +100,8 @@ static void StreamUsage(void)
     },
     *settings[]=
     {
-      "-authenticate value  decrypt image with this password",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
       "-compress type       type of pixel compression when writing the image",
@@ -118,6 +119,7 @@ static void StreamUsage(void)
       "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-seed value          seed a new sequence of pseudo-random numbers",
@@ -159,8 +161,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
 {
 #define DestroyStream() \
 { \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   stream_info=DestroyStreamInfo(stream_info); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
@@ -168,9 +169,8 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
 }
 #define ThrowStreamException(asperity,tag,option) \
 { \
-  if (exception->severity < (asperity)) \
-    (void) ThrowMagickException(exception,GetMagickModule(),asperity,tag, \
-      "`%s'",option); \
+  (void) ThrowMagickException(exception,GetMagickModule(),asperity,tag,"`%s'", \
+    option); \
   DestroyStream(); \
   return(MagickFalse); \
 }
@@ -193,8 +193,10 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
     channel;
 
   Image
-    *image,
-    *image_stack[MaxImageStackDepth+1];
+    *image;
+
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
 
   long
     j,
@@ -231,7 +233,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   if (argc < 3)
@@ -240,7 +242,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   format="%w,%h,%m";
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   stream_info=AcquireStreamInfo(image_info);
@@ -251,15 +253,8 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowStreamException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowStreamException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   status=OpenStream(image_info,stream_info,argv[argc-1],exception);
   if (status == MagickFalse)
     {
@@ -271,45 +266,42 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,pend);
         if (k == MaxImageStackDepth)
-          ThrowStreamException(OptionError,"ParenthesisNestedTooDeeply",
-            option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+          ThrowStreamException(OptionError,"ParenthesisNestedTooDeeply",option);
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowStreamException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
+        Image
+          *images;
+
         /*
           Stream input image.
         */
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
+        FireImageStack(MagickFalse,MagickTrue,pend);
         filename=argv[i];
         if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
           filename=argv[++i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
-        image=StreamImage(image_info,stream_info,exception);
-        status&=(image != (Image *) NULL) &&
+        images=StreamImage(image_info,stream_info,exception);
+        status&=(images != (Image *) NULL) &&
           (exception->severity < ErrorException);
-        if (image == (Image *) NULL)
+        if (images == (Image *) NULL)
           continue;
-        AppendImageToList(&image_stack[k],image);
+        AppendImageStack(images);
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -593,6 +585,11 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("regard-warnings",option+1) == 0)
           break;
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         ThrowStreamException(OptionError,"UnrecognizedOption",option)
       }
       case 's':
@@ -616,7 +613,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -625,7 +622,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowStreamInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("set",option+1) == 0)
@@ -719,18 +716,18 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
       default:
         ThrowStreamException(OptionError,"UnrecognizedOption",option)
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowStreamException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i-- != (long) (argc-1))
     ThrowStreamException(OptionError,"MissingAnImageFilename",argv[i]);
-  if (image_stack[k] == (Image *) NULL)
+  if (image == (Image *) NULL)
     ThrowStreamException(OptionError,"MissingAnImageFilename",argv[i]);
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+  FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   DestroyStream();
   return(status != 0 ? MagickTrue : MagickFalse);
 }
